{
 "cells": [
  {
   "attachments": {},
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Word2Vec from scratch"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "This [self-contained implementation](https://nathanrooy.github.io/posts/2018-03-22/word2vec-from-scratch-with-python-and-numpy) is instructive and you should [go through it](https://github.com/nathanrooy/word2vec-from-scratch-with-python/blob/master/word2vec.py) to understand the word2vec embedding. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import re\n",
    "from collections import defaultdict\n",
    "\n",
    "\n",
    "\n",
    "class word2vec():\n",
    "    def __init__ (self):\n",
    "        self.n = settings['n']\n",
    "        self.eta = settings['learning_rate']\n",
    "        self.epochs = settings['epochs']\n",
    "        self.window = settings['window_size']\n",
    "        pass\n",
    "    \n",
    "    \n",
    "    # GENERATE TRAINING DATA\n",
    "    def generate_training_data(self, settings, corpus):\n",
    "\n",
    "        # GENERATE WORD COUNTS\n",
    "        word_counts = defaultdict(int)\n",
    "        for row in corpus:\n",
    "            for word in row:\n",
    "                word_counts[word] += 1\n",
    "\n",
    "        self.v_count = len(word_counts.keys())\n",
    "\n",
    "        # GENERATE LOOKUP DICTIONARIES\n",
    "        self.words_list = sorted(list(word_counts.keys()),reverse=False)\n",
    "        self.word_index = dict((word, i) for i, word in enumerate(self.words_list))\n",
    "        self.index_word = dict((i, word) for i, word in enumerate(self.words_list))\n",
    "\n",
    "        training_data = []\n",
    "        # CYCLE THROUGH EACH SENTENCE IN CORPUS\n",
    "        for sentence in corpus:\n",
    "            sent_len = len(sentence)\n",
    "\n",
    "            # CYCLE THROUGH EACH WORD IN SENTENCE\n",
    "            for i, word in enumerate(sentence):\n",
    "                \n",
    "                #w_target  = sentence[i]\n",
    "                w_target = self.word2onehot(sentence[i])\n",
    "\n",
    "                # CYCLE THROUGH CONTEXT WINDOW\n",
    "                w_context = []\n",
    "                for j in range(i-self.window, i+self.window+1):\n",
    "                    if j!=i and j<=sent_len-1 and j>=0:\n",
    "                        w_context.append(self.word2onehot(sentence[j]))\n",
    "                training_data.append([w_target, w_context])\n",
    "        return np.array(training_data)\n",
    "\n",
    "\n",
    "    # SOFTMAX ACTIVATION FUNCTION\n",
    "    def softmax(self, x):\n",
    "        e_x = np.exp(x - np.max(x))\n",
    "        return e_x / e_x.sum(axis=0)\n",
    "\n",
    "\n",
    "    # CONVERT WORD TO ONE HOT ENCODING\n",
    "    def word2onehot(self, word):\n",
    "        word_vec = [0 for i in range(0, self.v_count)]\n",
    "        word_index = self.word_index[word]\n",
    "        word_vec[word_index] = 1\n",
    "        return word_vec\n",
    "\n",
    "\n",
    "    # FORWARD PASS\n",
    "    def forward_pass(self, x):\n",
    "        h = np.dot(self.w1.T, x)\n",
    "        u = np.dot(self.w2.T, h)\n",
    "        y_c = self.softmax(u)\n",
    "        return y_c, h, u\n",
    "                \n",
    "\n",
    "    # BACKPROPAGATION\n",
    "    def backprop(self, e, h, x):\n",
    "        dl_dw2 = np.outer(h, e)  \n",
    "        dl_dw1 = np.outer(x, np.dot(self.w2, e.T))\n",
    "\n",
    "        # UPDATE WEIGHTS\n",
    "        self.w1 = self.w1 - (self.eta * dl_dw1)\n",
    "        self.w2 = self.w2 - (self.eta * dl_dw2)\n",
    "        pass\n",
    "\n",
    "\n",
    "    # TRAIN W2V model\n",
    "    def train(self, training_data):\n",
    "        # INITIALIZE WEIGHT MATRICES\n",
    "        self.w1 = np.random.uniform(-0.8, 0.8, (self.v_count, self.n))     # embedding matrix\n",
    "        self.w2 = np.random.uniform(-0.8, 0.8, (self.n, self.v_count))     # context matrix\n",
    "        \n",
    "        # CYCLE THROUGH EACH EPOCH\n",
    "        for i in range(0, self.epochs):\n",
    "\n",
    "            self.loss = 0\n",
    "\n",
    "            # CYCLE THROUGH EACH TRAINING SAMPLE\n",
    "            for w_t, w_c in training_data:\n",
    "\n",
    "                # FORWARD PASS\n",
    "                y_pred, h, u = self.forward_pass(w_t)\n",
    "                \n",
    "                # CALCULATE ERROR\n",
    "                EI = np.sum([np.subtract(y_pred, word) for word in w_c], axis=0)\n",
    "\n",
    "                # BACKPROPAGATION\n",
    "                self.backprop(EI, h, w_t)\n",
    "\n",
    "                # CALCULATE LOSS\n",
    "                self.loss += -np.sum([u[word.index(1)] for word in w_c]) + len(w_c) * np.log(np.sum(np.exp(u)))\n",
    "                #self.loss += -2*np.log(len(w_c)) -np.sum([u[word.index(1)] for word in w_c]) + (len(w_c) * np.log(np.sum(np.exp(u))))\n",
    "                \n",
    "            print('EPOCH:',i, 'LOSS:', self.loss)\n",
    "        pass\n",
    "\n",
    "\n",
    "    # input a word, returns a vector (if available)\n",
    "    def word_vec(self, word):\n",
    "        w_index = self.word_index[word]\n",
    "        v_w = self.w1[w_index]\n",
    "        return v_w\n",
    "\n",
    "\n",
    "    # input a vector, returns nearest word(s)\n",
    "    def vec_sim(self, vec, top_n):\n",
    "\n",
    "        # CYCLE THROUGH VOCAB\n",
    "        word_sim = {}\n",
    "        for i in range(self.v_count):\n",
    "            v_w2 = self.w1[i]\n",
    "            theta_num = np.dot(vec, v_w2)\n",
    "            theta_den = np.linalg.norm(vec) * np.linalg.norm(v_w2)\n",
    "            theta = theta_num / theta_den\n",
    "\n",
    "            word = self.index_word[i]\n",
    "            word_sim[word] = theta\n",
    "\n",
    "        words_sorted = sorted(word_sim.items(), key=lambda item: item[1], reverse=True)\n",
    "\n",
    "        for word, sim in words_sorted[:top_n]:\n",
    "            print(word, sim)\n",
    "            \n",
    "        pass\n",
    "\n",
    "    # input word, returns top [n] most similar words\n",
    "    def word_sim(self, word, top_n):\n",
    "        \n",
    "        w1_index = self.word_index[word]\n",
    "        v_w1 = self.w1[w1_index]\n",
    "\n",
    "        # CYCLE THROUGH VOCAB\n",
    "        word_sim = {}\n",
    "        for i in range(self.v_count):\n",
    "            v_w2 = self.w1[i]\n",
    "            theta_num = np.dot(v_w1, v_w2)\n",
    "            theta_den = np.linalg.norm(v_w1) * np.linalg.norm(v_w2)\n",
    "            theta = theta_num / theta_den\n",
    "\n",
    "            word = self.index_word[i]\n",
    "            word_sim[word] = theta\n",
    "\n",
    "        words_sorted = sorted(word_sim.items(), key=lambda item: item[1], reverse=True)\n",
    "\n",
    "        for word, sim in words_sorted[:top_n]:\n",
    "            print(word, sim)\n",
    "            \n",
    "        pass\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/tmp/ipykernel_482824/2817892463.py:49: VisibleDeprecationWarning: Creating an ndarray from ragged nested sequences (which is a list-or-tuple of lists-or-tuples-or ndarrays with different lengths or shapes) is deprecated. If you meant to do this, you must specify 'dtype=object' when creating the ndarray.\n",
      "  return np.array(training_data)\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "EPOCH: 0 LOSS: 68.37096376709992\n",
      "EPOCH: 1 LOSS: 67.88313773129582\n",
      "EPOCH: 2 LOSS: 67.43127505997181\n",
      "EPOCH: 3 LOSS: 67.0112049943476\n",
      "EPOCH: 4 LOSS: 66.61935410862232\n",
      "EPOCH: 5 LOSS: 66.25264389886307\n",
      "EPOCH: 6 LOSS: 65.9084083928434\n",
      "EPOCH: 7 LOSS: 65.5843274465069\n",
      "EPOCH: 8 LOSS: 65.2783724111086\n",
      "EPOCH: 9 LOSS: 64.98876161794144\n",
      "EPOCH: 10 LOSS: 64.71392370243775\n",
      "EPOCH: 11 LOSS: 64.45246722531292\n",
      "EPOCH: 12 LOSS: 64.20315538093011\n",
      "EPOCH: 13 LOSS: 63.96488483826672\n",
      "EPOCH: 14 LOSS: 63.736667956900455\n",
      "EPOCH: 15 LOSS: 63.51761777345709\n",
      "EPOCH: 16 LOSS: 63.30693527348039\n",
      "EPOCH: 17 LOSS: 63.103898557554714\n",
      "EPOCH: 18 LOSS: 62.90785358463229\n",
      "EPOCH: 19 LOSS: 62.71820623435013\n",
      "EPOCH: 20 LOSS: 62.5344154770562\n",
      "EPOCH: 21 LOSS: 62.355987477886515\n",
      "EPOCH: 22 LOSS: 62.18247049153716\n",
      "EPOCH: 23 LOSS: 62.01345042888875\n",
      "EPOCH: 24 LOSS: 61.8485469965609\n",
      "EPOCH: 25 LOSS: 61.687410326726464\n",
      "EPOCH: 26 LOSS: 61.529718027831066\n",
      "EPOCH: 27 LOSS: 61.375172597813304\n",
      "EPOCH: 28 LOSS: 61.22349915045999\n",
      "EPOCH: 29 LOSS: 61.07444341301829\n",
      "EPOCH: 30 LOSS: 60.92776995941049\n",
      "EPOCH: 31 LOSS: 60.78326064858712\n",
      "EPOCH: 32 LOSS: 60.64071324189531\n",
      "EPOCH: 33 LOSS: 60.49994017698286\n",
      "EPOCH: 34 LOSS: 60.36076747882282\n",
      "EPOCH: 35 LOSS: 60.22303379103041\n",
      "EPOCH: 36 LOSS: 60.086589512832425\n",
      "EPOCH: 37 LOSS: 59.95129602890606\n",
      "EPOCH: 38 LOSS: 59.81702502088362\n",
      "EPOCH: 39 LOSS: 59.68365785066692\n",
      "EPOCH: 40 LOSS: 59.551085006848\n",
      "EPOCH: 41 LOSS: 59.4192056065221\n",
      "EPOCH: 42 LOSS: 59.28792694563046\n",
      "EPOCH: 43 LOSS: 59.15716409170691\n",
      "EPOCH: 44 LOSS: 59.02683951354147\n",
      "EPOCH: 45 LOSS: 58.89688274283187\n",
      "EPOCH: 46 LOSS: 58.76723006338306\n",
      "EPOCH: 47 LOSS: 58.63782422384758\n",
      "EPOCH: 48 LOSS: 58.50861417038416\n",
      "EPOCH: 49 LOSS: 58.37955479595795\n",
      "EPOCH: 50 LOSS: 58.250606703318354\n",
      "EPOCH: 51 LOSS: 58.12173597897814\n",
      "EPOCH: 52 LOSS: 57.99291397578218\n",
      "EPOCH: 53 LOSS: 57.86411710190244\n",
      "EPOCH: 54 LOSS: 57.73532661433058\n",
      "EPOCH: 55 LOSS: 57.60652841516267\n",
      "EPOCH: 56 LOSS: 57.477712849185245\n",
      "EPOCH: 57 LOSS: 57.34887450148033\n",
      "EPOCH: 58 LOSS: 57.22001199396845\n",
      "EPOCH: 59 LOSS: 57.0911277800063\n",
      "EPOCH: 60 LOSS: 56.96222793634795\n",
      "EPOCH: 61 LOSS: 56.83332195196609\n",
      "EPOCH: 62 LOSS: 56.704422513412844\n",
      "EPOCH: 63 LOSS: 56.57554528657579\n",
      "EPOCH: 64 LOSS: 56.44670869485567\n",
      "EPOCH: 65 LOSS: 56.31793369395395\n",
      "EPOCH: 66 LOSS: 56.18924354361151\n",
      "EPOCH: 67 LOSS: 56.06066357678256\n",
      "EPOCH: 68 LOSS: 55.93222096685808\n",
      "EPOCH: 69 LOSS: 55.80394449367079\n",
      "EPOCH: 70 LOSS: 55.675864309116534\n",
      "EPOCH: 71 LOSS: 55.54801170331372\n",
      "EPOCH: 72 LOSS: 55.42041887229419\n",
      "EPOCH: 73 LOSS: 55.29311868827151\n",
      "EPOCH: 74 LOSS: 55.16614447356976\n",
      "EPOCH: 75 LOSS: 55.039529779313945\n",
      "EPOCH: 76 LOSS: 54.913308169985086\n",
      "EPOCH: 77 LOSS: 54.78751301492747\n",
      "EPOCH: 78 LOSS: 54.66217728786512\n",
      "EPOCH: 79 LOSS: 54.5373333754388\n",
      "EPOCH: 80 LOSS: 54.41301289571659\n",
      "EPOCH: 81 LOSS: 54.28924652756113\n",
      "EPOCH: 82 LOSS: 54.16606385165704\n",
      "EPOCH: 83 LOSS: 54.04349320391423\n",
      "EPOCH: 84 LOSS: 53.921561541869664\n",
      "EPOCH: 85 LOSS: 53.80029432461181\n",
      "EPOCH: 86 LOSS: 53.67971540665192\n",
      "EPOCH: 87 LOSS: 53.559846946064454\n",
      "EPOCH: 88 LOSS: 53.4407093271179\n",
      "EPOCH: 89 LOSS: 53.322321097516884\n",
      "EPOCH: 90 LOSS: 53.20469892027958\n",
      "EPOCH: 91 LOSS: 53.087857540178575\n",
      "EPOCH: 92 LOSS: 52.971809764583156\n",
      "EPOCH: 93 LOSS: 52.856566458452356\n",
      "EPOCH: 94 LOSS: 52.74213655314484\n",
      "EPOCH: 95 LOSS: 52.62852706863143\n",
      "EPOCH: 96 LOSS: 52.515743148619755\n",
      "EPOCH: 97 LOSS: 52.40378810802827\n",
      "EPOCH: 98 LOSS: 52.292663492177866\n",
      "EPOCH: 99 LOSS: 52.182369147004415\n",
      "EPOCH: 100 LOSS: 52.0729032995341\n",
      "EPOCH: 101 LOSS: 51.96426264780659\n",
      "EPOCH: 102 LOSS: 51.85644245937806\n",
      "EPOCH: 103 LOSS: 51.7494366774877\n",
      "EPOCH: 104 LOSS: 51.64323803392955\n",
      "EPOCH: 105 LOSS: 51.53783816763342\n",
      "EPOCH: 106 LOSS: 51.433227747929116\n",
      "EPOCH: 107 LOSS: 51.32939660144491\n",
      "EPOCH: 108 LOSS: 51.226333841575276\n",
      "EPOCH: 109 LOSS: 51.12402799944632\n",
      "EPOCH: 110 LOSS: 51.02246715530874\n",
      "EPOCH: 111 LOSS: 50.921639069298955\n",
      "EPOCH: 112 LOSS: 50.82153131052964\n",
      "EPOCH: 113 LOSS: 50.72213138349953\n",
      "EPOCH: 114 LOSS: 50.623426850852326\n",
      "EPOCH: 115 LOSS: 50.52540545156136\n",
      "EPOCH: 116 LOSS: 50.4280552136734\n",
      "EPOCH: 117 LOSS: 50.33136456080898\n",
      "EPOCH: 118 LOSS: 50.23532241168773\n",
      "EPOCH: 119 LOSS: 50.13991827202481\n",
      "EPOCH: 120 LOSS: 50.04514231822726\n",
      "EPOCH: 121 LOSS: 49.95098547240561\n",
      "EPOCH: 122 LOSS: 49.85743946830692\n",
      "EPOCH: 123 LOSS: 49.76449690786663\n",
      "EPOCH: 124 LOSS: 49.672151308170434\n",
      "EPOCH: 125 LOSS: 49.58039713870986\n",
      "EPOCH: 126 LOSS: 49.48922984890737\n",
      "EPOCH: 127 LOSS: 49.398645885975945\n",
      "EPOCH: 128 LOSS: 49.30864270326568\n",
      "EPOCH: 129 LOSS: 49.21921875933163\n",
      "EPOCH: 130 LOSS: 49.13037350803614\n",
      "EPOCH: 131 LOSS: 49.042107380071194\n",
      "EPOCH: 132 LOSS: 48.954421756353625\n",
      "EPOCH: 133 LOSS: 48.86731893380633\n",
      "EPOCH: 134 LOSS: 48.78080208409239\n",
      "EPOCH: 135 LOSS: 48.69487520591525\n",
      "EPOCH: 136 LOSS: 48.6095430715377\n",
      "EPOCH: 137 LOSS: 48.524811168202824\n",
      "EPOCH: 138 LOSS: 48.44068563516454\n",
      "EPOCH: 139 LOSS: 48.3571731970503\n",
      "EPOCH: 140 LOSS: 48.274281094287076\n",
      "EPOCH: 141 LOSS: 48.19201701132183\n",
      "EPOCH: 142 LOSS: 48.11038900336024\n",
      "EPOCH: 143 LOSS: 48.02940542233373\n",
      "EPOCH: 144 LOSS: 47.94907484278316\n",
      "EPOCH: 145 LOSS: 47.86940598832027\n",
      "EPOCH: 146 LOSS: 47.790407659294274\n",
      "EPOCH: 147 LOSS: 47.71208866225256\n",
      "EPOCH: 148 LOSS: 47.63445774174025\n",
      "EPOCH: 149 LOSS: 47.557523514936264\n",
      "EPOCH: 150 LOSS: 47.48129440957224\n",
      "EPOCH: 151 LOSS: 47.40577860552679\n",
      "EPOCH: 152 LOSS: 47.330983980432094\n",
      "EPOCH: 153 LOSS: 47.25691805957311\n",
      "EPOCH: 154 LOSS: 47.1835879703022\n",
      "EPOCH: 155 LOSS: 47.111000401135385\n",
      "EPOCH: 156 LOSS: 47.03916156564047\n",
      "EPOCH: 157 LOSS: 46.96807717117308\n",
      "EPOCH: 158 LOSS: 46.897752392464994\n",
      "EPOCH: 159 LOSS: 46.828191850020154\n",
      "EPOCH: 160 LOSS: 46.75939959322797\n",
      "EPOCH: 161 LOSS: 46.69137908806191\n",
      "EPOCH: 162 LOSS: 46.624133209193545\n",
      "EPOCH: 163 LOSS: 46.55766423631874\n",
      "EPOCH: 164 LOSS: 46.49197385446388\n",
      "EPOCH: 165 LOSS: 46.42706315801561\n",
      "EPOCH: 166 LOSS: 46.36293265819842\n",
      "EPOCH: 167 LOSS: 46.299582293708205\n",
      "EPOCH: 168 LOSS: 46.23701144420076\n",
      "EPOCH: 169 LOSS: 46.1752189463264\n",
      "EPOCH: 170 LOSS: 46.11420311200062\n",
      "EPOCH: 171 LOSS: 46.053961748601104\n",
      "EPOCH: 172 LOSS: 45.994492180787255\n",
      "EPOCH: 173 LOSS: 45.93579127364532\n",
      "EPOCH: 174 LOSS: 45.87785545687328\n",
      "EPOCH: 175 LOSS: 45.820680749732944\n",
      "EPOCH: 176 LOSS: 45.764262786510905\n",
      "EPOCH: 177 LOSS: 45.708596842247275\n",
      "EPOCH: 178 LOSS: 45.65367785850857\n",
      "EPOCH: 179 LOSS: 45.59950046900022\n",
      "EPOCH: 180 LOSS: 45.54605902483295\n",
      "EPOCH: 181 LOSS: 45.49334761927784\n",
      "EPOCH: 182 LOSS: 45.44136011186352\n",
      "EPOCH: 183 LOSS: 45.39009015168919\n",
      "EPOCH: 184 LOSS: 45.339531199846064\n",
      "EPOCH: 185 LOSS: 45.289676550857415\n",
      "EPOCH: 186 LOSS: 45.240519353066404\n",
      "EPOCH: 187 LOSS: 45.19205262791601\n",
      "EPOCH: 188 LOSS: 45.14426928808233\n",
      "EPOCH: 189 LOSS: 45.09716215443602\n",
      "EPOCH: 190 LOSS: 45.05072397182075\n",
      "EPOCH: 191 LOSS: 45.00494742364921\n",
      "EPOCH: 192 LOSS: 44.95982514532849\n",
      "EPOCH: 193 LOSS: 44.915349736536186\n",
      "EPOCH: 194 LOSS: 44.871513772377405\n",
      "EPOCH: 195 LOSS: 44.82830981345978\n",
      "EPOCH: 196 LOSS: 44.78573041493042\n",
      "EPOCH: 197 LOSS: 44.74376813452354\n",
      "EPOCH: 198 LOSS: 44.702415539671875\n",
      "EPOCH: 199 LOSS: 44.661665213738125\n",
      "EPOCH: 200 LOSS: 44.6215097614251\n",
      "EPOCH: 201 LOSS: 44.581941813424905\n",
      "EPOCH: 202 LOSS: 44.54295403036777\n",
      "EPOCH: 203 LOSS: 44.50453910613209\n",
      "EPOCH: 204 LOSS: 44.466689770575925\n",
      "EPOCH: 205 LOSS: 44.429398791749605\n",
      "EPOCH: 206 LOSS: 44.39265897764748\n",
      "EPOCH: 207 LOSS: 44.35646317755508\n",
      "EPOCH: 208 LOSS: 44.320804283045334\n",
      "EPOCH: 209 LOSS: 44.285675228675125\n",
      "EPOCH: 210 LOSS: 44.251068992430824\n",
      "EPOCH: 211 LOSS: 44.216978595968115\n",
      "EPOCH: 212 LOSS: 44.18339710468847\n",
      "EPOCH: 213 LOSS: 44.15031762769129\n",
      "EPOCH: 214 LOSS: 44.11773331763766\n",
      "EPOCH: 215 LOSS: 44.08563737055789\n",
      "EPOCH: 216 LOSS: 44.05402302563212\n",
      "EPOCH: 217 LOSS: 44.022883564969845\n",
      "EPOCH: 218 LOSS: 43.992212313410796\n",
      "EPOCH: 219 LOSS: 43.96200263836693\n",
      "EPOCH: 220 LOSS: 43.93224794972159\n",
      "EPOCH: 221 LOSS: 43.90294169979992\n",
      "EPOCH: 222 LOSS: 43.87407738342075\n",
      "EPOCH: 223 LOSS: 43.845648538038766\n",
      "EPOCH: 224 LOSS: 43.81764874398226\n",
      "EPOCH: 225 LOSS: 43.790071624790315\n",
      "EPOCH: 226 LOSS: 43.76291084765062\n",
      "EPOCH: 227 LOSS: 43.73616012393771\n",
      "EPOCH: 228 LOSS: 43.709813209849266\n",
      "EPOCH: 229 LOSS: 43.683863907136924\n",
      "EPOCH: 230 LOSS: 43.65830606392653\n",
      "EPOCH: 231 LOSS: 43.63313357562156\n",
      "EPOCH: 232 LOSS: 43.60834038588268\n",
      "EPOCH: 233 LOSS: 43.58392048767539\n",
      "EPOCH: 234 LOSS: 43.55986792437707\n",
      "EPOCH: 235 LOSS: 43.53617679093442\n",
      "EPOCH: 236 LOSS: 43.512841235061586\n",
      "EPOCH: 237 LOSS: 43.48985545846968\n",
      "EPOCH: 238 LOSS: 43.46721371811746\n",
      "EPOCH: 239 LOSS: 43.44491032747387\n",
      "EPOCH: 240 LOSS: 43.42293965778251\n",
      "EPOCH: 241 LOSS: 43.40129613931899\n",
      "EPOCH: 242 LOSS: 43.37997426263202\n",
      "EPOCH: 243 LOSS: 43.35896857975963\n",
      "EPOCH: 244 LOSS: 43.338273705412504\n",
      "EPOCH: 245 LOSS: 43.31788431811664\n",
      "EPOCH: 246 LOSS: 43.29779516130849\n",
      "EPOCH: 247 LOSS: 43.27800104437614\n",
      "EPOCH: 248 LOSS: 43.25849684364037\n",
      "EPOCH: 249 LOSS: 43.2392775032711\n",
      "EPOCH: 250 LOSS: 43.22033803613397\n",
      "EPOCH: 251 LOSS: 43.20167352456375\n",
      "EPOCH: 252 LOSS: 43.18327912106108\n",
      "EPOCH: 253 LOSS: 43.16515004890994\n",
      "EPOCH: 254 LOSS: 43.14728160271425\n",
      "EPOCH: 255 LOSS: 43.129669148851605\n",
      "EPOCH: 256 LOSS: 43.112308125843946\n",
      "EPOCH: 257 LOSS: 43.09519404464461\n",
      "EPOCH: 258 LOSS: 43.07832248884188\n",
      "EPOCH: 259 LOSS: 43.06168911478023\n",
      "EPOCH: 260 LOSS: 43.04528965159979\n",
      "EPOCH: 261 LOSS: 43.02911990119601\n",
      "EPOCH: 262 LOSS: 43.01317573810143\n",
      "EPOCH: 263 LOSS: 42.997453109291456\n",
      "EPOCH: 264 LOSS: 42.98194803391708\n",
      "EPOCH: 265 LOSS: 42.96665660296688\n",
      "EPOCH: 266 LOSS: 42.95157497886178\n",
      "EPOCH: 267 LOSS: 42.93669939498514\n",
      "EPOCH: 268 LOSS: 42.922026155152054\n",
      "EPOCH: 269 LOSS: 42.90755163302077\n",
      "EPOCH: 270 LOSS: 42.893272271449995\n",
      "EPOCH: 271 LOSS: 42.87918458180569\n",
      "EPOCH: 272 LOSS: 42.86528514322063\n",
      "EPOCH: 273 LOSS: 42.85157060181058\n",
      "EPOCH: 274 LOSS: 42.838037669850486\n",
      "EPOCH: 275 LOSS: 42.82468312491433\n",
      "EPOCH: 276 LOSS: 42.81150380898192\n",
      "EPOCH: 277 LOSS: 42.79849662751623\n",
      "EPOCH: 278 LOSS: 42.785658548514384\n",
      "EPOCH: 279 LOSS: 42.77298660153565\n",
      "EPOCH: 280 LOSS: 42.76047787670943\n",
      "EPOCH: 281 LOSS: 42.7481295237263\n",
      "EPOCH: 282 LOSS: 42.735938750814924\n",
      "EPOCH: 283 LOSS: 42.72390282370756\n",
      "EPOCH: 284 LOSS: 42.71201906459673\n",
      "EPOCH: 285 LOSS: 42.70028485108564\n",
      "EPOCH: 286 LOSS: 42.68869761513452\n",
      "EPOCH: 287 LOSS: 42.67725484200507\n",
      "EPOCH: 288 LOSS: 42.66595406920524\n",
      "EPOCH: 289 LOSS: 42.654792885436024\n",
      "EPOCH: 290 LOSS: 42.643768929542155\n",
      "EPOCH: 291 LOSS: 42.63287988946833\n",
      "EPOCH: 292 LOSS: 42.62212350122259\n",
      "EPOCH: 293 LOSS: 42.61149754784787\n",
      "EPOCH: 294 LOSS: 42.60099985840353\n",
      "EPOCH: 295 LOSS: 42.59062830695757\n",
      "EPOCH: 296 LOSS: 42.58038081159076\n",
      "EPOCH: 297 LOSS: 42.57025533341357\n",
      "EPOCH: 298 LOSS: 42.56024987559684\n",
      "EPOCH: 299 LOSS: 42.55036248241668\n",
      "EPOCH: 300 LOSS: 42.540591238314526\n",
      "EPOCH: 301 LOSS: 42.530934266972636\n",
      "EPOCH: 302 LOSS: 42.52138973040578\n",
      "EPOCH: 303 LOSS: 42.51195582806925\n",
      "EPOCH: 304 LOSS: 42.50263079598368\n",
      "EPOCH: 305 LOSS: 42.49341290587689\n",
      "EPOCH: 306 LOSS: 42.48430046434294\n",
      "EPOCH: 307 LOSS: 42.47529181201857\n",
      "EPOCH: 308 LOSS: 42.466385322777015\n",
      "EPOCH: 309 LOSS: 42.457579402939416\n",
      "EPOCH: 310 LOSS: 42.44887249050355\n",
      "EPOCH: 311 LOSS: 42.44026305439015\n",
      "EPOCH: 312 LOSS: 42.43174959370646\n",
      "EPOCH: 313 LOSS: 42.423330637027085\n",
      "EPOCH: 314 LOSS: 42.41500474169175\n",
      "EPOCH: 315 LOSS: 42.406770493120334\n",
      "EPOCH: 316 LOSS: 42.39862650414415\n",
      "EPOCH: 317 LOSS: 42.390571414354\n",
      "EPOCH: 318 LOSS: 42.38260388946446\n",
      "EPOCH: 319 LOSS: 42.37472262069407\n",
      "EPOCH: 320 LOSS: 42.366926324161255\n",
      "EPOCH: 321 LOSS: 42.35921374029578\n",
      "EPOCH: 322 LOSS: 42.351583633265236\n",
      "EPOCH: 323 LOSS: 42.34403479041651\n",
      "EPOCH: 324 LOSS: 42.33656602173173\n",
      "EPOCH: 325 LOSS: 42.329176159298434\n",
      "EPOCH: 326 LOSS: 42.32186405679377\n",
      "EPOCH: 327 LOSS: 42.31462858898222\n",
      "EPOCH: 328 LOSS: 42.30746865122659\n",
      "EPOCH: 329 LOSS: 42.30038315901212\n",
      "EPOCH: 330 LOSS: 42.2933710474832\n",
      "EPOCH: 331 LOSS: 42.28643127099228\n",
      "EPOCH: 332 LOSS: 42.27956280266109\n",
      "EPOCH: 333 LOSS: 42.27276463395337\n",
      "EPOCH: 334 LOSS: 42.26603577425914\n",
      "EPOCH: 335 LOSS: 42.259375250489995\n",
      "EPOCH: 336 LOSS: 42.252782106685316\n",
      "EPOCH: 337 LOSS: 42.24625540362895\n",
      "EPOCH: 338 LOSS: 42.239794218476135\n",
      "EPOCH: 339 LOSS: 42.23339764439039\n",
      "EPOCH: 340 LOSS: 42.227064790190056\n",
      "EPOCH: 341 LOSS: 42.22079478000431\n",
      "EPOCH: 342 LOSS: 42.214586752938246\n",
      "EPOCH: 343 LOSS: 42.208439862746886\n",
      "EPOCH: 344 LOSS: 42.20235327751777\n",
      "EPOCH: 345 LOSS: 42.19632617936203\n",
      "EPOCH: 346 LOSS: 42.19035776411342\n",
      "EPOCH: 347 LOSS: 42.184447241035436\n",
      "EPOCH: 348 LOSS: 42.17859383253605\n",
      "EPOCH: 349 LOSS: 42.17279677388986\n",
      "EPOCH: 350 LOSS: 42.167055312967456\n",
      "EPOCH: 351 LOSS: 42.16136870997196\n",
      "EPOCH: 352 LOSS: 42.15573623718216\n",
      "EPOCH: 353 LOSS: 42.150157178702486\n",
      "EPOCH: 354 LOSS: 42.14463083021928\n",
      "EPOCH: 355 LOSS: 42.13915649876336\n",
      "EPOCH: 356 LOSS: 42.13373350247856\n",
      "EPOCH: 357 LOSS: 42.128361170396346\n",
      "EPOCH: 358 LOSS: 42.12303884221589\n",
      "EPOCH: 359 LOSS: 42.117765868089926\n",
      "EPOCH: 360 LOSS: 42.11254160841578\n",
      "EPOCH: 361 LOSS: 42.10736543363181\n",
      "EPOCH: 362 LOSS: 42.102236724018795\n",
      "EPOCH: 363 LOSS: 42.09715486950634\n",
      "EPOCH: 364 LOSS: 42.09211926948398\n",
      "EPOCH: 365 LOSS: 42.087129332617\n",
      "EPOCH: 366 LOSS: 42.08218447666681\n",
      "EPOCH: 367 LOSS: 42.077284128315505\n",
      "EPOCH: 368 LOSS: 42.072427722995\n",
      "EPOCH: 369 LOSS: 42.06761470472007\n",
      "EPOCH: 370 LOSS: 42.06284452592539\n",
      "EPOCH: 371 LOSS: 42.058116647306704\n",
      "EPOCH: 372 LOSS: 42.053430537665584\n",
      "EPOCH: 373 LOSS: 42.04878567375797\n",
      "EPOCH: 374 LOSS: 42.044181540146276\n",
      "EPOCH: 375 LOSS: 42.03961762905496\n",
      "EPOCH: 376 LOSS: 42.03509344022957\n",
      "EPOCH: 377 LOSS: 42.03060848079897\n",
      "EPOCH: 378 LOSS: 42.02616226514081\n",
      "EPOCH: 379 LOSS: 42.02175431475019\n",
      "EPOCH: 380 LOSS: 42.0173841581112\n",
      "EPOCH: 381 LOSS: 42.01305133057153\n",
      "EPOCH: 382 LOSS: 42.0087553742199\n",
      "EPOCH: 383 LOSS: 42.0044958377663\n",
      "EPOCH: 384 LOSS: 42.00027227642484\n",
      "EPOCH: 385 LOSS: 41.99608425179939\n",
      "EPOCH: 386 LOSS: 41.991931331771696\n",
      "EPOCH: 387 LOSS: 41.987813090391995\n",
      "EPOCH: 388 LOSS: 41.98372910777205\n",
      "EPOCH: 389 LOSS: 41.9796789699806\n",
      "EPOCH: 390 LOSS: 41.97566226894108\n",
      "EPOCH: 391 LOSS: 41.971678602331565\n",
      "EPOCH: 392 LOSS: 41.96772757348689\n",
      "EPOCH: 393 LOSS: 41.963808791302995\n",
      "EPOCH: 394 LOSS: 41.95992187014314\n",
      "EPOCH: 395 LOSS: 41.95606642974634\n",
      "EPOCH: 396 LOSS: 41.95224209513766\n",
      "EPOCH: 397 LOSS: 41.94844849654036\n",
      "EPOCH: 398 LOSS: 41.94468526929005\n",
      "EPOCH: 399 LOSS: 41.94095205375051\n",
      "EPOCH: 400 LOSS: 41.93724849523137\n",
      "EPOCH: 401 LOSS: 41.93357424390756\n",
      "EPOCH: 402 LOSS: 41.92992895474011\n",
      "EPOCH: 403 LOSS: 41.926312287399156\n",
      "EPOCH: 404 LOSS: 41.922723906187926\n",
      "EPOCH: 405 LOSS: 41.91916347996876\n",
      "EPOCH: 406 LOSS: 41.91563068209029\n",
      "EPOCH: 407 LOSS: 41.91212519031635\n",
      "EPOCH: 408 LOSS: 41.908646686756214\n",
      "EPOCH: 409 LOSS: 41.90519485779615\n",
      "EPOCH: 410 LOSS: 41.90176939403253\n",
      "EPOCH: 411 LOSS: 41.898369990206106\n",
      "EPOCH: 412 LOSS: 41.89499634513777\n",
      "EPOCH: 413 LOSS: 41.89164816166527\n",
      "EPOCH: 414 LOSS: 41.88832514658151\n",
      "EPOCH: 415 LOSS: 41.88502701057386\n",
      "EPOCH: 416 LOSS: 41.8817534681647\n",
      "EPOCH: 417 LOSS: 41.878504237653054\n",
      "EPOCH: 418 LOSS: 41.875279041057446\n",
      "EPOCH: 419 LOSS: 41.87207760405977\n",
      "EPOCH: 420 LOSS: 41.86889965595024\n",
      "EPOCH: 421 LOSS: 41.86574492957341\n",
      "EPOCH: 422 LOSS: 41.86261316127518\n",
      "EPOCH: 423 LOSS: 41.85950409085087\n",
      "EPOCH: 424 LOSS: 41.856417461494104\n",
      "EPOCH: 425 LOSS: 41.85335301974683\n",
      "EPOCH: 426 LOSS: 41.85031051545011\n",
      "EPOCH: 427 LOSS: 41.847289701695985\n",
      "EPOCH: 428 LOSS: 41.84429033477997\n",
      "EPOCH: 429 LOSS: 41.8413121741547\n",
      "EPOCH: 430 LOSS: 41.838354982384175\n",
      "EPOCH: 431 LOSS: 41.83541852509901\n",
      "EPOCH: 432 LOSS: 41.83250257095235\n",
      "EPOCH: 433 LOSS: 41.82960689157668\n",
      "EPOCH: 434 LOSS: 41.82673126154131\n",
      "EPOCH: 435 LOSS: 41.823875458310724\n",
      "EPOCH: 436 LOSS: 41.82103926220348\n",
      "EPOCH: 437 LOSS: 41.81822245635208\n",
      "EPOCH: 438 LOSS: 41.815424826663325\n",
      "EPOCH: 439 LOSS: 41.81264616177943\n",
      "EPOCH: 440 LOSS: 41.80988625303989\n",
      "EPOCH: 441 LOSS: 41.807144894443795\n",
      "EPOCH: 442 LOSS: 41.8044218826131\n",
      "EPOCH: 443 LOSS: 41.80171701675619\n",
      "EPOCH: 444 LOSS: 41.79903009863232\n",
      "EPOCH: 445 LOSS: 41.79636093251649\n",
      "EPOCH: 446 LOSS: 41.79370932516498\n",
      "EPOCH: 447 LOSS: 41.79107508578147\n",
      "EPOCH: 448 LOSS: 41.788458025983715\n",
      "EPOCH: 449 LOSS: 41.78585795977071\n",
      "EPOCH: 450 LOSS: 41.783274703490505\n",
      "EPOCH: 451 LOSS: 41.78070807580849\n",
      "EPOCH: 452 LOSS: 41.77815789767614\n",
      "EPOCH: 453 LOSS: 41.77562399230038\n",
      "EPOCH: 454 LOSS: 41.7731061851134\n",
      "EPOCH: 455 LOSS: 41.7706043037429\n",
      "EPOCH: 456 LOSS: 41.76811817798294\n",
      "EPOCH: 457 LOSS: 41.765647639765106\n",
      "EPOCH: 458 LOSS: 41.76319252313023\n",
      "EPOCH: 459 LOSS: 41.76075266420057\n",
      "EPOCH: 460 LOSS: 41.75832790115238\n",
      "EPOCH: 461 LOSS: 41.75591807418886\n",
      "EPOCH: 462 LOSS: 41.753523025513736\n",
      "EPOCH: 463 LOSS: 41.75114259930495\n",
      "EPOCH: 464 LOSS: 41.748776641689055\n",
      "EPOCH: 465 LOSS: 41.74642500071576\n",
      "EPOCH: 466 LOSS: 41.74408752633312\n",
      "EPOCH: 467 LOSS: 41.741764070362734\n",
      "EPOCH: 468 LOSS: 41.73945448647584\n",
      "EPOCH: 469 LOSS: 41.73715863016926\n",
      "EPOCH: 470 LOSS: 41.73487635874199\n",
      "EPOCH: 471 LOSS: 41.73260753127219\n",
      "EPOCH: 472 LOSS: 41.730352008594245\n",
      "EPOCH: 473 LOSS: 41.72810965327649\n",
      "EPOCH: 474 LOSS: 41.725880329599065\n",
      "EPOCH: 475 LOSS: 41.723663903532106\n",
      "EPOCH: 476 LOSS: 41.721460242714386\n",
      "EPOCH: 477 LOSS: 41.71926921643215\n",
      "EPOCH: 478 LOSS: 41.717090695598316\n",
      "EPOCH: 479 LOSS: 41.71492455273193\n",
      "EPOCH: 480 LOSS: 41.712770661937995\n",
      "EPOCH: 481 LOSS: 41.71062889888756\n",
      "EPOCH: 482 LOSS: 41.708499140798075\n",
      "EPOCH: 483 LOSS: 41.70638126641403\n",
      "EPOCH: 484 LOSS: 41.704275155987936\n",
      "EPOCH: 485 LOSS: 41.70218069126147\n",
      "EPOCH: 486 LOSS: 41.70009775544704\n",
      "EPOCH: 487 LOSS: 41.698026233209404\n",
      "EPOCH: 488 LOSS: 41.6959660106478\n",
      "EPOCH: 489 LOSS: 41.69391697527807\n",
      "EPOCH: 490 LOSS: 41.691879016015264\n",
      "EPOCH: 491 LOSS: 41.68985202315632\n",
      "EPOCH: 492 LOSS: 41.68783588836311\n",
      "EPOCH: 493 LOSS: 41.685830504645615\n",
      "EPOCH: 494 LOSS: 41.6838357663454\n",
      "EPOCH: 495 LOSS: 41.68185156911933\n",
      "EPOCH: 496 LOSS: 41.679877809923404\n",
      "EPOCH: 497 LOSS: 41.67791438699702\n",
      "EPOCH: 498 LOSS: 41.67596119984716\n",
      "EPOCH: 499 LOSS: 41.67401814923312\n",
      "EPOCH: 500 LOSS: 41.67208513715116\n",
      "EPOCH: 501 LOSS: 41.67016206681953\n",
      "EPOCH: 502 LOSS: 41.668248842663694\n",
      "EPOCH: 503 LOSS: 41.666345370301634\n",
      "EPOCH: 504 LOSS: 41.664451556529514\n",
      "EPOCH: 505 LOSS: 41.66256730930734\n",
      "EPOCH: 506 LOSS: 41.660692537745064\n",
      "EPOCH: 507 LOSS: 41.65882715208865\n",
      "EPOCH: 508 LOSS: 41.656971063706365\n",
      "EPOCH: 509 LOSS: 41.6551241850754\n",
      "EPOCH: 510 LOSS: 41.653286429768464\n",
      "EPOCH: 511 LOSS: 41.65145771244075\n",
      "EPOCH: 512 LOSS: 41.649637948816846\n",
      "EPOCH: 513 LOSS: 41.647827055678036\n",
      "EPOCH: 514 LOSS: 41.64602495084963\n",
      "EPOCH: 515 LOSS: 41.64423155318853\n",
      "EPOCH: 516 LOSS: 41.6424467825709\n",
      "EPOCH: 517 LOSS: 41.64067055988003\n",
      "EPOCH: 518 LOSS: 41.6389028069943\n",
      "EPOCH: 519 LOSS: 41.637143446775426\n",
      "EPOCH: 520 LOSS: 41.63539240305673\n",
      "EPOCH: 521 LOSS: 41.63364960063157\n",
      "EPOCH: 522 LOSS: 41.63191496524202\n",
      "EPOCH: 523 LOSS: 41.63018842356753\n",
      "EPOCH: 524 LOSS: 41.628469903213876\n",
      "EPOCH: 525 LOSS: 41.6267593327022\n",
      "EPOCH: 526 LOSS: 41.62505664145814\n",
      "EPOCH: 527 LOSS: 41.623361759801114\n",
      "EPOCH: 528 LOSS: 41.62167461893383\n",
      "EPOCH: 529 LOSS: 41.61999515093176\n",
      "EPOCH: 530 LOSS: 41.61832328873288\n",
      "EPOCH: 531 LOSS: 41.61665896612749\n",
      "EPOCH: 532 LOSS: 41.61500211774813\n",
      "EPOCH: 533 LOSS: 41.61335267905965\n",
      "EPOCH: 534 LOSS: 41.6117105863494\n",
      "EPOCH: 535 LOSS: 41.61007577671752\n",
      "EPOCH: 536 LOSS: 41.60844818806736\n",
      "EPOCH: 537 LOSS: 41.606827759096035\n",
      "EPOCH: 538 LOSS: 41.60521442928503\n",
      "EPOCH: 539 LOSS: 41.603608138890955\n",
      "EPOCH: 540 LOSS: 41.602008828936434\n",
      "EPOCH: 541 LOSS: 41.60041644120109\n",
      "EPOCH: 542 LOSS: 41.59883091821259\n",
      "EPOCH: 543 LOSS: 41.5972522032378\n",
      "EPOCH: 544 LOSS: 41.59568024027413\n",
      "EPOCH: 545 LOSS: 41.59411497404087\n",
      "EPOCH: 546 LOSS: 41.592556349970735\n",
      "EPOCH: 547 LOSS: 41.59100431420133\n",
      "EPOCH: 548 LOSS: 41.58945881356696\n",
      "EPOCH: 549 LOSS: 41.587919795590295\n",
      "EPOCH: 550 LOSS: 41.5863872084743\n",
      "EPOCH: 551 LOSS: 41.58486100109417\n",
      "EPOCH: 552 LOSS: 41.583341122989346\n",
      "EPOCH: 553 LOSS: 41.5818275243557\n",
      "EPOCH: 554 LOSS: 41.58032015603772\n",
      "EPOCH: 555 LOSS: 41.578818969520846\n",
      "EPOCH: 556 LOSS: 41.577323916923845\n",
      "EPOCH: 557 LOSS: 41.57583495099127\n",
      "EPOCH: 558 LOSS: 41.57435202508607\n",
      "EPOCH: 559 LOSS: 41.572875093182176\n",
      "EPOCH: 560 LOSS: 41.57140410985724\n",
      "EPOCH: 561 LOSS: 41.56993903028548\n",
      "EPOCH: 562 LOSS: 41.56847981023043\n",
      "EPOCH: 563 LOSS: 41.56702640603803\n",
      "EPOCH: 564 LOSS: 41.5655787746296\n",
      "EPOCH: 565 LOSS: 41.564136873494874\n",
      "EPOCH: 566 LOSS: 41.56270066068528\n",
      "EPOCH: 567 LOSS: 41.561270094807114\n",
      "EPOCH: 568 LOSS: 41.559845135014875\n",
      "EPOCH: 569 LOSS: 41.558425741004655\n",
      "EPOCH: 570 LOSS: 41.55701187300758\n",
      "EPOCH: 571 LOSS: 41.555603491783316\n",
      "EPOCH: 572 LOSS: 41.5542005586137\n",
      "EPOCH: 573 LOSS: 41.55280303529638\n",
      "EPOCH: 574 LOSS: 41.55141088413844\n",
      "EPOCH: 575 LOSS: 41.550024067950346\n",
      "EPOCH: 576 LOSS: 41.54864255003962\n",
      "EPOCH: 577 LOSS: 41.54726629420486\n",
      "EPOCH: 578 LOSS: 41.54589526472967\n",
      "EPOCH: 579 LOSS: 41.544529426376656\n",
      "EPOCH: 580 LOSS: 41.54316874438155\n",
      "EPOCH: 581 LOSS: 41.541813184447335\n",
      "EPOCH: 582 LOSS: 41.54046271273843\n",
      "EPOCH: 583 LOSS: 41.539117295874995\n",
      "EPOCH: 584 LOSS: 41.537776900927156\n",
      "EPOCH: 585 LOSS: 41.536441495409456\n",
      "EPOCH: 586 LOSS: 41.53511104727527\n",
      "EPOCH: 587 LOSS: 41.53378552491122\n",
      "EPOCH: 588 LOSS: 41.532464897131746\n",
      "EPOCH: 589 LOSS: 41.53114913317366\n",
      "EPOCH: 590 LOSS: 41.52983820269087\n",
      "EPOCH: 591 LOSS: 41.52853207574889\n",
      "EPOCH: 592 LOSS: 41.52723072281972\n",
      "EPOCH: 593 LOSS: 41.52593411477661\n",
      "EPOCH: 594 LOSS: 41.5246422228888\n",
      "EPOCH: 595 LOSS: 41.52335501881651\n",
      "EPOCH: 596 LOSS: 41.52207247460575\n",
      "EPOCH: 597 LOSS: 41.52079456268346\n",
      "EPOCH: 598 LOSS: 41.51952125585235\n",
      "EPOCH: 599 LOSS: 41.518252527286066\n",
      "EPOCH: 600 LOSS: 41.51698835052429\n",
      "EPOCH: 601 LOSS: 41.5157286994679\n",
      "EPOCH: 602 LOSS: 41.514473548374134\n",
      "EPOCH: 603 LOSS: 41.513222871851895\n",
      "EPOCH: 604 LOSS: 41.51197664485696\n",
      "EPOCH: 605 LOSS: 41.51073484268739\n",
      "EPOCH: 606 LOSS: 41.50949744097886\n",
      "EPOCH: 607 LOSS: 41.508264415700076\n",
      "EPOCH: 608 LOSS: 41.50703574314825\n",
      "EPOCH: 609 LOSS: 41.50581139994456\n",
      "EPOCH: 610 LOSS: 41.50459136302973\n",
      "EPOCH: 611 LOSS: 41.503375609659585\n",
      "EPOCH: 612 LOSS: 41.502164117400696\n",
      "EPOCH: 613 LOSS: 41.50095686412596\n",
      "EPOCH: 614 LOSS: 41.49975382801042\n",
      "EPOCH: 615 LOSS: 41.49855498752686\n",
      "EPOCH: 616 LOSS: 41.49736032144171\n",
      "EPOCH: 617 LOSS: 41.49616980881075\n",
      "EPOCH: 618 LOSS: 41.49498342897502\n",
      "EPOCH: 619 LOSS: 41.49380116155669\n",
      "EPOCH: 620 LOSS: 41.49262298645498\n",
      "EPOCH: 621 LOSS: 41.49144888384208\n",
      "EPOCH: 622 LOSS: 41.490278834159255\n",
      "EPOCH: 623 LOSS: 41.48911281811273\n",
      "EPOCH: 624 LOSS: 41.48795081666989\n",
      "EPOCH: 625 LOSS: 41.48679281105525\n",
      "EPOCH: 626 LOSS: 41.485638782746754\n",
      "EPOCH: 627 LOSS: 41.48448871347176\n",
      "EPOCH: 628 LOSS: 41.48334258520342\n",
      "EPOCH: 629 LOSS: 41.482200380156776\n",
      "EPOCH: 630 LOSS: 41.48106208078516\n",
      "EPOCH: 631 LOSS: 41.479927669776394\n",
      "EPOCH: 632 LOSS: 41.478797130049216\n",
      "EPOCH: 633 LOSS: 41.477670444749585\n",
      "EPOCH: 634 LOSS: 41.47654759724715\n",
      "EPOCH: 635 LOSS: 41.47542857113166\n",
      "EPOCH: 636 LOSS: 41.47431335020944\n",
      "EPOCH: 637 LOSS: 41.4732019184999\n",
      "EPOCH: 638 LOSS: 41.472094260232076\n",
      "EPOCH: 639 LOSS: 41.47099035984122\n",
      "EPOCH: 640 LOSS: 41.46989020196534\n",
      "EPOCH: 641 LOSS: 41.468793771441945\n",
      "EPOCH: 642 LOSS: 41.467701053304594\n",
      "EPOCH: 643 LOSS: 41.466612032779665\n",
      "EPOCH: 644 LOSS: 41.46552669528305\n",
      "EPOCH: 645 LOSS: 41.464445026417\n",
      "EPOCH: 646 LOSS: 41.46336701196677\n",
      "EPOCH: 647 LOSS: 41.4622926378976\n",
      "EPOCH: 648 LOSS: 41.46122189035141\n",
      "EPOCH: 649 LOSS: 41.46015475564385\n",
      "EPOCH: 650 LOSS: 41.4590912202611\n",
      "EPOCH: 651 LOSS: 41.45803127085685\n",
      "EPOCH: 652 LOSS: 41.456974894249285\n",
      "EPOCH: 653 LOSS: 41.45592207741808\n",
      "EPOCH: 654 LOSS: 41.45487280750145\n",
      "EPOCH: 655 LOSS: 41.45382707179323\n",
      "EPOCH: 656 LOSS: 41.45278485773989\n",
      "EPOCH: 657 LOSS: 41.4517461529378\n",
      "EPOCH: 658 LOSS: 41.45071094513023\n",
      "EPOCH: 659 LOSS: 41.449679222204715\n",
      "EPOCH: 660 LOSS: 41.44865097219008\n",
      "EPOCH: 661 LOSS: 41.44762618325382\n",
      "EPOCH: 662 LOSS: 41.44660484369935\n",
      "EPOCH: 663 LOSS: 41.445586941963256\n",
      "EPOCH: 664 LOSS: 41.44457246661269\n",
      "EPOCH: 665 LOSS: 41.443561406342695\n",
      "EPOCH: 666 LOSS: 41.442553749973605\n",
      "EPOCH: 667 LOSS: 41.44154948644848\n",
      "EPOCH: 668 LOSS: 41.44054860483054\n",
      "EPOCH: 669 LOSS: 41.43955109430064\n",
      "EPOCH: 670 LOSS: 41.438556944154804\n",
      "EPOCH: 671 LOSS: 41.43756614380172\n",
      "EPOCH: 672 LOSS: 41.43657868276033\n",
      "EPOCH: 673 LOSS: 41.43559455065742\n",
      "EPOCH: 674 LOSS: 41.43461373722525\n",
      "EPOCH: 675 LOSS: 41.433636232299165\n",
      "EPOCH: 676 LOSS: 41.43266202581534\n",
      "EPOCH: 677 LOSS: 41.431691107808405\n",
      "EPOCH: 678 LOSS: 41.430723468409255\n",
      "EPOCH: 679 LOSS: 41.429759097842755\n",
      "EPOCH: 680 LOSS: 41.428797986425565\n",
      "EPOCH: 681 LOSS: 41.427840124563936\n",
      "EPOCH: 682 LOSS: 41.42688550275162\n",
      "EPOCH: 683 LOSS: 41.42593411156757\n",
      "EPOCH: 684 LOSS: 41.4249859416741\n",
      "EPOCH: 685 LOSS: 41.4240409838146\n",
      "EPOCH: 686 LOSS: 41.42309922881161\n",
      "EPOCH: 687 LOSS: 41.4221606675647\n",
      "EPOCH: 688 LOSS: 41.421225291048636\n",
      "EPOCH: 689 LOSS: 41.42029309031125\n",
      "EPOCH: 690 LOSS: 41.41936405647165\n",
      "EPOCH: 691 LOSS: 41.418438180718205\n",
      "EPOCH: 692 LOSS: 41.41751545430675\n",
      "EPOCH: 693 LOSS: 41.416595868558645\n",
      "EPOCH: 694 LOSS: 41.415679414859056\n",
      "EPOCH: 695 LOSS: 41.414766084655064\n",
      "EPOCH: 696 LOSS: 41.41385586945395\n",
      "EPOCH: 697 LOSS: 41.41294876082141\n",
      "EPOCH: 698 LOSS: 41.41204475037989\n",
      "EPOCH: 699 LOSS: 41.411143829806804\n",
      "EPOCH: 700 LOSS: 41.41024599083298\n",
      "EPOCH: 701 LOSS: 41.40935122524097\n",
      "EPOCH: 702 LOSS: 41.408459524863375\n",
      "EPOCH: 703 LOSS: 41.40757088158138\n",
      "EPOCH: 704 LOSS: 41.40668528732306\n",
      "EPOCH: 705 LOSS: 41.40580273406199\n",
      "EPOCH: 706 LOSS: 41.404923213815636\n",
      "EPOCH: 707 LOSS: 41.404046718643855\n",
      "EPOCH: 708 LOSS: 41.40317324064752\n",
      "EPOCH: 709 LOSS: 41.40230277196702\n",
      "EPOCH: 710 LOSS: 41.40143530478089\n",
      "EPOCH: 711 LOSS: 41.40057083130443\n",
      "EPOCH: 712 LOSS: 41.39970934378829\n",
      "EPOCH: 713 LOSS: 41.3988508345172\n",
      "EPOCH: 714 LOSS: 41.397995295808684\n",
      "EPOCH: 715 LOSS: 41.39714272001167\n",
      "EPOCH: 716 LOSS: 41.39629309950536\n",
      "EPOCH: 717 LOSS: 41.39544642669787\n",
      "EPOCH: 718 LOSS: 41.39460269402515\n",
      "EPOCH: 719 LOSS: 41.39376189394967\n",
      "EPOCH: 720 LOSS: 41.392924018959384\n",
      "EPOCH: 721 LOSS: 41.392089061566494\n",
      "EPOCH: 722 LOSS: 41.39125701430636\n",
      "EPOCH: 723 LOSS: 41.390427869736456\n",
      "EPOCH: 724 LOSS: 41.389601620435265\n",
      "EPOCH: 725 LOSS: 41.3887782590012\n",
      "EPOCH: 726 LOSS: 41.38795777805165\n",
      "EPOCH: 727 LOSS: 41.387140170221954\n",
      "EPOCH: 728 LOSS: 41.38632542816444\n",
      "EPOCH: 729 LOSS: 41.38551354454744\n",
      "EPOCH: 730 LOSS: 41.384704512054356\n",
      "EPOCH: 731 LOSS: 41.38389832338284\n",
      "EPOCH: 732 LOSS: 41.38309497124375\n",
      "EPOCH: 733 LOSS: 41.3822944483605\n",
      "EPOCH: 734 LOSS: 41.381496747467956\n",
      "EPOCH: 735 LOSS: 41.38070186131188\n",
      "EPOCH: 736 LOSS: 41.379909782647935\n",
      "EPOCH: 737 LOSS: 41.379120504241\n",
      "EPOCH: 738 LOSS: 41.37833401886441\n",
      "EPOCH: 739 LOSS: 41.37755031929914\n",
      "EPOCH: 740 LOSS: 41.37676939833323\n",
      "EPOCH: 741 LOSS: 41.37599124876098\n",
      "EPOCH: 742 LOSS: 41.37521586338229\n",
      "EPOCH: 743 LOSS: 41.374443235002005\n",
      "EPOCH: 744 LOSS: 41.373673356429364\n",
      "EPOCH: 745 LOSS: 41.37290622047724\n",
      "EPOCH: 746 LOSS: 41.37214181996168\n",
      "EPOCH: 747 LOSS: 41.37138014770125\n",
      "EPOCH: 748 LOSS: 41.37062119651645\n",
      "EPOCH: 749 LOSS: 41.369864959229304\n",
      "EPOCH: 750 LOSS: 41.36911142866269\n",
      "EPOCH: 751 LOSS: 41.368360597639935\n",
      "EPOCH: 752 LOSS: 41.36761245898429\n",
      "EPOCH: 753 LOSS: 41.36686700551847\n",
      "EPOCH: 754 LOSS: 41.36612423006422\n",
      "EPOCH: 755 LOSS: 41.36538412544189\n",
      "EPOCH: 756 LOSS: 41.36464668446998\n",
      "EPOCH: 757 LOSS: 41.36391189996481\n",
      "EPOCH: 758 LOSS: 41.36317976474003\n",
      "EPOCH: 759 LOSS: 41.362450271606434\n",
      "EPOCH: 760 LOSS: 41.361723413371415\n",
      "EPOCH: 761 LOSS: 41.36099918283879\n",
      "EPOCH: 762 LOSS: 41.3602775728084\n",
      "EPOCH: 763 LOSS: 41.359558576075834\n",
      "EPOCH: 764 LOSS: 41.35884218543219\n",
      "EPOCH: 765 LOSS: 41.35812839366373\n",
      "EPOCH: 766 LOSS: 41.357417193551704\n",
      "EPOCH: 767 LOSS: 41.35670857787202\n",
      "EPOCH: 768 LOSS: 41.35600253939515\n",
      "EPOCH: 769 LOSS: 41.35529907088581\n",
      "EPOCH: 770 LOSS: 41.354598165102814\n",
      "EPOCH: 771 LOSS: 41.35389981479888\n",
      "EPOCH: 772 LOSS: 41.35320401272052\n",
      "EPOCH: 773 LOSS: 41.35251075160775\n",
      "EPOCH: 774 LOSS: 41.35182002419413\n",
      "EPOCH: 775 LOSS: 41.35113182320653\n",
      "EPOCH: 776 LOSS: 41.350446141364976\n",
      "EPOCH: 777 LOSS: 41.34976297138269\n",
      "EPOCH: 778 LOSS: 41.349082305965865\n",
      "EPOCH: 779 LOSS: 41.348404137813674\n",
      "EPOCH: 780 LOSS: 41.34772845961819\n",
      "EPOCH: 781 LOSS: 41.34705526406428\n",
      "EPOCH: 782 LOSS: 41.34638454382963\n",
      "EPOCH: 783 LOSS: 41.34571629158471\n",
      "EPOCH: 784 LOSS: 41.345050499992716\n",
      "EPOCH: 785 LOSS: 41.34438716170958\n",
      "EPOCH: 786 LOSS: 41.343726269383964\n",
      "EPOCH: 787 LOSS: 41.343067815657335\n",
      "EPOCH: 788 LOSS: 41.34241179316392\n",
      "EPOCH: 789 LOSS: 41.34175819453073\n",
      "EPOCH: 790 LOSS: 41.34110701237765\n",
      "EPOCH: 791 LOSS: 41.34045823931747\n",
      "EPOCH: 792 LOSS: 41.33981186795597\n",
      "EPOCH: 793 LOSS: 41.33916789089197\n",
      "EPOCH: 794 LOSS: 41.33852630071737\n",
      "EPOCH: 795 LOSS: 41.33788709001732\n",
      "EPOCH: 796 LOSS: 41.337250251370264\n",
      "EPOCH: 797 LOSS: 41.33661577734807\n",
      "EPOCH: 798 LOSS: 41.335983660516106\n",
      "EPOCH: 799 LOSS: 41.33535389343339\n",
      "EPOCH: 800 LOSS: 41.33472646865275\n",
      "EPOCH: 801 LOSS: 41.33410137872087\n",
      "EPOCH: 802 LOSS: 41.333478616178496\n",
      "EPOCH: 803 LOSS: 41.33285817356061\n",
      "EPOCH: 804 LOSS: 41.332240043396496\n",
      "EPOCH: 805 LOSS: 41.331624218210045\n",
      "EPOCH: 806 LOSS: 41.33101069051973\n",
      "EPOCH: 807 LOSS: 41.330399452838975\n",
      "EPOCH: 808 LOSS: 41.32979049767619\n",
      "EPOCH: 809 LOSS: 41.32918381753507\n",
      "EPOCH: 810 LOSS: 41.32857940491469\n",
      "EPOCH: 811 LOSS: 41.32797725230978\n",
      "EPOCH: 812 LOSS: 41.327377352210874\n",
      "EPOCH: 813 LOSS: 41.32677969710455\n",
      "EPOCH: 814 LOSS: 41.32618427947365\n",
      "EPOCH: 815 LOSS: 41.325591091797456\n",
      "EPOCH: 816 LOSS: 41.32500012655194\n",
      "EPOCH: 817 LOSS: 41.32441137621\n",
      "EPOCH: 818 LOSS: 41.3238248332417\n",
      "EPOCH: 819 LOSS: 41.32324049011441\n",
      "EPOCH: 820 LOSS: 41.322658339293184\n",
      "EPOCH: 821 LOSS: 41.32207837324087\n",
      "EPOCH: 822 LOSS: 41.32150058441851\n",
      "EPOCH: 823 LOSS: 41.3209249652854\n",
      "EPOCH: 824 LOSS: 41.320351508299495\n",
      "EPOCH: 825 LOSS: 41.31978020591758\n",
      "EPOCH: 826 LOSS: 41.319211050595555\n",
      "EPOCH: 827 LOSS: 41.31864403478872\n",
      "EPOCH: 828 LOSS: 41.318079150951945\n",
      "EPOCH: 829 LOSS: 41.31751639154006\n",
      "EPOCH: 830 LOSS: 41.31695574900802\n",
      "EPOCH: 831 LOSS: 41.31639721581122\n",
      "EPOCH: 832 LOSS: 41.31584078440577\n",
      "EPOCH: 833 LOSS: 41.31528644724874\n",
      "EPOCH: 834 LOSS: 41.31473419679842\n",
      "EPOCH: 835 LOSS: 41.31418402551468\n",
      "EPOCH: 836 LOSS: 41.31363592585913\n",
      "EPOCH: 837 LOSS: 41.313089890295494\n",
      "EPOCH: 838 LOSS: 41.31254591128982\n",
      "EPOCH: 839 LOSS: 41.31200398131077\n",
      "EPOCH: 840 LOSS: 41.31146409282995\n",
      "EPOCH: 841 LOSS: 41.310926238322175\n",
      "EPOCH: 842 LOSS: 41.31039041026567\n",
      "EPOCH: 843 LOSS: 41.309856601142435\n",
      "EPOCH: 844 LOSS: 41.30932480343852\n",
      "EPOCH: 845 LOSS: 41.30879500964428\n",
      "EPOCH: 846 LOSS: 41.30826721225464\n",
      "EPOCH: 847 LOSS: 41.30774140376943\n",
      "EPOCH: 848 LOSS: 41.30721757669366\n",
      "EPOCH: 849 LOSS: 41.306695723537686\n",
      "EPOCH: 850 LOSS: 41.306175836817715\n",
      "EPOCH: 851 LOSS: 41.30565790905584\n",
      "EPOCH: 852 LOSS: 41.3051419327805\n",
      "EPOCH: 853 LOSS: 41.30462790052667\n",
      "EPOCH: 854 LOSS: 41.30411580483613\n",
      "EPOCH: 855 LOSS: 41.30360563825783\n",
      "EPOCH: 856 LOSS: 41.303097393348054\n",
      "EPOCH: 857 LOSS: 41.3025910626708\n",
      "EPOCH: 858 LOSS: 41.30208663879796\n",
      "EPOCH: 859 LOSS: 41.301584114309655\n",
      "EPOCH: 860 LOSS: 41.301083481794485\n",
      "EPOCH: 861 LOSS: 41.30058473384979\n",
      "EPOCH: 862 LOSS: 41.300087863081956\n",
      "EPOCH: 863 LOSS: 41.29959286210662\n",
      "EPOCH: 864 LOSS: 41.29909972354901\n",
      "EPOCH: 865 LOSS: 41.298608440044134\n",
      "EPOCH: 866 LOSS: 41.29811900423709\n",
      "EPOCH: 867 LOSS: 41.297631408783296\n",
      "EPOCH: 868 LOSS: 41.297145646348824\n",
      "EPOCH: 869 LOSS: 41.296661709610504\n",
      "EPOCH: 870 LOSS: 41.296179591256355\n",
      "EPOCH: 871 LOSS: 41.2956992839857\n",
      "EPOCH: 872 LOSS: 41.29522078050948\n",
      "EPOCH: 873 LOSS: 41.29474407355052\n",
      "EPOCH: 874 LOSS: 41.2942691558437\n",
      "EPOCH: 875 LOSS: 41.29379602013631\n",
      "EPOCH: 876 LOSS: 41.29332465918813\n",
      "EPOCH: 877 LOSS: 41.29285506577183\n",
      "EPOCH: 878 LOSS: 41.29238723267315\n",
      "EPOCH: 879 LOSS: 41.29192115269106\n",
      "EPOCH: 880 LOSS: 41.29145681863811\n",
      "EPOCH: 881 LOSS: 41.29099422334058\n",
      "EPOCH: 882 LOSS: 41.290533359638744\n",
      "EPOCH: 883 LOSS: 41.29007422038706\n",
      "EPOCH: 884 LOSS: 41.28961679845442\n",
      "EPOCH: 885 LOSS: 41.28916108672433\n",
      "EPOCH: 886 LOSS: 41.2887070780952\n",
      "EPOCH: 887 LOSS: 41.28825476548051\n",
      "EPOCH: 888 LOSS: 41.28780414180895\n",
      "EPOCH: 889 LOSS: 41.28735520002477\n",
      "EPOCH: 890 LOSS: 41.28690793308789\n",
      "EPOCH: 891 LOSS: 41.2864623339741\n",
      "EPOCH: 892 LOSS: 41.28601839567529\n",
      "EPOCH: 893 LOSS: 41.28557611119969\n",
      "EPOCH: 894 LOSS: 41.28513547357191\n",
      "EPOCH: 895 LOSS: 41.284696475833336\n",
      "EPOCH: 896 LOSS: 41.28425911104214\n",
      "EPOCH: 897 LOSS: 41.283823372273545\n",
      "EPOCH: 898 LOSS: 41.28338925262001\n",
      "EPOCH: 899 LOSS: 41.28295674519142\n",
      "EPOCH: 900 LOSS: 41.28252584311517\n",
      "EPOCH: 901 LOSS: 41.28209653953648\n",
      "EPOCH: 902 LOSS: 41.281668827618404\n",
      "EPOCH: 903 LOSS: 41.28124270054216\n",
      "EPOCH: 904 LOSS: 41.28081815150715\n",
      "EPOCH: 905 LOSS: 41.28039517373123\n",
      "EPOCH: 906 LOSS: 41.27997376045077\n",
      "EPOCH: 907 LOSS: 41.27955390492094\n",
      "EPOCH: 908 LOSS: 41.27913560041567\n",
      "EPOCH: 909 LOSS: 41.278718840228\n",
      "EPOCH: 910 LOSS: 41.278303617670076\n",
      "EPOCH: 911 LOSS: 41.27788992607341\n",
      "EPOCH: 912 LOSS: 41.27747775878886\n",
      "EPOCH: 913 LOSS: 41.27706710918699\n",
      "EPOCH: 914 LOSS: 41.27665797065795\n",
      "EPOCH: 915 LOSS: 41.276250336611845\n",
      "EPOCH: 916 LOSS: 41.27584420047866\n",
      "EPOCH: 917 LOSS: 41.27543955570856\n",
      "EPOCH: 918 LOSS: 41.27503639577184\n",
      "EPOCH: 919 LOSS: 41.27463471415923\n",
      "EPOCH: 920 LOSS: 41.2742345043818\n",
      "EPOCH: 921 LOSS: 41.27383575997126\n",
      "EPOCH: 922 LOSS: 41.27343847447999\n",
      "EPOCH: 923 LOSS: 41.2730426414811\n",
      "EPOCH: 924 LOSS: 41.27264825456861\n",
      "EPOCH: 925 LOSS: 41.27225530735755\n",
      "EPOCH: 926 LOSS: 41.271863793483995\n",
      "EPOCH: 927 LOSS: 41.27147370660522\n",
      "EPOCH: 928 LOSS: 41.27108504039974\n",
      "EPOCH: 929 LOSS: 41.270697788567475\n",
      "EPOCH: 930 LOSS: 41.27031194482974\n",
      "EPOCH: 931 LOSS: 41.26992750292944\n",
      "EPOCH: 932 LOSS: 41.26954445663101\n",
      "EPOCH: 933 LOSS: 41.26916279972065\n",
      "EPOCH: 934 LOSS: 41.268782526006284\n",
      "EPOCH: 935 LOSS: 41.26840362931768\n",
      "EPOCH: 936 LOSS: 41.268026103506536\n",
      "EPOCH: 937 LOSS: 41.26764994244649\n",
      "EPOCH: 938 LOSS: 41.26727514003324\n",
      "EPOCH: 939 LOSS: 41.266901690184625\n",
      "EPOCH: 940 LOSS: 41.266529586840576\n",
      "EPOCH: 941 LOSS: 41.266158823963295\n",
      "EPOCH: 942 LOSS: 41.26578939553724\n",
      "EPOCH: 943 LOSS: 41.2654212955692\n",
      "EPOCH: 944 LOSS: 41.26505451808835\n",
      "EPOCH: 945 LOSS: 41.26468905714629\n",
      "EPOCH: 946 LOSS: 41.26432490681707\n",
      "EPOCH: 947 LOSS: 41.263962061197276\n",
      "EPOCH: 948 LOSS: 41.26360051440606\n",
      "EPOCH: 949 LOSS: 41.26324026058508\n",
      "EPOCH: 950 LOSS: 41.26288129389873\n",
      "EPOCH: 951 LOSS: 41.262523608533996\n",
      "EPOCH: 952 LOSS: 41.26216719870056\n",
      "EPOCH: 953 LOSS: 41.261812058630845\n",
      "EPOCH: 954 LOSS: 41.261458182579986\n",
      "EPOCH: 955 LOSS: 41.26110556482591\n",
      "EPOCH: 956 LOSS: 41.26075419966932\n",
      "EPOCH: 957 LOSS: 41.260404081433734\n",
      "EPOCH: 958 LOSS: 41.26005520446547\n",
      "EPOCH: 959 LOSS: 41.25970756313373\n",
      "EPOCH: 960 LOSS: 41.259361151830525\n",
      "EPOCH: 961 LOSS: 41.25901596497077\n",
      "EPOCH: 962 LOSS: 41.25867199699223\n",
      "EPOCH: 963 LOSS: 41.25832924235555\n",
      "EPOCH: 964 LOSS: 41.25798769554428\n",
      "EPOCH: 965 LOSS: 41.25764735106483\n",
      "EPOCH: 966 LOSS: 41.25730820344653\n",
      "EPOCH: 967 LOSS: 41.25697024724158\n",
      "EPOCH: 968 LOSS: 41.256633477025076\n",
      "EPOCH: 969 LOSS: 41.25629788739499\n",
      "EPOCH: 970 LOSS: 41.25596347297218\n",
      "EPOCH: 971 LOSS: 41.255630228400335\n",
      "EPOCH: 972 LOSS: 41.255298148346064\n",
      "EPOCH: 973 LOSS: 41.254967227498774\n",
      "EPOCH: 974 LOSS: 41.25463746057072\n",
      "EPOCH: 975 LOSS: 41.254308842296965\n",
      "EPOCH: 976 LOSS: 41.253981367435394\n",
      "EPOCH: 977 LOSS: 41.25365503076666\n",
      "EPOCH: 978 LOSS: 41.25332982709418\n",
      "EPOCH: 979 LOSS: 41.2530057512441\n",
      "EPOCH: 980 LOSS: 41.25268279806534\n",
      "EPOCH: 981 LOSS: 41.25236096242941\n",
      "EPOCH: 982 LOSS: 41.25204023923058\n",
      "EPOCH: 983 LOSS: 41.25172062338574\n",
      "EPOCH: 984 LOSS: 41.25140210983435\n",
      "EPOCH: 985 LOSS: 41.25108469353849\n",
      "EPOCH: 986 LOSS: 41.25076836948279\n",
      "EPOCH: 987 LOSS: 41.25045313267437\n",
      "EPOCH: 988 LOSS: 41.25013897814284\n",
      "EPOCH: 989 LOSS: 41.249825900940245\n",
      "EPOCH: 990 LOSS: 41.24951389614108\n",
      "EPOCH: 991 LOSS: 41.24920295884215\n",
      "EPOCH: 992 LOSS: 41.24889308416262\n",
      "EPOCH: 993 LOSS: 41.24858426724393\n",
      "EPOCH: 994 LOSS: 41.248276503249784\n",
      "EPOCH: 995 LOSS: 41.247969787366074\n",
      "EPOCH: 996 LOSS: 41.24766411480087\n",
      "EPOCH: 997 LOSS: 41.2473594807843\n",
      "EPOCH: 998 LOSS: 41.247055880568624\n",
      "EPOCH: 999 LOSS: 41.24675330942806\n",
      "EPOCH: 1000 LOSS: 41.24645176265884\n",
      "EPOCH: 1001 LOSS: 41.24615123557911\n",
      "EPOCH: 1002 LOSS: 41.245851723528844\n",
      "EPOCH: 1003 LOSS: 41.24555322186987\n",
      "EPOCH: 1004 LOSS: 41.24525572598576\n",
      "EPOCH: 1005 LOSS: 41.2449592312818\n",
      "EPOCH: 1006 LOSS: 41.24466373318491\n",
      "EPOCH: 1007 LOSS: 41.244369227143636\n",
      "EPOCH: 1008 LOSS: 41.24407570862808\n",
      "EPOCH: 1009 LOSS: 41.24378317312976\n",
      "EPOCH: 1010 LOSS: 41.2434916161617\n",
      "EPOCH: 1011 LOSS: 41.2432010332582\n",
      "EPOCH: 1012 LOSS: 41.24291141997496\n",
      "EPOCH: 1013 LOSS: 41.242622771888854\n",
      "EPOCH: 1014 LOSS: 41.24233508459797\n",
      "EPOCH: 1015 LOSS: 41.24204835372152\n",
      "EPOCH: 1016 LOSS: 41.24176257489976\n",
      "EPOCH: 1017 LOSS: 41.241477743793936\n",
      "EPOCH: 1018 LOSS: 41.24119385608626\n",
      "EPOCH: 1019 LOSS: 41.240910907479766\n",
      "EPOCH: 1020 LOSS: 41.2406288936983\n",
      "EPOCH: 1021 LOSS: 41.24034781048647\n",
      "EPOCH: 1022 LOSS: 41.24006765360951\n",
      "EPOCH: 1023 LOSS: 41.23978841885323\n",
      "EPOCH: 1024 LOSS: 41.23951010202408\n",
      "EPOCH: 1025 LOSS: 41.23923269894886\n",
      "EPOCH: 1026 LOSS: 41.238956205474814\n",
      "EPOCH: 1027 LOSS: 41.23868061746946\n",
      "EPOCH: 1028 LOSS: 41.238405930820676\n",
      "EPOCH: 1029 LOSS: 41.23813214143638\n",
      "EPOCH: 1030 LOSS: 41.237859245244714\n",
      "EPOCH: 1031 LOSS: 41.237587238193825\n",
      "EPOCH: 1032 LOSS: 41.23731611625179\n",
      "EPOCH: 1033 LOSS: 41.23704587540663\n",
      "EPOCH: 1034 LOSS: 41.23677651166615\n",
      "EPOCH: 1035 LOSS: 41.236508021057936\n",
      "EPOCH: 1036 LOSS: 41.23624039962923\n",
      "EPOCH: 1037 LOSS: 41.23597364344687\n",
      "EPOCH: 1038 LOSS: 41.23570774859725\n",
      "EPOCH: 1039 LOSS: 41.23544271118618\n",
      "EPOCH: 1040 LOSS: 41.235178527338846\n",
      "EPOCH: 1041 LOSS: 41.23491519319978\n",
      "EPOCH: 1042 LOSS: 41.23465270493271\n",
      "EPOCH: 1043 LOSS: 41.234391058720476\n",
      "EPOCH: 1044 LOSS: 41.23413025076507\n",
      "EPOCH: 1045 LOSS: 41.23387027728741\n",
      "EPOCH: 1046 LOSS: 41.233611134527386\n",
      "EPOCH: 1047 LOSS: 41.23335281874371\n",
      "EPOCH: 1048 LOSS: 41.23309532621384\n",
      "EPOCH: 1049 LOSS: 41.23283865323398\n",
      "EPOCH: 1050 LOSS: 41.2325827961189\n",
      "EPOCH: 1051 LOSS: 41.23232775120191\n",
      "EPOCH: 1052 LOSS: 41.23207351483477\n",
      "EPOCH: 1053 LOSS: 41.231820083387646\n",
      "EPOCH: 1054 LOSS: 41.231567453248985\n",
      "EPOCH: 1055 LOSS: 41.23131562082547\n",
      "EPOCH: 1056 LOSS: 41.23106458254192\n",
      "EPOCH: 1057 LOSS: 41.2308143348412\n",
      "EPOCH: 1058 LOSS: 41.230564874184196\n",
      "EPOCH: 1059 LOSS: 41.23031619704969\n",
      "EPOCH: 1060 LOSS: 41.23006829993429\n",
      "EPOCH: 1061 LOSS: 41.22982117935234\n",
      "EPOCH: 1062 LOSS: 41.22957483183589\n",
      "EPOCH: 1063 LOSS: 41.22932925393456\n",
      "EPOCH: 1064 LOSS: 41.22908444221548\n",
      "EPOCH: 1065 LOSS: 41.228840393263255\n",
      "EPOCH: 1066 LOSS: 41.22859710367979\n",
      "EPOCH: 1067 LOSS: 41.22835457008432\n",
      "EPOCH: 1068 LOSS: 41.228112789113226\n",
      "EPOCH: 1069 LOSS: 41.22787175742004\n",
      "EPOCH: 1070 LOSS: 41.22763147167536\n",
      "EPOCH: 1071 LOSS: 41.227391928566675\n",
      "EPOCH: 1072 LOSS: 41.22715312479845\n",
      "EPOCH: 1073 LOSS: 41.22691505709186\n",
      "EPOCH: 1074 LOSS: 41.226677722184874\n",
      "EPOCH: 1075 LOSS: 41.22644111683207\n",
      "EPOCH: 1076 LOSS: 41.22620523780462\n",
      "EPOCH: 1077 LOSS: 41.22597008189017\n",
      "EPOCH: 1078 LOSS: 41.225735645892755\n",
      "EPOCH: 1079 LOSS: 41.22550192663281\n",
      "EPOCH: 1080 LOSS: 41.225268920946945\n",
      "EPOCH: 1081 LOSS: 41.22503662568799\n",
      "EPOCH: 1082 LOSS: 41.22480503772488\n",
      "EPOCH: 1083 LOSS: 41.22457415394253\n",
      "EPOCH: 1084 LOSS: 41.224343971241844\n",
      "EPOCH: 1085 LOSS: 41.22411448653957\n",
      "EPOCH: 1086 LOSS: 41.22388569676822\n",
      "EPOCH: 1087 LOSS: 41.22365759887603\n",
      "EPOCH: 1088 LOSS: 41.2234301898269\n",
      "EPOCH: 1089 LOSS: 41.22320346660023\n",
      "EPOCH: 1090 LOSS: 41.22297742619095\n",
      "EPOCH: 1091 LOSS: 41.22275206560933\n",
      "EPOCH: 1092 LOSS: 41.22252738188102\n",
      "EPOCH: 1093 LOSS: 41.22230337204691\n",
      "EPOCH: 1094 LOSS: 41.22208003316298\n",
      "EPOCH: 1095 LOSS: 41.22185736230044\n",
      "EPOCH: 1096 LOSS: 41.2216353565454\n",
      "EPOCH: 1097 LOSS: 41.22141401299898\n",
      "EPOCH: 1098 LOSS: 41.22119332877715\n",
      "EPOCH: 1099 LOSS: 41.22097330101062\n",
      "EPOCH: 1100 LOSS: 41.22075392684491\n",
      "EPOCH: 1101 LOSS: 41.220535203440114\n",
      "EPOCH: 1102 LOSS: 41.220317127970915\n",
      "EPOCH: 1103 LOSS: 41.220099697626466\n",
      "EPOCH: 1104 LOSS: 41.21988290961035\n",
      "EPOCH: 1105 LOSS: 41.21966676114051\n",
      "EPOCH: 1106 LOSS: 41.21945124944912\n",
      "EPOCH: 1107 LOSS: 41.21923637178259\n",
      "EPOCH: 1108 LOSS: 41.21902212540141\n",
      "EPOCH: 1109 LOSS: 41.218808507580135\n",
      "EPOCH: 1110 LOSS: 41.2185955156073\n",
      "EPOCH: 1111 LOSS: 41.218383146785335\n",
      "EPOCH: 1112 LOSS: 41.2181713984305\n",
      "EPOCH: 1113 LOSS: 41.2179602678728\n",
      "EPOCH: 1114 LOSS: 41.217749752455944\n",
      "EPOCH: 1115 LOSS: 41.217539849537246\n",
      "EPOCH: 1116 LOSS: 41.21733055648754\n",
      "EPOCH: 1117 LOSS: 41.21712187069116\n",
      "EPOCH: 1118 LOSS: 41.21691378954581\n",
      "EPOCH: 1119 LOSS: 41.21670631046255\n",
      "EPOCH: 1120 LOSS: 41.21649943086565\n",
      "EPOCH: 1121 LOSS: 41.21629314819265\n",
      "EPOCH: 1122 LOSS: 41.216087459894084\n",
      "EPOCH: 1123 LOSS: 41.21588236343363\n",
      "EPOCH: 1124 LOSS: 41.215677856287925\n",
      "EPOCH: 1125 LOSS: 41.21547393594646\n",
      "EPOCH: 1126 LOSS: 41.21527059991164\n",
      "EPOCH: 1127 LOSS: 41.21506784569857\n",
      "EPOCH: 1128 LOSS: 41.21486567083509\n",
      "EPOCH: 1129 LOSS: 41.214664072861694\n",
      "EPOCH: 1130 LOSS: 41.21446304933136\n",
      "EPOCH: 1131 LOSS: 41.214262597809665\n",
      "EPOCH: 1132 LOSS: 41.21406271587453\n",
      "EPOCH: 1133 LOSS: 41.21386340111631\n",
      "EPOCH: 1134 LOSS: 41.21366465113759\n",
      "EPOCH: 1135 LOSS: 41.2134664635532\n",
      "EPOCH: 1136 LOSS: 41.21326883599018\n",
      "EPOCH: 1137 LOSS: 41.213071766087594\n",
      "EPOCH: 1138 LOSS: 41.212875251496584\n",
      "EPOCH: 1139 LOSS: 41.212679289880256\n",
      "EPOCH: 1140 LOSS: 41.21248387891356\n",
      "EPOCH: 1141 LOSS: 41.21228901628339\n",
      "EPOCH: 1142 LOSS: 41.21209469968829\n",
      "EPOCH: 1143 LOSS: 41.211900926838595\n",
      "EPOCH: 1144 LOSS: 41.21170769545624\n",
      "EPOCH: 1145 LOSS: 41.21151500327474\n",
      "EPOCH: 1146 LOSS: 41.21132284803916\n",
      "EPOCH: 1147 LOSS: 41.211131227505966\n",
      "EPOCH: 1148 LOSS: 41.21094013944305\n",
      "EPOCH: 1149 LOSS: 41.210749581629614\n",
      "EPOCH: 1150 LOSS: 41.21055955185615\n",
      "EPOCH: 1151 LOSS: 41.2103700479243\n",
      "EPOCH: 1152 LOSS: 41.21018106764689\n",
      "EPOCH: 1153 LOSS: 41.20999260884782\n",
      "EPOCH: 1154 LOSS: 41.209804669361986\n",
      "EPOCH: 1155 LOSS: 41.209617247035276\n",
      "EPOCH: 1156 LOSS: 41.20943033972444\n",
      "EPOCH: 1157 LOSS: 41.20924394529709\n",
      "EPOCH: 1158 LOSS: 41.209058061631595\n",
      "EPOCH: 1159 LOSS: 41.20887268661705\n",
      "EPOCH: 1160 LOSS: 41.20868781815322\n",
      "EPOCH: 1161 LOSS: 41.20850345415046\n",
      "EPOCH: 1162 LOSS: 41.20831959252965\n",
      "EPOCH: 1163 LOSS: 41.20813623122218\n",
      "EPOCH: 1164 LOSS: 41.20795336816983\n",
      "EPOCH: 1165 LOSS: 41.20777100132477\n",
      "EPOCH: 1166 LOSS: 41.20758912864949\n",
      "EPOCH: 1167 LOSS: 41.20740774811669\n",
      "EPOCH: 1168 LOSS: 41.2072268577093\n",
      "EPOCH: 1169 LOSS: 41.20704645542036\n",
      "EPOCH: 1170 LOSS: 41.20686653925303\n",
      "EPOCH: 1171 LOSS: 41.206687107220446\n",
      "EPOCH: 1172 LOSS: 41.20650815734576\n",
      "EPOCH: 1173 LOSS: 41.20632968766202\n",
      "EPOCH: 1174 LOSS: 41.20615169621208\n",
      "EPOCH: 1175 LOSS: 41.2059741810487\n",
      "EPOCH: 1176 LOSS: 41.20579714023432\n",
      "EPOCH: 1177 LOSS: 41.205620571841074\n",
      "EPOCH: 1178 LOSS: 41.205444473950756\n",
      "EPOCH: 1179 LOSS: 41.20526884465474\n",
      "EPOCH: 1180 LOSS: 41.205093682053935\n",
      "EPOCH: 1181 LOSS: 41.20491898425875\n",
      "EPOCH: 1182 LOSS: 41.20474474938896\n",
      "EPOCH: 1183 LOSS: 41.20457097557379\n",
      "EPOCH: 1184 LOSS: 41.204397660951734\n",
      "EPOCH: 1185 LOSS: 41.204224803670584\n",
      "EPOCH: 1186 LOSS: 41.20405240188733\n",
      "EPOCH: 1187 LOSS: 41.20388045376814\n",
      "EPOCH: 1188 LOSS: 41.20370895748831\n",
      "EPOCH: 1189 LOSS: 41.20353791123216\n",
      "EPOCH: 1190 LOSS: 41.20336731319307\n",
      "EPOCH: 1191 LOSS: 41.20319716157336\n",
      "EPOCH: 1192 LOSS: 41.20302745458425\n",
      "EPOCH: 1193 LOSS: 41.202858190445866\n",
      "EPOCH: 1194 LOSS: 41.2026893673871\n",
      "EPOCH: 1195 LOSS: 41.20252098364563\n",
      "EPOCH: 1196 LOSS: 41.20235303746785\n",
      "EPOCH: 1197 LOSS: 41.20218552710884\n",
      "EPOCH: 1198 LOSS: 41.20201845083225\n",
      "EPOCH: 1199 LOSS: 41.20185180691033\n",
      "EPOCH: 1200 LOSS: 41.20168559362388\n",
      "EPOCH: 1201 LOSS: 41.2015198092621\n",
      "EPOCH: 1202 LOSS: 41.201354452122715\n",
      "EPOCH: 1203 LOSS: 41.20118952051172\n",
      "EPOCH: 1204 LOSS: 41.20102501274354\n",
      "EPOCH: 1205 LOSS: 41.20086092714081\n",
      "EPOCH: 1206 LOSS: 41.20069726203447\n",
      "EPOCH: 1207 LOSS: 41.2005340157636\n",
      "EPOCH: 1208 LOSS: 41.20037118667548\n",
      "EPOCH: 1209 LOSS: 41.20020877312541\n",
      "EPOCH: 1210 LOSS: 41.20004677347689\n",
      "EPOCH: 1211 LOSS: 41.19988518610127\n",
      "EPOCH: 1212 LOSS: 41.19972400937796\n",
      "EPOCH: 1213 LOSS: 41.19956324169428\n",
      "EPOCH: 1214 LOSS: 41.19940288144541\n",
      "EPOCH: 1215 LOSS: 41.199242927034405\n",
      "EPOCH: 1216 LOSS: 41.19908337687203\n",
      "EPOCH: 1217 LOSS: 41.19892422937689\n",
      "EPOCH: 1218 LOSS: 41.19876548297527\n",
      "EPOCH: 1219 LOSS: 41.19860713610104\n",
      "EPOCH: 1220 LOSS: 41.1984491871958\n",
      "EPOCH: 1221 LOSS: 41.19829163470864\n",
      "EPOCH: 1222 LOSS: 41.19813447709623\n",
      "EPOCH: 1223 LOSS: 41.19797771282272\n",
      "EPOCH: 1224 LOSS: 41.19782134035971\n",
      "EPOCH: 1225 LOSS: 41.19766535818618\n",
      "EPOCH: 1226 LOSS: 41.19750976478852\n",
      "EPOCH: 1227 LOSS: 41.19735455866043\n",
      "EPOCH: 1228 LOSS: 41.197199738302864\n",
      "EPOCH: 1229 LOSS: 41.1970453022241\n",
      "EPOCH: 1230 LOSS: 41.19689124893951\n",
      "EPOCH: 1231 LOSS: 41.19673757697173\n",
      "EPOCH: 1232 LOSS: 41.196584284850424\n",
      "EPOCH: 1233 LOSS: 41.19643137111246\n",
      "EPOCH: 1234 LOSS: 41.19627883430162\n",
      "EPOCH: 1235 LOSS: 41.1961266729688\n",
      "EPOCH: 1236 LOSS: 41.195974885671795\n",
      "EPOCH: 1237 LOSS: 41.19582347097534\n",
      "EPOCH: 1238 LOSS: 41.1956724274511\n",
      "EPOCH: 1239 LOSS: 41.19552175367753\n",
      "EPOCH: 1240 LOSS: 41.19537144823994\n",
      "EPOCH: 1241 LOSS: 41.195221509730395\n",
      "EPOCH: 1242 LOSS: 41.19507193674772\n",
      "EPOCH: 1243 LOSS: 41.19492272789742\n",
      "EPOCH: 1244 LOSS: 41.19477388179166\n",
      "EPOCH: 1245 LOSS: 41.194625397049236\n",
      "EPOCH: 1246 LOSS: 41.194477272295565\n",
      "EPOCH: 1247 LOSS: 41.19432950616254\n",
      "EPOCH: 1248 LOSS: 41.19418209728866\n",
      "EPOCH: 1249 LOSS: 41.19403504431885\n",
      "EPOCH: 1250 LOSS: 41.19388834590448\n",
      "EPOCH: 1251 LOSS: 41.19374200070336\n",
      "EPOCH: 1252 LOSS: 41.193596007379654\n",
      "EPOCH: 1253 LOSS: 41.193450364603855\n",
      "EPOCH: 1254 LOSS: 41.19330507105276\n",
      "EPOCH: 1255 LOSS: 41.19316012540948\n",
      "EPOCH: 1256 LOSS: 41.19301552636327\n",
      "EPOCH: 1257 LOSS: 41.19287127260968\n",
      "EPOCH: 1258 LOSS: 41.192727362850384\n",
      "EPOCH: 1259 LOSS: 41.19258379579316\n",
      "EPOCH: 1260 LOSS: 41.19244057015193\n",
      "EPOCH: 1261 LOSS: 41.192297684646654\n",
      "EPOCH: 1262 LOSS: 41.19215513800332\n",
      "EPOCH: 1263 LOSS: 41.192012928953936\n",
      "EPOCH: 1264 LOSS: 41.191871056236444\n",
      "EPOCH: 1265 LOSS: 41.191729518594734\n",
      "EPOCH: 1266 LOSS: 41.19158831477862\n",
      "EPOCH: 1267 LOSS: 41.19144744354374\n",
      "EPOCH: 1268 LOSS: 41.191306903651565\n",
      "EPOCH: 1269 LOSS: 41.19116669386941\n",
      "EPOCH: 1270 LOSS: 41.191026812970335\n",
      "EPOCH: 1271 LOSS: 41.19088725973313\n",
      "EPOCH: 1272 LOSS: 41.1907480329423\n",
      "EPOCH: 1273 LOSS: 41.190609131388044\n",
      "EPOCH: 1274 LOSS: 41.190470553866184\n",
      "EPOCH: 1275 LOSS: 41.19033229917816\n",
      "EPOCH: 1276 LOSS: 41.190194366131\n",
      "EPOCH: 1277 LOSS: 41.19005675353729\n",
      "EPOCH: 1278 LOSS: 41.18991946021512\n",
      "EPOCH: 1279 LOSS: 41.18978248498811\n",
      "EPOCH: 1280 LOSS: 41.18964582668529\n",
      "EPOCH: 1281 LOSS: 41.18950948414117\n",
      "EPOCH: 1282 LOSS: 41.18937345619564\n",
      "EPOCH: 1283 LOSS: 41.18923774169393\n",
      "EPOCH: 1284 LOSS: 41.18910233948671\n",
      "EPOCH: 1285 LOSS: 41.1889672484299\n",
      "EPOCH: 1286 LOSS: 41.188832467384664\n",
      "EPOCH: 1287 LOSS: 41.18869799521752\n",
      "EPOCH: 1288 LOSS: 41.18856383080015\n",
      "EPOCH: 1289 LOSS: 41.18842997300946\n",
      "EPOCH: 1290 LOSS: 41.18829642072752\n",
      "EPOCH: 1291 LOSS: 41.188163172841556\n",
      "EPOCH: 1292 LOSS: 41.1880302282439\n",
      "EPOCH: 1293 LOSS: 41.18789758583197\n",
      "EPOCH: 1294 LOSS: 41.18776524450826\n",
      "EPOCH: 1295 LOSS: 41.18763320318027\n",
      "EPOCH: 1296 LOSS: 41.187501460760565\n",
      "EPOCH: 1297 LOSS: 41.187370016166625\n",
      "EPOCH: 1298 LOSS: 41.18723886832091\n",
      "EPOCH: 1299 LOSS: 41.18710801615079\n",
      "EPOCH: 1300 LOSS: 41.18697745858859\n",
      "EPOCH: 1301 LOSS: 41.18684719457143\n",
      "EPOCH: 1302 LOSS: 41.18671722304132\n",
      "EPOCH: 1303 LOSS: 41.186587542945105\n",
      "EPOCH: 1304 LOSS: 41.18645815323441\n",
      "EPOCH: 1305 LOSS: 41.18632905286559\n",
      "EPOCH: 1306 LOSS: 41.18620024079979\n",
      "EPOCH: 1307 LOSS: 41.18607171600288\n",
      "EPOCH: 1308 LOSS: 41.18594347744538\n",
      "EPOCH: 1309 LOSS: 41.18581552410252\n",
      "EPOCH: 1310 LOSS: 41.185687854954125\n",
      "EPOCH: 1311 LOSS: 41.185560468984704\n",
      "EPOCH: 1312 LOSS: 41.18543336518329\n",
      "EPOCH: 1313 LOSS: 41.18530654254353\n",
      "EPOCH: 1314 LOSS: 41.18518000006358\n",
      "EPOCH: 1315 LOSS: 41.185053736746156\n",
      "EPOCH: 1316 LOSS: 41.18492775159844\n",
      "EPOCH: 1317 LOSS: 41.18480204363209\n",
      "EPOCH: 1318 LOSS: 41.18467661186323\n",
      "EPOCH: 1319 LOSS: 41.18455145531237\n",
      "EPOCH: 1320 LOSS: 41.184426573004465\n",
      "EPOCH: 1321 LOSS: 41.18430196396883\n",
      "EPOCH: 1322 LOSS: 41.18417762723909\n",
      "EPOCH: 1323 LOSS: 41.184053561853275\n",
      "EPOCH: 1324 LOSS: 41.183929766853666\n",
      "EPOCH: 1325 LOSS: 41.18380624128687\n",
      "EPOCH: 1326 LOSS: 41.18368298420372\n",
      "EPOCH: 1327 LOSS: 41.18355999465931\n",
      "EPOCH: 1328 LOSS: 41.18343727171294\n",
      "EPOCH: 1329 LOSS: 41.183314814428115\n",
      "EPOCH: 1330 LOSS: 41.1831926218725\n",
      "EPOCH: 1331 LOSS: 41.18307069311791\n",
      "EPOCH: 1332 LOSS: 41.182949027240305\n",
      "EPOCH: 1333 LOSS: 41.18282762331974\n",
      "EPOCH: 1334 LOSS: 41.18270648044034\n",
      "EPOCH: 1335 LOSS: 41.18258559769033\n",
      "EPOCH: 1336 LOSS: 41.18246497416193\n",
      "EPOCH: 1337 LOSS: 41.18234460895144\n",
      "EPOCH: 1338 LOSS: 41.1822245011591\n",
      "EPOCH: 1339 LOSS: 41.182104649889155\n",
      "EPOCH: 1340 LOSS: 41.18198505424981\n",
      "EPOCH: 1341 LOSS: 41.181865713353204\n",
      "EPOCH: 1342 LOSS: 41.18174662631539\n",
      "EPOCH: 1343 LOSS: 41.18162779225632\n",
      "EPOCH: 1344 LOSS: 41.181509210299794\n",
      "EPOCH: 1345 LOSS: 41.18139087957354\n",
      "EPOCH: 1346 LOSS: 41.18127279920902\n",
      "EPOCH: 1347 LOSS: 41.18115496834159\n",
      "EPOCH: 1348 LOSS: 41.18103738611036\n",
      "EPOCH: 1349 LOSS: 41.18092005165823\n",
      "EPOCH: 1350 LOSS: 41.18080296413186\n",
      "EPOCH: 1351 LOSS: 41.18068612268163\n",
      "EPOCH: 1352 LOSS: 41.18056952646164\n",
      "EPOCH: 1353 LOSS: 41.180453174629704\n",
      "EPOCH: 1354 LOSS: 41.18033706634728\n",
      "EPOCH: 1355 LOSS: 41.1802212007795\n",
      "EPOCH: 1356 LOSS: 41.18010557709516\n",
      "EPOCH: 1357 LOSS: 41.17999019446664\n",
      "EPOCH: 1358 LOSS: 41.179875052069946\n",
      "EPOCH: 1359 LOSS: 41.17976014908464\n",
      "EPOCH: 1360 LOSS: 41.1796454846939\n",
      "EPOCH: 1361 LOSS: 41.17953105808439\n",
      "EPOCH: 1362 LOSS: 41.17941686844632\n",
      "EPOCH: 1363 LOSS: 41.17930291497342\n",
      "EPOCH: 1364 LOSS: 41.17918919686292\n",
      "EPOCH: 1365 LOSS: 41.1790757133155\n",
      "EPOCH: 1366 LOSS: 41.17896246353531\n",
      "EPOCH: 1367 LOSS: 41.178849446729934\n",
      "EPOCH: 1368 LOSS: 41.17873666211037\n",
      "EPOCH: 1369 LOSS: 41.178624108891015\n",
      "EPOCH: 1370 LOSS: 41.17851178628967\n",
      "EPOCH: 1371 LOSS: 41.178399693527474\n",
      "EPOCH: 1372 LOSS: 41.17828782982896\n",
      "EPOCH: 1373 LOSS: 41.17817619442194\n",
      "EPOCH: 1374 LOSS: 41.17806478653757\n",
      "EPOCH: 1375 LOSS: 41.17795360541033\n",
      "EPOCH: 1376 LOSS: 41.17784265027791\n",
      "EPOCH: 1377 LOSS: 41.17773192038133\n",
      "EPOCH: 1378 LOSS: 41.17762141496485\n",
      "EPOCH: 1379 LOSS: 41.17751113327592\n",
      "EPOCH: 1380 LOSS: 41.17740107456527\n",
      "EPOCH: 1381 LOSS: 41.17729123808674\n",
      "EPOCH: 1382 LOSS: 41.17718162309744\n",
      "EPOCH: 1383 LOSS: 41.17707222885761\n",
      "EPOCH: 1384 LOSS: 41.17696305463062\n",
      "EPOCH: 1385 LOSS: 41.176854099683\n",
      "EPOCH: 1386 LOSS: 41.17674536328441\n",
      "EPOCH: 1387 LOSS: 41.176636844707566\n",
      "EPOCH: 1388 LOSS: 41.17652854322831\n",
      "EPOCH: 1389 LOSS: 41.176420458125534\n",
      "EPOCH: 1390 LOSS: 41.17631258868122\n",
      "EPOCH: 1391 LOSS: 41.17620493418033\n",
      "EPOCH: 1392 LOSS: 41.17609749391089\n",
      "EPOCH: 1393 LOSS: 41.175990267163954\n",
      "EPOCH: 1394 LOSS: 41.17588325323349\n",
      "EPOCH: 1395 LOSS: 41.17577645141656\n",
      "EPOCH: 1396 LOSS: 41.175669861013084\n",
      "EPOCH: 1397 LOSS: 41.17556348132599\n",
      "EPOCH: 1398 LOSS: 41.17545731166112\n",
      "EPOCH: 1399 LOSS: 41.175351351327244\n",
      "EPOCH: 1400 LOSS: 41.17524559963603\n",
      "EPOCH: 1401 LOSS: 41.175140055902034\n",
      "EPOCH: 1402 LOSS: 41.175034719442685\n",
      "EPOCH: 1403 LOSS: 41.17492958957829\n",
      "EPOCH: 1404 LOSS: 41.17482466563199\n",
      "EPOCH: 1405 LOSS: 41.174719946929734\n",
      "EPOCH: 1406 LOSS: 41.17461543280033\n",
      "EPOCH: 1407 LOSS: 41.174511122575375\n",
      "EPOCH: 1408 LOSS: 41.17440701558925\n",
      "EPOCH: 1409 LOSS: 41.17430311117912\n",
      "EPOCH: 1410 LOSS: 41.17419940868489\n",
      "EPOCH: 1411 LOSS: 41.17409590744924\n",
      "EPOCH: 1412 LOSS: 41.173992606817585\n",
      "EPOCH: 1413 LOSS: 41.17388950613803\n",
      "EPOCH: 1414 LOSS: 41.17378660476141\n",
      "EPOCH: 1415 LOSS: 41.17368390204127\n",
      "EPOCH: 1416 LOSS: 41.1735813973338\n",
      "EPOCH: 1417 LOSS: 41.17347908999786\n",
      "EPOCH: 1418 LOSS: 41.173376979395016\n",
      "EPOCH: 1419 LOSS: 41.17327506488941\n",
      "EPOCH: 1420 LOSS: 41.17317334584782\n",
      "EPOCH: 1421 LOSS: 41.17307182163968\n",
      "EPOCH: 1422 LOSS: 41.172970491637\n",
      "EPOCH: 1423 LOSS: 41.17286935521439\n",
      "EPOCH: 1424 LOSS: 41.17276841174899\n",
      "EPOCH: 1425 LOSS: 41.172667660620576\n",
      "EPOCH: 1426 LOSS: 41.1725671012114\n",
      "EPOCH: 1427 LOSS: 41.17246673290632\n",
      "EPOCH: 1428 LOSS: 41.17236655509269\n",
      "EPOCH: 1429 LOSS: 41.172266567160335\n",
      "EPOCH: 1430 LOSS: 41.17216676850166\n",
      "EPOCH: 1431 LOSS: 41.17206715851151\n",
      "EPOCH: 1432 LOSS: 41.17196773658722\n",
      "EPOCH: 1433 LOSS: 41.17186850212857\n",
      "EPOCH: 1434 LOSS: 41.17176945453781\n",
      "EPOCH: 1435 LOSS: 41.17167059321964\n",
      "EPOCH: 1436 LOSS: 41.171571917581154\n",
      "EPOCH: 1437 LOSS: 41.1714734270319\n",
      "EPOCH: 1438 LOSS: 41.17137512098379\n",
      "EPOCH: 1439 LOSS: 41.17127699885117\n",
      "EPOCH: 1440 LOSS: 41.171179060050726\n",
      "EPOCH: 1441 LOSS: 41.17108130400156\n",
      "EPOCH: 1442 LOSS: 41.170983730125094\n",
      "EPOCH: 1443 LOSS: 41.17088633784509\n",
      "EPOCH: 1444 LOSS: 41.17078912658769\n",
      "EPOCH: 1445 LOSS: 41.17069209578133\n",
      "EPOCH: 1446 LOSS: 41.17059524485674\n",
      "EPOCH: 1447 LOSS: 41.17049857324696\n",
      "EPOCH: 1448 LOSS: 41.17040208038737\n",
      "EPOCH: 1449 LOSS: 41.17030576571554\n",
      "EPOCH: 1450 LOSS: 41.17020962867141\n",
      "EPOCH: 1451 LOSS: 41.17011366869708\n",
      "EPOCH: 1452 LOSS: 41.17001788523694\n",
      "EPOCH: 1453 LOSS: 41.16992227773763\n",
      "EPOCH: 1454 LOSS: 41.169826845648\n",
      "EPOCH: 1455 LOSS: 41.16973158841909\n",
      "EPOCH: 1456 LOSS: 41.16963650550416\n",
      "EPOCH: 1457 LOSS: 41.16954159635868\n",
      "EPOCH: 1458 LOSS: 41.16944686044027\n",
      "EPOCH: 1459 LOSS: 41.16935229720873\n",
      "EPOCH: 1460 LOSS: 41.16925790612605\n",
      "EPOCH: 1461 LOSS: 41.169163686656326\n",
      "EPOCH: 1462 LOSS: 41.16906963826582\n",
      "EPOCH: 1463 LOSS: 41.168975760422896\n",
      "EPOCH: 1464 LOSS: 41.16888205259809\n",
      "EPOCH: 1465 LOSS: 41.16878851426401\n",
      "EPOCH: 1466 LOSS: 41.16869514489534\n",
      "EPOCH: 1467 LOSS: 41.1686019439689\n",
      "EPOCH: 1468 LOSS: 41.16850891096356\n",
      "EPOCH: 1469 LOSS: 41.168416045360274\n",
      "EPOCH: 1470 LOSS: 41.16832334664205\n",
      "EPOCH: 1471 LOSS: 41.168230814293935\n",
      "EPOCH: 1472 LOSS: 41.16813844780303\n",
      "EPOCH: 1473 LOSS: 41.168046246658456\n",
      "EPOCH: 1474 LOSS: 41.16795421035137\n",
      "EPOCH: 1475 LOSS: 41.16786233837491\n",
      "EPOCH: 1476 LOSS: 41.16777063022424\n",
      "EPOCH: 1477 LOSS: 41.16767908539651\n",
      "EPOCH: 1478 LOSS: 41.16758770339084\n",
      "EPOCH: 1479 LOSS: 41.167496483708334\n",
      "EPOCH: 1480 LOSS: 41.16740542585207\n",
      "EPOCH: 1481 LOSS: 41.16731452932706\n",
      "EPOCH: 1482 LOSS: 41.167223793640275\n",
      "EPOCH: 1483 LOSS: 41.167133218300584\n",
      "EPOCH: 1484 LOSS: 41.16704280281885\n",
      "EPOCH: 1485 LOSS: 41.16695254670778\n",
      "EPOCH: 1486 LOSS: 41.16686244948205\n",
      "EPOCH: 1487 LOSS: 41.166772510658205\n",
      "EPOCH: 1488 LOSS: 41.16668272975468\n",
      "EPOCH: 1489 LOSS: 41.16659310629181\n",
      "EPOCH: 1490 LOSS: 41.16650363979177\n",
      "EPOCH: 1491 LOSS: 41.16641432977863\n",
      "EPOCH: 1492 LOSS: 41.16632517577829\n",
      "EPOCH: 1493 LOSS: 41.166236177318524\n",
      "EPOCH: 1494 LOSS: 41.16614733392891\n",
      "EPOCH: 1495 LOSS: 41.16605864514089\n",
      "EPOCH: 1496 LOSS: 41.165970110487706\n",
      "EPOCH: 1497 LOSS: 41.165881729504406\n",
      "EPOCH: 1498 LOSS: 41.165793501727876\n",
      "EPOCH: 1499 LOSS: 41.165705426696746\n",
      "EPOCH: 1500 LOSS: 41.16561750395145\n",
      "EPOCH: 1501 LOSS: 41.165529733034255\n",
      "EPOCH: 1502 LOSS: 41.165442113489085\n",
      "EPOCH: 1503 LOSS: 41.16535464486175\n",
      "EPOCH: 1504 LOSS: 41.16526732669975\n",
      "EPOCH: 1505 LOSS: 41.16518015855229\n",
      "EPOCH: 1506 LOSS: 41.16509313997042\n",
      "EPOCH: 1507 LOSS: 41.16500627050682\n",
      "EPOCH: 1508 LOSS: 41.16491954971595\n",
      "EPOCH: 1509 LOSS: 41.16483297715392\n",
      "EPOCH: 1510 LOSS: 41.164746552378645\n",
      "EPOCH: 1511 LOSS: 41.16466027494964\n",
      "EPOCH: 1512 LOSS: 41.164574144428165\n",
      "EPOCH: 1513 LOSS: 41.16448816037714\n",
      "EPOCH: 1514 LOSS: 41.1644023223612\n",
      "EPOCH: 1515 LOSS: 41.16431662994655\n",
      "EPOCH: 1516 LOSS: 41.16423108270116\n",
      "EPOCH: 1517 LOSS: 41.16414568019461\n",
      "EPOCH: 1518 LOSS: 41.16406042199807\n",
      "EPOCH: 1519 LOSS: 41.16397530768447\n",
      "EPOCH: 1520 LOSS: 41.16389033682821\n",
      "EPOCH: 1521 LOSS: 41.163805509005456\n",
      "EPOCH: 1522 LOSS: 41.163720823793916\n",
      "EPOCH: 1523 LOSS: 41.163636280772884\n",
      "EPOCH: 1524 LOSS: 41.16355187952333\n",
      "EPOCH: 1525 LOSS: 41.16346761962773\n",
      "EPOCH: 1526 LOSS: 41.16338350067018\n",
      "EPOCH: 1527 LOSS: 41.16329952223637\n",
      "EPOCH: 1528 LOSS: 41.16321568391355\n",
      "EPOCH: 1529 LOSS: 41.163131985290505\n",
      "EPOCH: 1530 LOSS: 41.16304842595761\n",
      "EPOCH: 1531 LOSS: 41.162965005506784\n",
      "EPOCH: 1532 LOSS: 41.16288172353145\n",
      "EPOCH: 1533 LOSS: 41.16279857962661\n",
      "EPOCH: 1534 LOSS: 41.16271557338878\n",
      "EPOCH: 1535 LOSS: 41.16263270441597\n",
      "EPOCH: 1536 LOSS: 41.16254997230775\n",
      "EPOCH: 1537 LOSS: 41.16246737666517\n",
      "EPOCH: 1538 LOSS: 41.16238491709076\n",
      "EPOCH: 1539 LOSS: 41.162302593188585\n",
      "EPOCH: 1540 LOSS: 41.16222040456417\n",
      "EPOCH: 1541 LOSS: 41.162138350824506\n",
      "EPOCH: 1542 LOSS: 41.1620564315781\n",
      "EPOCH: 1543 LOSS: 41.161974646434885\n",
      "EPOCH: 1544 LOSS: 41.161892995006276\n",
      "EPOCH: 1545 LOSS: 41.16181147690513\n",
      "EPOCH: 1546 LOSS: 41.16173009174574\n",
      "EPOCH: 1547 LOSS: 41.161648839143865\n",
      "EPOCH: 1548 LOSS: 41.16156771871668\n",
      "EPOCH: 1549 LOSS: 41.16148673008279\n",
      "EPOCH: 1550 LOSS: 41.16140587286223\n",
      "EPOCH: 1551 LOSS: 41.161325146676425\n",
      "EPOCH: 1552 LOSS: 41.16124455114824\n",
      "EPOCH: 1553 LOSS: 41.16116408590191\n",
      "EPOCH: 1554 LOSS: 41.16108375056307\n",
      "EPOCH: 1555 LOSS: 41.16100354475878\n",
      "EPOCH: 1556 LOSS: 41.16092346811743\n",
      "EPOCH: 1557 LOSS: 41.16084352026881\n",
      "EPOCH: 1558 LOSS: 41.16076370084411\n",
      "EPOCH: 1559 LOSS: 41.16068400947582\n",
      "EPOCH: 1560 LOSS: 41.160604445797844\n",
      "EPOCH: 1561 LOSS: 41.1605250094454\n",
      "EPOCH: 1562 LOSS: 41.1604457000551\n",
      "EPOCH: 1563 LOSS: 41.160366517264855\n",
      "EPOCH: 1564 LOSS: 41.1602874607139\n",
      "EPOCH: 1565 LOSS: 41.16020853004284\n",
      "EPOCH: 1566 LOSS: 41.16012972489356\n",
      "EPOCH: 1567 LOSS: 41.160051044909295\n",
      "EPOCH: 1568 LOSS: 41.159972489734585\n",
      "EPOCH: 1569 LOSS: 41.159894059015244\n",
      "EPOCH: 1570 LOSS: 41.15981575239844\n",
      "EPOCH: 1571 LOSS: 41.159737569532574\n",
      "EPOCH: 1572 LOSS: 41.159659510067364\n",
      "EPOCH: 1573 LOSS: 41.15958157365384\n",
      "EPOCH: 1574 LOSS: 41.15950375994423\n",
      "EPOCH: 1575 LOSS: 41.15942606859211\n",
      "EPOCH: 1576 LOSS: 41.15934849925229\n",
      "EPOCH: 1577 LOSS: 41.15927105158081\n",
      "EPOCH: 1578 LOSS: 41.15919372523503\n",
      "EPOCH: 1579 LOSS: 41.15911651987349\n",
      "EPOCH: 1580 LOSS: 41.15903943515601\n",
      "EPOCH: 1581 LOSS: 41.15896247074365\n",
      "EPOCH: 1582 LOSS: 41.15888562629871\n",
      "EPOCH: 1583 LOSS: 41.15880890148465\n",
      "EPOCH: 1584 LOSS: 41.15873229596624\n",
      "EPOCH: 1585 LOSS: 41.1586558094094\n",
      "EPOCH: 1586 LOSS: 41.15857944148131\n",
      "EPOCH: 1587 LOSS: 41.158503191850315\n",
      "EPOCH: 1588 LOSS: 41.15842706018597\n",
      "EPOCH: 1589 LOSS: 41.158351046159055\n",
      "EPOCH: 1590 LOSS: 41.158275149441494\n",
      "EPOCH: 1591 LOSS: 41.15819936970642\n",
      "EPOCH: 1592 LOSS: 41.15812370662814\n",
      "EPOCH: 1593 LOSS: 41.15804815988214\n",
      "EPOCH: 1594 LOSS: 41.15797272914507\n",
      "EPOCH: 1595 LOSS: 41.15789741409474\n",
      "EPOCH: 1596 LOSS: 41.15782221441013\n",
      "EPOCH: 1597 LOSS: 41.15774712977137\n",
      "EPOCH: 1598 LOSS: 41.15767215985973\n",
      "EPOCH: 1599 LOSS: 41.15759730435761\n",
      "EPOCH: 1600 LOSS: 41.157522562948586\n",
      "EPOCH: 1601 LOSS: 41.15744793531736\n",
      "EPOCH: 1602 LOSS: 41.15737342114972\n",
      "EPOCH: 1603 LOSS: 41.15729902013264\n",
      "EPOCH: 1604 LOSS: 41.157224731954166\n",
      "EPOCH: 1605 LOSS: 41.15715055630349\n",
      "EPOCH: 1606 LOSS: 41.15707649287089\n",
      "EPOCH: 1607 LOSS: 41.157002541347765\n",
      "EPOCH: 1608 LOSS: 41.15692870142659\n",
      "EPOCH: 1609 LOSS: 41.156854972800964\n",
      "EPOCH: 1610 LOSS: 41.15678135516556\n",
      "EPOCH: 1611 LOSS: 41.15670784821615\n",
      "EPOCH: 1612 LOSS: 41.15663445164957\n",
      "EPOCH: 1613 LOSS: 41.15656116516374\n",
      "EPOCH: 1614 LOSS: 41.156487988457656\n",
      "EPOCH: 1615 LOSS: 41.15641492123138\n",
      "EPOCH: 1616 LOSS: 41.156341963186016\n",
      "EPOCH: 1617 LOSS: 41.15626911402377\n",
      "EPOCH: 1618 LOSS: 41.15619637344787\n",
      "EPOCH: 1619 LOSS: 41.156123741162595\n",
      "EPOCH: 1620 LOSS: 41.15605121687327\n",
      "EPOCH: 1621 LOSS: 41.15597880028629\n",
      "EPOCH: 1622 LOSS: 41.155906491109\n",
      "EPOCH: 1623 LOSS: 41.15583428904991\n",
      "EPOCH: 1624 LOSS: 41.155762193818425\n",
      "EPOCH: 1625 LOSS: 41.15569020512506\n",
      "EPOCH: 1626 LOSS: 41.15561832268131\n",
      "EPOCH: 1627 LOSS: 41.1555465461997\n",
      "EPOCH: 1628 LOSS: 41.15547487539375\n",
      "EPOCH: 1629 LOSS: 41.155403309977984\n",
      "EPOCH: 1630 LOSS: 41.155331849667945\n",
      "EPOCH: 1631 LOSS: 41.155260494180176\n",
      "EPOCH: 1632 LOSS: 41.155189243232186\n",
      "EPOCH: 1633 LOSS: 41.155118096542495\n",
      "EPOCH: 1634 LOSS: 41.155047053830586\n",
      "EPOCH: 1635 LOSS: 41.154976114816925\n",
      "EPOCH: 1636 LOSS: 41.15490527922299\n",
      "EPOCH: 1637 LOSS: 41.154834546771205\n",
      "EPOCH: 1638 LOSS: 41.15476391718496\n",
      "EPOCH: 1639 LOSS: 41.154693390188584\n",
      "EPOCH: 1640 LOSS: 41.15462296550743\n",
      "EPOCH: 1641 LOSS: 41.15455264286774\n",
      "EPOCH: 1642 LOSS: 41.15448242199676\n",
      "EPOCH: 1643 LOSS: 41.15441230262263\n",
      "EPOCH: 1644 LOSS: 41.154342284474495\n",
      "EPOCH: 1645 LOSS: 41.15427236728238\n",
      "EPOCH: 1646 LOSS: 41.1542025507773\n",
      "EPOCH: 1647 LOSS: 41.154132834691154\n",
      "EPOCH: 1648 LOSS: 41.15406321875681\n",
      "EPOCH: 1649 LOSS: 41.15399370270803\n",
      "EPOCH: 1650 LOSS: 41.15392428627949\n",
      "EPOCH: 1651 LOSS: 41.15385496920683\n",
      "EPOCH: 1652 LOSS: 41.15378575122656\n",
      "EPOCH: 1653 LOSS: 41.15371663207611\n",
      "EPOCH: 1654 LOSS: 41.15364761149381\n",
      "EPOCH: 1655 LOSS: 41.153578689218904\n",
      "EPOCH: 1656 LOSS: 41.15350986499153\n",
      "EPOCH: 1657 LOSS: 41.153441138552694\n",
      "EPOCH: 1658 LOSS: 41.15337250964433\n",
      "EPOCH: 1659 LOSS: 41.15330397800925\n",
      "EPOCH: 1660 LOSS: 41.153235543391105\n",
      "EPOCH: 1661 LOSS: 41.153167205534515\n",
      "EPOCH: 1662 LOSS: 41.15309896418488\n",
      "EPOCH: 1663 LOSS: 41.153030819088514\n",
      "EPOCH: 1664 LOSS: 41.15296276999262\n",
      "EPOCH: 1665 LOSS: 41.15289481664522\n",
      "EPOCH: 1666 LOSS: 41.15282695879523\n",
      "EPOCH: 1667 LOSS: 41.15275919619242\n",
      "EPOCH: 1668 LOSS: 41.1526915285874\n",
      "EPOCH: 1669 LOSS: 41.15262395573161\n",
      "EPOCH: 1670 LOSS: 41.152556477377416\n",
      "EPOCH: 1671 LOSS: 41.15248909327794\n",
      "EPOCH: 1672 LOSS: 41.1524218031872\n",
      "EPOCH: 1673 LOSS: 41.152354606860015\n",
      "EPOCH: 1674 LOSS: 41.15228750405204\n",
      "EPOCH: 1675 LOSS: 41.15222049451979\n",
      "EPOCH: 1676 LOSS: 41.15215357802059\n",
      "EPOCH: 1677 LOSS: 41.15208675431256\n",
      "EPOCH: 1678 LOSS: 41.15202002315472\n",
      "EPOCH: 1679 LOSS: 41.15195338430678\n",
      "EPOCH: 1680 LOSS: 41.15188683752936\n",
      "EPOCH: 1681 LOSS: 41.151820382583864\n",
      "EPOCH: 1682 LOSS: 41.151754019232534\n",
      "EPOCH: 1683 LOSS: 41.15168774723833\n",
      "EPOCH: 1684 LOSS: 41.15162156636509\n",
      "EPOCH: 1685 LOSS: 41.15155547637741\n",
      "EPOCH: 1686 LOSS: 41.15148947704069\n",
      "EPOCH: 1687 LOSS: 41.15142356812112\n",
      "EPOCH: 1688 LOSS: 41.15135774938568\n",
      "EPOCH: 1689 LOSS: 41.15129202060215\n",
      "EPOCH: 1690 LOSS: 41.151226381539026\n",
      "EPOCH: 1691 LOSS: 41.151160831965655\n",
      "EPOCH: 1692 LOSS: 41.151095371652104\n",
      "EPOCH: 1693 LOSS: 41.151030000369275\n",
      "EPOCH: 1694 LOSS: 41.150964717888755\n",
      "EPOCH: 1695 LOSS: 41.150899523982964\n",
      "EPOCH: 1696 LOSS: 41.15083441842502\n",
      "EPOCH: 1697 LOSS: 41.15076940098889\n",
      "EPOCH: 1698 LOSS: 41.15070447144922\n",
      "EPOCH: 1699 LOSS: 41.150639629581406\n",
      "EPOCH: 1700 LOSS: 41.15057487516165\n",
      "EPOCH: 1701 LOSS: 41.150510207966846\n",
      "EPOCH: 1702 LOSS: 41.150445627774666\n",
      "EPOCH: 1703 LOSS: 41.1503811343635\n",
      "EPOCH: 1704 LOSS: 41.150316727512504\n",
      "EPOCH: 1705 LOSS: 41.1502524070015\n",
      "EPOCH: 1706 LOSS: 41.150188172611166\n",
      "EPOCH: 1707 LOSS: 41.150124024122775\n",
      "EPOCH: 1708 LOSS: 41.15005996131838\n",
      "EPOCH: 1709 LOSS: 41.149995983980794\n",
      "EPOCH: 1710 LOSS: 41.1499320918935\n",
      "EPOCH: 1711 LOSS: 41.14986828484069\n",
      "EPOCH: 1712 LOSS: 41.14980456260733\n",
      "EPOCH: 1713 LOSS: 41.14974092497903\n",
      "EPOCH: 1714 LOSS: 41.14967737174217\n",
      "EPOCH: 1715 LOSS: 41.149613902683754\n",
      "EPOCH: 1716 LOSS: 41.14955051759157\n",
      "EPOCH: 1717 LOSS: 41.14948721625408\n",
      "EPOCH: 1718 LOSS: 41.14942399846042\n",
      "EPOCH: 1719 LOSS: 41.149360864000414\n",
      "EPOCH: 1720 LOSS: 41.14929781266467\n",
      "EPOCH: 1721 LOSS: 41.14923484424435\n",
      "EPOCH: 1722 LOSS: 41.149171958531376\n",
      "EPOCH: 1723 LOSS: 41.14910915531836\n",
      "EPOCH: 1724 LOSS: 41.14904643439857\n",
      "EPOCH: 1725 LOSS: 41.14898379556597\n",
      "EPOCH: 1726 LOSS: 41.14892123861516\n",
      "EPOCH: 1727 LOSS: 41.14885876334148\n",
      "EPOCH: 1728 LOSS: 41.148796369540875\n",
      "EPOCH: 1729 LOSS: 41.14873405700998\n",
      "EPOCH: 1730 LOSS: 41.14867182554612\n",
      "EPOCH: 1731 LOSS: 41.14860967494723\n",
      "EPOCH: 1732 LOSS: 41.14854760501197\n",
      "EPOCH: 1733 LOSS: 41.148485615539585\n",
      "EPOCH: 1734 LOSS: 41.148423706330036\n",
      "EPOCH: 1735 LOSS: 41.1483618771839\n",
      "EPOCH: 1736 LOSS: 41.1483001279024\n",
      "EPOCH: 1737 LOSS: 41.14823845828741\n",
      "EPOCH: 1738 LOSS: 41.148176868141505\n",
      "EPOCH: 1739 LOSS: 41.1481153572678\n",
      "EPOCH: 1740 LOSS: 41.14805392547012\n",
      "EPOCH: 1741 LOSS: 41.147992572552894\n",
      "EPOCH: 1742 LOSS: 41.147931298321225\n",
      "EPOCH: 1743 LOSS: 41.14787010258081\n",
      "EPOCH: 1744 LOSS: 41.14780898513795\n",
      "EPOCH: 1745 LOSS: 41.14774794579964\n",
      "EPOCH: 1746 LOSS: 41.14768698437346\n",
      "EPOCH: 1747 LOSS: 41.14762610066762\n",
      "EPOCH: 1748 LOSS: 41.147565294490946\n",
      "EPOCH: 1749 LOSS: 41.14750456565286\n",
      "EPOCH: 1750 LOSS: 41.14744391396344\n",
      "EPOCH: 1751 LOSS: 41.14738333923337\n",
      "EPOCH: 1752 LOSS: 41.14732284127389\n",
      "EPOCH: 1753 LOSS: 41.147262419896904\n",
      "EPOCH: 1754 LOSS: 41.147202074914915\n",
      "EPOCH: 1755 LOSS: 41.14714180614099\n",
      "EPOCH: 1756 LOSS: 41.14708161338885\n",
      "EPOCH: 1757 LOSS: 41.14702149647277\n",
      "EPOCH: 1758 LOSS: 41.146961455207624\n",
      "EPOCH: 1759 LOSS: 41.1469014894089\n",
      "EPOCH: 1760 LOSS: 41.146841598892685\n",
      "EPOCH: 1761 LOSS: 41.14678178347562\n",
      "EPOCH: 1762 LOSS: 41.14672204297494\n",
      "EPOCH: 1763 LOSS: 41.14666237720851\n",
      "EPOCH: 1764 LOSS: 41.146602785994695\n",
      "EPOCH: 1765 LOSS: 41.14654326915251\n",
      "EPOCH: 1766 LOSS: 41.14648382650153\n",
      "EPOCH: 1767 LOSS: 41.14642445786188\n",
      "EPOCH: 1768 LOSS: 41.14636516305427\n",
      "EPOCH: 1769 LOSS: 41.1463059419\n",
      "EPOCH: 1770 LOSS: 41.14624679422093\n",
      "EPOCH: 1771 LOSS: 41.14618771983946\n",
      "EPOCH: 1772 LOSS: 41.146128718578595\n",
      "EPOCH: 1773 LOSS: 41.14606979026186\n",
      "EPOCH: 1774 LOSS: 41.14601093471336\n",
      "EPOCH: 1775 LOSS: 41.14595215175777\n",
      "EPOCH: 1776 LOSS: 41.145893441220316\n",
      "EPOCH: 1777 LOSS: 41.14583480292675\n",
      "EPOCH: 1778 LOSS: 41.14577623670341\n",
      "EPOCH: 1779 LOSS: 41.14571774237717\n",
      "EPOCH: 1780 LOSS: 41.14565931977545\n",
      "EPOCH: 1781 LOSS: 41.145600968726185\n",
      "EPOCH: 1782 LOSS: 41.14554268905793\n",
      "EPOCH: 1783 LOSS: 41.14548448059969\n",
      "EPOCH: 1784 LOSS: 41.145426343181065\n",
      "EPOCH: 1785 LOSS: 41.1453682766322\n",
      "EPOCH: 1786 LOSS: 41.145310280783725\n",
      "EPOCH: 1787 LOSS: 41.14525235546684\n",
      "EPOCH: 1788 LOSS: 41.14519450051326\n",
      "EPOCH: 1789 LOSS: 41.14513671575526\n",
      "EPOCH: 1790 LOSS: 41.14507900102558\n",
      "EPOCH: 1791 LOSS: 41.14502135615753\n",
      "EPOCH: 1792 LOSS: 41.14496378098495\n",
      "EPOCH: 1793 LOSS: 41.14490627534217\n",
      "EPOCH: 1794 LOSS: 41.14484883906405\n",
      "EPOCH: 1795 LOSS: 41.14479147198597\n",
      "EPOCH: 1796 LOSS: 41.144734173943846\n",
      "EPOCH: 1797 LOSS: 41.144676944774055\n",
      "EPOCH: 1798 LOSS: 41.14461978431352\n",
      "EPOCH: 1799 LOSS: 41.144562692399674\n",
      "EPOCH: 1800 LOSS: 41.14450566887045\n",
      "EPOCH: 1801 LOSS: 41.14444871356429\n",
      "EPOCH: 1802 LOSS: 41.14439182632011\n",
      "EPOCH: 1803 LOSS: 41.14433500697739\n",
      "EPOCH: 1804 LOSS: 41.14427825537604\n",
      "EPOCH: 1805 LOSS: 41.144221571356496\n",
      "EPOCH: 1806 LOSS: 41.14416495475972\n",
      "EPOCH: 1807 LOSS: 41.14410840542715\n",
      "EPOCH: 1808 LOSS: 41.144051923200635\n",
      "EPOCH: 1809 LOSS: 41.14399550792267\n",
      "EPOCH: 1810 LOSS: 41.143939159436094\n",
      "EPOCH: 1811 LOSS: 41.14388287758434\n",
      "EPOCH: 1812 LOSS: 41.14382666221124\n",
      "EPOCH: 1813 LOSS: 41.14377051316115\n",
      "EPOCH: 1814 LOSS: 41.14371443027892\n",
      "EPOCH: 1815 LOSS: 41.14365841340985\n",
      "EPOCH: 1816 LOSS: 41.14360246239975\n",
      "EPOCH: 1817 LOSS: 41.14354657709485\n",
      "EPOCH: 1818 LOSS: 41.14349075734192\n",
      "EPOCH: 1819 LOSS: 41.14343500298815\n",
      "EPOCH: 1820 LOSS: 41.14337931388124\n",
      "EPOCH: 1821 LOSS: 41.14332368986932\n",
      "EPOCH: 1822 LOSS: 41.14326813080103\n",
      "EPOCH: 1823 LOSS: 41.14321263652543\n",
      "EPOCH: 1824 LOSS: 41.14315720689208\n",
      "EPOCH: 1825 LOSS: 41.143101841750976\n",
      "EPOCH: 1826 LOSS: 41.14304654095259\n",
      "EPOCH: 1827 LOSS: 41.14299130434787\n",
      "EPOCH: 1828 LOSS: 41.142936131788154\n",
      "EPOCH: 1829 LOSS: 41.1428810231253\n",
      "EPOCH: 1830 LOSS: 41.142825978211604\n",
      "EPOCH: 1831 LOSS: 41.142770996899785\n",
      "EPOCH: 1832 LOSS: 41.14271607904306\n",
      "EPOCH: 1833 LOSS: 41.14266122449505\n",
      "EPOCH: 1834 LOSS: 41.142606433109854\n",
      "EPOCH: 1835 LOSS: 41.14255170474199\n",
      "EPOCH: 1836 LOSS: 41.14249703924644\n",
      "EPOCH: 1837 LOSS: 41.1424424364786\n",
      "EPOCH: 1838 LOSS: 41.14238789629435\n",
      "EPOCH: 1839 LOSS: 41.14233341854998\n",
      "EPOCH: 1840 LOSS: 41.1422790031022\n",
      "EPOCH: 1841 LOSS: 41.14222464980819\n",
      "EPOCH: 1842 LOSS: 41.14217035852556\n",
      "EPOCH: 1843 LOSS: 41.142116129112296\n",
      "EPOCH: 1844 LOSS: 41.14206196142692\n",
      "EPOCH: 1845 LOSS: 41.14200785532827\n",
      "EPOCH: 1846 LOSS: 41.141953810675695\n",
      "EPOCH: 1847 LOSS: 41.14189982732892\n",
      "EPOCH: 1848 LOSS: 41.14184590514812\n",
      "EPOCH: 1849 LOSS: 41.141792043993874\n",
      "EPOCH: 1850 LOSS: 41.141738243727204\n",
      "EPOCH: 1851 LOSS: 41.14168450420952\n",
      "EPOCH: 1852 LOSS: 41.14163082530271\n",
      "EPOCH: 1853 LOSS: 41.14157720686899\n",
      "EPOCH: 1854 LOSS: 41.14152364877106\n",
      "EPOCH: 1855 LOSS: 41.14147015087202\n",
      "EPOCH: 1856 LOSS: 41.14141671303537\n",
      "EPOCH: 1857 LOSS: 41.141363335125014\n",
      "EPOCH: 1858 LOSS: 41.141310017005274\n",
      "EPOCH: 1859 LOSS: 41.14125675854088\n",
      "EPOCH: 1860 LOSS: 41.141203559596995\n",
      "EPOCH: 1861 LOSS: 41.14115042003912\n",
      "EPOCH: 1862 LOSS: 41.14109733973322\n",
      "EPOCH: 1863 LOSS: 41.141044318545646\n",
      "EPOCH: 1864 LOSS: 41.14099135634313\n",
      "EPOCH: 1865 LOSS: 41.14093845299282\n",
      "EPOCH: 1866 LOSS: 41.140885608362254\n",
      "EPOCH: 1867 LOSS: 41.140832822319375\n",
      "EPOCH: 1868 LOSS: 41.140780094732534\n",
      "EPOCH: 1869 LOSS: 41.1407274254704\n",
      "EPOCH: 1870 LOSS: 41.14067481440213\n",
      "EPOCH: 1871 LOSS: 41.14062226139725\n",
      "EPOCH: 1872 LOSS: 41.14056976632557\n",
      "EPOCH: 1873 LOSS: 41.14051732905746\n",
      "EPOCH: 1874 LOSS: 41.14046494946355\n",
      "EPOCH: 1875 LOSS: 41.14041262741488\n",
      "EPOCH: 1876 LOSS: 41.140360362782914\n",
      "EPOCH: 1877 LOSS: 41.140308155439456\n",
      "EPOCH: 1878 LOSS: 41.14025600525668\n",
      "EPOCH: 1879 LOSS: 41.14020391210721\n",
      "EPOCH: 1880 LOSS: 41.14015187586394\n",
      "EPOCH: 1881 LOSS: 41.14009989640026\n",
      "EPOCH: 1882 LOSS: 41.14004797358984\n",
      "EPOCH: 1883 LOSS: 41.13999610730674\n",
      "EPOCH: 1884 LOSS: 41.13994429742545\n",
      "EPOCH: 1885 LOSS: 41.139892543820785\n",
      "EPOCH: 1886 LOSS: 41.13984084636791\n",
      "EPOCH: 1887 LOSS: 41.1397892049424\n",
      "EPOCH: 1888 LOSS: 41.13973761942019\n",
      "EPOCH: 1889 LOSS: 41.13968608967756\n",
      "EPOCH: 1890 LOSS: 41.13963461559118\n",
      "EPOCH: 1891 LOSS: 41.139583197038036\n",
      "EPOCH: 1892 LOSS: 41.13953183389554\n",
      "EPOCH: 1893 LOSS: 41.13948052604144\n",
      "EPOCH: 1894 LOSS: 41.139429273353805\n",
      "EPOCH: 1895 LOSS: 41.13937807571112\n",
      "EPOCH: 1896 LOSS: 41.13932693299216\n",
      "EPOCH: 1897 LOSS: 41.139275845076156\n",
      "EPOCH: 1898 LOSS: 41.139224811842595\n",
      "EPOCH: 1899 LOSS: 41.139173833171355\n",
      "EPOCH: 1900 LOSS: 41.13912290894269\n",
      "EPOCH: 1901 LOSS: 41.13907203903714\n",
      "EPOCH: 1902 LOSS: 41.13902122333566\n",
      "EPOCH: 1903 LOSS: 41.13897046171952\n",
      "EPOCH: 1904 LOSS: 41.13891975407036\n",
      "EPOCH: 1905 LOSS: 41.13886910027012\n",
      "EPOCH: 1906 LOSS: 41.13881850020112\n",
      "EPOCH: 1907 LOSS: 41.138767953746026\n",
      "EPOCH: 1908 LOSS: 41.13871746078783\n",
      "EPOCH: 1909 LOSS: 41.13866702120987\n",
      "EPOCH: 1910 LOSS: 41.13861663489584\n",
      "EPOCH: 1911 LOSS: 41.138566301729725\n",
      "EPOCH: 1912 LOSS: 41.1385160215959\n",
      "EPOCH: 1913 LOSS: 41.13846579437905\n",
      "EPOCH: 1914 LOSS: 41.13841561996419\n",
      "EPOCH: 1915 LOSS: 41.13836549823669\n",
      "EPOCH: 1916 LOSS: 41.138315429082226\n",
      "EPOCH: 1917 LOSS: 41.13826541238683\n",
      "EPOCH: 1918 LOSS: 41.138215448036846\n",
      "EPOCH: 1919 LOSS: 41.13816553591896\n",
      "EPOCH: 1920 LOSS: 41.13811567592016\n",
      "EPOCH: 1921 LOSS: 41.1380658679278\n",
      "EPOCH: 1922 LOSS: 41.138016111829536\n",
      "EPOCH: 1923 LOSS: 41.13796640751334\n",
      "EPOCH: 1924 LOSS: 41.13791675486752\n",
      "EPOCH: 1925 LOSS: 41.13786715378072\n",
      "EPOCH: 1926 LOSS: 41.13781760414188\n",
      "EPOCH: 1927 LOSS: 41.137768105840266\n",
      "EPOCH: 1928 LOSS: 41.13771865876546\n",
      "EPOCH: 1929 LOSS: 41.13766926280739\n",
      "EPOCH: 1930 LOSS: 41.13761991785624\n",
      "EPOCH: 1931 LOSS: 41.13757062380258\n",
      "EPOCH: 1932 LOSS: 41.137521380537265\n",
      "EPOCH: 1933 LOSS: 41.137472187951424\n",
      "EPOCH: 1934 LOSS: 41.13742304593656\n",
      "EPOCH: 1935 LOSS: 41.13737395438446\n",
      "EPOCH: 1936 LOSS: 41.13732491318719\n",
      "EPOCH: 1937 LOSS: 41.137275922237215\n",
      "EPOCH: 1938 LOSS: 41.13722698142719\n",
      "EPOCH: 1939 LOSS: 41.13717809065017\n",
      "EPOCH: 1940 LOSS: 41.13712924979948\n",
      "EPOCH: 1941 LOSS: 41.13708045876874\n",
      "EPOCH: 1942 LOSS: 41.13703171745188\n",
      "EPOCH: 1943 LOSS: 41.13698302574316\n",
      "EPOCH: 1944 LOSS: 41.136934383537096\n",
      "EPOCH: 1945 LOSS: 41.13688579072854\n",
      "EPOCH: 1946 LOSS: 41.13683724721262\n",
      "EPOCH: 1947 LOSS: 41.136788752884776\n",
      "EPOCH: 1948 LOSS: 41.13674030764074\n",
      "EPOCH: 1949 LOSS: 41.13669191137655\n",
      "EPOCH: 1950 LOSS: 41.136643563988514\n",
      "EPOCH: 1951 LOSS: 41.13659526537327\n",
      "EPOCH: 1952 LOSS: 41.13654701542772\n",
      "EPOCH: 1953 LOSS: 41.136498814049105\n",
      "EPOCH: 1954 LOSS: 41.136450661134866\n",
      "EPOCH: 1955 LOSS: 41.136402556582816\n",
      "EPOCH: 1956 LOSS: 41.13635450029105\n",
      "EPOCH: 1957 LOSS: 41.13630649215787\n",
      "EPOCH: 1958 LOSS: 41.136258532081996\n",
      "EPOCH: 1959 LOSS: 41.136210619962334\n",
      "EPOCH: 1960 LOSS: 41.13616275569812\n",
      "EPOCH: 1961 LOSS: 41.136114939188836\n",
      "EPOCH: 1962 LOSS: 41.136067170334314\n",
      "EPOCH: 1963 LOSS: 41.136019449034585\n",
      "EPOCH: 1964 LOSS: 41.13597177519004\n",
      "EPOCH: 1965 LOSS: 41.13592414870129\n",
      "EPOCH: 1966 LOSS: 41.135876569469254\n",
      "EPOCH: 1967 LOSS: 41.13582903739513\n",
      "EPOCH: 1968 LOSS: 41.1357815523804\n",
      "EPOCH: 1969 LOSS: 41.13573411432677\n",
      "EPOCH: 1970 LOSS: 41.13568672313633\n",
      "EPOCH: 1971 LOSS: 41.13563937871131\n",
      "EPOCH: 1972 LOSS: 41.13559208095434\n",
      "EPOCH: 1973 LOSS: 41.13554482976822\n",
      "EPOCH: 1974 LOSS: 41.1354976250561\n",
      "EPOCH: 1975 LOSS: 41.13545046672135\n",
      "EPOCH: 1976 LOSS: 41.13540335466763\n",
      "EPOCH: 1977 LOSS: 41.135356288798874\n",
      "EPOCH: 1978 LOSS: 41.13530926901926\n",
      "EPOCH: 1979 LOSS: 41.1352622952333\n",
      "EPOCH: 1980 LOSS: 41.13521536734566\n",
      "EPOCH: 1981 LOSS: 41.13516848526138\n",
      "EPOCH: 1982 LOSS: 41.13512164888572\n",
      "EPOCH: 1983 LOSS: 41.135074858124185\n",
      "EPOCH: 1984 LOSS: 41.135028112882566\n",
      "EPOCH: 1985 LOSS: 41.134981413066924\n",
      "EPOCH: 1986 LOSS: 41.134934758583555\n",
      "EPOCH: 1987 LOSS: 41.13488814933905\n",
      "EPOCH: 1988 LOSS: 41.134841585240224\n",
      "EPOCH: 1989 LOSS: 41.13479506619417\n",
      "EPOCH: 1990 LOSS: 41.134748592108245\n",
      "EPOCH: 1991 LOSS: 41.13470216289004\n",
      "EPOCH: 1992 LOSS: 41.134655778447424\n",
      "EPOCH: 1993 LOSS: 41.1346094386885\n",
      "EPOCH: 1994 LOSS: 41.134563143521646\n",
      "EPOCH: 1995 LOSS: 41.13451689285549\n",
      "EPOCH: 1996 LOSS: 41.134470686598895\n",
      "EPOCH: 1997 LOSS: 41.13442452466099\n",
      "EPOCH: 1998 LOSS: 41.13437840695117\n",
      "EPOCH: 1999 LOSS: 41.134332333379064\n",
      "EPOCH: 2000 LOSS: 41.13428630385451\n",
      "EPOCH: 2001 LOSS: 41.13424031828768\n",
      "EPOCH: 2002 LOSS: 41.13419437658892\n",
      "EPOCH: 2003 LOSS: 41.13414847866886\n",
      "EPOCH: 2004 LOSS: 41.13410262443837\n",
      "EPOCH: 2005 LOSS: 41.13405681380856\n",
      "EPOCH: 2006 LOSS: 41.13401104669078\n",
      "EPOCH: 2007 LOSS: 41.13396532299664\n",
      "EPOCH: 2008 LOSS: 41.13391964263795\n",
      "EPOCH: 2009 LOSS: 41.13387400552685\n",
      "EPOCH: 2010 LOSS: 41.13382841157561\n",
      "EPOCH: 2011 LOSS: 41.13378286069682\n",
      "EPOCH: 2012 LOSS: 41.13373735280329\n",
      "EPOCH: 2013 LOSS: 41.133691887808055\n",
      "EPOCH: 2014 LOSS: 41.133646465624395\n",
      "EPOCH: 2015 LOSS: 41.13360108616583\n",
      "EPOCH: 2016 LOSS: 41.133555749346115\n",
      "EPOCH: 2017 LOSS: 41.13351045507924\n",
      "EPOCH: 2018 LOSS: 41.13346520327943\n",
      "EPOCH: 2019 LOSS: 41.13341999386115\n",
      "EPOCH: 2020 LOSS: 41.13337482673909\n",
      "EPOCH: 2021 LOSS: 41.13332970182816\n",
      "EPOCH: 2022 LOSS: 41.13328461904352\n",
      "EPOCH: 2023 LOSS: 41.133239578300575\n",
      "EPOCH: 2024 LOSS: 41.133194579514935\n",
      "EPOCH: 2025 LOSS: 41.13314962260243\n",
      "EPOCH: 2026 LOSS: 41.13310470747916\n",
      "EPOCH: 2027 LOSS: 41.13305983406143\n",
      "EPOCH: 2028 LOSS: 41.13301500226575\n",
      "EPOCH: 2029 LOSS: 41.132970212008864\n",
      "EPOCH: 2030 LOSS: 41.132925463207805\n",
      "EPOCH: 2031 LOSS: 41.13288075577973\n",
      "EPOCH: 2032 LOSS: 41.13283608964211\n",
      "EPOCH: 2033 LOSS: 41.132791464712575\n",
      "EPOCH: 2034 LOSS: 41.13274688090901\n",
      "EPOCH: 2035 LOSS: 41.132702338149514\n",
      "EPOCH: 2036 LOSS: 41.132657836352415\n",
      "EPOCH: 2037 LOSS: 41.13261337543625\n",
      "EPOCH: 2038 LOSS: 41.13256895531977\n",
      "EPOCH: 2039 LOSS: 41.13252457592198\n",
      "EPOCH: 2040 LOSS: 41.13248023716205\n",
      "EPOCH: 2041 LOSS: 41.13243593895942\n",
      "EPOCH: 2042 LOSS: 41.1323916812337\n",
      "EPOCH: 2043 LOSS: 41.13234746390477\n",
      "EPOCH: 2044 LOSS: 41.132303286892686\n",
      "EPOCH: 2045 LOSS: 41.13225915011772\n",
      "EPOCH: 2046 LOSS: 41.132215053500374\n",
      "EPOCH: 2047 LOSS: 41.132170996961335\n",
      "EPOCH: 2048 LOSS: 41.132126980421546\n",
      "EPOCH: 2049 LOSS: 41.13208300380214\n",
      "EPOCH: 2050 LOSS: 41.13203906702447\n",
      "EPOCH: 2051 LOSS: 41.13199517001006\n",
      "EPOCH: 2052 LOSS: 41.13195131268069\n",
      "EPOCH: 2053 LOSS: 41.13190749495834\n",
      "EPOCH: 2054 LOSS: 41.1318637167652\n",
      "EPOCH: 2055 LOSS: 41.131819978023636\n",
      "EPOCH: 2056 LOSS: 41.131776278656275\n",
      "EPOCH: 2057 LOSS: 41.131732618585886\n",
      "EPOCH: 2058 LOSS: 41.131688997735516\n",
      "EPOCH: 2059 LOSS: 41.13164541602838\n",
      "EPOCH: 2060 LOSS: 41.131601873387886\n",
      "EPOCH: 2061 LOSS: 41.13155836973765\n",
      "EPOCH: 2062 LOSS: 41.13151490500151\n",
      "EPOCH: 2063 LOSS: 41.1314714791035\n",
      "EPOCH: 2064 LOSS: 41.13142809196785\n",
      "EPOCH: 2065 LOSS: 41.13138474351899\n",
      "EPOCH: 2066 LOSS: 41.13134143368157\n",
      "EPOCH: 2067 LOSS: 41.13129816238042\n",
      "EPOCH: 2068 LOSS: 41.13125492954056\n",
      "EPOCH: 2069 LOSS: 41.131211735087234\n",
      "EPOCH: 2070 LOSS: 41.131168578945875\n",
      "EPOCH: 2071 LOSS: 41.13112546104212\n",
      "EPOCH: 2072 LOSS: 41.13108238130178\n",
      "EPOCH: 2073 LOSS: 41.13103933965087\n",
      "EPOCH: 2074 LOSS: 41.13099633601565\n",
      "EPOCH: 2075 LOSS: 41.13095337032249\n",
      "EPOCH: 2076 LOSS: 41.13091044249802\n",
      "EPOCH: 2077 LOSS: 41.13086755246903\n",
      "EPOCH: 2078 LOSS: 41.13082470016252\n",
      "EPOCH: 2079 LOSS: 41.13078188550567\n",
      "EPOCH: 2080 LOSS: 41.130739108425864\n",
      "EPOCH: 2081 LOSS: 41.13069636885068\n",
      "EPOCH: 2082 LOSS: 41.13065366670787\n",
      "EPOCH: 2083 LOSS: 41.1306110019254\n",
      "EPOCH: 2084 LOSS: 41.13056837443139\n",
      "EPOCH: 2085 LOSS: 41.13052578415416\n",
      "EPOCH: 2086 LOSS: 41.13048323102227\n",
      "EPOCH: 2087 LOSS: 41.13044071496439\n",
      "EPOCH: 2088 LOSS: 41.130398235909425\n",
      "EPOCH: 2089 LOSS: 41.13035579378644\n",
      "EPOCH: 2090 LOSS: 41.13031338852473\n",
      "EPOCH: 2091 LOSS: 41.13027102005373\n",
      "EPOCH: 2092 LOSS: 41.130228688303056\n",
      "EPOCH: 2093 LOSS: 41.13018639320256\n",
      "EPOCH: 2094 LOSS: 41.13014413468221\n",
      "EPOCH: 2095 LOSS: 41.13010191267222\n",
      "EPOCH: 2096 LOSS: 41.13005972710295\n",
      "EPOCH: 2097 LOSS: 41.130017577904944\n",
      "EPOCH: 2098 LOSS: 41.12997546500895\n",
      "EPOCH: 2099 LOSS: 41.129933388345854\n",
      "EPOCH: 2100 LOSS: 41.129891347846765\n",
      "EPOCH: 2101 LOSS: 41.12984934344294\n",
      "EPOCH: 2102 LOSS: 41.129807375065866\n",
      "EPOCH: 2103 LOSS: 41.12976544264713\n",
      "EPOCH: 2104 LOSS: 41.12972354611855\n",
      "EPOCH: 2105 LOSS: 41.12968168541213\n",
      "EPOCH: 2106 LOSS: 41.12963986046\n",
      "EPOCH: 2107 LOSS: 41.12959807119452\n",
      "EPOCH: 2108 LOSS: 41.1295563175482\n",
      "EPOCH: 2109 LOSS: 41.12951459945372\n",
      "EPOCH: 2110 LOSS: 41.129472916843945\n",
      "EPOCH: 2111 LOSS: 41.12943126965192\n",
      "EPOCH: 2112 LOSS: 41.129389657810826\n",
      "EPOCH: 2113 LOSS: 41.129348081254086\n",
      "EPOCH: 2114 LOSS: 41.12930653991523\n",
      "EPOCH: 2115 LOSS: 41.12926503372799\n",
      "EPOCH: 2116 LOSS: 41.12922356262625\n",
      "EPOCH: 2117 LOSS: 41.1291821265441\n",
      "EPOCH: 2118 LOSS: 41.12914072541578\n",
      "EPOCH: 2119 LOSS: 41.12909935917568\n",
      "EPOCH: 2120 LOSS: 41.12905802775839\n",
      "EPOCH: 2121 LOSS: 41.12901673109864\n",
      "EPOCH: 2122 LOSS: 41.12897546913137\n",
      "EPOCH: 2123 LOSS: 41.128934241791654\n",
      "EPOCH: 2124 LOSS: 41.128893049014735\n",
      "EPOCH: 2125 LOSS: 41.128851890736016\n",
      "EPOCH: 2126 LOSS: 41.1288107668911\n",
      "EPOCH: 2127 LOSS: 41.12876967741573\n",
      "EPOCH: 2128 LOSS: 41.12872862224581\n",
      "EPOCH: 2129 LOSS: 41.128687601317424\n",
      "EPOCH: 2130 LOSS: 41.128646614566804\n",
      "EPOCH: 2131 LOSS: 41.12860566193036\n",
      "EPOCH: 2132 LOSS: 41.12856474334467\n",
      "EPOCH: 2133 LOSS: 41.128523858746426\n",
      "EPOCH: 2134 LOSS: 41.12848300807255\n",
      "EPOCH: 2135 LOSS: 41.1284421912601\n",
      "EPOCH: 2136 LOSS: 41.12840140824626\n",
      "EPOCH: 2137 LOSS: 41.12836065896844\n",
      "EPOCH: 2138 LOSS: 41.128319943364154\n",
      "EPOCH: 2139 LOSS: 41.12827926137108\n",
      "EPOCH: 2140 LOSS: 41.128238612927106\n",
      "EPOCH: 2141 LOSS: 41.128197997970204\n",
      "EPOCH: 2142 LOSS: 41.12815741643857\n",
      "EPOCH: 2143 LOSS: 41.12811686827051\n",
      "EPOCH: 2144 LOSS: 41.12807635340453\n",
      "EPOCH: 2145 LOSS: 41.128035871779254\n",
      "EPOCH: 2146 LOSS: 41.127995423333466\n",
      "EPOCH: 2147 LOSS: 41.127955008006154\n",
      "EPOCH: 2148 LOSS: 41.12791462573639\n",
      "EPOCH: 2149 LOSS: 41.12787427646346\n",
      "EPOCH: 2150 LOSS: 41.12783396012675\n",
      "EPOCH: 2151 LOSS: 41.127793676665846\n",
      "EPOCH: 2152 LOSS: 41.12775342602048\n",
      "EPOCH: 2153 LOSS: 41.127713208130494\n",
      "EPOCH: 2154 LOSS: 41.12767302293596\n",
      "EPOCH: 2155 LOSS: 41.12763287037703\n",
      "EPOCH: 2156 LOSS: 41.12759275039401\n",
      "EPOCH: 2157 LOSS: 41.127552662927414\n",
      "EPOCH: 2158 LOSS: 41.127512607917865\n",
      "EPOCH: 2159 LOSS: 41.12747258530614\n",
      "EPOCH: 2160 LOSS: 41.12743259503317\n",
      "EPOCH: 2161 LOSS: 41.12739263704003\n",
      "EPOCH: 2162 LOSS: 41.127352711267974\n",
      "EPOCH: 2163 LOSS: 41.127312817658336\n",
      "EPOCH: 2164 LOSS: 41.12727295615268\n",
      "EPOCH: 2165 LOSS: 41.12723312669262\n",
      "EPOCH: 2166 LOSS: 41.12719332922005\n",
      "EPOCH: 2167 LOSS: 41.12715356367688\n",
      "EPOCH: 2168 LOSS: 41.12711383000522\n",
      "EPOCH: 2169 LOSS: 41.127074128147356\n",
      "EPOCH: 2170 LOSS: 41.12703445804566\n",
      "EPOCH: 2171 LOSS: 41.12699481964268\n",
      "EPOCH: 2172 LOSS: 41.12695521288113\n",
      "EPOCH: 2173 LOSS: 41.1269156377038\n",
      "EPOCH: 2174 LOSS: 41.12687609405371\n",
      "EPOCH: 2175 LOSS: 41.12683658187395\n",
      "EPOCH: 2176 LOSS: 41.126797101107776\n",
      "EPOCH: 2177 LOSS: 41.126757651698604\n",
      "EPOCH: 2178 LOSS: 41.12671823359\n",
      "EPOCH: 2179 LOSS: 41.12667884672558\n",
      "EPOCH: 2180 LOSS: 41.12663949104925\n",
      "EPOCH: 2181 LOSS: 41.126600166504915\n",
      "EPOCH: 2182 LOSS: 41.12656087303671\n",
      "EPOCH: 2183 LOSS: 41.126521610588874\n",
      "EPOCH: 2184 LOSS: 41.126482379105795\n",
      "EPOCH: 2185 LOSS: 41.12644317853198\n",
      "EPOCH: 2186 LOSS: 41.1264040088121\n",
      "EPOCH: 2187 LOSS: 41.12636486989096\n",
      "EPOCH: 2188 LOSS: 41.126325761713495\n",
      "EPOCH: 2189 LOSS: 41.12628668422475\n",
      "EPOCH: 2190 LOSS: 41.12624763736997\n",
      "EPOCH: 2191 LOSS: 41.12620862109448\n",
      "EPOCH: 2192 LOSS: 41.126169635343764\n",
      "EPOCH: 2193 LOSS: 41.12613068006343\n",
      "EPOCH: 2194 LOSS: 41.12609175519925\n",
      "EPOCH: 2195 LOSS: 41.12605286069707\n",
      "EPOCH: 2196 LOSS: 41.126013996502955\n",
      "EPOCH: 2197 LOSS: 41.125975162563016\n",
      "EPOCH: 2198 LOSS: 41.12593635882357\n",
      "EPOCH: 2199 LOSS: 41.125897585231016\n",
      "EPOCH: 2200 LOSS: 41.12585884173191\n",
      "EPOCH: 2201 LOSS: 41.125820128272935\n",
      "EPOCH: 2202 LOSS: 41.12578144480089\n",
      "EPOCH: 2203 LOSS: 41.125742791262766\n",
      "EPOCH: 2204 LOSS: 41.12570416760559\n",
      "EPOCH: 2205 LOSS: 41.125665573776594\n",
      "EPOCH: 2206 LOSS: 41.125627009723104\n",
      "EPOCH: 2207 LOSS: 41.12558847539259\n",
      "EPOCH: 2208 LOSS: 41.12554997073265\n",
      "EPOCH: 2209 LOSS: 41.125511495691015\n",
      "EPOCH: 2210 LOSS: 41.12547305021552\n",
      "EPOCH: 2211 LOSS: 41.125434634254155\n",
      "EPOCH: 2212 LOSS: 41.12539624775503\n",
      "EPOCH: 2213 LOSS: 41.12535789066637\n",
      "EPOCH: 2214 LOSS: 41.12531956293657\n",
      "EPOCH: 2215 LOSS: 41.125281264514086\n",
      "EPOCH: 2216 LOSS: 41.125242995347556\n",
      "EPOCH: 2217 LOSS: 41.125204755385695\n",
      "EPOCH: 2218 LOSS: 41.1251665445774\n",
      "EPOCH: 2219 LOSS: 41.12512836287165\n",
      "EPOCH: 2220 LOSS: 41.125090210217564\n",
      "EPOCH: 2221 LOSS: 41.12505208656438\n",
      "EPOCH: 2222 LOSS: 41.12501399186145\n",
      "EPOCH: 2223 LOSS: 41.1249759260583\n",
      "EPOCH: 2224 LOSS: 41.124937889104515\n",
      "EPOCH: 2225 LOSS: 41.12489988094983\n",
      "EPOCH: 2226 LOSS: 41.12486190154413\n",
      "EPOCH: 2227 LOSS: 41.12482395083736\n",
      "EPOCH: 2228 LOSS: 41.12478602877963\n",
      "EPOCH: 2229 LOSS: 41.12474813532117\n",
      "EPOCH: 2230 LOSS: 41.124710270412336\n",
      "EPOCH: 2231 LOSS: 41.12467243400357\n",
      "EPOCH: 2232 LOSS: 41.12463462604546\n",
      "EPOCH: 2233 LOSS: 41.12459684648875\n",
      "EPOCH: 2234 LOSS: 41.124559095284205\n",
      "EPOCH: 2235 LOSS: 41.1245213723828\n",
      "EPOCH: 2236 LOSS: 41.12448367773561\n",
      "EPOCH: 2237 LOSS: 41.12444601129379\n",
      "EPOCH: 2238 LOSS: 41.12440837300866\n",
      "EPOCH: 2239 LOSS: 41.124370762831646\n",
      "EPOCH: 2240 LOSS: 41.12433318071425\n",
      "EPOCH: 2241 LOSS: 41.12429562660815\n",
      "EPOCH: 2242 LOSS: 41.12425810046511\n",
      "EPOCH: 2243 LOSS: 41.12422060223703\n",
      "EPOCH: 2244 LOSS: 41.124183131875874\n",
      "EPOCH: 2245 LOSS: 41.124145689333815\n",
      "EPOCH: 2246 LOSS: 41.12410827456304\n",
      "EPOCH: 2247 LOSS: 41.12407088751592\n",
      "EPOCH: 2248 LOSS: 41.12403352814492\n",
      "EPOCH: 2249 LOSS: 41.12399619640262\n",
      "EPOCH: 2250 LOSS: 41.123958892241696\n",
      "EPOCH: 2251 LOSS: 41.12392161561497\n",
      "EPOCH: 2252 LOSS: 41.12388436647535\n",
      "EPOCH: 2253 LOSS: 41.12384714477587\n",
      "EPOCH: 2254 LOSS: 41.1238099504697\n",
      "EPOCH: 2255 LOSS: 41.12377278351007\n",
      "EPOCH: 2256 LOSS: 41.12373564385036\n",
      "EPOCH: 2257 LOSS: 41.12369853144406\n",
      "EPOCH: 2258 LOSS: 41.12366144624477\n",
      "EPOCH: 2259 LOSS: 41.12362438820616\n",
      "EPOCH: 2260 LOSS: 41.12358735728208\n",
      "EPOCH: 2261 LOSS: 41.12355035342645\n",
      "EPOCH: 2262 LOSS: 41.1235133765933\n",
      "EPOCH: 2263 LOSS: 41.1234764267368\n",
      "EPOCH: 2264 LOSS: 41.12343950381118\n",
      "EPOCH: 2265 LOSS: 41.12340260777079\n",
      "EPOCH: 2266 LOSS: 41.12336573857016\n",
      "EPOCH: 2267 LOSS: 41.123328896163834\n",
      "EPOCH: 2268 LOSS: 41.1232920805065\n",
      "EPOCH: 2269 LOSS: 41.12325529155298\n",
      "EPOCH: 2270 LOSS: 41.12321852925817\n",
      "EPOCH: 2271 LOSS: 41.1231817935771\n",
      "EPOCH: 2272 LOSS: 41.123145084464866\n",
      "EPOCH: 2273 LOSS: 41.12310840187672\n",
      "EPOCH: 2274 LOSS: 41.12307174576797\n",
      "EPOCH: 2275 LOSS: 41.123035116094094\n",
      "EPOCH: 2276 LOSS: 41.122998512810625\n",
      "EPOCH: 2277 LOSS: 41.12296193587321\n",
      "EPOCH: 2278 LOSS: 41.12292538523759\n",
      "EPOCH: 2279 LOSS: 41.122888860859675\n",
      "EPOCH: 2280 LOSS: 41.12285236269538\n",
      "EPOCH: 2281 LOSS: 41.122815890700835\n",
      "EPOCH: 2282 LOSS: 41.12277944483216\n",
      "EPOCH: 2283 LOSS: 41.122743025045665\n",
      "EPOCH: 2284 LOSS: 41.122706631297746\n",
      "EPOCH: 2285 LOSS: 41.122670263544855\n",
      "EPOCH: 2286 LOSS: 41.1226339217436\n",
      "EPOCH: 2287 LOSS: 41.12259760585069\n",
      "EPOCH: 2288 LOSS: 41.12256131582289\n",
      "EPOCH: 2289 LOSS: 41.12252505161712\n",
      "EPOCH: 2290 LOSS: 41.122488813190344\n",
      "EPOCH: 2291 LOSS: 41.1224526004997\n",
      "EPOCH: 2292 LOSS: 41.122416413502364\n",
      "EPOCH: 2293 LOSS: 41.122380252155665\n",
      "EPOCH: 2294 LOSS: 41.122344116416976\n",
      "EPOCH: 2295 LOSS: 41.1223080062438\n",
      "EPOCH: 2296 LOSS: 41.122271921593764\n",
      "EPOCH: 2297 LOSS: 41.12223586242455\n",
      "EPOCH: 2298 LOSS: 41.12219982869396\n",
      "EPOCH: 2299 LOSS: 41.1221638203599\n",
      "EPOCH: 2300 LOSS: 41.12212783738037\n",
      "EPOCH: 2301 LOSS: 41.12209187971347\n",
      "EPOCH: 2302 LOSS: 41.12205594731739\n",
      "EPOCH: 2303 LOSS: 41.12202004015042\n",
      "EPOCH: 2304 LOSS: 41.12198415817096\n",
      "EPOCH: 2305 LOSS: 41.1219483013375\n",
      "EPOCH: 2306 LOSS: 41.12191246960861\n",
      "EPOCH: 2307 LOSS: 41.121876662943\n",
      "EPOCH: 2308 LOSS: 41.121840881299434\n",
      "EPOCH: 2309 LOSS: 41.121805124636786\n",
      "EPOCH: 2310 LOSS: 41.12176939291403\n",
      "EPOCH: 2311 LOSS: 41.12173368609024\n",
      "EPOCH: 2312 LOSS: 41.12169800412456\n",
      "EPOCH: 2313 LOSS: 41.12166234697629\n",
      "EPOCH: 2314 LOSS: 41.12162671460473\n",
      "EPOCH: 2315 LOSS: 41.121591106969376\n",
      "EPOCH: 2316 LOSS: 41.12155552402973\n",
      "EPOCH: 2317 LOSS: 41.12151996574546\n",
      "EPOCH: 2318 LOSS: 41.1214844320763\n",
      "EPOCH: 2319 LOSS: 41.12144892298203\n",
      "EPOCH: 2320 LOSS: 41.12141343842262\n",
      "EPOCH: 2321 LOSS: 41.121377978358055\n",
      "EPOCH: 2322 LOSS: 41.12134254274845\n",
      "EPOCH: 2323 LOSS: 41.12130713155397\n",
      "EPOCH: 2324 LOSS: 41.12127174473494\n",
      "EPOCH: 2325 LOSS: 41.12123638225174\n",
      "EPOCH: 2326 LOSS: 41.12120104406481\n",
      "EPOCH: 2327 LOSS: 41.12116573013475\n",
      "EPOCH: 2328 LOSS: 41.121130440422185\n",
      "EPOCH: 2329 LOSS: 41.121095174887884\n",
      "EPOCH: 2330 LOSS: 41.12105993349267\n",
      "EPOCH: 2331 LOSS: 41.121024716197475\n",
      "EPOCH: 2332 LOSS: 41.12098952296333\n",
      "EPOCH: 2333 LOSS: 41.12095435375133\n",
      "EPOCH: 2334 LOSS: 41.12091920852266\n",
      "EPOCH: 2335 LOSS: 41.12088408723862\n",
      "EPOCH: 2336 LOSS: 41.1208489898606\n",
      "EPOCH: 2337 LOSS: 41.120813916350045\n",
      "EPOCH: 2338 LOSS: 41.12077886666851\n",
      "EPOCH: 2339 LOSS: 41.12074384077765\n",
      "EPOCH: 2340 LOSS: 41.120708838639196\n",
      "EPOCH: 2341 LOSS: 41.12067386021495\n",
      "EPOCH: 2342 LOSS: 41.12063890546684\n",
      "EPOCH: 2343 LOSS: 41.12060397435685\n",
      "EPOCH: 2344 LOSS: 41.12056906684704\n",
      "EPOCH: 2345 LOSS: 41.120534182899625\n",
      "EPOCH: 2346 LOSS: 41.12049932247682\n",
      "EPOCH: 2347 LOSS: 41.120464485540985\n",
      "EPOCH: 2348 LOSS: 41.12042967205454\n",
      "EPOCH: 2349 LOSS: 41.120394881980005\n",
      "EPOCH: 2350 LOSS: 41.12036011527997\n",
      "EPOCH: 2351 LOSS: 41.12032537191714\n",
      "EPOCH: 2352 LOSS: 41.120290651854276\n",
      "EPOCH: 2353 LOSS: 41.12025595505422\n",
      "EPOCH: 2354 LOSS: 41.12022128147995\n",
      "EPOCH: 2355 LOSS: 41.12018663109444\n",
      "EPOCH: 2356 LOSS: 41.12015200386084\n",
      "EPOCH: 2357 LOSS: 41.12011739974233\n",
      "EPOCH: 2358 LOSS: 41.12008281870218\n",
      "EPOCH: 2359 LOSS: 41.12004826070376\n",
      "EPOCH: 2360 LOSS: 41.120013725710535\n",
      "EPOCH: 2361 LOSS: 41.119979213685994\n",
      "EPOCH: 2362 LOSS: 41.11994472459378\n",
      "EPOCH: 2363 LOSS: 41.11991025839759\n",
      "EPOCH: 2364 LOSS: 41.11987581506117\n",
      "EPOCH: 2365 LOSS: 41.119841394548395\n",
      "EPOCH: 2366 LOSS: 41.119806996823215\n",
      "EPOCH: 2367 LOSS: 41.11977262184963\n",
      "EPOCH: 2368 LOSS: 41.11973826959178\n",
      "EPOCH: 2369 LOSS: 41.11970394001382\n",
      "EPOCH: 2370 LOSS: 41.119669633080036\n",
      "EPOCH: 2371 LOSS: 41.119635348754755\n",
      "EPOCH: 2372 LOSS: 41.11960108700244\n",
      "EPOCH: 2373 LOSS: 41.11956684778756\n",
      "EPOCH: 2374 LOSS: 41.11953263107473\n",
      "EPOCH: 2375 LOSS: 41.119498436828614\n",
      "EPOCH: 2376 LOSS: 41.11946426501398\n",
      "EPOCH: 2377 LOSS: 41.11943011559563\n",
      "EPOCH: 2378 LOSS: 41.119395988538486\n",
      "EPOCH: 2379 LOSS: 41.119361883807514\n",
      "EPOCH: 2380 LOSS: 41.11932780136782\n",
      "EPOCH: 2381 LOSS: 41.11929374118453\n",
      "EPOCH: 2382 LOSS: 41.11925970322287\n",
      "EPOCH: 2383 LOSS: 41.11922568744812\n",
      "EPOCH: 2384 LOSS: 41.119191693825705\n",
      "EPOCH: 2385 LOSS: 41.119157722321056\n",
      "EPOCH: 2386 LOSS: 41.11912377289972\n",
      "EPOCH: 2387 LOSS: 41.119089845527284\n",
      "EPOCH: 2388 LOSS: 41.11905594016948\n",
      "EPOCH: 2389 LOSS: 41.11902205679205\n",
      "EPOCH: 2390 LOSS: 41.11898819536084\n",
      "EPOCH: 2391 LOSS: 41.1189543558418\n",
      "EPOCH: 2392 LOSS: 41.118920538200896\n",
      "EPOCH: 2393 LOSS: 41.1188867424042\n",
      "EPOCH: 2394 LOSS: 41.1188529684179\n",
      "EPOCH: 2395 LOSS: 41.11881921620818\n",
      "EPOCH: 2396 LOSS: 41.118785485741356\n",
      "EPOCH: 2397 LOSS: 41.118751776983814\n",
      "EPOCH: 2398 LOSS: 41.118718089901996\n",
      "EPOCH: 2399 LOSS: 41.11868442446244\n",
      "EPOCH: 2400 LOSS: 41.11865078063174\n",
      "EPOCH: 2401 LOSS: 41.11861715837658\n",
      "EPOCH: 2402 LOSS: 41.1185835576637\n",
      "EPOCH: 2403 LOSS: 41.11854997845994\n",
      "EPOCH: 2404 LOSS: 41.11851642073218\n",
      "EPOCH: 2405 LOSS: 41.11848288444741\n",
      "EPOCH: 2406 LOSS: 41.11844936957266\n",
      "EPOCH: 2407 LOSS: 41.11841587607507\n",
      "EPOCH: 2408 LOSS: 41.11838240392183\n",
      "EPOCH: 2409 LOSS: 41.11834895308019\n",
      "EPOCH: 2410 LOSS: 41.118315523517495\n",
      "EPOCH: 2411 LOSS: 41.118282115201175\n",
      "EPOCH: 2412 LOSS: 41.118248728098685\n",
      "EPOCH: 2413 LOSS: 41.1182153621776\n",
      "EPOCH: 2414 LOSS: 41.118182017405545\n",
      "EPOCH: 2415 LOSS: 41.118148693750214\n",
      "EPOCH: 2416 LOSS: 41.11811539117939\n",
      "EPOCH: 2417 LOSS: 41.11808210966091\n",
      "EPOCH: 2418 LOSS: 41.118048849162676\n",
      "EPOCH: 2419 LOSS: 41.118015609652694\n",
      "EPOCH: 2420 LOSS: 41.117982391099005\n",
      "EPOCH: 2421 LOSS: 41.11794919346974\n",
      "EPOCH: 2422 LOSS: 41.1179160167331\n",
      "EPOCH: 2423 LOSS: 41.117882860857335\n",
      "EPOCH: 2424 LOSS: 41.117849725810814\n",
      "EPOCH: 2425 LOSS: 41.11781661156192\n",
      "EPOCH: 2426 LOSS: 41.117783518079136\n",
      "EPOCH: 2427 LOSS: 41.11775044533101\n",
      "EPOCH: 2428 LOSS: 41.11771739328615\n",
      "EPOCH: 2429 LOSS: 41.117684361913255\n",
      "EPOCH: 2430 LOSS: 41.11765135118106\n",
      "EPOCH: 2431 LOSS: 41.11761836105842\n",
      "EPOCH: 2432 LOSS: 41.11758539151419\n",
      "EPOCH: 2433 LOSS: 41.11755244251735\n",
      "EPOCH: 2434 LOSS: 41.11751951403693\n",
      "EPOCH: 2435 LOSS: 41.117486606042\n",
      "EPOCH: 2436 LOSS: 41.11745371850174\n",
      "EPOCH: 2437 LOSS: 41.11742085138541\n",
      "EPOCH: 2438 LOSS: 41.11738800466226\n",
      "EPOCH: 2439 LOSS: 41.1173551783017\n",
      "EPOCH: 2440 LOSS: 41.11732237227314\n",
      "EPOCH: 2441 LOSS: 41.117289586546065\n",
      "EPOCH: 2442 LOSS: 41.117256821090066\n",
      "EPOCH: 2443 LOSS: 41.11722407587477\n",
      "EPOCH: 2444 LOSS: 41.117191350869895\n",
      "EPOCH: 2445 LOSS: 41.11715864604517\n",
      "EPOCH: 2446 LOSS: 41.11712596137045\n",
      "EPOCH: 2447 LOSS: 41.11709329681563\n",
      "EPOCH: 2448 LOSS: 41.11706065235067\n",
      "EPOCH: 2449 LOSS: 41.117028027945615\n",
      "EPOCH: 2450 LOSS: 41.11699542357055\n",
      "EPOCH: 2451 LOSS: 41.11696283919563\n",
      "EPOCH: 2452 LOSS: 41.11693027479107\n",
      "EPOCH: 2453 LOSS: 41.1168977303272\n",
      "EPOCH: 2454 LOSS: 41.11686520577433\n",
      "EPOCH: 2455 LOSS: 41.1168327011029\n",
      "EPOCH: 2456 LOSS: 41.116800216283394\n",
      "EPOCH: 2457 LOSS: 41.11676775128635\n",
      "EPOCH: 2458 LOSS: 41.11673530608239\n",
      "EPOCH: 2459 LOSS: 41.11670288064219\n",
      "EPOCH: 2460 LOSS: 41.11667047493647\n",
      "EPOCH: 2461 LOSS: 41.11663808893606\n",
      "EPOCH: 2462 LOSS: 41.11660572261181\n",
      "EPOCH: 2463 LOSS: 41.11657337593465\n",
      "EPOCH: 2464 LOSS: 41.11654104887559\n",
      "EPOCH: 2465 LOSS: 41.116508741405625\n",
      "EPOCH: 2466 LOSS: 41.11647645349594\n",
      "EPOCH: 2467 LOSS: 41.1164441851177\n",
      "EPOCH: 2468 LOSS: 41.11641193624212\n",
      "EPOCH: 2469 LOSS: 41.11637970684055\n",
      "EPOCH: 2470 LOSS: 41.116347496884295\n",
      "EPOCH: 2471 LOSS: 41.11631530634483\n",
      "EPOCH: 2472 LOSS: 41.11628313519363\n",
      "EPOCH: 2473 LOSS: 41.11625098340224\n",
      "EPOCH: 2474 LOSS: 41.116218850942275\n",
      "EPOCH: 2475 LOSS: 41.11618673778544\n",
      "EPOCH: 2476 LOSS: 41.116154643903414\n",
      "EPOCH: 2477 LOSS: 41.11612256926803\n",
      "EPOCH: 2478 LOSS: 41.11609051385114\n",
      "EPOCH: 2479 LOSS: 41.11605847762465\n",
      "EPOCH: 2480 LOSS: 41.11602646056056\n",
      "EPOCH: 2481 LOSS: 41.11599446263087\n",
      "EPOCH: 2482 LOSS: 41.11596248380772\n",
      "EPOCH: 2483 LOSS: 41.115930524063224\n",
      "EPOCH: 2484 LOSS: 41.11589858336964\n",
      "EPOCH: 2485 LOSS: 41.11586666169922\n",
      "EPOCH: 2486 LOSS: 41.1158347590243\n",
      "EPOCH: 2487 LOSS: 41.115802875317286\n",
      "EPOCH: 2488 LOSS: 41.11577101055063\n",
      "EPOCH: 2489 LOSS: 41.11573916469685\n",
      "EPOCH: 2490 LOSS: 41.115707337728495\n",
      "EPOCH: 2491 LOSS: 41.11567552961823\n",
      "EPOCH: 2492 LOSS: 41.11564374033871\n",
      "EPOCH: 2493 LOSS: 41.115611969862705\n",
      "EPOCH: 2494 LOSS: 41.11558021816302\n",
      "EPOCH: 2495 LOSS: 41.11554848521253\n",
      "EPOCH: 2496 LOSS: 41.11551677098413\n",
      "EPOCH: 2497 LOSS: 41.115485075450806\n",
      "EPOCH: 2498 LOSS: 41.1154533985856\n",
      "EPOCH: 2499 LOSS: 41.11542174036161\n",
      "EPOCH: 2500 LOSS: 41.115390100751995\n",
      "EPOCH: 2501 LOSS: 41.115358479729956\n",
      "EPOCH: 2502 LOSS: 41.115326877268764\n",
      "EPOCH: 2503 LOSS: 41.115295293341724\n",
      "EPOCH: 2504 LOSS: 41.11526372792222\n",
      "EPOCH: 2505 LOSS: 41.115232180983696\n",
      "EPOCH: 2506 LOSS: 41.11520065249967\n",
      "EPOCH: 2507 LOSS: 41.11516914244365\n",
      "EPOCH: 2508 LOSS: 41.115137650789265\n",
      "EPOCH: 2509 LOSS: 41.11510617751016\n",
      "EPOCH: 2510 LOSS: 41.115074722580054\n",
      "EPOCH: 2511 LOSS: 41.115043285972746\n",
      "EPOCH: 2512 LOSS: 41.11501186766205\n",
      "EPOCH: 2513 LOSS: 41.11498046762182\n",
      "EPOCH: 2514 LOSS: 41.11494908582603\n",
      "EPOCH: 2515 LOSS: 41.114917722248656\n",
      "EPOCH: 2516 LOSS: 41.11488637686375\n",
      "EPOCH: 2517 LOSS: 41.11485504964543\n",
      "EPOCH: 2518 LOSS: 41.11482374056784\n",
      "EPOCH: 2519 LOSS: 41.1147924496052\n",
      "EPOCH: 2520 LOSS: 41.11476117673176\n",
      "EPOCH: 2521 LOSS: 41.114729921921864\n",
      "EPOCH: 2522 LOSS: 41.11469868514987\n",
      "EPOCH: 2523 LOSS: 41.11466746639022\n",
      "EPOCH: 2524 LOSS: 41.1146362656174\n",
      "EPOCH: 2525 LOSS: 41.11460508280592\n",
      "EPOCH: 2526 LOSS: 41.11457391793042\n",
      "EPOCH: 2527 LOSS: 41.11454277096551\n",
      "EPOCH: 2528 LOSS: 41.11451164188588\n",
      "EPOCH: 2529 LOSS: 41.1144805306663\n",
      "EPOCH: 2530 LOSS: 41.114449437281564\n",
      "EPOCH: 2531 LOSS: 41.114418361706534\n",
      "EPOCH: 2532 LOSS: 41.114387303916125\n",
      "EPOCH: 2533 LOSS: 41.11435626388527\n",
      "EPOCH: 2534 LOSS: 41.11432524158902\n",
      "EPOCH: 2535 LOSS: 41.11429423700243\n",
      "EPOCH: 2536 LOSS: 41.11426325010059\n",
      "EPOCH: 2537 LOSS: 41.114232280858715\n",
      "EPOCH: 2538 LOSS: 41.11420132925201\n",
      "EPOCH: 2539 LOSS: 41.11417039525574\n",
      "EPOCH: 2540 LOSS: 41.114139478845246\n",
      "EPOCH: 2541 LOSS: 41.11410857999589\n",
      "EPOCH: 2542 LOSS: 41.114077698683126\n",
      "EPOCH: 2543 LOSS: 41.1140468348824\n",
      "EPOCH: 2544 LOSS: 41.114015988569264\n",
      "EPOCH: 2545 LOSS: 41.113985159719306\n",
      "EPOCH: 2546 LOSS: 41.113954348308155\n",
      "EPOCH: 2547 LOSS: 41.113923554311484\n",
      "EPOCH: 2548 LOSS: 41.113892777705054\n",
      "EPOCH: 2549 LOSS: 41.113862018464616\n",
      "EPOCH: 2550 LOSS: 41.11383127656603\n",
      "EPOCH: 2551 LOSS: 41.11380055198518\n",
      "EPOCH: 2552 LOSS: 41.11376984469799\n",
      "EPOCH: 2553 LOSS: 41.11373915468046\n",
      "EPOCH: 2554 LOSS: 41.11370848190861\n",
      "EPOCH: 2555 LOSS: 41.11367782635855\n",
      "EPOCH: 2556 LOSS: 41.11364718800639\n",
      "EPOCH: 2557 LOSS: 41.11361656682834\n",
      "EPOCH: 2558 LOSS: 41.113585962800606\n",
      "EPOCH: 2559 LOSS: 41.11355537589948\n",
      "EPOCH: 2560 LOSS: 41.11352480610131\n",
      "EPOCH: 2561 LOSS: 41.11349425338247\n",
      "EPOCH: 2562 LOSS: 41.11346371771938\n",
      "EPOCH: 2563 LOSS: 41.11343319908855\n",
      "EPOCH: 2564 LOSS: 41.113402697466455\n",
      "EPOCH: 2565 LOSS: 41.1133722128297\n",
      "EPOCH: 2566 LOSS: 41.113341745154926\n",
      "EPOCH: 2567 LOSS: 41.11331129441881\n",
      "EPOCH: 2568 LOSS: 41.11328086059801\n",
      "EPOCH: 2569 LOSS: 41.113250443669365\n",
      "EPOCH: 2570 LOSS: 41.11322004360966\n",
      "EPOCH: 2571 LOSS: 41.113189660395754\n",
      "EPOCH: 2572 LOSS: 41.113159294004575\n",
      "EPOCH: 2573 LOSS: 41.11312894441308\n",
      "EPOCH: 2574 LOSS: 41.11309861159827\n",
      "EPOCH: 2575 LOSS: 41.1130682955372\n",
      "EPOCH: 2576 LOSS: 41.11303799620698\n",
      "EPOCH: 2577 LOSS: 41.11300771358475\n",
      "EPOCH: 2578 LOSS: 41.11297744764771\n",
      "EPOCH: 2579 LOSS: 41.11294719837309\n",
      "EPOCH: 2580 LOSS: 41.11291696573821\n",
      "EPOCH: 2581 LOSS: 41.11288674972035\n",
      "EPOCH: 2582 LOSS: 41.11285655029696\n",
      "EPOCH: 2583 LOSS: 41.11282636744542\n",
      "EPOCH: 2584 LOSS: 41.11279620114322\n",
      "EPOCH: 2585 LOSS: 41.11276605136787\n",
      "EPOCH: 2586 LOSS: 41.11273591809696\n",
      "EPOCH: 2587 LOSS: 41.112705801308095\n",
      "EPOCH: 2588 LOSS: 41.11267570097891\n",
      "EPOCH: 2589 LOSS: 41.11264561708714\n",
      "EPOCH: 2590 LOSS: 41.1126155496105\n",
      "EPOCH: 2591 LOSS: 41.11258549852681\n",
      "EPOCH: 2592 LOSS: 41.112555463813905\n",
      "EPOCH: 2593 LOSS: 41.11252544544969\n",
      "EPOCH: 2594 LOSS: 41.112495443412044\n",
      "EPOCH: 2595 LOSS: 41.11246545767899\n",
      "EPOCH: 2596 LOSS: 41.11243548822853\n",
      "EPOCH: 2597 LOSS: 41.112405535038725\n",
      "EPOCH: 2598 LOSS: 41.112375598087695\n",
      "EPOCH: 2599 LOSS: 41.11234567735359\n",
      "EPOCH: 2600 LOSS: 41.1123157728146\n",
      "EPOCH: 2601 LOSS: 41.112285884448966\n",
      "EPOCH: 2602 LOSS: 41.112256012234994\n",
      "EPOCH: 2603 LOSS: 41.112226156150996\n",
      "EPOCH: 2604 LOSS: 41.11219631617537\n",
      "EPOCH: 2605 LOSS: 41.1121664922865\n",
      "EPOCH: 2606 LOSS: 41.11213668446288\n",
      "EPOCH: 2607 LOSS: 41.112106892683\n",
      "EPOCH: 2608 LOSS: 41.11207711692541\n",
      "EPOCH: 2609 LOSS: 41.11204735716872\n",
      "EPOCH: 2610 LOSS: 41.11201761339153\n",
      "EPOCH: 2611 LOSS: 41.11198788557256\n",
      "EPOCH: 2612 LOSS: 41.11195817369051\n",
      "EPOCH: 2613 LOSS: 41.111928477724135\n",
      "EPOCH: 2614 LOSS: 41.11189879765227\n",
      "EPOCH: 2615 LOSS: 41.11186913345375\n",
      "EPOCH: 2616 LOSS: 41.11183948510748\n",
      "EPOCH: 2617 LOSS: 41.11180985259239\n",
      "EPOCH: 2618 LOSS: 41.11178023588745\n",
      "EPOCH: 2619 LOSS: 41.1117506349717\n",
      "EPOCH: 2620 LOSS: 41.11172104982418\n",
      "EPOCH: 2621 LOSS: 41.11169148042401\n",
      "EPOCH: 2622 LOSS: 41.111661926750344\n",
      "EPOCH: 2623 LOSS: 41.111632388782354\n",
      "EPOCH: 2624 LOSS: 41.11160286649928\n",
      "EPOCH: 2625 LOSS: 41.11157335988041\n",
      "EPOCH: 2626 LOSS: 41.11154386890504\n",
      "EPOCH: 2627 LOSS: 41.111514393552525\n",
      "EPOCH: 2628 LOSS: 41.111484933802274\n",
      "EPOCH: 2629 LOSS: 41.1114554896337\n",
      "EPOCH: 2630 LOSS: 41.11142606102633\n",
      "EPOCH: 2631 LOSS: 41.11139664795965\n",
      "EPOCH: 2632 LOSS: 41.111367250413224\n",
      "EPOCH: 2633 LOSS: 41.111337868366675\n",
      "EPOCH: 2634 LOSS: 41.11130850179963\n",
      "EPOCH: 2635 LOSS: 41.11127915069176\n",
      "EPOCH: 2636 LOSS: 41.11124981502282\n",
      "EPOCH: 2637 LOSS: 41.11122049477257\n",
      "EPOCH: 2638 LOSS: 41.1111911899208\n",
      "EPOCH: 2639 LOSS: 41.111161900447385\n",
      "EPOCH: 2640 LOSS: 41.111132626332186\n",
      "EPOCH: 2641 LOSS: 41.11110336755512\n",
      "EPOCH: 2642 LOSS: 41.11107412409619\n",
      "EPOCH: 2643 LOSS: 41.11104489593538\n",
      "EPOCH: 2644 LOSS: 41.111015683052734\n",
      "EPOCH: 2645 LOSS: 41.11098648542834\n",
      "EPOCH: 2646 LOSS: 41.11095730304234\n",
      "EPOCH: 2647 LOSS: 41.110928135874886\n",
      "EPOCH: 2648 LOSS: 41.11089898390618\n",
      "EPOCH: 2649 LOSS: 41.11086984711647\n",
      "EPOCH: 2650 LOSS: 41.11084072548604\n",
      "EPOCH: 2651 LOSS: 41.110811618995214\n",
      "EPOCH: 2652 LOSS: 41.11078252762437\n",
      "EPOCH: 2653 LOSS: 41.11075345135387\n",
      "EPOCH: 2654 LOSS: 41.11072439016419\n",
      "EPOCH: 2655 LOSS: 41.11069534403577\n",
      "EPOCH: 2656 LOSS: 41.11066631294917\n",
      "EPOCH: 2657 LOSS: 41.1106372968849\n",
      "EPOCH: 2658 LOSS: 41.1106082958236\n",
      "EPOCH: 2659 LOSS: 41.11057930974587\n",
      "EPOCH: 2660 LOSS: 41.110550338632414\n",
      "EPOCH: 2661 LOSS: 41.1105213824639\n",
      "EPOCH: 2662 LOSS: 41.11049244122109\n",
      "EPOCH: 2663 LOSS: 41.110463514884785\n",
      "EPOCH: 2664 LOSS: 41.11043460343579\n",
      "EPOCH: 2665 LOSS: 41.11040570685496\n",
      "EPOCH: 2666 LOSS: 41.11037682512322\n",
      "EPOCH: 2667 LOSS: 41.11034795822148\n",
      "EPOCH: 2668 LOSS: 41.11031910613072\n",
      "EPOCH: 2669 LOSS: 41.11029026883196\n",
      "EPOCH: 2670 LOSS: 41.11026144630625\n",
      "EPOCH: 2671 LOSS: 41.11023263853467\n",
      "EPOCH: 2672 LOSS: 41.11020384549831\n",
      "EPOCH: 2673 LOSS: 41.11017506717838\n",
      "EPOCH: 2674 LOSS: 41.11014630355606\n",
      "EPOCH: 2675 LOSS: 41.11011755461259\n",
      "EPOCH: 2676 LOSS: 41.11008882032921\n",
      "EPOCH: 2677 LOSS: 41.11006010068727\n",
      "EPOCH: 2678 LOSS: 41.11003139566809\n",
      "EPOCH: 2679 LOSS: 41.11000270525306\n",
      "EPOCH: 2680 LOSS: 41.10997402942357\n",
      "EPOCH: 2681 LOSS: 41.10994536816109\n",
      "EPOCH: 2682 LOSS: 41.10991672144715\n",
      "EPOCH: 2683 LOSS: 41.10988808926324\n",
      "EPOCH: 2684 LOSS: 41.10985947159089\n",
      "EPOCH: 2685 LOSS: 41.10983086841174\n",
      "EPOCH: 2686 LOSS: 41.10980227970741\n",
      "EPOCH: 2687 LOSS: 41.1097737054596\n",
      "EPOCH: 2688 LOSS: 41.10974514564997\n",
      "EPOCH: 2689 LOSS: 41.1097166002603\n",
      "EPOCH: 2690 LOSS: 41.10968806927234\n",
      "EPOCH: 2691 LOSS: 41.10965955266791\n",
      "EPOCH: 2692 LOSS: 41.10963105042886\n",
      "EPOCH: 2693 LOSS: 41.10960256253706\n",
      "EPOCH: 2694 LOSS: 41.10957408897447\n",
      "EPOCH: 2695 LOSS: 41.109545629722994\n",
      "EPOCH: 2696 LOSS: 41.10951718476465\n",
      "EPOCH: 2697 LOSS: 41.10948875408145\n",
      "EPOCH: 2698 LOSS: 41.10946033765547\n",
      "EPOCH: 2699 LOSS: 41.109431935468756\n",
      "EPOCH: 2700 LOSS: 41.10940354750351\n",
      "EPOCH: 2701 LOSS: 41.10937517374184\n",
      "EPOCH: 2702 LOSS: 41.10934681416596\n",
      "EPOCH: 2703 LOSS: 41.10931846875811\n",
      "EPOCH: 2704 LOSS: 41.10929013750054\n",
      "EPOCH: 2705 LOSS: 41.10926182037555\n",
      "EPOCH: 2706 LOSS: 41.109233517365496\n",
      "EPOCH: 2707 LOSS: 41.10920522845274\n",
      "EPOCH: 2708 LOSS: 41.10917695361968\n",
      "EPOCH: 2709 LOSS: 41.10914869284875\n",
      "EPOCH: 2710 LOSS: 41.109120446122425\n",
      "EPOCH: 2711 LOSS: 41.109092213423224\n",
      "EPOCH: 2712 LOSS: 41.10906399473366\n",
      "EPOCH: 2713 LOSS: 41.10903579003633\n",
      "EPOCH: 2714 LOSS: 41.10900759931382\n",
      "EPOCH: 2715 LOSS: 41.108979422548785\n",
      "EPOCH: 2716 LOSS: 41.108951259723895\n",
      "EPOCH: 2717 LOSS: 41.108923110821856\n",
      "EPOCH: 2718 LOSS: 41.10889497582541\n",
      "EPOCH: 2719 LOSS: 41.10886685471732\n",
      "EPOCH: 2720 LOSS: 41.1088387474804\n",
      "EPOCH: 2721 LOSS: 41.108810654097496\n",
      "EPOCH: 2722 LOSS: 41.10878257455147\n",
      "EPOCH: 2723 LOSS: 41.10875450882523\n",
      "EPOCH: 2724 LOSS: 41.108726456901714\n",
      "EPOCH: 2725 LOSS: 41.1086984187639\n",
      "EPOCH: 2726 LOSS: 41.10867039439478\n",
      "EPOCH: 2727 LOSS: 41.1086423837774\n",
      "EPOCH: 2728 LOSS: 41.10861438689482\n",
      "EPOCH: 2729 LOSS: 41.10858640373015\n",
      "EPOCH: 2730 LOSS: 41.10855843426653\n",
      "EPOCH: 2731 LOSS: 41.10853047848708\n",
      "EPOCH: 2732 LOSS: 41.10850253637507\n",
      "EPOCH: 2733 LOSS: 41.10847460791368\n",
      "EPOCH: 2734 LOSS: 41.10844669308619\n",
      "EPOCH: 2735 LOSS: 41.10841879187587\n",
      "EPOCH: 2736 LOSS: 41.108390904266074\n",
      "EPOCH: 2737 LOSS: 41.10836303024016\n",
      "EPOCH: 2738 LOSS: 41.1083351697815\n",
      "EPOCH: 2739 LOSS: 41.10830732287354\n",
      "EPOCH: 2740 LOSS: 41.108279489499694\n",
      "EPOCH: 2741 LOSS: 41.108251669643494\n",
      "EPOCH: 2742 LOSS: 41.1082238632884\n",
      "EPOCH: 2743 LOSS: 41.108196070418025\n",
      "EPOCH: 2744 LOSS: 41.108168291015886\n",
      "EPOCH: 2745 LOSS: 41.108140525065636\n",
      "EPOCH: 2746 LOSS: 41.108112772550896\n",
      "EPOCH: 2747 LOSS: 41.10808503345534\n",
      "EPOCH: 2748 LOSS: 41.10805730776267\n",
      "EPOCH: 2749 LOSS: 41.108029595456635\n",
      "EPOCH: 2750 LOSS: 41.10800189652097\n",
      "EPOCH: 2751 LOSS: 41.10797421093949\n",
      "EPOCH: 2752 LOSS: 41.10794653869603\n",
      "EPOCH: 2753 LOSS: 41.10791887977442\n",
      "EPOCH: 2754 LOSS: 41.10789123415859\n",
      "EPOCH: 2755 LOSS: 41.10786360183242\n",
      "EPOCH: 2756 LOSS: 41.10783598277987\n",
      "EPOCH: 2757 LOSS: 41.10780837698492\n",
      "EPOCH: 2758 LOSS: 41.107780784431576\n",
      "EPOCH: 2759 LOSS: 41.10775320510389\n",
      "EPOCH: 2760 LOSS: 41.10772563898591\n",
      "EPOCH: 2761 LOSS: 41.10769808606176\n",
      "EPOCH: 2762 LOSS: 41.107670546315546\n",
      "EPOCH: 2763 LOSS: 41.10764301973144\n",
      "EPOCH: 2764 LOSS: 41.10761550629363\n",
      "EPOCH: 2765 LOSS: 41.107588005986344\n",
      "EPOCH: 2766 LOSS: 41.10756051879383\n",
      "EPOCH: 2767 LOSS: 41.10753304470034\n",
      "EPOCH: 2768 LOSS: 41.107505583690205\n",
      "EPOCH: 2769 LOSS: 41.10747813574777\n",
      "EPOCH: 2770 LOSS: 41.107450700857385\n",
      "EPOCH: 2771 LOSS: 41.10742327900344\n",
      "EPOCH: 2772 LOSS: 41.1073958701704\n",
      "EPOCH: 2773 LOSS: 41.107368474342685\n",
      "EPOCH: 2774 LOSS: 41.10734109150478\n",
      "EPOCH: 2775 LOSS: 41.10731372164121\n",
      "EPOCH: 2776 LOSS: 41.10728636473651\n",
      "EPOCH: 2777 LOSS: 41.10725902077527\n",
      "EPOCH: 2778 LOSS: 41.10723168974207\n",
      "EPOCH: 2779 LOSS: 41.10720437162153\n",
      "EPOCH: 2780 LOSS: 41.10717706639834\n",
      "EPOCH: 2781 LOSS: 41.10714977405716\n",
      "EPOCH: 2782 LOSS: 41.107122494582725\n",
      "EPOCH: 2783 LOSS: 41.107095227959775\n",
      "EPOCH: 2784 LOSS: 41.10706797417306\n",
      "EPOCH: 2785 LOSS: 41.10704073320741\n",
      "EPOCH: 2786 LOSS: 41.10701350504765\n",
      "EPOCH: 2787 LOSS: 41.1069862896786\n",
      "EPOCH: 2788 LOSS: 41.106959087085215\n",
      "EPOCH: 2789 LOSS: 41.10693189725234\n",
      "EPOCH: 2790 LOSS: 41.10690472016495\n",
      "EPOCH: 2791 LOSS: 41.106877555808026\n",
      "EPOCH: 2792 LOSS: 41.106850404166536\n",
      "EPOCH: 2793 LOSS: 41.106823265225536\n",
      "EPOCH: 2794 LOSS: 41.10679613897005\n",
      "EPOCH: 2795 LOSS: 41.10676902538519\n",
      "EPOCH: 2796 LOSS: 41.10674192445604\n",
      "EPOCH: 2797 LOSS: 41.10671483616776\n",
      "EPOCH: 2798 LOSS: 41.10668776050548\n",
      "EPOCH: 2799 LOSS: 41.106660697454444\n",
      "EPOCH: 2800 LOSS: 41.106633646999825\n",
      "EPOCH: 2801 LOSS: 41.1066066091269\n",
      "EPOCH: 2802 LOSS: 41.106579583820924\n",
      "EPOCH: 2803 LOSS: 41.106552571067205\n",
      "EPOCH: 2804 LOSS: 41.10652557085107\n",
      "EPOCH: 2805 LOSS: 41.106498583157894\n",
      "EPOCH: 2806 LOSS: 41.10647160797303\n",
      "EPOCH: 2807 LOSS: 41.106444645281904\n",
      "EPOCH: 2808 LOSS: 41.10641769506995\n",
      "EPOCH: 2809 LOSS: 41.10639075732264\n",
      "EPOCH: 2810 LOSS: 41.10636383202545\n",
      "EPOCH: 2811 LOSS: 41.10633691916392\n",
      "EPOCH: 2812 LOSS: 41.10631001872358\n",
      "EPOCH: 2813 LOSS: 41.106283130689995\n",
      "EPOCH: 2814 LOSS: 41.10625625504878\n",
      "EPOCH: 2815 LOSS: 41.10622939178553\n",
      "EPOCH: 2816 LOSS: 41.10620254088593\n",
      "EPOCH: 2817 LOSS: 41.10617570233565\n",
      "EPOCH: 2818 LOSS: 41.10614887612037\n",
      "EPOCH: 2819 LOSS: 41.10612206222585\n",
      "EPOCH: 2820 LOSS: 41.106095260637815\n",
      "EPOCH: 2821 LOSS: 41.106068471342084\n",
      "EPOCH: 2822 LOSS: 41.10604169432443\n",
      "EPOCH: 2823 LOSS: 41.106014929570705\n",
      "EPOCH: 2824 LOSS: 41.10598817706678\n",
      "EPOCH: 2825 LOSS: 41.10596143679852\n",
      "EPOCH: 2826 LOSS: 41.105934708751846\n",
      "EPOCH: 2827 LOSS: 41.10590799291269\n",
      "EPOCH: 2828 LOSS: 41.10588128926703\n",
      "EPOCH: 2829 LOSS: 41.10585459780085\n",
      "EPOCH: 2830 LOSS: 41.10582791850016\n",
      "EPOCH: 2831 LOSS: 41.10580125135101\n",
      "EPOCH: 2832 LOSS: 41.10577459633945\n",
      "EPOCH: 2833 LOSS: 41.10574795345158\n",
      "EPOCH: 2834 LOSS: 41.10572132267353\n",
      "EPOCH: 2835 LOSS: 41.105694703991425\n",
      "EPOCH: 2836 LOSS: 41.10566809739144\n",
      "EPOCH: 2837 LOSS: 41.10564150285977\n",
      "EPOCH: 2838 LOSS: 41.10561492038263\n",
      "EPOCH: 2839 LOSS: 41.10558834994627\n",
      "EPOCH: 2840 LOSS: 41.10556179153693\n",
      "EPOCH: 2841 LOSS: 41.10553524514094\n",
      "EPOCH: 2842 LOSS: 41.105508710744616\n",
      "EPOCH: 2843 LOSS: 41.10548218833428\n",
      "EPOCH: 2844 LOSS: 41.105455677896316\n",
      "EPOCH: 2845 LOSS: 41.1054291794171\n",
      "EPOCH: 2846 LOSS: 41.10540269288307\n",
      "EPOCH: 2847 LOSS: 41.105376218280654\n",
      "EPOCH: 2848 LOSS: 41.10534975559633\n",
      "EPOCH: 2849 LOSS: 41.10532330481658\n",
      "EPOCH: 2850 LOSS: 41.10529686592792\n",
      "EPOCH: 2851 LOSS: 41.10527043891689\n",
      "EPOCH: 2852 LOSS: 41.10524402377007\n",
      "EPOCH: 2853 LOSS: 41.10521762047404\n",
      "EPOCH: 2854 LOSS: 41.105191229015404\n",
      "EPOCH: 2855 LOSS: 41.10516484938079\n",
      "EPOCH: 2856 LOSS: 41.10513848155691\n",
      "EPOCH: 2857 LOSS: 41.105112125530404\n",
      "EPOCH: 2858 LOSS: 41.10508578128799\n",
      "EPOCH: 2859 LOSS: 41.10505944881643\n",
      "EPOCH: 2860 LOSS: 41.105033128102434\n",
      "EPOCH: 2861 LOSS: 41.10500681913282\n",
      "EPOCH: 2862 LOSS: 41.104980521894376\n",
      "EPOCH: 2863 LOSS: 41.10495423637395\n",
      "EPOCH: 2864 LOSS: 41.10492796255838\n",
      "EPOCH: 2865 LOSS: 41.10490170043454\n",
      "EPOCH: 2866 LOSS: 41.104875449989336\n",
      "EPOCH: 2867 LOSS: 41.10484921120971\n",
      "EPOCH: 2868 LOSS: 41.10482298408258\n",
      "EPOCH: 2869 LOSS: 41.10479676859495\n",
      "EPOCH: 2870 LOSS: 41.104770564733776\n",
      "EPOCH: 2871 LOSS: 41.1047443724861\n",
      "EPOCH: 2872 LOSS: 41.10471819183897\n",
      "EPOCH: 2873 LOSS: 41.10469202277943\n",
      "EPOCH: 2874 LOSS: 41.10466586529459\n",
      "EPOCH: 2875 LOSS: 41.104639719371534\n",
      "EPOCH: 2876 LOSS: 41.10461358499742\n",
      "EPOCH: 2877 LOSS: 41.10458746215939\n",
      "EPOCH: 2878 LOSS: 41.10456135084464\n",
      "EPOCH: 2879 LOSS: 41.10453525104037\n",
      "EPOCH: 2880 LOSS: 41.10450916273379\n",
      "EPOCH: 2881 LOSS: 41.10448308591216\n",
      "EPOCH: 2882 LOSS: 41.10445702056274\n",
      "EPOCH: 2883 LOSS: 41.10443096667284\n",
      "EPOCH: 2884 LOSS: 41.10440492422978\n",
      "EPOCH: 2885 LOSS: 41.1043788932209\n",
      "EPOCH: 2886 LOSS: 41.10435287363354\n",
      "EPOCH: 2887 LOSS: 41.10432686545511\n",
      "EPOCH: 2888 LOSS: 41.10430086867299\n",
      "EPOCH: 2889 LOSS: 41.10427488327463\n",
      "EPOCH: 2890 LOSS: 41.104248909247495\n",
      "EPOCH: 2891 LOSS: 41.104222946579036\n",
      "EPOCH: 2892 LOSS: 41.10419699525676\n",
      "EPOCH: 2893 LOSS: 41.10417105526818\n",
      "EPOCH: 2894 LOSS: 41.104145126600834\n",
      "EPOCH: 2895 LOSS: 41.104119209242306\n",
      "EPOCH: 2896 LOSS: 41.104093303180164\n",
      "EPOCH: 2897 LOSS: 41.10406740840202\n",
      "EPOCH: 2898 LOSS: 41.10404152489551\n",
      "EPOCH: 2899 LOSS: 41.10401565264827\n",
      "EPOCH: 2900 LOSS: 41.10398979164799\n",
      "EPOCH: 2901 LOSS: 41.10396394188234\n",
      "EPOCH: 2902 LOSS: 41.10393810333909\n",
      "EPOCH: 2903 LOSS: 41.10391227600593\n",
      "EPOCH: 2904 LOSS: 41.10388645987062\n",
      "EPOCH: 2905 LOSS: 41.10386065492098\n",
      "EPOCH: 2906 LOSS: 41.10383486114479\n",
      "EPOCH: 2907 LOSS: 41.10380907852986\n",
      "EPOCH: 2908 LOSS: 41.10378330706406\n",
      "EPOCH: 2909 LOSS: 41.103757546735274\n",
      "EPOCH: 2910 LOSS: 41.10373179753136\n",
      "EPOCH: 2911 LOSS: 41.10370605944024\n",
      "EPOCH: 2912 LOSS: 41.103680332449855\n",
      "EPOCH: 2913 LOSS: 41.10365461654813\n",
      "EPOCH: 2914 LOSS: 41.10362891172308\n",
      "EPOCH: 2915 LOSS: 41.10360321796268\n",
      "EPOCH: 2916 LOSS: 41.103577535254956\n",
      "EPOCH: 2917 LOSS: 41.103551863587924\n",
      "EPOCH: 2918 LOSS: 41.10352620294966\n",
      "EPOCH: 2919 LOSS: 41.10350055332826\n",
      "EPOCH: 2920 LOSS: 41.103474914711796\n",
      "EPOCH: 2921 LOSS: 41.103449287088424\n",
      "EPOCH: 2922 LOSS: 41.103423670446254\n",
      "EPOCH: 2923 LOSS: 41.10339806477348\n",
      "EPOCH: 2924 LOSS: 41.10337247005826\n",
      "EPOCH: 2925 LOSS: 41.10334688628882\n",
      "EPOCH: 2926 LOSS: 41.10332131345337\n",
      "EPOCH: 2927 LOSS: 41.10329575154017\n",
      "EPOCH: 2928 LOSS: 41.10327020053747\n",
      "EPOCH: 2929 LOSS: 41.1032446604336\n",
      "EPOCH: 2930 LOSS: 41.10321913121683\n",
      "EPOCH: 2931 LOSS: 41.10319361287549\n",
      "EPOCH: 2932 LOSS: 41.103168105397934\n",
      "EPOCH: 2933 LOSS: 41.103142608772544\n",
      "EPOCH: 2934 LOSS: 41.10311712298769\n",
      "EPOCH: 2935 LOSS: 41.10309164803182\n",
      "EPOCH: 2936 LOSS: 41.103066183893326\n",
      "EPOCH: 2937 LOSS: 41.10304073056067\n",
      "EPOCH: 2938 LOSS: 41.103015288022334\n",
      "EPOCH: 2939 LOSS: 41.102989856266795\n",
      "EPOCH: 2940 LOSS: 41.10296443528257\n",
      "EPOCH: 2941 LOSS: 41.102939025058205\n",
      "EPOCH: 2942 LOSS: 41.102913625582204\n",
      "EPOCH: 2943 LOSS: 41.10288823684321\n",
      "EPOCH: 2944 LOSS: 41.10286285882974\n",
      "EPOCH: 2945 LOSS: 41.10283749153045\n",
      "EPOCH: 2946 LOSS: 41.10281213493397\n",
      "EPOCH: 2947 LOSS: 41.10278678902893\n",
      "EPOCH: 2948 LOSS: 41.102761453804014\n",
      "EPOCH: 2949 LOSS: 41.102736129247916\n",
      "EPOCH: 2950 LOSS: 41.10271081534934\n",
      "EPOCH: 2951 LOSS: 41.102685512097\n",
      "EPOCH: 2952 LOSS: 41.10266021947966\n",
      "EPOCH: 2953 LOSS: 41.10263493748608\n",
      "EPOCH: 2954 LOSS: 41.10260966610507\n",
      "EPOCH: 2955 LOSS: 41.10258440532541\n",
      "EPOCH: 2956 LOSS: 41.10255915513592\n",
      "EPOCH: 2957 LOSS: 41.10253391552547\n",
      "EPOCH: 2958 LOSS: 41.10250868648292\n",
      "EPOCH: 2959 LOSS: 41.10248346799715\n",
      "EPOCH: 2960 LOSS: 41.10245826005706\n",
      "EPOCH: 2961 LOSS: 41.10243306265157\n",
      "EPOCH: 2962 LOSS: 41.10240787576964\n",
      "EPOCH: 2963 LOSS: 41.10238269940021\n",
      "EPOCH: 2964 LOSS: 41.10235753353227\n",
      "EPOCH: 2965 LOSS: 41.10233237815481\n",
      "EPOCH: 2966 LOSS: 41.10230723325685\n",
      "EPOCH: 2967 LOSS: 41.10228209882743\n",
      "EPOCH: 2968 LOSS: 41.10225697485563\n",
      "EPOCH: 2969 LOSS: 41.10223186133048\n",
      "EPOCH: 2970 LOSS: 41.10220675824108\n",
      "EPOCH: 2971 LOSS: 41.10218166557658\n",
      "EPOCH: 2972 LOSS: 41.10215658332606\n",
      "EPOCH: 2973 LOSS: 41.10213151147869\n",
      "EPOCH: 2974 LOSS: 41.102106450023655\n",
      "EPOCH: 2975 LOSS: 41.10208139895013\n",
      "EPOCH: 2976 LOSS: 41.102056358247296\n",
      "EPOCH: 2977 LOSS: 41.10203132790441\n",
      "EPOCH: 2978 LOSS: 41.1020063079107\n",
      "EPOCH: 2979 LOSS: 41.101981298255424\n",
      "EPOCH: 2980 LOSS: 41.101956298927874\n",
      "EPOCH: 2981 LOSS: 41.10193130991733\n",
      "EPOCH: 2982 LOSS: 41.10190633121311\n",
      "EPOCH: 2983 LOSS: 41.10188136280454\n",
      "EPOCH: 2984 LOSS: 41.101856404681\n",
      "EPOCH: 2985 LOSS: 41.10183145683184\n",
      "EPOCH: 2986 LOSS: 41.10180651924644\n",
      "EPOCH: 2987 LOSS: 41.10178159191423\n",
      "EPOCH: 2988 LOSS: 41.10175667482461\n",
      "EPOCH: 2989 LOSS: 41.10173176796703\n",
      "EPOCH: 2990 LOSS: 41.10170687133097\n",
      "EPOCH: 2991 LOSS: 41.10168198490587\n",
      "EPOCH: 2992 LOSS: 41.10165710868126\n",
      "EPOCH: 2993 LOSS: 41.101632242646644\n",
      "EPOCH: 2994 LOSS: 41.10160738679154\n",
      "EPOCH: 2995 LOSS: 41.101582541105515\n",
      "EPOCH: 2996 LOSS: 41.10155770557813\n",
      "EPOCH: 2997 LOSS: 41.10153288019897\n",
      "EPOCH: 2998 LOSS: 41.101508064957635\n",
      "EPOCH: 2999 LOSS: 41.10148325984376\n",
      "EPOCH: 3000 LOSS: 41.10145846484696\n",
      "EPOCH: 3001 LOSS: 41.101433679956905\n",
      "EPOCH: 3002 LOSS: 41.10140890516326\n",
      "EPOCH: 3003 LOSS: 41.10138414045572\n",
      "EPOCH: 3004 LOSS: 41.101359385824\n",
      "EPOCH: 3005 LOSS: 41.10133464125782\n",
      "EPOCH: 3006 LOSS: 41.101309906746906\n",
      "EPOCH: 3007 LOSS: 41.10128518228106\n",
      "EPOCH: 3008 LOSS: 41.101260467850025\n",
      "EPOCH: 3009 LOSS: 41.1012357634436\n",
      "EPOCH: 3010 LOSS: 41.1012110690516\n",
      "EPOCH: 3011 LOSS: 41.10118638466385\n",
      "EPOCH: 3012 LOSS: 41.10116171027021\n",
      "EPOCH: 3013 LOSS: 41.101137045860526\n",
      "EPOCH: 3014 LOSS: 41.10111239142471\n",
      "EPOCH: 3015 LOSS: 41.101087746952615\n",
      "EPOCH: 3016 LOSS: 41.101063112434204\n",
      "EPOCH: 3017 LOSS: 41.101038487859356\n",
      "EPOCH: 3018 LOSS: 41.101013873218065\n",
      "EPOCH: 3019 LOSS: 41.10098926850028\n",
      "EPOCH: 3020 LOSS: 41.10096467369596\n",
      "EPOCH: 3021 LOSS: 41.10094008879515\n",
      "EPOCH: 3022 LOSS: 41.10091551378783\n",
      "EPOCH: 3023 LOSS: 41.100890948664045\n",
      "EPOCH: 3024 LOSS: 41.10086639341385\n",
      "EPOCH: 3025 LOSS: 41.1008418480273\n",
      "EPOCH: 3026 LOSS: 41.10081731249449\n",
      "EPOCH: 3027 LOSS: 41.100792786805506\n",
      "EPOCH: 3028 LOSS: 41.10076827095048\n",
      "EPOCH: 3029 LOSS: 41.10074376491953\n",
      "EPOCH: 3030 LOSS: 41.10071926870282\n",
      "EPOCH: 3031 LOSS: 41.10069478229048\n",
      "EPOCH: 3032 LOSS: 41.10067030567274\n",
      "EPOCH: 3033 LOSS: 41.10064583883976\n",
      "EPOCH: 3034 LOSS: 41.100621381781785\n",
      "EPOCH: 3035 LOSS: 41.10059693448903\n",
      "EPOCH: 3036 LOSS: 41.100572496951756\n",
      "EPOCH: 3037 LOSS: 41.100548069160205\n",
      "EPOCH: 3038 LOSS: 41.10052365110469\n",
      "EPOCH: 3039 LOSS: 41.10049924277546\n",
      "EPOCH: 3040 LOSS: 41.10047484416286\n",
      "EPOCH: 3041 LOSS: 41.1004504552572\n",
      "EPOCH: 3042 LOSS: 41.10042607604886\n",
      "EPOCH: 3043 LOSS: 41.10040170652816\n",
      "EPOCH: 3044 LOSS: 41.100377346685505\n",
      "EPOCH: 3045 LOSS: 41.10035299651127\n",
      "EPOCH: 3046 LOSS: 41.10032865599587\n",
      "EPOCH: 3047 LOSS: 41.100304325129734\n",
      "EPOCH: 3048 LOSS: 41.1002800039033\n",
      "EPOCH: 3049 LOSS: 41.100255692307016\n",
      "EPOCH: 3050 LOSS: 41.100231390331366\n",
      "EPOCH: 3051 LOSS: 41.10020709796683\n",
      "EPOCH: 3052 LOSS: 41.100182815203915\n",
      "EPOCH: 3053 LOSS: 41.100158542033135\n",
      "EPOCH: 3054 LOSS: 41.10013427844504\n",
      "EPOCH: 3055 LOSS: 41.10011002443017\n",
      "EPOCH: 3056 LOSS: 41.10008577997909\n",
      "EPOCH: 3057 LOSS: 41.1000615450824\n",
      "EPOCH: 3058 LOSS: 41.10003731973066\n",
      "EPOCH: 3059 LOSS: 41.10001310391452\n",
      "EPOCH: 3060 LOSS: 41.099988897624584\n",
      "EPOCH: 3061 LOSS: 41.099964700851515\n",
      "EPOCH: 3062 LOSS: 41.09994051358598\n",
      "EPOCH: 3063 LOSS: 41.09991633581862\n",
      "EPOCH: 3064 LOSS: 41.099892167540155\n",
      "EPOCH: 3065 LOSS: 41.09986800874127\n",
      "EPOCH: 3066 LOSS: 41.0998438594127\n",
      "EPOCH: 3067 LOSS: 41.09981971954518\n",
      "EPOCH: 3068 LOSS: 41.09979558912946\n",
      "EPOCH: 3069 LOSS: 41.099771468156305\n",
      "EPOCH: 3070 LOSS: 41.099747356616504\n",
      "EPOCH: 3071 LOSS: 41.09972325450085\n",
      "EPOCH: 3072 LOSS: 41.09969916180013\n",
      "EPOCH: 3073 LOSS: 41.099675078505214\n",
      "EPOCH: 3074 LOSS: 41.09965100460693\n",
      "EPOCH: 3075 LOSS: 41.09962694009613\n",
      "EPOCH: 3076 LOSS: 41.09960288496368\n",
      "EPOCH: 3077 LOSS: 41.09957883920049\n",
      "EPOCH: 3078 LOSS: 41.09955480279742\n",
      "EPOCH: 3079 LOSS: 41.099530775745436\n",
      "EPOCH: 3080 LOSS: 41.099506758035446\n",
      "EPOCH: 3081 LOSS: 41.09948274965839\n",
      "EPOCH: 3082 LOSS: 41.09945875060525\n",
      "EPOCH: 3083 LOSS: 41.09943476086699\n",
      "EPOCH: 3084 LOSS: 41.09941078043461\n",
      "EPOCH: 3085 LOSS: 41.099386809299105\n",
      "EPOCH: 3086 LOSS: 41.099362847451495\n",
      "EPOCH: 3087 LOSS: 41.09933889488282\n",
      "EPOCH: 3088 LOSS: 41.099314951584134\n",
      "EPOCH: 3089 LOSS: 41.099291017546506\n",
      "EPOCH: 3090 LOSS: 41.099267092760996\n",
      "EPOCH: 3091 LOSS: 41.09924317721871\n",
      "EPOCH: 3092 LOSS: 41.099219270910744\n",
      "EPOCH: 3093 LOSS: 41.099195373828245\n",
      "EPOCH: 3094 LOSS: 41.09917148596235\n",
      "EPOCH: 3095 LOSS: 41.09914760730419\n",
      "EPOCH: 3096 LOSS: 41.099123737844906\n",
      "EPOCH: 3097 LOSS: 41.09909987757573\n",
      "EPOCH: 3098 LOSS: 41.09907602648785\n",
      "EPOCH: 3099 LOSS: 41.09905218457246\n",
      "EPOCH: 3100 LOSS: 41.09902835182076\n",
      "EPOCH: 3101 LOSS: 41.09900452822404\n",
      "EPOCH: 3102 LOSS: 41.0989807137735\n",
      "EPOCH: 3103 LOSS: 41.09895690846044\n",
      "EPOCH: 3104 LOSS: 41.09893311227614\n",
      "EPOCH: 3105 LOSS: 41.09890932521187\n",
      "EPOCH: 3106 LOSS: 41.098885547258945\n",
      "EPOCH: 3107 LOSS: 41.098861778408704\n",
      "EPOCH: 3108 LOSS: 41.098838018652465\n",
      "EPOCH: 3109 LOSS: 41.09881426798158\n",
      "EPOCH: 3110 LOSS: 41.09879052638745\n",
      "EPOCH: 3111 LOSS: 41.098766793861394\n",
      "EPOCH: 3112 LOSS: 41.09874307039484\n",
      "EPOCH: 3113 LOSS: 41.09871935597917\n",
      "EPOCH: 3114 LOSS: 41.09869565060583\n",
      "EPOCH: 3115 LOSS: 41.09867195426625\n",
      "EPOCH: 3116 LOSS: 41.098648266951855\n",
      "EPOCH: 3117 LOSS: 41.098624588654125\n",
      "EPOCH: 3118 LOSS: 41.098600919364536\n",
      "EPOCH: 3119 LOSS: 41.09857725907457\n",
      "EPOCH: 3120 LOSS: 41.098553607775735\n",
      "EPOCH: 3121 LOSS: 41.098529965459534\n",
      "EPOCH: 3122 LOSS: 41.09850633211751\n",
      "EPOCH: 3123 LOSS: 41.0984827077412\n",
      "EPOCH: 3124 LOSS: 41.09845909232216\n",
      "EPOCH: 3125 LOSS: 41.098435485851965\n",
      "EPOCH: 3126 LOSS: 41.09841188832219\n",
      "EPOCH: 3127 LOSS: 41.098388299724434\n",
      "EPOCH: 3128 LOSS: 41.098364720050334\n",
      "EPOCH: 3129 LOSS: 41.09834114929147\n",
      "EPOCH: 3130 LOSS: 41.09831758743952\n",
      "EPOCH: 3131 LOSS: 41.098294034486095\n",
      "EPOCH: 3132 LOSS: 41.098270490422884\n",
      "EPOCH: 3133 LOSS: 41.09824695524157\n",
      "EPOCH: 3134 LOSS: 41.098223428933835\n",
      "EPOCH: 3135 LOSS: 41.09819991149139\n",
      "EPOCH: 3136 LOSS: 41.098176402905935\n",
      "EPOCH: 3137 LOSS: 41.09815290316922\n",
      "EPOCH: 3138 LOSS: 41.09812941227297\n",
      "EPOCH: 3139 LOSS: 41.09810593020896\n",
      "EPOCH: 3140 LOSS: 41.09808245696895\n",
      "EPOCH: 3141 LOSS: 41.098058992544736\n",
      "EPOCH: 3142 LOSS: 41.098035536928094\n",
      "EPOCH: 3143 LOSS: 41.09801209011084\n",
      "EPOCH: 3144 LOSS: 41.09798865208481\n",
      "EPOCH: 3145 LOSS: 41.09796522284183\n",
      "EPOCH: 3146 LOSS: 41.09794180237375\n",
      "EPOCH: 3147 LOSS: 41.097918390672405\n",
      "EPOCH: 3148 LOSS: 41.09789498772972\n",
      "EPOCH: 3149 LOSS: 41.09787159353755\n",
      "EPOCH: 3150 LOSS: 41.097848208087804\n",
      "EPOCH: 3151 LOSS: 41.09782483137239\n",
      "EPOCH: 3152 LOSS: 41.097801463383234\n",
      "EPOCH: 3153 LOSS: 41.09777810411226\n",
      "EPOCH: 3154 LOSS: 41.09775475355145\n",
      "EPOCH: 3155 LOSS: 41.09773141169275\n",
      "EPOCH: 3156 LOSS: 41.09770807852816\n",
      "EPOCH: 3157 LOSS: 41.097684754049624\n",
      "EPOCH: 3158 LOSS: 41.09766143824919\n",
      "EPOCH: 3159 LOSS: 41.09763813111884\n",
      "EPOCH: 3160 LOSS: 41.097614832650606\n",
      "EPOCH: 3161 LOSS: 41.097591542836554\n",
      "EPOCH: 3162 LOSS: 41.09756826166871\n",
      "EPOCH: 3163 LOSS: 41.09754498913916\n",
      "EPOCH: 3164 LOSS: 41.097521725239936\n",
      "EPOCH: 3165 LOSS: 41.0974984699632\n",
      "EPOCH: 3166 LOSS: 41.097475223301\n",
      "EPOCH: 3167 LOSS: 41.097451985245456\n",
      "EPOCH: 3168 LOSS: 41.09742875578873\n",
      "EPOCH: 3169 LOSS: 41.09740553492291\n",
      "EPOCH: 3170 LOSS: 41.09738232264019\n",
      "EPOCH: 3171 LOSS: 41.09735911893272\n",
      "EPOCH: 3172 LOSS: 41.09733592379268\n",
      "EPOCH: 3173 LOSS: 41.09731273721224\n",
      "EPOCH: 3174 LOSS: 41.09728955918365\n",
      "EPOCH: 3175 LOSS: 41.09726638969905\n",
      "EPOCH: 3176 LOSS: 41.09724322875073\n",
      "EPOCH: 3177 LOSS: 41.097220076330885\n",
      "EPOCH: 3178 LOSS: 41.0971969324318\n",
      "EPOCH: 3179 LOSS: 41.09717379704572\n",
      "EPOCH: 3180 LOSS: 41.09715067016493\n",
      "EPOCH: 3181 LOSS: 41.097127551781696\n",
      "EPOCH: 3182 LOSS: 41.09710444188832\n",
      "EPOCH: 3183 LOSS: 41.09708134047713\n",
      "EPOCH: 3184 LOSS: 41.09705824754044\n",
      "EPOCH: 3185 LOSS: 41.09703516307058\n",
      "EPOCH: 3186 LOSS: 41.0970120870599\n",
      "EPOCH: 3187 LOSS: 41.09698901950077\n",
      "EPOCH: 3188 LOSS: 41.09696596038553\n",
      "EPOCH: 3189 LOSS: 41.096942909706584\n",
      "EPOCH: 3190 LOSS: 41.096919867456336\n",
      "EPOCH: 3191 LOSS: 41.09689683362717\n",
      "EPOCH: 3192 LOSS: 41.09687380821153\n",
      "EPOCH: 3193 LOSS: 41.0968507912018\n",
      "EPOCH: 3194 LOSS: 41.09682778259047\n",
      "EPOCH: 3195 LOSS: 41.09680478236996\n",
      "EPOCH: 3196 LOSS: 41.09678179053276\n",
      "EPOCH: 3197 LOSS: 41.096758807071325\n",
      "EPOCH: 3198 LOSS: 41.09673583197816\n",
      "EPOCH: 3199 LOSS: 41.09671286524575\n",
      "EPOCH: 3200 LOSS: 41.09668990686661\n",
      "EPOCH: 3201 LOSS: 41.09666695683328\n",
      "EPOCH: 3202 LOSS: 41.09664401513827\n",
      "EPOCH: 3203 LOSS: 41.096621081774146\n",
      "EPOCH: 3204 LOSS: 41.09659815673346\n",
      "EPOCH: 3205 LOSS: 41.09657524000877\n",
      "EPOCH: 3206 LOSS: 41.09655233159267\n",
      "EPOCH: 3207 LOSS: 41.096529431477755\n",
      "EPOCH: 3208 LOSS: 41.09650653965661\n",
      "EPOCH: 3209 LOSS: 41.09648365612187\n",
      "EPOCH: 3210 LOSS: 41.09646078086615\n",
      "EPOCH: 3211 LOSS: 41.09643791388212\n",
      "EPOCH: 3212 LOSS: 41.09641505516236\n",
      "EPOCH: 3213 LOSS: 41.09639220469959\n",
      "EPOCH: 3214 LOSS: 41.09636936248648\n",
      "EPOCH: 3215 LOSS: 41.09634652851567\n",
      "EPOCH: 3216 LOSS: 41.0963237027799\n",
      "EPOCH: 3217 LOSS: 41.09630088527187\n",
      "EPOCH: 3218 LOSS: 41.096278075984245\n",
      "EPOCH: 3219 LOSS: 41.09625527490983\n",
      "EPOCH: 3220 LOSS: 41.09623248204132\n",
      "EPOCH: 3221 LOSS: 41.096209697371464\n",
      "EPOCH: 3222 LOSS: 41.09618692089305\n",
      "EPOCH: 3223 LOSS: 41.09616415259882\n",
      "EPOCH: 3224 LOSS: 41.096141392481584\n",
      "EPOCH: 3225 LOSS: 41.0961186405341\n",
      "EPOCH: 3226 LOSS: 41.09609589674923\n",
      "EPOCH: 3227 LOSS: 41.09607316111974\n",
      "EPOCH: 3228 LOSS: 41.09605043363849\n",
      "EPOCH: 3229 LOSS: 41.0960277142983\n",
      "EPOCH: 3230 LOSS: 41.09600500309203\n",
      "EPOCH: 3231 LOSS: 41.09598230001255\n",
      "EPOCH: 3232 LOSS: 41.095959605052705\n",
      "EPOCH: 3233 LOSS: 41.09593691820539\n",
      "EPOCH: 3234 LOSS: 41.095914239463525\n",
      "EPOCH: 3235 LOSS: 41.095891568819965\n",
      "EPOCH: 3236 LOSS: 41.09586890626768\n",
      "EPOCH: 3237 LOSS: 41.09584625179954\n",
      "EPOCH: 3238 LOSS: 41.09582360540854\n",
      "EPOCH: 3239 LOSS: 41.09580096708757\n",
      "EPOCH: 3240 LOSS: 41.09577833682964\n",
      "EPOCH: 3241 LOSS: 41.09575571462769\n",
      "EPOCH: 3242 LOSS: 41.09573310047469\n",
      "EPOCH: 3243 LOSS: 41.095710494363644\n",
      "EPOCH: 3244 LOSS: 41.09568789628758\n",
      "EPOCH: 3245 LOSS: 41.09566530623947\n",
      "EPOCH: 3246 LOSS: 41.095642724212354\n",
      "EPOCH: 3247 LOSS: 41.09562015019927\n",
      "EPOCH: 3248 LOSS: 41.095597584193236\n",
      "EPOCH: 3249 LOSS: 41.09557502618734\n",
      "EPOCH: 3250 LOSS: 41.095552476174646\n",
      "EPOCH: 3251 LOSS: 41.09552993414819\n",
      "EPOCH: 3252 LOSS: 41.095507400101084\n",
      "EPOCH: 3253 LOSS: 41.095484874026425\n",
      "EPOCH: 3254 LOSS: 41.09546235591733\n",
      "EPOCH: 3255 LOSS: 41.09543984576689\n",
      "EPOCH: 3256 LOSS: 41.095417343568265\n",
      "EPOCH: 3257 LOSS: 41.09539484931457\n",
      "EPOCH: 3258 LOSS: 41.095372362998944\n",
      "EPOCH: 3259 LOSS: 41.09534988461456\n",
      "EPOCH: 3260 LOSS: 41.0953274141546\n",
      "EPOCH: 3261 LOSS: 41.09530495161223\n",
      "EPOCH: 3262 LOSS: 41.095282496980644\n",
      "EPOCH: 3263 LOSS: 41.095260050253\n",
      "EPOCH: 3264 LOSS: 41.09523761142259\n",
      "EPOCH: 3265 LOSS: 41.09521518048257\n",
      "EPOCH: 3266 LOSS: 41.0951927574262\n",
      "EPOCH: 3267 LOSS: 41.095170342246696\n",
      "EPOCH: 3268 LOSS: 41.095147934937344\n",
      "EPOCH: 3269 LOSS: 41.09512553549138\n",
      "EPOCH: 3270 LOSS: 41.09510314390207\n",
      "EPOCH: 3271 LOSS: 41.095080760162716\n",
      "EPOCH: 3272 LOSS: 41.09505838426659\n",
      "EPOCH: 3273 LOSS: 41.095036016207025\n",
      "EPOCH: 3274 LOSS: 41.09501365597729\n",
      "EPOCH: 3275 LOSS: 41.09499130357074\n",
      "EPOCH: 3276 LOSS: 41.09496895898069\n",
      "EPOCH: 3277 LOSS: 41.094946622200474\n",
      "EPOCH: 3278 LOSS: 41.09492429322347\n",
      "EPOCH: 3279 LOSS: 41.09490197204302\n",
      "EPOCH: 3280 LOSS: 41.0948796586525\n",
      "EPOCH: 3281 LOSS: 41.09485735304531\n",
      "EPOCH: 3282 LOSS: 41.09483505521479\n",
      "EPOCH: 3283 LOSS: 41.0948127651544\n",
      "EPOCH: 3284 LOSS: 41.09479048285751\n",
      "EPOCH: 3285 LOSS: 41.09476820831757\n",
      "EPOCH: 3286 LOSS: 41.09474594152799\n",
      "EPOCH: 3287 LOSS: 41.094723682482226\n",
      "EPOCH: 3288 LOSS: 41.094701431173704\n",
      "EPOCH: 3289 LOSS: 41.094679187595915\n",
      "EPOCH: 3290 LOSS: 41.094656951742294\n",
      "EPOCH: 3291 LOSS: 41.094634723606354\n",
      "EPOCH: 3292 LOSS: 41.09461250318158\n",
      "EPOCH: 3293 LOSS: 41.09459029046144\n",
      "EPOCH: 3294 LOSS: 41.09456808543948\n",
      "EPOCH: 3295 LOSS: 41.094545888109195\n",
      "EPOCH: 3296 LOSS: 41.094523698464116\n",
      "EPOCH: 3297 LOSS: 41.094501516497786\n",
      "EPOCH: 3298 LOSS: 41.094479342203755\n",
      "EPOCH: 3299 LOSS: 41.09445717557557\n",
      "EPOCH: 3300 LOSS: 41.09443501660682\n",
      "EPOCH: 3301 LOSS: 41.09441286529104\n",
      "EPOCH: 3302 LOSS: 41.09439072162185\n",
      "EPOCH: 3303 LOSS: 41.09436858559284\n",
      "EPOCH: 3304 LOSS: 41.094346457197595\n",
      "EPOCH: 3305 LOSS: 41.094324336429736\n",
      "EPOCH: 3306 LOSS: 41.09430222328291\n",
      "EPOCH: 3307 LOSS: 41.09428011775073\n",
      "EPOCH: 3308 LOSS: 41.094258019826825\n",
      "EPOCH: 3309 LOSS: 41.09423592950487\n",
      "EPOCH: 3310 LOSS: 41.0942138467785\n",
      "EPOCH: 3311 LOSS: 41.09419177164142\n",
      "EPOCH: 3312 LOSS: 41.094169704087285\n",
      "EPOCH: 3313 LOSS: 41.09414764410978\n",
      "EPOCH: 3314 LOSS: 41.09412559170262\n",
      "EPOCH: 3315 LOSS: 41.09410354685952\n",
      "EPOCH: 3316 LOSS: 41.09408150957416\n",
      "EPOCH: 3317 LOSS: 41.094059479840304\n",
      "EPOCH: 3318 LOSS: 41.094037457651666\n",
      "EPOCH: 3319 LOSS: 41.09401544300198\n",
      "EPOCH: 3320 LOSS: 41.09399343588502\n",
      "EPOCH: 3321 LOSS: 41.09397143629455\n",
      "EPOCH: 3322 LOSS: 41.09394944422434\n",
      "EPOCH: 3323 LOSS: 41.09392745966817\n",
      "EPOCH: 3324 LOSS: 41.09390548261981\n",
      "EPOCH: 3325 LOSS: 41.09388351307308\n",
      "EPOCH: 3326 LOSS: 41.09386155102179\n",
      "EPOCH: 3327 LOSS: 41.093839596459745\n",
      "EPOCH: 3328 LOSS: 41.09381764938077\n",
      "EPOCH: 3329 LOSS: 41.093795709778725\n",
      "EPOCH: 3330 LOSS: 41.09377377764744\n",
      "EPOCH: 3331 LOSS: 41.09375185298074\n",
      "EPOCH: 3332 LOSS: 41.09372993577255\n",
      "EPOCH: 3333 LOSS: 41.093708026016685\n",
      "EPOCH: 3334 LOSS: 41.093686123707045\n",
      "EPOCH: 3335 LOSS: 41.09366422883753\n",
      "EPOCH: 3336 LOSS: 41.09364234140202\n",
      "EPOCH: 3337 LOSS: 41.09362046139444\n",
      "EPOCH: 3338 LOSS: 41.093598588808675\n",
      "EPOCH: 3339 LOSS: 41.09357672363869\n",
      "EPOCH: 3340 LOSS: 41.0935548658784\n",
      "EPOCH: 3341 LOSS: 41.093533015521736\n",
      "EPOCH: 3342 LOSS: 41.093511172562664\n",
      "EPOCH: 3343 LOSS: 41.093489336995155\n",
      "EPOCH: 3344 LOSS: 41.09346750881316\n",
      "EPOCH: 3345 LOSS: 41.09344568801065\n",
      "EPOCH: 3346 LOSS: 41.09342387458164\n",
      "EPOCH: 3347 LOSS: 41.0934020685201\n",
      "EPOCH: 3348 LOSS: 41.093380269820045\n",
      "EPOCH: 3349 LOSS: 41.09335847847548\n",
      "EPOCH: 3350 LOSS: 41.09333669448044\n",
      "EPOCH: 3351 LOSS: 41.093314917828934\n",
      "EPOCH: 3352 LOSS: 41.093293148515016\n",
      "EPOCH: 3353 LOSS: 41.09327138653274\n",
      "EPOCH: 3354 LOSS: 41.09324963187615\n",
      "EPOCH: 3355 LOSS: 41.09322788453932\n",
      "EPOCH: 3356 LOSS: 41.0932061445163\n",
      "EPOCH: 3357 LOSS: 41.093184411801204\n",
      "EPOCH: 3358 LOSS: 41.093162686388084\n",
      "EPOCH: 3359 LOSS: 41.09314096827108\n",
      "EPOCH: 3360 LOSS: 41.09311925744427\n",
      "EPOCH: 3361 LOSS: 41.093097553901785\n",
      "EPOCH: 3362 LOSS: 41.09307585763774\n",
      "EPOCH: 3363 LOSS: 41.093054168646276\n",
      "EPOCH: 3364 LOSS: 41.09303248692153\n",
      "EPOCH: 3365 LOSS: 41.09301081245765\n",
      "EPOCH: 3366 LOSS: 41.092989145248794\n",
      "EPOCH: 3367 LOSS: 41.09296748528912\n",
      "EPOCH: 3368 LOSS: 41.09294583257284\n",
      "EPOCH: 3369 LOSS: 41.092924187094106\n",
      "EPOCH: 3370 LOSS: 41.09290254884711\n",
      "EPOCH: 3371 LOSS: 41.09288091782605\n",
      "EPOCH: 3372 LOSS: 41.09285929402513\n",
      "EPOCH: 3373 LOSS: 41.09283767743859\n",
      "EPOCH: 3374 LOSS: 41.092816068060635\n",
      "EPOCH: 3375 LOSS: 41.09279446588552\n",
      "EPOCH: 3376 LOSS: 41.09277287090746\n",
      "EPOCH: 3377 LOSS: 41.09275128312072\n",
      "EPOCH: 3378 LOSS: 41.09272970251955\n",
      "EPOCH: 3379 LOSS: 41.09270812909823\n",
      "EPOCH: 3380 LOSS: 41.092686562851014\n",
      "EPOCH: 3381 LOSS: 41.0926650037722\n",
      "EPOCH: 3382 LOSS: 41.09264345185606\n",
      "EPOCH: 3383 LOSS: 41.09262190709692\n",
      "EPOCH: 3384 LOSS: 41.09260036948908\n",
      "EPOCH: 3385 LOSS: 41.09257883902684\n",
      "EPOCH: 3386 LOSS: 41.09255731570454\n",
      "EPOCH: 3387 LOSS: 41.0925357995165\n",
      "EPOCH: 3388 LOSS: 41.092514290457046\n",
      "EPOCH: 3389 LOSS: 41.09249278852056\n",
      "EPOCH: 3390 LOSS: 41.092471293701394\n",
      "EPOCH: 3391 LOSS: 41.09244980599387\n",
      "EPOCH: 3392 LOSS: 41.092428325392405\n",
      "EPOCH: 3393 LOSS: 41.09240685189134\n",
      "EPOCH: 3394 LOSS: 41.0923853854851\n",
      "EPOCH: 3395 LOSS: 41.09236392616807\n",
      "EPOCH: 3396 LOSS: 41.09234247393463\n",
      "EPOCH: 3397 LOSS: 41.09232102877922\n",
      "EPOCH: 3398 LOSS: 41.092299590696236\n",
      "EPOCH: 3399 LOSS: 41.09227815968012\n",
      "EPOCH: 3400 LOSS: 41.092256735725314\n",
      "EPOCH: 3401 LOSS: 41.09223531882625\n",
      "EPOCH: 3402 LOSS: 41.09221390897737\n",
      "EPOCH: 3403 LOSS: 41.09219250617315\n",
      "EPOCH: 3404 LOSS: 41.09217111040807\n",
      "EPOCH: 3405 LOSS: 41.09214972167655\n",
      "EPOCH: 3406 LOSS: 41.092128339973115\n",
      "EPOCH: 3407 LOSS: 41.09210696529227\n",
      "EPOCH: 3408 LOSS: 41.09208559762847\n",
      "EPOCH: 3409 LOSS: 41.09206423697625\n",
      "EPOCH: 3410 LOSS: 41.09204288333011\n",
      "EPOCH: 3411 LOSS: 41.09202153668457\n",
      "EPOCH: 3412 LOSS: 41.09200019703417\n",
      "EPOCH: 3413 LOSS: 41.091978864373445\n",
      "EPOCH: 3414 LOSS: 41.09195753869692\n",
      "EPOCH: 3415 LOSS: 41.09193621999917\n",
      "EPOCH: 3416 LOSS: 41.09191490827476\n",
      "EPOCH: 3417 LOSS: 41.09189360351823\n",
      "EPOCH: 3418 LOSS: 41.091872305724166\n",
      "EPOCH: 3419 LOSS: 41.091851014887155\n",
      "EPOCH: 3420 LOSS: 41.09182973100179\n",
      "EPOCH: 3421 LOSS: 41.09180845406265\n",
      "EPOCH: 3422 LOSS: 41.09178718406438\n",
      "EPOCH: 3423 LOSS: 41.09176592100154\n",
      "EPOCH: 3424 LOSS: 41.091744664868806\n",
      "EPOCH: 3425 LOSS: 41.09172341566075\n",
      "EPOCH: 3426 LOSS: 41.091702173372056\n",
      "EPOCH: 3427 LOSS: 41.09168093799734\n",
      "EPOCH: 3428 LOSS: 41.09165970953125\n",
      "EPOCH: 3429 LOSS: 41.09163848796846\n",
      "EPOCH: 3430 LOSS: 41.09161727330363\n",
      "EPOCH: 3431 LOSS: 41.091596065531434\n",
      "EPOCH: 3432 LOSS: 41.091574864646546\n",
      "EPOCH: 3433 LOSS: 41.09155367064366\n",
      "EPOCH: 3434 LOSS: 41.09153248351747\n",
      "EPOCH: 3435 LOSS: 41.09151130326266\n",
      "EPOCH: 3436 LOSS: 41.091490129873975\n",
      "EPOCH: 3437 LOSS: 41.09146896334612\n",
      "EPOCH: 3438 LOSS: 41.09144780367381\n",
      "EPOCH: 3439 LOSS: 41.09142665085177\n",
      "EPOCH: 3440 LOSS: 41.09140550487476\n",
      "EPOCH: 3441 LOSS: 41.091384365737525\n",
      "EPOCH: 3442 LOSS: 41.091363233434805\n",
      "EPOCH: 3443 LOSS: 41.09134210796136\n",
      "EPOCH: 3444 LOSS: 41.091320989311974\n",
      "EPOCH: 3445 LOSS: 41.091299877481426\n",
      "EPOCH: 3446 LOSS: 41.09127877246447\n",
      "EPOCH: 3447 LOSS: 41.091257674255935\n",
      "EPOCH: 3448 LOSS: 41.0912365828506\n",
      "EPOCH: 3449 LOSS: 41.09121549824326\n",
      "EPOCH: 3450 LOSS: 41.09119442042872\n",
      "EPOCH: 3451 LOSS: 41.091173349401835\n",
      "EPOCH: 3452 LOSS: 41.091152285157406\n",
      "EPOCH: 3453 LOSS: 41.091131227690276\n",
      "EPOCH: 3454 LOSS: 41.09111017699529\n",
      "EPOCH: 3455 LOSS: 41.09108913306727\n",
      "EPOCH: 3456 LOSS: 41.0910680959011\n",
      "EPOCH: 3457 LOSS: 41.09104706549162\n",
      "EPOCH: 3458 LOSS: 41.09102604183373\n",
      "EPOCH: 3459 LOSS: 41.091005024922275\n",
      "EPOCH: 3460 LOSS: 41.090984014752145\n",
      "EPOCH: 3461 LOSS: 41.09096301131825\n",
      "EPOCH: 3462 LOSS: 41.09094201461546\n",
      "EPOCH: 3463 LOSS: 41.0909210246387\n",
      "EPOCH: 3464 LOSS: 41.09090004138286\n",
      "EPOCH: 3465 LOSS: 41.09087906484288\n",
      "EPOCH: 3466 LOSS: 41.09085809501369\n",
      "EPOCH: 3467 LOSS: 41.09083713189019\n",
      "EPOCH: 3468 LOSS: 41.09081617546734\n",
      "EPOCH: 3469 LOSS: 41.090795225740095\n",
      "EPOCH: 3470 LOSS: 41.090774282703386\n",
      "EPOCH: 3471 LOSS: 41.09075334635221\n",
      "EPOCH: 3472 LOSS: 41.0907324166815\n",
      "EPOCH: 3473 LOSS: 41.090711493686236\n",
      "EPOCH: 3474 LOSS: 41.0906905773614\n",
      "EPOCH: 3475 LOSS: 41.09066966770198\n",
      "EPOCH: 3476 LOSS: 41.09064876470299\n",
      "EPOCH: 3477 LOSS: 41.090627868359405\n",
      "EPOCH: 3478 LOSS: 41.090606978666244\n",
      "EPOCH: 3479 LOSS: 41.09058609561853\n",
      "EPOCH: 3480 LOSS: 41.09056521921126\n",
      "EPOCH: 3481 LOSS: 41.09054434943949\n",
      "EPOCH: 3482 LOSS: 41.090523486298245\n",
      "EPOCH: 3483 LOSS: 41.09050262978258\n",
      "EPOCH: 3484 LOSS: 41.0904817798875\n",
      "EPOCH: 3485 LOSS: 41.09046093660811\n",
      "EPOCH: 3486 LOSS: 41.090440099939464\n",
      "EPOCH: 3487 LOSS: 41.09041926987661\n",
      "EPOCH: 3488 LOSS: 41.090398446414646\n",
      "EPOCH: 3489 LOSS: 41.09037762954864\n",
      "EPOCH: 3490 LOSS: 41.09035681927369\n",
      "EPOCH: 3491 LOSS: 41.090336015584896\n",
      "EPOCH: 3492 LOSS: 41.09031521847733\n",
      "EPOCH: 3493 LOSS: 41.09029442794615\n",
      "EPOCH: 3494 LOSS: 41.09027364398642\n",
      "EPOCH: 3495 LOSS: 41.090252866593325\n",
      "EPOCH: 3496 LOSS: 41.09023209576195\n",
      "EPOCH: 3497 LOSS: 41.090211331487424\n",
      "EPOCH: 3498 LOSS: 41.090190573764914\n",
      "EPOCH: 3499 LOSS: 41.09016982258956\n",
      "EPOCH: 3500 LOSS: 41.09014907795653\n",
      "EPOCH: 3501 LOSS: 41.09012833986097\n",
      "EPOCH: 3502 LOSS: 41.09010760829804\n",
      "EPOCH: 3503 LOSS: 41.09008688326294\n",
      "EPOCH: 3504 LOSS: 41.09006616475086\n",
      "EPOCH: 3505 LOSS: 41.090045452756954\n",
      "EPOCH: 3506 LOSS: 41.09002474727643\n",
      "EPOCH: 3507 LOSS: 41.090004048304486\n",
      "EPOCH: 3508 LOSS: 41.08998335583635\n",
      "EPOCH: 3509 LOSS: 41.089962669867205\n",
      "EPOCH: 3510 LOSS: 41.0899419903923\n",
      "EPOCH: 3511 LOSS: 41.08992131740686\n",
      "EPOCH: 3512 LOSS: 41.08990065090609\n",
      "EPOCH: 3513 LOSS: 41.08987999088526\n",
      "EPOCH: 3514 LOSS: 41.089859337339604\n",
      "EPOCH: 3515 LOSS: 41.08983869026439\n",
      "EPOCH: 3516 LOSS: 41.08981804965485\n",
      "EPOCH: 3517 LOSS: 41.08979741550627\n",
      "EPOCH: 3518 LOSS: 41.08977678781392\n",
      "EPOCH: 3519 LOSS: 41.08975616657307\n",
      "EPOCH: 3520 LOSS: 41.089735551779\n",
      "EPOCH: 3521 LOSS: 41.089714943427026\n",
      "EPOCH: 3522 LOSS: 41.08969434151241\n",
      "EPOCH: 3523 LOSS: 41.0896737460305\n",
      "EPOCH: 3524 LOSS: 41.08965315697657\n",
      "EPOCH: 3525 LOSS: 41.08963257434594\n",
      "EPOCH: 3526 LOSS: 41.08961199813395\n",
      "EPOCH: 3527 LOSS: 41.08959142833592\n",
      "EPOCH: 3528 LOSS: 41.08957086494718\n",
      "EPOCH: 3529 LOSS: 41.08955030796305\n",
      "EPOCH: 3530 LOSS: 41.089529757378926\n",
      "EPOCH: 3531 LOSS: 41.08950921319014\n",
      "EPOCH: 3532 LOSS: 41.089488675392055\n",
      "EPOCH: 3533 LOSS: 41.089468143980014\n",
      "EPOCH: 3534 LOSS: 41.089447618949414\n",
      "EPOCH: 3535 LOSS: 41.08942710029563\n",
      "EPOCH: 3536 LOSS: 41.08940658801404\n",
      "EPOCH: 3537 LOSS: 41.08938608210004\n",
      "EPOCH: 3538 LOSS: 41.089365582549014\n",
      "EPOCH: 3539 LOSS: 41.089345089356385\n",
      "EPOCH: 3540 LOSS: 41.08932460251755\n",
      "EPOCH: 3541 LOSS: 41.08930412202792\n",
      "EPOCH: 3542 LOSS: 41.08928364788294\n",
      "EPOCH: 3543 LOSS: 41.08926318007799\n",
      "EPOCH: 3544 LOSS: 41.089242718608574\n",
      "EPOCH: 3545 LOSS: 41.08922226347007\n",
      "EPOCH: 3546 LOSS: 41.08920181465793\n",
      "EPOCH: 3547 LOSS: 41.08918137216763\n",
      "EPOCH: 3548 LOSS: 41.08916093599463\n",
      "EPOCH: 3549 LOSS: 41.08914050613436\n",
      "EPOCH: 3550 LOSS: 41.08912008258231\n",
      "EPOCH: 3551 LOSS: 41.08909966533399\n",
      "EPOCH: 3552 LOSS: 41.08907925438483\n",
      "EPOCH: 3553 LOSS: 41.089058849730336\n",
      "EPOCH: 3554 LOSS: 41.089038451366\n",
      "EPOCH: 3555 LOSS: 41.089018059287305\n",
      "EPOCH: 3556 LOSS: 41.088997673489786\n",
      "EPOCH: 3557 LOSS: 41.08897729396895\n",
      "EPOCH: 3558 LOSS: 41.08895692072029\n",
      "EPOCH: 3559 LOSS: 41.088936553739366\n",
      "EPOCH: 3560 LOSS: 41.08891619302167\n",
      "EPOCH: 3561 LOSS: 41.08889583856276\n",
      "EPOCH: 3562 LOSS: 41.08887549035819\n",
      "EPOCH: 3563 LOSS: 41.08885514840346\n",
      "EPOCH: 3564 LOSS: 41.08883481269417\n",
      "EPOCH: 3565 LOSS: 41.08881448322583\n",
      "EPOCH: 3566 LOSS: 41.08879415999405\n",
      "EPOCH: 3567 LOSS: 41.088773842994385\n",
      "EPOCH: 3568 LOSS: 41.08875353222241\n",
      "EPOCH: 3569 LOSS: 41.08873322767369\n",
      "EPOCH: 3570 LOSS: 41.08871292934385\n",
      "EPOCH: 3571 LOSS: 41.08869263722845\n",
      "EPOCH: 3572 LOSS: 41.0886723513231\n",
      "EPOCH: 3573 LOSS: 41.08865207162341\n",
      "EPOCH: 3574 LOSS: 41.08863179812497\n",
      "EPOCH: 3575 LOSS: 41.08861153082342\n",
      "EPOCH: 3576 LOSS: 41.088591269714385\n",
      "EPOCH: 3577 LOSS: 41.088571014793466\n",
      "EPOCH: 3578 LOSS: 41.088550766056315\n",
      "EPOCH: 3579 LOSS: 41.08853052349858\n",
      "EPOCH: 3580 LOSS: 41.08851028711589\n",
      "EPOCH: 3581 LOSS: 41.0884900569039\n",
      "EPOCH: 3582 LOSS: 41.08846983285825\n",
      "EPOCH: 3583 LOSS: 41.08844961497464\n",
      "EPOCH: 3584 LOSS: 41.0884294032487\n",
      "EPOCH: 3585 LOSS: 41.08840919767612\n",
      "EPOCH: 3586 LOSS: 41.088388998252604\n",
      "EPOCH: 3587 LOSS: 41.088368804973776\n",
      "EPOCH: 3588 LOSS: 41.08834861783538\n",
      "EPOCH: 3589 LOSS: 41.08832843683308\n",
      "EPOCH: 3590 LOSS: 41.0883082619626\n",
      "EPOCH: 3591 LOSS: 41.088288093219646\n",
      "EPOCH: 3592 LOSS: 41.0882679305999\n",
      "EPOCH: 3593 LOSS: 41.08824777409911\n",
      "EPOCH: 3594 LOSS: 41.08822762371298\n",
      "EPOCH: 3595 LOSS: 41.08820747943726\n",
      "EPOCH: 3596 LOSS: 41.08818734126767\n",
      "EPOCH: 3597 LOSS: 41.08816720919995\n",
      "EPOCH: 3598 LOSS: 41.08814708322986\n",
      "EPOCH: 3599 LOSS: 41.08812696335314\n",
      "EPOCH: 3600 LOSS: 41.08810684956555\n",
      "EPOCH: 3601 LOSS: 41.08808674186283\n",
      "EPOCH: 3602 LOSS: 41.08806664024079\n",
      "EPOCH: 3603 LOSS: 41.08804654469517\n",
      "EPOCH: 3604 LOSS: 41.088026455221765\n",
      "EPOCH: 3605 LOSS: 41.08800637181634\n",
      "EPOCH: 3606 LOSS: 41.08798629447471\n",
      "EPOCH: 3607 LOSS: 41.08796622319266\n",
      "EPOCH: 3608 LOSS: 41.087946157966\n",
      "EPOCH: 3609 LOSS: 41.0879260987905\n",
      "EPOCH: 3610 LOSS: 41.08790604566201\n",
      "EPOCH: 3611 LOSS: 41.087885998576326\n",
      "EPOCH: 3612 LOSS: 41.08786595752926\n",
      "EPOCH: 3613 LOSS: 41.08784592251667\n",
      "EPOCH: 3614 LOSS: 41.08782589353439\n",
      "EPOCH: 3615 LOSS: 41.08780587057822\n",
      "EPOCH: 3616 LOSS: 41.08778585364402\n",
      "EPOCH: 3617 LOSS: 41.08776584272765\n",
      "EPOCH: 3618 LOSS: 41.087745837824976\n",
      "EPOCH: 3619 LOSS: 41.087725838931824\n",
      "EPOCH: 3620 LOSS: 41.08770584604408\n",
      "EPOCH: 3621 LOSS: 41.0876858591576\n",
      "EPOCH: 3622 LOSS: 41.087665878268275\n",
      "EPOCH: 3623 LOSS: 41.08764590337196\n",
      "EPOCH: 3624 LOSS: 41.08762593446458\n",
      "EPOCH: 3625 LOSS: 41.08760597154199\n",
      "EPOCH: 3626 LOSS: 41.087586014600106\n",
      "EPOCH: 3627 LOSS: 41.08756606363483\n",
      "EPOCH: 3628 LOSS: 41.087546118642045\n",
      "EPOCH: 3629 LOSS: 41.087526179617704\n",
      "EPOCH: 3630 LOSS: 41.08750624655767\n",
      "EPOCH: 3631 LOSS: 41.08748631945791\n",
      "EPOCH: 3632 LOSS: 41.08746639831435\n",
      "EPOCH: 3633 LOSS: 41.08744648312292\n",
      "EPOCH: 3634 LOSS: 41.087426573879526\n",
      "EPOCH: 3635 LOSS: 41.087406670580144\n",
      "EPOCH: 3636 LOSS: 41.08738677322072\n",
      "EPOCH: 3637 LOSS: 41.08736688179718\n",
      "EPOCH: 3638 LOSS: 41.08734699630551\n",
      "EPOCH: 3639 LOSS: 41.08732711674166\n",
      "EPOCH: 3640 LOSS: 41.087307243101634\n",
      "EPOCH: 3641 LOSS: 41.087287375381344\n",
      "EPOCH: 3642 LOSS: 41.08726751357682\n",
      "EPOCH: 3643 LOSS: 41.08724765768402\n",
      "EPOCH: 3644 LOSS: 41.08722780769894\n",
      "EPOCH: 3645 LOSS: 41.08720796361759\n",
      "EPOCH: 3646 LOSS: 41.087188125435944\n",
      "EPOCH: 3647 LOSS: 41.08716829315003\n",
      "EPOCH: 3648 LOSS: 41.087148466755835\n",
      "EPOCH: 3649 LOSS: 41.08712864624939\n",
      "EPOCH: 3650 LOSS: 41.08710883162671\n",
      "EPOCH: 3651 LOSS: 41.0870890228838\n",
      "EPOCH: 3652 LOSS: 41.08706922001674\n",
      "EPOCH: 3653 LOSS: 41.08704942302151\n",
      "EPOCH: 3654 LOSS: 41.08702963189419\n",
      "EPOCH: 3655 LOSS: 41.08700984663079\n",
      "EPOCH: 3656 LOSS: 41.0869900672274\n",
      "EPOCH: 3657 LOSS: 41.086970293680025\n",
      "EPOCH: 3658 LOSS: 41.08695052598477\n",
      "EPOCH: 3659 LOSS: 41.086930764137676\n",
      "EPOCH: 3660 LOSS: 41.08691100813483\n",
      "EPOCH: 3661 LOSS: 41.086891257972276\n",
      "EPOCH: 3662 LOSS: 41.086871513646116\n",
      "EPOCH: 3663 LOSS: 41.08685177515244\n",
      "EPOCH: 3664 LOSS: 41.08683204248733\n",
      "EPOCH: 3665 LOSS: 41.08681231564685\n",
      "EPOCH: 3666 LOSS: 41.086792594627155\n",
      "EPOCH: 3667 LOSS: 41.086772879424316\n",
      "EPOCH: 3668 LOSS: 41.08675317003444\n",
      "EPOCH: 3669 LOSS: 41.08673346645366\n",
      "EPOCH: 3670 LOSS: 41.086713768678074\n",
      "EPOCH: 3671 LOSS: 41.08669407670381\n",
      "EPOCH: 3672 LOSS: 41.08667439052701\n",
      "EPOCH: 3673 LOSS: 41.086654710143804\n",
      "EPOCH: 3674 LOSS: 41.08663503555031\n",
      "EPOCH: 3675 LOSS: 41.086615366742684\n",
      "EPOCH: 3676 LOSS: 41.08659570371708\n",
      "EPOCH: 3677 LOSS: 41.086576046469645\n",
      "EPOCH: 3678 LOSS: 41.08655639499652\n",
      "EPOCH: 3679 LOSS: 41.0865367492939\n",
      "EPOCH: 3680 LOSS: 41.08651710935794\n",
      "EPOCH: 3681 LOSS: 41.08649747518479\n",
      "EPOCH: 3682 LOSS: 41.08647784677065\n",
      "EPOCH: 3683 LOSS: 41.0864582241117\n",
      "EPOCH: 3684 LOSS: 41.086438607204116\n",
      "EPOCH: 3685 LOSS: 41.08641899604409\n",
      "EPOCH: 3686 LOSS: 41.08639939062782\n",
      "EPOCH: 3687 LOSS: 41.086379790951504\n",
      "EPOCH: 3688 LOSS: 41.08636019701134\n",
      "EPOCH: 3689 LOSS: 41.08634060880357\n",
      "EPOCH: 3690 LOSS: 41.08632102632438\n",
      "EPOCH: 3691 LOSS: 41.08630144956999\n",
      "EPOCH: 3692 LOSS: 41.08628187853663\n",
      "EPOCH: 3693 LOSS: 41.086262313220516\n",
      "EPOCH: 3694 LOSS: 41.086242753617896\n",
      "EPOCH: 3695 LOSS: 41.086223199725\n",
      "EPOCH: 3696 LOSS: 41.08620365153807\n",
      "EPOCH: 3697 LOSS: 41.08618410905338\n",
      "EPOCH: 3698 LOSS: 41.08616457226713\n",
      "EPOCH: 3699 LOSS: 41.08614504117561\n",
      "EPOCH: 3700 LOSS: 41.08612551577508\n",
      "EPOCH: 3701 LOSS: 41.086105996061804\n",
      "EPOCH: 3702 LOSS: 41.08608648203204\n",
      "EPOCH: 3703 LOSS: 41.08606697368208\n",
      "EPOCH: 3704 LOSS: 41.086047471008186\n",
      "EPOCH: 3705 LOSS: 41.086027974006626\n",
      "EPOCH: 3706 LOSS: 41.08600848267375\n",
      "EPOCH: 3707 LOSS: 41.085988997005806\n",
      "EPOCH: 3708 LOSS: 41.085969516999086\n",
      "EPOCH: 3709 LOSS: 41.08595004264991\n",
      "EPOCH: 3710 LOSS: 41.08593057395459\n",
      "EPOCH: 3711 LOSS: 41.08591111090943\n",
      "EPOCH: 3712 LOSS: 41.085891653510735\n",
      "EPOCH: 3713 LOSS: 41.08587220175483\n",
      "EPOCH: 3714 LOSS: 41.085852755638044\n",
      "EPOCH: 3715 LOSS: 41.0858333151567\n",
      "EPOCH: 3716 LOSS: 41.08581388030716\n",
      "EPOCH: 3717 LOSS: 41.08579445108571\n",
      "EPOCH: 3718 LOSS: 41.08577502748874\n",
      "EPOCH: 3719 LOSS: 41.08575560951258\n",
      "EPOCH: 3720 LOSS: 41.08573619715358\n",
      "EPOCH: 3721 LOSS: 41.085716790408085\n",
      "EPOCH: 3722 LOSS: 41.08569738927249\n",
      "EPOCH: 3723 LOSS: 41.085677993743126\n",
      "EPOCH: 3724 LOSS: 41.08565860381636\n",
      "EPOCH: 3725 LOSS: 41.08563921948861\n",
      "EPOCH: 3726 LOSS: 41.08561984075621\n",
      "EPOCH: 3727 LOSS: 41.08560046761555\n",
      "EPOCH: 3728 LOSS: 41.08558110006304\n",
      "EPOCH: 3729 LOSS: 41.08556173809505\n",
      "EPOCH: 3730 LOSS: 41.08554238170799\n",
      "EPOCH: 3731 LOSS: 41.085523030898244\n",
      "EPOCH: 3732 LOSS: 41.08550368566223\n",
      "EPOCH: 3733 LOSS: 41.085484345996356\n",
      "EPOCH: 3734 LOSS: 41.085465011897035\n",
      "EPOCH: 3735 LOSS: 41.08544568336067\n",
      "EPOCH: 3736 LOSS: 41.085426360383714\n",
      "EPOCH: 3737 LOSS: 41.08540704296256\n",
      "EPOCH: 3738 LOSS: 41.085387731093675\n",
      "EPOCH: 3739 LOSS: 41.085368424773456\n",
      "EPOCH: 3740 LOSS: 41.085349123998355\n",
      "EPOCH: 3741 LOSS: 41.085329828764834\n",
      "EPOCH: 3742 LOSS: 41.085310539069326\n",
      "EPOCH: 3743 LOSS: 41.0852912549083\n",
      "EPOCH: 3744 LOSS: 41.085271976278186\n",
      "EPOCH: 3745 LOSS: 41.08525270317544\n",
      "EPOCH: 3746 LOSS: 41.085233435596564\n",
      "EPOCH: 3747 LOSS: 41.08521417353802\n",
      "EPOCH: 3748 LOSS: 41.08519491699626\n",
      "EPOCH: 3749 LOSS: 41.08517566596777\n",
      "EPOCH: 3750 LOSS: 41.08515642044903\n",
      "EPOCH: 3751 LOSS: 41.08513718043654\n",
      "EPOCH: 3752 LOSS: 41.085117945926775\n",
      "EPOCH: 3753 LOSS: 41.08509871691626\n",
      "EPOCH: 3754 LOSS: 41.08507949340145\n",
      "EPOCH: 3755 LOSS: 41.085060275378886\n",
      "EPOCH: 3756 LOSS: 41.08504106284506\n",
      "EPOCH: 3757 LOSS: 41.08502185579647\n",
      "EPOCH: 3758 LOSS: 41.085002654229655\n",
      "EPOCH: 3759 LOSS: 41.08498345814114\n",
      "EPOCH: 3760 LOSS: 41.084964267527425\n",
      "EPOCH: 3761 LOSS: 41.08494508238505\n",
      "EPOCH: 3762 LOSS: 41.08492590271054\n",
      "EPOCH: 3763 LOSS: 41.08490672850047\n",
      "EPOCH: 3764 LOSS: 41.084887559751316\n",
      "EPOCH: 3765 LOSS: 41.08486839645968\n",
      "EPOCH: 3766 LOSS: 41.08484923862208\n",
      "EPOCH: 3767 LOSS: 41.0848300862351\n",
      "EPOCH: 3768 LOSS: 41.08481093929527\n",
      "EPOCH: 3769 LOSS: 41.08479179779914\n",
      "EPOCH: 3770 LOSS: 41.08477266174332\n",
      "EPOCH: 3771 LOSS: 41.08475353112435\n",
      "EPOCH: 3772 LOSS: 41.0847344059388\n",
      "EPOCH: 3773 LOSS: 41.08471528618326\n",
      "EPOCH: 3774 LOSS: 41.08469617185432\n",
      "EPOCH: 3775 LOSS: 41.08467706294856\n",
      "EPOCH: 3776 LOSS: 41.08465795946255\n",
      "EPOCH: 3777 LOSS: 41.08463886139291\n",
      "EPOCH: 3778 LOSS: 41.08461976873624\n",
      "EPOCH: 3779 LOSS: 41.08460068148912\n",
      "EPOCH: 3780 LOSS: 41.084581599648175\n",
      "EPOCH: 3781 LOSS: 41.08456252321002\n",
      "EPOCH: 3782 LOSS: 41.08454345217124\n",
      "EPOCH: 3783 LOSS: 41.084524386528486\n",
      "EPOCH: 3784 LOSS: 41.084505326278375\n",
      "EPOCH: 3785 LOSS: 41.08448627141752\n",
      "EPOCH: 3786 LOSS: 41.08446722194255\n",
      "EPOCH: 3787 LOSS: 41.08444817785013\n",
      "EPOCH: 3788 LOSS: 41.08442913913686\n",
      "EPOCH: 3789 LOSS: 41.0844101057994\n",
      "EPOCH: 3790 LOSS: 41.084391077834425\n",
      "EPOCH: 3791 LOSS: 41.08437205523853\n",
      "EPOCH: 3792 LOSS: 41.0843530380084\n",
      "EPOCH: 3793 LOSS: 41.0843340261407\n",
      "EPOCH: 3794 LOSS: 41.0843150196321\n",
      "EPOCH: 3795 LOSS: 41.084296018479236\n",
      "EPOCH: 3796 LOSS: 41.0842770226788\n",
      "EPOCH: 3797 LOSS: 41.08425803222745\n",
      "EPOCH: 3798 LOSS: 41.084239047121876\n",
      "EPOCH: 3799 LOSS: 41.084220067358764\n",
      "EPOCH: 3800 LOSS: 41.084201092934784\n",
      "EPOCH: 3801 LOSS: 41.08418212384666\n",
      "EPOCH: 3802 LOSS: 41.08416316009103\n",
      "EPOCH: 3803 LOSS: 41.08414420166464\n",
      "EPOCH: 3804 LOSS: 41.08412524856419\n",
      "EPOCH: 3805 LOSS: 41.08410630078637\n",
      "EPOCH: 3806 LOSS: 41.08408735832787\n",
      "EPOCH: 3807 LOSS: 41.08406842118543\n",
      "EPOCH: 3808 LOSS: 41.08404948935578\n",
      "EPOCH: 3809 LOSS: 41.08403056283561\n",
      "EPOCH: 3810 LOSS: 41.084011641621665\n",
      "EPOCH: 3811 LOSS: 41.083992725710644\n",
      "EPOCH: 3812 LOSS: 41.083973815099334\n",
      "EPOCH: 3813 LOSS: 41.083954909784424\n",
      "EPOCH: 3814 LOSS: 41.08393600976268\n",
      "EPOCH: 3815 LOSS: 41.08391711503083\n",
      "EPOCH: 3816 LOSS: 41.08389822558562\n",
      "EPOCH: 3817 LOSS: 41.083879341423824\n",
      "EPOCH: 3818 LOSS: 41.08386046254218\n",
      "EPOCH: 3819 LOSS: 41.08384158893744\n",
      "EPOCH: 3820 LOSS: 41.0838227206064\n",
      "EPOCH: 3821 LOSS: 41.08380385754579\n",
      "EPOCH: 3822 LOSS: 41.08378499975238\n",
      "EPOCH: 3823 LOSS: 41.08376614722298\n",
      "EPOCH: 3824 LOSS: 41.083747299954354\n",
      "EPOCH: 3825 LOSS: 41.08372845794325\n",
      "EPOCH: 3826 LOSS: 41.08370962118652\n",
      "EPOCH: 3827 LOSS: 41.083690789680894\n",
      "EPOCH: 3828 LOSS: 41.08367196342318\n",
      "EPOCH: 3829 LOSS: 41.083653142410185\n",
      "EPOCH: 3830 LOSS: 41.083634326638716\n",
      "EPOCH: 3831 LOSS: 41.08361551610556\n",
      "EPOCH: 3832 LOSS: 41.08359671080754\n",
      "EPOCH: 3833 LOSS: 41.08357791074143\n",
      "EPOCH: 3834 LOSS: 41.0835591159041\n",
      "EPOCH: 3835 LOSS: 41.08354032629235\n",
      "EPOCH: 3836 LOSS: 41.08352154190299\n",
      "EPOCH: 3837 LOSS: 41.08350276273285\n",
      "EPOCH: 3838 LOSS: 41.08348398877876\n",
      "EPOCH: 3839 LOSS: 41.08346522003757\n",
      "EPOCH: 3840 LOSS: 41.0834464565061\n",
      "EPOCH: 3841 LOSS: 41.08342769818118\n",
      "EPOCH: 3842 LOSS: 41.0834089450597\n",
      "EPOCH: 3843 LOSS: 41.08339019713846\n",
      "EPOCH: 3844 LOSS: 41.08337145441435\n",
      "EPOCH: 3845 LOSS: 41.083352716884185\n",
      "EPOCH: 3846 LOSS: 41.083333984544865\n",
      "EPOCH: 3847 LOSS: 41.08331525739323\n",
      "EPOCH: 3848 LOSS: 41.083296535426136\n",
      "EPOCH: 3849 LOSS: 41.08327781864048\n",
      "EPOCH: 3850 LOSS: 41.083259107033115\n",
      "EPOCH: 3851 LOSS: 41.08324040060094\n",
      "EPOCH: 3852 LOSS: 41.083221699340825\n",
      "EPOCH: 3853 LOSS: 41.08320300324965\n",
      "EPOCH: 3854 LOSS: 41.0831843123243\n",
      "EPOCH: 3855 LOSS: 41.08316562656168\n",
      "EPOCH: 3856 LOSS: 41.08314694595868\n",
      "EPOCH: 3857 LOSS: 41.08312827051219\n",
      "EPOCH: 3858 LOSS: 41.083109600219125\n",
      "EPOCH: 3859 LOSS: 41.0830909350764\n",
      "EPOCH: 3860 LOSS: 41.083072275080895\n",
      "EPOCH: 3861 LOSS: 41.083053620229535\n",
      "EPOCH: 3862 LOSS: 41.08303497051925\n",
      "EPOCH: 3863 LOSS: 41.08301632594696\n",
      "EPOCH: 3864 LOSS: 41.08299768650954\n",
      "EPOCH: 3865 LOSS: 41.082979052204\n",
      "EPOCH: 3866 LOSS: 41.0829604230272\n",
      "EPOCH: 3867 LOSS: 41.08294179897612\n",
      "EPOCH: 3868 LOSS: 41.082923180047686\n",
      "EPOCH: 3869 LOSS: 41.0829045662388\n",
      "EPOCH: 3870 LOSS: 41.082885957546466\n",
      "EPOCH: 3871 LOSS: 41.08286735396759\n",
      "EPOCH: 3872 LOSS: 41.082848755499136\n",
      "EPOCH: 3873 LOSS: 41.082830162138066\n",
      "EPOCH: 3874 LOSS: 41.082811573881344\n",
      "EPOCH: 3875 LOSS: 41.08279299072593\n",
      "EPOCH: 3876 LOSS: 41.08277441266877\n",
      "EPOCH: 3877 LOSS: 41.08275583970684\n",
      "EPOCH: 3878 LOSS: 41.08273727183713\n",
      "EPOCH: 3879 LOSS: 41.08271870905659\n",
      "EPOCH: 3880 LOSS: 41.08270015136222\n",
      "EPOCH: 3881 LOSS: 41.082681598750995\n",
      "EPOCH: 3882 LOSS: 41.08266305121992\n",
      "EPOCH: 3883 LOSS: 41.08264450876594\n",
      "EPOCH: 3884 LOSS: 41.082625971386086\n",
      "EPOCH: 3885 LOSS: 41.082607439077336\n",
      "EPOCH: 3886 LOSS: 41.08258891183671\n",
      "EPOCH: 3887 LOSS: 41.08257038966117\n",
      "EPOCH: 3888 LOSS: 41.08255187254778\n",
      "EPOCH: 3889 LOSS: 41.082533360493514\n",
      "EPOCH: 3890 LOSS: 41.08251485349539\n",
      "EPOCH: 3891 LOSS: 41.08249635155042\n",
      "EPOCH: 3892 LOSS: 41.082477854655636\n",
      "EPOCH: 3893 LOSS: 41.082459362808045\n",
      "EPOCH: 3894 LOSS: 41.0824408760047\n",
      "EPOCH: 3895 LOSS: 41.08242239424261\n",
      "EPOCH: 3896 LOSS: 41.082403917518825\n",
      "EPOCH: 3897 LOSS: 41.082385445830354\n",
      "EPOCH: 3898 LOSS: 41.08236697917427\n",
      "EPOCH: 3899 LOSS: 41.082348517547594\n",
      "EPOCH: 3900 LOSS: 41.082330060947385\n",
      "EPOCH: 3901 LOSS: 41.08231160937069\n",
      "EPOCH: 3902 LOSS: 41.08229316281455\n",
      "EPOCH: 3903 LOSS: 41.082274721276036\n",
      "EPOCH: 3904 LOSS: 41.082256284752205\n",
      "EPOCH: 3905 LOSS: 41.08223785324012\n",
      "EPOCH: 3906 LOSS: 41.08221942673685\n",
      "EPOCH: 3907 LOSS: 41.08220100523946\n",
      "EPOCH: 3908 LOSS: 41.08218258874504\n",
      "EPOCH: 3909 LOSS: 41.08216417725063\n",
      "EPOCH: 3910 LOSS: 41.08214577075335\n",
      "EPOCH: 3911 LOSS: 41.08212736925026\n",
      "EPOCH: 3912 LOSS: 41.082108972738446\n",
      "EPOCH: 3913 LOSS: 41.08209058121501\n",
      "EPOCH: 3914 LOSS: 41.082072194677046\n",
      "EPOCH: 3915 LOSS: 41.08205381312163\n",
      "EPOCH: 3916 LOSS: 41.082035436545866\n",
      "EPOCH: 3917 LOSS: 41.082017064946896\n",
      "EPOCH: 3918 LOSS: 41.08199869832177\n",
      "EPOCH: 3919 LOSS: 41.08198033666764\n",
      "EPOCH: 3920 LOSS: 41.08196197998158\n",
      "EPOCH: 3921 LOSS: 41.08194362826073\n",
      "EPOCH: 3922 LOSS: 41.08192528150221\n",
      "EPOCH: 3923 LOSS: 41.08190693970314\n",
      "EPOCH: 3924 LOSS: 41.08188860286062\n",
      "EPOCH: 3925 LOSS: 41.08187027097182\n",
      "EPOCH: 3926 LOSS: 41.08185194403384\n",
      "EPOCH: 3927 LOSS: 41.08183362204384\n",
      "EPOCH: 3928 LOSS: 41.08181530499894\n",
      "EPOCH: 3929 LOSS: 41.08179699289629\n",
      "EPOCH: 3930 LOSS: 41.081778685733\n",
      "EPOCH: 3931 LOSS: 41.08176038350628\n",
      "EPOCH: 3932 LOSS: 41.081742086213225\n",
      "EPOCH: 3933 LOSS: 41.08172379385102\n",
      "EPOCH: 3934 LOSS: 41.08170550641682\n",
      "EPOCH: 3935 LOSS: 41.081687223907764\n",
      "EPOCH: 3936 LOSS: 41.08166894632103\n",
      "EPOCH: 3937 LOSS: 41.08165067365378\n",
      "EPOCH: 3938 LOSS: 41.08163240590319\n",
      "EPOCH: 3939 LOSS: 41.081614143066446\n",
      "EPOCH: 3940 LOSS: 41.08159588514069\n",
      "EPOCH: 3941 LOSS: 41.08157763212313\n",
      "EPOCH: 3942 LOSS: 41.0815593840109\n",
      "EPOCH: 3943 LOSS: 41.08154114080125\n",
      "EPOCH: 3944 LOSS: 41.08152290249134\n",
      "EPOCH: 3945 LOSS: 41.08150466907836\n",
      "EPOCH: 3946 LOSS: 41.081486440559495\n",
      "EPOCH: 3947 LOSS: 41.08146821693197\n",
      "EPOCH: 3948 LOSS: 41.08144999819295\n",
      "EPOCH: 3949 LOSS: 41.08143178433966\n",
      "EPOCH: 3950 LOSS: 41.0814135753693\n",
      "EPOCH: 3951 LOSS: 41.08139537127908\n",
      "EPOCH: 3952 LOSS: 41.08137717206622\n",
      "EPOCH: 3953 LOSS: 41.08135897772794\n",
      "EPOCH: 3954 LOSS: 41.081340788261414\n",
      "EPOCH: 3955 LOSS: 41.08132260366393\n",
      "EPOCH: 3956 LOSS: 41.081304423932686\n",
      "EPOCH: 3957 LOSS: 41.08128624906488\n",
      "EPOCH: 3958 LOSS: 41.0812680790578\n",
      "EPOCH: 3959 LOSS: 41.08124991390863\n",
      "EPOCH: 3960 LOSS: 41.08123175361464\n",
      "EPOCH: 3961 LOSS: 41.08121359817306\n",
      "EPOCH: 3962 LOSS: 41.08119544758111\n",
      "EPOCH: 3963 LOSS: 41.081177301836064\n",
      "EPOCH: 3964 LOSS: 41.08115916093516\n",
      "EPOCH: 3965 LOSS: 41.08114102487566\n",
      "EPOCH: 3966 LOSS: 41.08112289365482\n",
      "EPOCH: 3967 LOSS: 41.08110476726987\n",
      "EPOCH: 3968 LOSS: 41.081086645718116\n",
      "EPOCH: 3969 LOSS: 41.08106852899677\n",
      "EPOCH: 3970 LOSS: 41.081050417103135\n",
      "EPOCH: 3971 LOSS: 41.081032310034495\n",
      "EPOCH: 3972 LOSS: 41.08101420778808\n",
      "EPOCH: 3973 LOSS: 41.0809961103612\n",
      "EPOCH: 3974 LOSS: 41.08097801775113\n",
      "EPOCH: 3975 LOSS: 41.08095992995512\n",
      "EPOCH: 3976 LOSS: 41.08094184697049\n",
      "EPOCH: 3977 LOSS: 41.0809237687945\n",
      "EPOCH: 3978 LOSS: 41.08090569542448\n",
      "EPOCH: 3979 LOSS: 41.080887626857695\n",
      "EPOCH: 3980 LOSS: 41.08086956309144\n",
      "EPOCH: 3981 LOSS: 41.08085150412302\n",
      "EPOCH: 3982 LOSS: 41.08083344994975\n",
      "EPOCH: 3983 LOSS: 41.080815400568916\n",
      "EPOCH: 3984 LOSS: 41.08079735597785\n",
      "EPOCH: 3985 LOSS: 41.08077931617383\n",
      "EPOCH: 3986 LOSS: 41.080761281154196\n",
      "EPOCH: 3987 LOSS: 41.08074325091626\n",
      "EPOCH: 3988 LOSS: 41.08072522545733\n",
      "EPOCH: 3989 LOSS: 41.08070720477474\n",
      "EPOCH: 3990 LOSS: 41.08068918886582\n",
      "EPOCH: 3991 LOSS: 41.08067117772788\n",
      "EPOCH: 3992 LOSS: 41.08065317135828\n",
      "EPOCH: 3993 LOSS: 41.08063516975433\n",
      "EPOCH: 3994 LOSS: 41.08061717291337\n",
      "EPOCH: 3995 LOSS: 41.08059918083275\n",
      "EPOCH: 3996 LOSS: 41.080581193509815\n",
      "EPOCH: 3997 LOSS: 41.08056321094191\n",
      "EPOCH: 3998 LOSS: 41.08054523312636\n",
      "EPOCH: 3999 LOSS: 41.08052726006054\n",
      "EPOCH: 4000 LOSS: 41.080509291741805\n",
      "EPOCH: 4001 LOSS: 41.0804913281675\n",
      "EPOCH: 4002 LOSS: 41.080473369334996\n",
      "EPOCH: 4003 LOSS: 41.08045541524165\n",
      "EPOCH: 4004 LOSS: 41.08043746588483\n",
      "EPOCH: 4005 LOSS: 41.08041952126191\n",
      "EPOCH: 4006 LOSS: 41.08040158137024\n",
      "EPOCH: 4007 LOSS: 41.08038364620721\n",
      "EPOCH: 4008 LOSS: 41.080365715770185\n",
      "EPOCH: 4009 LOSS: 41.08034779005659\n",
      "EPOCH: 4010 LOSS: 41.080329869063746\n",
      "EPOCH: 4011 LOSS: 41.08031195278907\n",
      "EPOCH: 4012 LOSS: 41.08029404122994\n",
      "EPOCH: 4013 LOSS: 41.08027613438377\n",
      "EPOCH: 4014 LOSS: 41.08025823224793\n",
      "EPOCH: 4015 LOSS: 41.08024033481981\n",
      "EPOCH: 4016 LOSS: 41.08022244209683\n",
      "EPOCH: 4017 LOSS: 41.08020455407639\n",
      "EPOCH: 4018 LOSS: 41.08018667075587\n",
      "EPOCH: 4019 LOSS: 41.08016879213271\n",
      "EPOCH: 4020 LOSS: 41.0801509182043\n",
      "EPOCH: 4021 LOSS: 41.08013304896807\n",
      "EPOCH: 4022 LOSS: 41.08011518442143\n",
      "EPOCH: 4023 LOSS: 41.08009732456178\n",
      "EPOCH: 4024 LOSS: 41.08007946938655\n",
      "EPOCH: 4025 LOSS: 41.0800616188932\n",
      "EPOCH: 4026 LOSS: 41.080043773079076\n",
      "EPOCH: 4027 LOSS: 41.08002593194168\n",
      "EPOCH: 4028 LOSS: 41.08000809547843\n",
      "EPOCH: 4029 LOSS: 41.07999026368676\n",
      "EPOCH: 4030 LOSS: 41.07997243656408\n",
      "EPOCH: 4031 LOSS: 41.07995461410786\n",
      "EPOCH: 4032 LOSS: 41.07993679631553\n",
      "EPOCH: 4033 LOSS: 41.07991898318454\n",
      "EPOCH: 4034 LOSS: 41.07990117471234\n",
      "EPOCH: 4035 LOSS: 41.079883370896376\n",
      "EPOCH: 4036 LOSS: 41.07986557173411\n",
      "EPOCH: 4037 LOSS: 41.07984777722299\n",
      "EPOCH: 4038 LOSS: 41.07982998736047\n",
      "EPOCH: 4039 LOSS: 41.07981220214402\n",
      "EPOCH: 4040 LOSS: 41.07979442157112\n",
      "EPOCH: 4041 LOSS: 41.07977664563922\n",
      "EPOCH: 4042 LOSS: 41.079758874345785\n",
      "EPOCH: 4043 LOSS: 41.07974110768831\n",
      "EPOCH: 4044 LOSS: 41.079723345664235\n",
      "EPOCH: 4045 LOSS: 41.07970558827107\n",
      "EPOCH: 4046 LOSS: 41.07968783550628\n",
      "EPOCH: 4047 LOSS: 41.07967008736735\n",
      "EPOCH: 4048 LOSS: 41.07965234385176\n",
      "EPOCH: 4049 LOSS: 41.07963460495702\n",
      "EPOCH: 4050 LOSS: 41.07961687068059\n",
      "EPOCH: 4051 LOSS: 41.079599141020005\n",
      "EPOCH: 4052 LOSS: 41.07958141597272\n",
      "EPOCH: 4053 LOSS: 41.07956369553625\n",
      "EPOCH: 4054 LOSS: 41.07954597970809\n",
      "EPOCH: 4055 LOSS: 41.079528268485774\n",
      "EPOCH: 4056 LOSS: 41.07951056186677\n",
      "EPOCH: 4057 LOSS: 41.07949285984861\n",
      "EPOCH: 4058 LOSS: 41.07947516242881\n",
      "EPOCH: 4059 LOSS: 41.07945746960485\n",
      "EPOCH: 4060 LOSS: 41.0794397813743\n",
      "EPOCH: 4061 LOSS: 41.07942209773463\n",
      "EPOCH: 4062 LOSS: 41.07940441868338\n",
      "EPOCH: 4063 LOSS: 41.07938674421809\n",
      "EPOCH: 4064 LOSS: 41.07936907433628\n",
      "EPOCH: 4065 LOSS: 41.07935140903547\n",
      "EPOCH: 4066 LOSS: 41.07933374831321\n",
      "EPOCH: 4067 LOSS: 41.079316092167\n",
      "EPOCH: 4068 LOSS: 41.079298440594414\n",
      "EPOCH: 4069 LOSS: 41.07928079359299\n",
      "EPOCH: 4070 LOSS: 41.07926315116026\n",
      "EPOCH: 4071 LOSS: 41.07924551329377\n",
      "EPOCH: 4072 LOSS: 41.07922787999105\n",
      "EPOCH: 4073 LOSS: 41.07921025124969\n",
      "EPOCH: 4074 LOSS: 41.07919262706722\n",
      "EPOCH: 4075 LOSS: 41.07917500744121\n",
      "EPOCH: 4076 LOSS: 41.0791573923692\n",
      "EPOCH: 4077 LOSS: 41.07913978184874\n",
      "EPOCH: 4078 LOSS: 41.07912217587742\n",
      "EPOCH: 4079 LOSS: 41.07910457445279\n",
      "EPOCH: 4080 LOSS: 41.07908697757243\n",
      "EPOCH: 4081 LOSS: 41.0790693852339\n",
      "EPOCH: 4082 LOSS: 41.07905179743478\n",
      "EPOCH: 4083 LOSS: 41.07903421417266\n",
      "EPOCH: 4084 LOSS: 41.079016635445086\n",
      "EPOCH: 4085 LOSS: 41.078999061249654\n",
      "EPOCH: 4086 LOSS: 41.078981491583946\n",
      "EPOCH: 4087 LOSS: 41.07896392644558\n",
      "EPOCH: 4088 LOSS: 41.07894636583209\n",
      "EPOCH: 4089 LOSS: 41.07892880974109\n",
      "EPOCH: 4090 LOSS: 41.07891125817019\n",
      "EPOCH: 4091 LOSS: 41.07889371111695\n",
      "EPOCH: 4092 LOSS: 41.07887616857901\n",
      "EPOCH: 4093 LOSS: 41.07885863055394\n",
      "EPOCH: 4094 LOSS: 41.07884109703934\n",
      "EPOCH: 4095 LOSS: 41.07882356803284\n",
      "EPOCH: 4096 LOSS: 41.07880604353204\n",
      "EPOCH: 4097 LOSS: 41.07878852353454\n",
      "EPOCH: 4098 LOSS: 41.07877100803797\n",
      "EPOCH: 4099 LOSS: 41.078753497039905\n",
      "EPOCH: 4100 LOSS: 41.078735990538014\n",
      "EPOCH: 4101 LOSS: 41.07871848852989\n",
      "EPOCH: 4102 LOSS: 41.078700991013164\n",
      "EPOCH: 4103 LOSS: 41.078683497985466\n",
      "EPOCH: 4104 LOSS: 41.078666009444404\n",
      "EPOCH: 4105 LOSS: 41.078648525387635\n",
      "EPOCH: 4106 LOSS: 41.078631045812756\n",
      "EPOCH: 4107 LOSS: 41.07861357071744\n",
      "EPOCH: 4108 LOSS: 41.0785961000993\n",
      "EPOCH: 4109 LOSS: 41.07857863395598\n",
      "EPOCH: 4110 LOSS: 41.07856117228511\n",
      "EPOCH: 4111 LOSS: 41.07854371508435\n",
      "EPOCH: 4112 LOSS: 41.07852626235139\n",
      "EPOCH: 4113 LOSS: 41.07850881408379\n",
      "EPOCH: 4114 LOSS: 41.07849137027927\n",
      "EPOCH: 4115 LOSS: 41.078473930935445\n",
      "EPOCH: 4116 LOSS: 41.07845649604999\n",
      "EPOCH: 4117 LOSS: 41.07843906562056\n",
      "EPOCH: 4118 LOSS: 41.078421639644816\n",
      "EPOCH: 4119 LOSS: 41.07840421812041\n",
      "EPOCH: 4120 LOSS: 41.07838680104504\n",
      "EPOCH: 4121 LOSS: 41.07836938841636\n",
      "EPOCH: 4122 LOSS: 41.078351980232014\n",
      "EPOCH: 4123 LOSS: 41.0783345764897\n",
      "EPOCH: 4124 LOSS: 41.07831717718709\n",
      "EPOCH: 4125 LOSS: 41.078299782321864\n",
      "EPOCH: 4126 LOSS: 41.07828239189172\n",
      "EPOCH: 4127 LOSS: 41.07826500589428\n",
      "EPOCH: 4128 LOSS: 41.07824762432729\n",
      "EPOCH: 4129 LOSS: 41.078230247188415\n",
      "EPOCH: 4130 LOSS: 41.07821287447535\n",
      "EPOCH: 4131 LOSS: 41.078195506185764\n",
      "EPOCH: 4132 LOSS: 41.07817814231737\n",
      "EPOCH: 4133 LOSS: 41.07816078286787\n",
      "EPOCH: 4134 LOSS: 41.07814342783496\n",
      "EPOCH: 4135 LOSS: 41.078126077216325\n",
      "EPOCH: 4136 LOSS: 41.07810873100969\n",
      "EPOCH: 4137 LOSS: 41.07809138921274\n",
      "EPOCH: 4138 LOSS: 41.07807405182322\n",
      "EPOCH: 4139 LOSS: 41.07805671883878\n",
      "EPOCH: 4140 LOSS: 41.07803939025719\n",
      "EPOCH: 4141 LOSS: 41.078022066076116\n",
      "EPOCH: 4142 LOSS: 41.07800474629332\n",
      "EPOCH: 4143 LOSS: 41.077987430906504\n",
      "EPOCH: 4144 LOSS: 41.07797011991338\n",
      "EPOCH: 4145 LOSS: 41.077952813311676\n",
      "EPOCH: 4146 LOSS: 41.07793551109913\n",
      "EPOCH: 4147 LOSS: 41.07791821327345\n",
      "EPOCH: 4148 LOSS: 41.07790091983239\n",
      "EPOCH: 4149 LOSS: 41.07788363077367\n",
      "EPOCH: 4150 LOSS: 41.07786634609503\n",
      "EPOCH: 4151 LOSS: 41.07784906579421\n",
      "EPOCH: 4152 LOSS: 41.077831789868945\n",
      "EPOCH: 4153 LOSS: 41.07781451831697\n",
      "EPOCH: 4154 LOSS: 41.07779725113604\n",
      "EPOCH: 4155 LOSS: 41.0777799883239\n",
      "EPOCH: 4156 LOSS: 41.07776272987827\n",
      "EPOCH: 4157 LOSS: 41.07774547579698\n",
      "EPOCH: 4158 LOSS: 41.0777282260777\n",
      "EPOCH: 4159 LOSS: 41.077710980718216\n",
      "EPOCH: 4160 LOSS: 41.077693739716295\n",
      "EPOCH: 4161 LOSS: 41.07767650306971\n",
      "EPOCH: 4162 LOSS: 41.07765927077618\n",
      "EPOCH: 4163 LOSS: 41.0776420428335\n",
      "EPOCH: 4164 LOSS: 41.07762481923943\n",
      "EPOCH: 4165 LOSS: 41.07760759999174\n",
      "EPOCH: 4166 LOSS: 41.077590385088186\n",
      "EPOCH: 4167 LOSS: 41.07757317452658\n",
      "EPOCH: 4168 LOSS: 41.07755596830465\n",
      "EPOCH: 4169 LOSS: 41.077538766420204\n",
      "EPOCH: 4170 LOSS: 41.07752156887102\n",
      "EPOCH: 4171 LOSS: 41.07750437565487\n",
      "EPOCH: 4172 LOSS: 41.07748718676956\n",
      "EPOCH: 4173 LOSS: 41.07747000221285\n",
      "EPOCH: 4174 LOSS: 41.07745282198253\n",
      "EPOCH: 4175 LOSS: 41.0774356460764\n",
      "EPOCH: 4176 LOSS: 41.07741847449226\n",
      "EPOCH: 4177 LOSS: 41.07740130722791\n",
      "EPOCH: 4178 LOSS: 41.077384144281126\n",
      "EPOCH: 4179 LOSS: 41.07736698564971\n",
      "EPOCH: 4180 LOSS: 41.07734983133149\n",
      "EPOCH: 4181 LOSS: 41.07733268132425\n",
      "EPOCH: 4182 LOSS: 41.07731553562579\n",
      "EPOCH: 4183 LOSS: 41.07729839423392\n",
      "EPOCH: 4184 LOSS: 41.07728125714648\n",
      "EPOCH: 4185 LOSS: 41.07726412436123\n",
      "EPOCH: 4186 LOSS: 41.077246995876045\n",
      "EPOCH: 4187 LOSS: 41.07722987168869\n",
      "EPOCH: 4188 LOSS: 41.07721275179702\n",
      "EPOCH: 4189 LOSS: 41.07719563619883\n",
      "EPOCH: 4190 LOSS: 41.07717852489197\n",
      "EPOCH: 4191 LOSS: 41.077161417874244\n",
      "EPOCH: 4192 LOSS: 41.077144315143485\n",
      "EPOCH: 4193 LOSS: 41.07712721669753\n",
      "EPOCH: 4194 LOSS: 41.07711012253421\n",
      "EPOCH: 4195 LOSS: 41.07709303265135\n",
      "EPOCH: 4196 LOSS: 41.07707594704677\n",
      "EPOCH: 4197 LOSS: 41.07705886571836\n",
      "EPOCH: 4198 LOSS: 41.07704178866393\n",
      "EPOCH: 4199 LOSS: 41.077024715881294\n",
      "EPOCH: 4200 LOSS: 41.07700764736836\n",
      "EPOCH: 4201 LOSS: 41.07699058312291\n",
      "EPOCH: 4202 LOSS: 41.07697352314284\n",
      "EPOCH: 4203 LOSS: 41.07695646742597\n",
      "EPOCH: 4204 LOSS: 41.076939415970216\n",
      "EPOCH: 4205 LOSS: 41.07692236877331\n",
      "EPOCH: 4206 LOSS: 41.07690532583323\n",
      "EPOCH: 4207 LOSS: 41.076888287147774\n",
      "EPOCH: 4208 LOSS: 41.07687125271483\n",
      "EPOCH: 4209 LOSS: 41.07685422253224\n",
      "EPOCH: 4210 LOSS: 41.076837196597864\n",
      "EPOCH: 4211 LOSS: 41.07682017490961\n",
      "EPOCH: 4212 LOSS: 41.07680315746532\n",
      "EPOCH: 4213 LOSS: 41.076786144262854\n",
      "EPOCH: 4214 LOSS: 41.07676913530011\n",
      "EPOCH: 4215 LOSS: 41.07675213057496\n",
      "EPOCH: 4216 LOSS: 41.07673513008527\n",
      "EPOCH: 4217 LOSS: 41.07671813382891\n",
      "EPOCH: 4218 LOSS: 41.076701141803795\n",
      "EPOCH: 4219 LOSS: 41.0766841540078\n",
      "EPOCH: 4220 LOSS: 41.076667170438796\n",
      "EPOCH: 4221 LOSS: 41.07665019109467\n",
      "EPOCH: 4222 LOSS: 41.076633215973324\n",
      "EPOCH: 4223 LOSS: 41.07661624507264\n",
      "EPOCH: 4224 LOSS: 41.076599278390546\n",
      "EPOCH: 4225 LOSS: 41.07658231592488\n",
      "EPOCH: 4226 LOSS: 41.07656535767359\n",
      "EPOCH: 4227 LOSS: 41.07654840363457\n",
      "EPOCH: 4228 LOSS: 41.0765314538057\n",
      "EPOCH: 4229 LOSS: 41.07651450818487\n",
      "EPOCH: 4230 LOSS: 41.076497566770044\n",
      "EPOCH: 4231 LOSS: 41.0764806295591\n",
      "EPOCH: 4232 LOSS: 41.076463696549936\n",
      "EPOCH: 4233 LOSS: 41.076446767740485\n",
      "EPOCH: 4234 LOSS: 41.07642984312863\n",
      "EPOCH: 4235 LOSS: 41.07641292271233\n",
      "EPOCH: 4236 LOSS: 41.076396006489475\n",
      "EPOCH: 4237 LOSS: 41.076379094458\n",
      "EPOCH: 4238 LOSS: 41.07636218661581\n",
      "EPOCH: 4239 LOSS: 41.07634528296086\n",
      "EPOCH: 4240 LOSS: 41.07632838349105\n",
      "EPOCH: 4241 LOSS: 41.07631148820431\n",
      "EPOCH: 4242 LOSS: 41.076294597098595\n",
      "EPOCH: 4243 LOSS: 41.07627771017181\n",
      "EPOCH: 4244 LOSS: 41.07626082742188\n",
      "EPOCH: 4245 LOSS: 41.07624394884677\n",
      "EPOCH: 4246 LOSS: 41.076227074444425\n",
      "EPOCH: 4247 LOSS: 41.076210204212764\n",
      "EPOCH: 4248 LOSS: 41.076193338149714\n",
      "EPOCH: 4249 LOSS: 41.07617647625326\n",
      "EPOCH: 4250 LOSS: 41.07615961852132\n",
      "EPOCH: 4251 LOSS: 41.076142764951854\n",
      "EPOCH: 4252 LOSS: 41.076125915542804\n",
      "EPOCH: 4253 LOSS: 41.076109070292134\n",
      "EPOCH: 4254 LOSS: 41.07609222919778\n",
      "EPOCH: 4255 LOSS: 41.07607539225771\n",
      "EPOCH: 4256 LOSS: 41.0760585594699\n",
      "EPOCH: 4257 LOSS: 41.07604173083225\n",
      "EPOCH: 4258 LOSS: 41.0760249063428\n",
      "EPOCH: 4259 LOSS: 41.07600808599947\n",
      "EPOCH: 4260 LOSS: 41.07599126980023\n",
      "EPOCH: 4261 LOSS: 41.07597445774303\n",
      "EPOCH: 4262 LOSS: 41.07595764982588\n",
      "EPOCH: 4263 LOSS: 41.07594084604671\n",
      "EPOCH: 4264 LOSS: 41.075924046403536\n",
      "EPOCH: 4265 LOSS: 41.07590725089431\n",
      "EPOCH: 4266 LOSS: 41.07589045951701\n",
      "EPOCH: 4267 LOSS: 41.075873672269616\n",
      "EPOCH: 4268 LOSS: 41.075856889150096\n",
      "EPOCH: 4269 LOSS: 41.07584011015646\n",
      "EPOCH: 4270 LOSS: 41.07582333528668\n",
      "EPOCH: 4271 LOSS: 41.07580656453874\n",
      "EPOCH: 4272 LOSS: 41.07578979791063\n",
      "EPOCH: 4273 LOSS: 41.07577303540033\n",
      "EPOCH: 4274 LOSS: 41.07575627700587\n",
      "EPOCH: 4275 LOSS: 41.075739522725186\n",
      "EPOCH: 4276 LOSS: 41.07572277255633\n",
      "EPOCH: 4277 LOSS: 41.07570602649727\n",
      "EPOCH: 4278 LOSS: 41.075689284546016\n",
      "EPOCH: 4279 LOSS: 41.07567254670056\n",
      "EPOCH: 4280 LOSS: 41.07565581295893\n",
      "EPOCH: 4281 LOSS: 41.07563908331909\n",
      "EPOCH: 4282 LOSS: 41.07562235777908\n",
      "EPOCH: 4283 LOSS: 41.07560563633692\n",
      "EPOCH: 4284 LOSS: 41.07558891899059\n",
      "EPOCH: 4285 LOSS: 41.07557220573811\n",
      "EPOCH: 4286 LOSS: 41.075555496577515\n",
      "EPOCH: 4287 LOSS: 41.0755387915068\n",
      "EPOCH: 4288 LOSS: 41.07552209052398\n",
      "EPOCH: 4289 LOSS: 41.07550539362711\n",
      "EPOCH: 4290 LOSS: 41.07548870081418\n",
      "EPOCH: 4291 LOSS: 41.07547201208324\n",
      "EPOCH: 4292 LOSS: 41.07545532743229\n",
      "EPOCH: 4293 LOSS: 41.07543864685937\n",
      "EPOCH: 4294 LOSS: 41.0754219703625\n",
      "EPOCH: 4295 LOSS: 41.075405297939724\n",
      "EPOCH: 4296 LOSS: 41.07538862958907\n",
      "EPOCH: 4297 LOSS: 41.075371965308584\n",
      "EPOCH: 4298 LOSS: 41.0753553050963\n",
      "EPOCH: 4299 LOSS: 41.075338648950236\n",
      "EPOCH: 4300 LOSS: 41.07532199686847\n",
      "EPOCH: 4301 LOSS: 41.075305348849\n",
      "EPOCH: 4302 LOSS: 41.075288704889914\n",
      "EPOCH: 4303 LOSS: 41.07527206498923\n",
      "EPOCH: 4304 LOSS: 41.07525542914501\n",
      "EPOCH: 4305 LOSS: 41.07523879735529\n",
      "EPOCH: 4306 LOSS: 41.075222169618144\n",
      "EPOCH: 4307 LOSS: 41.07520554593161\n",
      "EPOCH: 4308 LOSS: 41.075188926293734\n",
      "EPOCH: 4309 LOSS: 41.07517231070259\n",
      "EPOCH: 4310 LOSS: 41.075155699156234\n",
      "EPOCH: 4311 LOSS: 41.07513909165273\n",
      "EPOCH: 4312 LOSS: 41.07512248819012\n",
      "EPOCH: 4313 LOSS: 41.075105888766494\n",
      "EPOCH: 4314 LOSS: 41.075089293379925\n",
      "EPOCH: 4315 LOSS: 41.07507270202844\n",
      "EPOCH: 4316 LOSS: 41.075056114710144\n",
      "EPOCH: 4317 LOSS: 41.075039531423094\n",
      "EPOCH: 4318 LOSS: 41.075022952165384\n",
      "EPOCH: 4319 LOSS: 41.07500637693505\n",
      "EPOCH: 4320 LOSS: 41.0749898057302\n",
      "EPOCH: 4321 LOSS: 41.07497323854892\n",
      "EPOCH: 4322 LOSS: 41.07495667538925\n",
      "EPOCH: 4323 LOSS: 41.07494011624931\n",
      "EPOCH: 4324 LOSS: 41.074923561127164\n",
      "EPOCH: 4325 LOSS: 41.07490701002091\n",
      "EPOCH: 4326 LOSS: 41.07489046292863\n",
      "EPOCH: 4327 LOSS: 41.0748739198484\n",
      "EPOCH: 4328 LOSS: 41.074857380778354\n",
      "EPOCH: 4329 LOSS: 41.07484084571654\n",
      "EPOCH: 4330 LOSS: 41.07482431466106\n",
      "EPOCH: 4331 LOSS: 41.07480778761003\n",
      "EPOCH: 4332 LOSS: 41.07479126456154\n",
      "EPOCH: 4333 LOSS: 41.07477474551367\n",
      "EPOCH: 4334 LOSS: 41.07475823046455\n",
      "EPOCH: 4335 LOSS: 41.07474171941227\n",
      "EPOCH: 4336 LOSS: 41.07472521235495\n",
      "EPOCH: 4337 LOSS: 41.07470870929066\n",
      "EPOCH: 4338 LOSS: 41.07469221021755\n",
      "EPOCH: 4339 LOSS: 41.074675715133694\n",
      "EPOCH: 4340 LOSS: 41.074659224037234\n",
      "EPOCH: 4341 LOSS: 41.074642736926265\n",
      "EPOCH: 4342 LOSS: 41.07462625379892\n",
      "EPOCH: 4343 LOSS: 41.0746097746533\n",
      "EPOCH: 4344 LOSS: 41.074593299487525\n",
      "EPOCH: 4345 LOSS: 41.074576828299726\n",
      "EPOCH: 4346 LOSS: 41.07456036108802\n",
      "EPOCH: 4347 LOSS: 41.074543897850525\n",
      "EPOCH: 4348 LOSS: 41.07452743858538\n",
      "EPOCH: 4349 LOSS: 41.07451098329069\n",
      "EPOCH: 4350 LOSS: 41.074494531964625\n",
      "EPOCH: 4351 LOSS: 41.07447808460526\n",
      "EPOCH: 4352 LOSS: 41.074461641210775\n",
      "EPOCH: 4353 LOSS: 41.07444520177927\n",
      "EPOCH: 4354 LOSS: 41.07442876630893\n",
      "EPOCH: 4355 LOSS: 41.07441233479783\n",
      "EPOCH: 4356 LOSS: 41.07439590724415\n",
      "EPOCH: 4357 LOSS: 41.07437948364601\n",
      "EPOCH: 4358 LOSS: 41.074363064001574\n",
      "EPOCH: 4359 LOSS: 41.07434664830899\n",
      "EPOCH: 4360 LOSS: 41.07433023656636\n",
      "EPOCH: 4361 LOSS: 41.074313828771885\n",
      "EPOCH: 4362 LOSS: 41.07429742492368\n",
      "EPOCH: 4363 LOSS: 41.0742810250199\n",
      "EPOCH: 4364 LOSS: 41.07426462905872\n",
      "EPOCH: 4365 LOSS: 41.07424823703827\n",
      "EPOCH: 4366 LOSS: 41.074231848956714\n",
      "EPOCH: 4367 LOSS: 41.07421546481221\n",
      "EPOCH: 4368 LOSS: 41.07419908460292\n",
      "EPOCH: 4369 LOSS: 41.07418270832701\n",
      "EPOCH: 4370 LOSS: 41.07416633598263\n",
      "EPOCH: 4371 LOSS: 41.07414996756796\n",
      "EPOCH: 4372 LOSS: 41.074133603081144\n",
      "EPOCH: 4373 LOSS: 41.07411724252037\n",
      "EPOCH: 4374 LOSS: 41.0741008858838\n",
      "EPOCH: 4375 LOSS: 41.0740845331696\n",
      "EPOCH: 4376 LOSS: 41.07406818437597\n",
      "EPOCH: 4377 LOSS: 41.07405183950104\n",
      "EPOCH: 4378 LOSS: 41.074035498543\n",
      "EPOCH: 4379 LOSS: 41.074019161500054\n",
      "EPOCH: 4380 LOSS: 41.074002828370354\n",
      "EPOCH: 4381 LOSS: 41.0739864991521\n",
      "EPOCH: 4382 LOSS: 41.07397017384345\n",
      "EPOCH: 4383 LOSS: 41.073953852442614\n",
      "EPOCH: 4384 LOSS: 41.073937534947774\n",
      "EPOCH: 4385 LOSS: 41.07392122135709\n",
      "EPOCH: 4386 LOSS: 41.07390491166879\n",
      "EPOCH: 4387 LOSS: 41.07388860588103\n",
      "EPOCH: 4388 LOSS: 41.07387230399202\n",
      "EPOCH: 4389 LOSS: 41.073856005999964\n",
      "EPOCH: 4390 LOSS: 41.073839711903034\n",
      "EPOCH: 4391 LOSS: 41.07382342169943\n",
      "EPOCH: 4392 LOSS: 41.07380713538737\n",
      "EPOCH: 4393 LOSS: 41.073790852965054\n",
      "EPOCH: 4394 LOSS: 41.07377457443066\n",
      "EPOCH: 4395 LOSS: 41.07375829978241\n",
      "EPOCH: 4396 LOSS: 41.07374202901849\n",
      "EPOCH: 4397 LOSS: 41.07372576213714\n",
      "EPOCH: 4398 LOSS: 41.07370949913654\n",
      "EPOCH: 4399 LOSS: 41.0736932400149\n",
      "EPOCH: 4400 LOSS: 41.07367698477046\n",
      "EPOCH: 4401 LOSS: 41.0736607334014\n",
      "EPOCH: 4402 LOSS: 41.07364448590596\n",
      "EPOCH: 4403 LOSS: 41.073628242282325\n",
      "EPOCH: 4404 LOSS: 41.07361200252875\n",
      "EPOCH: 4405 LOSS: 41.07359576664342\n",
      "EPOCH: 4406 LOSS: 41.073579534624585\n",
      "EPOCH: 4407 LOSS: 41.07356330647045\n",
      "EPOCH: 4408 LOSS: 41.07354708217926\n",
      "EPOCH: 4409 LOSS: 41.073530861749205\n",
      "EPOCH: 4410 LOSS: 41.07351464517855\n",
      "EPOCH: 4411 LOSS: 41.073498432465485\n",
      "EPOCH: 4412 LOSS: 41.07348222360828\n",
      "EPOCH: 4413 LOSS: 41.07346601860514\n",
      "EPOCH: 4414 LOSS: 41.07344981745432\n",
      "EPOCH: 4415 LOSS: 41.073433620154034\n",
      "EPOCH: 4416 LOSS: 41.073417426702534\n",
      "EPOCH: 4417 LOSS: 41.07340123709804\n",
      "EPOCH: 4418 LOSS: 41.07338505133881\n",
      "EPOCH: 4419 LOSS: 41.073368869423085\n",
      "EPOCH: 4420 LOSS: 41.073352691349086\n",
      "EPOCH: 4421 LOSS: 41.073336517115095\n",
      "EPOCH: 4422 LOSS: 41.073320346719306\n",
      "EPOCH: 4423 LOSS: 41.07330418016003\n",
      "EPOCH: 4424 LOSS: 41.07328801743547\n",
      "EPOCH: 4425 LOSS: 41.07327185854389\n",
      "EPOCH: 4426 LOSS: 41.07325570348354\n",
      "EPOCH: 4427 LOSS: 41.073239552252694\n",
      "EPOCH: 4428 LOSS: 41.073223404849564\n",
      "EPOCH: 4429 LOSS: 41.07320726127244\n",
      "EPOCH: 4430 LOSS: 41.07319112151957\n",
      "EPOCH: 4431 LOSS: 41.07317498558922\n",
      "EPOCH: 4432 LOSS: 41.073158853479654\n",
      "EPOCH: 4433 LOSS: 41.07314272518912\n",
      "EPOCH: 4434 LOSS: 41.073126600715895\n",
      "EPOCH: 4435 LOSS: 41.07311048005823\n",
      "EPOCH: 4436 LOSS: 41.073094363214416\n",
      "EPOCH: 4437 LOSS: 41.07307825018271\n",
      "EPOCH: 4438 LOSS: 41.07306214096137\n",
      "EPOCH: 4439 LOSS: 41.07304603554869\n",
      "EPOCH: 4440 LOSS: 41.07302993394294\n",
      "EPOCH: 4441 LOSS: 41.07301383614237\n",
      "EPOCH: 4442 LOSS: 41.072997742145276\n",
      "EPOCH: 4443 LOSS: 41.072981651949945\n",
      "EPOCH: 4444 LOSS: 41.07296556555465\n",
      "EPOCH: 4445 LOSS: 41.072949482957654\n",
      "EPOCH: 4446 LOSS: 41.07293340415726\n",
      "EPOCH: 4447 LOSS: 41.07291732915175\n",
      "EPOCH: 4448 LOSS: 41.0729012579394\n",
      "EPOCH: 4449 LOSS: 41.07288519051849\n",
      "EPOCH: 4450 LOSS: 41.072869126887355\n",
      "EPOCH: 4451 LOSS: 41.07285306704422\n",
      "EPOCH: 4452 LOSS: 41.07283701098743\n",
      "EPOCH: 4453 LOSS: 41.07282095871524\n",
      "EPOCH: 4454 LOSS: 41.07280491022597\n",
      "EPOCH: 4455 LOSS: 41.07278886551788\n",
      "EPOCH: 4456 LOSS: 41.07277282458932\n",
      "EPOCH: 4457 LOSS: 41.07275678743856\n",
      "EPOCH: 4458 LOSS: 41.07274075406389\n",
      "EPOCH: 4459 LOSS: 41.072724724463626\n",
      "EPOCH: 4460 LOSS: 41.07270869863608\n",
      "EPOCH: 4461 LOSS: 41.072692676579535\n",
      "EPOCH: 4462 LOSS: 41.0726766582923\n",
      "EPOCH: 4463 LOSS: 41.07266064377272\n",
      "EPOCH: 4464 LOSS: 41.07264463301907\n",
      "EPOCH: 4465 LOSS: 41.07262862602963\n",
      "EPOCH: 4466 LOSS: 41.07261262280277\n",
      "EPOCH: 4467 LOSS: 41.07259662333679\n",
      "EPOCH: 4468 LOSS: 41.072580627629996\n",
      "EPOCH: 4469 LOSS: 41.07256463568069\n",
      "EPOCH: 4470 LOSS: 41.07254864748722\n",
      "EPOCH: 4471 LOSS: 41.07253266304788\n",
      "EPOCH: 4472 LOSS: 41.072516682361005\n",
      "EPOCH: 4473 LOSS: 41.07250070542491\n",
      "EPOCH: 4474 LOSS: 41.07248473223791\n",
      "EPOCH: 4475 LOSS: 41.072468762798366\n",
      "EPOCH: 4476 LOSS: 41.07245279710457\n",
      "EPOCH: 4477 LOSS: 41.07243683515486\n",
      "EPOCH: 4478 LOSS: 41.07242087694755\n",
      "EPOCH: 4479 LOSS: 41.072404922481\n",
      "EPOCH: 4480 LOSS: 41.07238897175354\n",
      "EPOCH: 4481 LOSS: 41.07237302476347\n",
      "EPOCH: 4482 LOSS: 41.07235708150917\n",
      "EPOCH: 4483 LOSS: 41.07234114198894\n",
      "EPOCH: 4484 LOSS: 41.07232520620113\n",
      "EPOCH: 4485 LOSS: 41.07230927414408\n",
      "EPOCH: 4486 LOSS: 41.07229334581614\n",
      "EPOCH: 4487 LOSS: 41.07227742121564\n",
      "EPOCH: 4488 LOSS: 41.07226150034094\n",
      "EPOCH: 4489 LOSS: 41.072245583190345\n",
      "EPOCH: 4490 LOSS: 41.072229669762244\n",
      "EPOCH: 4491 LOSS: 41.07221376005498\n",
      "EPOCH: 4492 LOSS: 41.072197854066886\n",
      "EPOCH: 4493 LOSS: 41.072181951796324\n",
      "EPOCH: 4494 LOSS: 41.07216605324162\n",
      "EPOCH: 4495 LOSS: 41.072150158401186\n",
      "EPOCH: 4496 LOSS: 41.07213426727331\n",
      "EPOCH: 4497 LOSS: 41.07211837985639\n",
      "EPOCH: 4498 LOSS: 41.07210249614877\n",
      "EPOCH: 4499 LOSS: 41.07208661614881\n",
      "EPOCH: 4500 LOSS: 41.07207073985488\n",
      "EPOCH: 4501 LOSS: 41.072054867265315\n",
      "EPOCH: 4502 LOSS: 41.072038998378524\n",
      "EPOCH: 4503 LOSS: 41.072023133192815\n",
      "EPOCH: 4504 LOSS: 41.0720072717066\n",
      "EPOCH: 4505 LOSS: 41.07199141391824\n",
      "EPOCH: 4506 LOSS: 41.07197555982608\n",
      "EPOCH: 4507 LOSS: 41.0719597094285\n",
      "EPOCH: 4508 LOSS: 41.07194386272388\n",
      "EPOCH: 4509 LOSS: 41.07192801971058\n",
      "EPOCH: 4510 LOSS: 41.071912180387\n",
      "EPOCH: 4511 LOSS: 41.071896344751494\n",
      "EPOCH: 4512 LOSS: 41.07188051280244\n",
      "EPOCH: 4513 LOSS: 41.07186468453822\n",
      "EPOCH: 4514 LOSS: 41.07184885995722\n",
      "EPOCH: 4515 LOSS: 41.071833039057815\n",
      "EPOCH: 4516 LOSS: 41.07181722183837\n",
      "EPOCH: 4517 LOSS: 41.071801408297304\n",
      "EPOCH: 4518 LOSS: 41.071785598432974\n",
      "EPOCH: 4519 LOSS: 41.07176979224379\n",
      "EPOCH: 4520 LOSS: 41.07175398972814\n",
      "EPOCH: 4521 LOSS: 41.07173819088437\n",
      "EPOCH: 4522 LOSS: 41.07172239571092\n",
      "EPOCH: 4523 LOSS: 41.07170660420615\n",
      "EPOCH: 4524 LOSS: 41.07169081636848\n",
      "EPOCH: 4525 LOSS: 41.07167503219629\n",
      "EPOCH: 4526 LOSS: 41.071659251687976\n",
      "EPOCH: 4527 LOSS: 41.07164347484195\n",
      "EPOCH: 4528 LOSS: 41.07162770165658\n",
      "EPOCH: 4529 LOSS: 41.07161193213028\n",
      "EPOCH: 4530 LOSS: 41.07159616626148\n",
      "EPOCH: 4531 LOSS: 41.07158040404855\n",
      "EPOCH: 4532 LOSS: 41.071564645489886\n",
      "EPOCH: 4533 LOSS: 41.07154889058393\n",
      "EPOCH: 4534 LOSS: 41.07153313932905\n",
      "EPOCH: 4535 LOSS: 41.0715173917237\n",
      "EPOCH: 4536 LOSS: 41.07150164776624\n",
      "EPOCH: 4537 LOSS: 41.071485907455134\n",
      "EPOCH: 4538 LOSS: 41.071470170788736\n",
      "EPOCH: 4539 LOSS: 41.071454437765496\n",
      "EPOCH: 4540 LOSS: 41.07143870838382\n",
      "EPOCH: 4541 LOSS: 41.07142298264213\n",
      "EPOCH: 4542 LOSS: 41.07140726053882\n",
      "EPOCH: 4543 LOSS: 41.071391542072355\n",
      "EPOCH: 4544 LOSS: 41.071375827241106\n",
      "EPOCH: 4545 LOSS: 41.07136011604352\n",
      "EPOCH: 4546 LOSS: 41.07134440847801\n",
      "EPOCH: 4547 LOSS: 41.07132870454301\n",
      "EPOCH: 4548 LOSS: 41.071313004236956\n",
      "EPOCH: 4549 LOSS: 41.07129730755824\n",
      "EPOCH: 4550 LOSS: 41.07128161450532\n",
      "EPOCH: 4551 LOSS: 41.071265925076595\n",
      "EPOCH: 4552 LOSS: 41.071250239270526\n",
      "EPOCH: 4553 LOSS: 41.07123455708554\n",
      "EPOCH: 4554 LOSS: 41.07121887852006\n",
      "EPOCH: 4555 LOSS: 41.07120320357251\n",
      "EPOCH: 4556 LOSS: 41.07118753224137\n",
      "EPOCH: 4557 LOSS: 41.07117186452501\n",
      "EPOCH: 4558 LOSS: 41.07115620042194\n",
      "EPOCH: 4559 LOSS: 41.071140539930546\n",
      "EPOCH: 4560 LOSS: 41.07112488304929\n",
      "EPOCH: 4561 LOSS: 41.071109229776624\n",
      "EPOCH: 4562 LOSS: 41.07109358011096\n",
      "EPOCH: 4563 LOSS: 41.07107793405077\n",
      "EPOCH: 4564 LOSS: 41.07106229159449\n",
      "EPOCH: 4565 LOSS: 41.07104665274058\n",
      "EPOCH: 4566 LOSS: 41.07103101748748\n",
      "EPOCH: 4567 LOSS: 41.071015385833626\n",
      "EPOCH: 4568 LOSS: 41.070999757777486\n",
      "EPOCH: 4569 LOSS: 41.07098413331752\n",
      "EPOCH: 4570 LOSS: 41.07096851245214\n",
      "EPOCH: 4571 LOSS: 41.07095289517985\n",
      "EPOCH: 4572 LOSS: 41.0709372814991\n",
      "EPOCH: 4573 LOSS: 41.070921671408314\n",
      "EPOCH: 4574 LOSS: 41.070906064905984\n",
      "EPOCH: 4575 LOSS: 41.07089046199055\n",
      "EPOCH: 4576 LOSS: 41.070874862660474\n",
      "EPOCH: 4577 LOSS: 41.07085926691423\n",
      "EPOCH: 4578 LOSS: 41.07084367475028\n",
      "EPOCH: 4579 LOSS: 41.0708280861671\n",
      "EPOCH: 4580 LOSS: 41.07081250116312\n",
      "EPOCH: 4581 LOSS: 41.07079691973685\n",
      "EPOCH: 4582 LOSS: 41.07078134188673\n",
      "EPOCH: 4583 LOSS: 41.07076576761122\n",
      "EPOCH: 4584 LOSS: 41.07075019690883\n",
      "EPOCH: 4585 LOSS: 41.07073462977803\n",
      "EPOCH: 4586 LOSS: 41.070719066217265\n",
      "EPOCH: 4587 LOSS: 41.070703506224994\n",
      "EPOCH: 4588 LOSS: 41.070687949799755\n",
      "EPOCH: 4589 LOSS: 41.07067239693999\n",
      "EPOCH: 4590 LOSS: 41.070656847644166\n",
      "EPOCH: 4591 LOSS: 41.070641301910776\n",
      "EPOCH: 4592 LOSS: 41.07062575973833\n",
      "EPOCH: 4593 LOSS: 41.07061022112525\n",
      "EPOCH: 4594 LOSS: 41.070594686070066\n",
      "EPOCH: 4595 LOSS: 41.07057915457126\n",
      "EPOCH: 4596 LOSS: 41.07056362662729\n",
      "EPOCH: 4597 LOSS: 41.07054810223668\n",
      "EPOCH: 4598 LOSS: 41.070532581397885\n",
      "EPOCH: 4599 LOSS: 41.070517064109424\n",
      "EPOCH: 4600 LOSS: 41.07050155036977\n",
      "EPOCH: 4601 LOSS: 41.070486040177414\n",
      "EPOCH: 4602 LOSS: 41.07047053353085\n",
      "EPOCH: 4603 LOSS: 41.0704550304286\n",
      "EPOCH: 4604 LOSS: 41.07043953086913\n",
      "EPOCH: 4605 LOSS: 41.070424034850944\n",
      "EPOCH: 4606 LOSS: 41.07040854237253\n",
      "EPOCH: 4607 LOSS: 41.070393053432426\n",
      "EPOCH: 4608 LOSS: 41.070377568029095\n",
      "EPOCH: 4609 LOSS: 41.070362086161055\n",
      "EPOCH: 4610 LOSS: 41.0703466078268\n",
      "EPOCH: 4611 LOSS: 41.07033113302483\n",
      "EPOCH: 4612 LOSS: 41.070315661753675\n",
      "EPOCH: 4613 LOSS: 41.07030019401183\n",
      "EPOCH: 4614 LOSS: 41.070284729797805\n",
      "EPOCH: 4615 LOSS: 41.07026926911009\n",
      "EPOCH: 4616 LOSS: 41.07025381194722\n",
      "EPOCH: 4617 LOSS: 41.070238358307684\n",
      "EPOCH: 4618 LOSS: 41.07022290819003\n",
      "EPOCH: 4619 LOSS: 41.070207461592744\n",
      "EPOCH: 4620 LOSS: 41.070192018514355\n",
      "EPOCH: 4621 LOSS: 41.070176578953365\n",
      "EPOCH: 4622 LOSS: 41.070161142908304\n",
      "EPOCH: 4623 LOSS: 41.07014571037769\n",
      "EPOCH: 4624 LOSS: 41.07013028136001\n",
      "EPOCH: 4625 LOSS: 41.07011485585385\n",
      "EPOCH: 4626 LOSS: 41.070099433857685\n",
      "EPOCH: 4627 LOSS: 41.07008401537007\n",
      "EPOCH: 4628 LOSS: 41.07006860038949\n",
      "EPOCH: 4629 LOSS: 41.07005318891449\n",
      "EPOCH: 4630 LOSS: 41.07003778094361\n",
      "EPOCH: 4631 LOSS: 41.07002237647537\n",
      "EPOCH: 4632 LOSS: 41.07000697550829\n",
      "EPOCH: 4633 LOSS: 41.06999157804091\n",
      "EPOCH: 4634 LOSS: 41.06997618407177\n",
      "EPOCH: 4635 LOSS: 41.069960793599385\n",
      "EPOCH: 4636 LOSS: 41.069945406622296\n",
      "EPOCH: 4637 LOSS: 41.06993002313904\n",
      "EPOCH: 4638 LOSS: 41.06991464314816\n",
      "EPOCH: 4639 LOSS: 41.06989926664819\n",
      "EPOCH: 4640 LOSS: 41.069883893637666\n",
      "EPOCH: 4641 LOSS: 41.06986852411513\n",
      "EPOCH: 4642 LOSS: 41.06985315807912\n",
      "EPOCH: 4643 LOSS: 41.06983779552819\n",
      "EPOCH: 4644 LOSS: 41.06982243646086\n",
      "EPOCH: 4645 LOSS: 41.069807080875684\n",
      "EPOCH: 4646 LOSS: 41.06979172877122\n",
      "EPOCH: 4647 LOSS: 41.069776380146\n",
      "EPOCH: 4648 LOSS: 41.069761034998606\n",
      "EPOCH: 4649 LOSS: 41.06974569332754\n",
      "EPOCH: 4650 LOSS: 41.069730355131384\n",
      "EPOCH: 4651 LOSS: 41.06971502040867\n",
      "EPOCH: 4652 LOSS: 41.06969968915798\n",
      "EPOCH: 4653 LOSS: 41.06968436137784\n",
      "EPOCH: 4654 LOSS: 41.0696690370668\n",
      "EPOCH: 4655 LOSS: 41.06965371622345\n",
      "EPOCH: 4656 LOSS: 41.06963839884633\n",
      "EPOCH: 4657 LOSS: 41.06962308493398\n",
      "EPOCH: 4658 LOSS: 41.069607774484986\n",
      "EPOCH: 4659 LOSS: 41.069592467497884\n",
      "EPOCH: 4660 LOSS: 41.069577163971275\n",
      "EPOCH: 4661 LOSS: 41.06956186390367\n",
      "EPOCH: 4662 LOSS: 41.069546567293685\n",
      "EPOCH: 4663 LOSS: 41.069531274139855\n",
      "EPOCH: 4664 LOSS: 41.06951598444075\n",
      "EPOCH: 4665 LOSS: 41.06950069819494\n",
      "EPOCH: 4666 LOSS: 41.069485415401\n",
      "EPOCH: 4667 LOSS: 41.06947013605749\n",
      "EPOCH: 4668 LOSS: 41.06945486016299\n",
      "EPOCH: 4669 LOSS: 41.06943958771606\n",
      "EPOCH: 4670 LOSS: 41.0694243187153\n",
      "EPOCH: 4671 LOSS: 41.06940905315923\n",
      "EPOCH: 4672 LOSS: 41.06939379104649\n",
      "EPOCH: 4673 LOSS: 41.069378532375616\n",
      "EPOCH: 4674 LOSS: 41.06936327714521\n",
      "EPOCH: 4675 LOSS: 41.069348025353825\n",
      "EPOCH: 4676 LOSS: 41.069332777000064\n",
      "EPOCH: 4677 LOSS: 41.06931753208248\n",
      "EPOCH: 4678 LOSS: 41.06930229059969\n",
      "EPOCH: 4679 LOSS: 41.06928705255026\n",
      "EPOCH: 4680 LOSS: 41.06927181793277\n",
      "EPOCH: 4681 LOSS: 41.06925658674581\n",
      "EPOCH: 4682 LOSS: 41.069241358987966\n",
      "EPOCH: 4683 LOSS: 41.06922613465784\n",
      "EPOCH: 4684 LOSS: 41.06921091375399\n",
      "EPOCH: 4685 LOSS: 41.06919569627504\n",
      "EPOCH: 4686 LOSS: 41.069180482219565\n",
      "EPOCH: 4687 LOSS: 41.06916527158615\n",
      "EPOCH: 4688 LOSS: 41.06915006437338\n",
      "EPOCH: 4689 LOSS: 41.069134860579894\n",
      "EPOCH: 4690 LOSS: 41.06911966020423\n",
      "EPOCH: 4691 LOSS: 41.069104463245026\n",
      "EPOCH: 4692 LOSS: 41.06908926970088\n",
      "EPOCH: 4693 LOSS: 41.069074079570356\n",
      "EPOCH: 4694 LOSS: 41.069058892852084\n",
      "EPOCH: 4695 LOSS: 41.06904370954465\n",
      "EPOCH: 4696 LOSS: 41.06902852964668\n",
      "EPOCH: 4697 LOSS: 41.06901335315674\n",
      "EPOCH: 4698 LOSS: 41.06899818007347\n",
      "EPOCH: 4699 LOSS: 41.068983010395435\n",
      "EPOCH: 4700 LOSS: 41.068967844121275\n",
      "EPOCH: 4701 LOSS: 41.06895268124959\n",
      "EPOCH: 4702 LOSS: 41.06893752177898\n",
      "EPOCH: 4703 LOSS: 41.06892236570807\n",
      "EPOCH: 4704 LOSS: 41.06890721303546\n",
      "EPOCH: 4705 LOSS: 41.06889206375975\n",
      "EPOCH: 4706 LOSS: 41.06887691787958\n",
      "EPOCH: 4707 LOSS: 41.06886177539354\n",
      "EPOCH: 4708 LOSS: 41.068846636300265\n",
      "EPOCH: 4709 LOSS: 41.06883150059834\n",
      "EPOCH: 4710 LOSS: 41.06881636828641\n",
      "EPOCH: 4711 LOSS: 41.06880123936309\n",
      "EPOCH: 4712 LOSS: 41.068786113827\n",
      "EPOCH: 4713 LOSS: 41.06877099167674\n",
      "EPOCH: 4714 LOSS: 41.06875587291095\n",
      "EPOCH: 4715 LOSS: 41.06874075752826\n",
      "EPOCH: 4716 LOSS: 41.06872564552728\n",
      "EPOCH: 4717 LOSS: 41.06871053690662\n",
      "EPOCH: 4718 LOSS: 41.06869543166493\n",
      "EPOCH: 4719 LOSS: 41.06868032980084\n",
      "EPOCH: 4720 LOSS: 41.068665231312956\n",
      "EPOCH: 4721 LOSS: 41.06865013619991\n",
      "EPOCH: 4722 LOSS: 41.06863504446035\n",
      "EPOCH: 4723 LOSS: 41.0686199560929\n",
      "EPOCH: 4724 LOSS: 41.06860487109619\n",
      "EPOCH: 4725 LOSS: 41.06858978946884\n",
      "EPOCH: 4726 LOSS: 41.06857471120949\n",
      "EPOCH: 4727 LOSS: 41.06855963631679\n",
      "EPOCH: 4728 LOSS: 41.06854456478937\n",
      "EPOCH: 4729 LOSS: 41.06852949662586\n",
      "EPOCH: 4730 LOSS: 41.06851443182488\n",
      "EPOCH: 4731 LOSS: 41.068499370385126\n",
      "EPOCH: 4732 LOSS: 41.06848431230517\n",
      "EPOCH: 4733 LOSS: 41.068469257583715\n",
      "EPOCH: 4734 LOSS: 41.068454206219364\n",
      "EPOCH: 4735 LOSS: 41.06843915821075\n",
      "EPOCH: 4736 LOSS: 41.06842411355656\n",
      "EPOCH: 4737 LOSS: 41.068409072255434\n",
      "EPOCH: 4738 LOSS: 41.068394034305975\n",
      "EPOCH: 4739 LOSS: 41.068378999706866\n",
      "EPOCH: 4740 LOSS: 41.06836396845674\n",
      "EPOCH: 4741 LOSS: 41.06834894055426\n",
      "EPOCH: 4742 LOSS: 41.068333915998075\n",
      "EPOCH: 4743 LOSS: 41.06831889478682\n",
      "EPOCH: 4744 LOSS: 41.068303876919174\n",
      "EPOCH: 4745 LOSS: 41.06828886239378\n",
      "EPOCH: 4746 LOSS: 41.06827385120927\n",
      "EPOCH: 4747 LOSS: 41.06825884336433\n",
      "EPOCH: 4748 LOSS: 41.068243838857605\n",
      "EPOCH: 4749 LOSS: 41.068228837687755\n",
      "EPOCH: 4750 LOSS: 41.068213839853435\n",
      "EPOCH: 4751 LOSS: 41.06819884535331\n",
      "EPOCH: 4752 LOSS: 41.068183854186024\n",
      "EPOCH: 4753 LOSS: 41.06816886635027\n",
      "EPOCH: 4754 LOSS: 41.06815388184469\n",
      "EPOCH: 4755 LOSS: 41.06813890066795\n",
      "EPOCH: 4756 LOSS: 41.06812392281872\n",
      "EPOCH: 4757 LOSS: 41.068108948295645\n",
      "EPOCH: 4758 LOSS: 41.06809397709742\n",
      "EPOCH: 4759 LOSS: 41.06807900922273\n",
      "EPOCH: 4760 LOSS: 41.06806404467018\n",
      "EPOCH: 4761 LOSS: 41.068049083438474\n",
      "EPOCH: 4762 LOSS: 41.06803412552631\n",
      "EPOCH: 4763 LOSS: 41.068019170932324\n",
      "EPOCH: 4764 LOSS: 41.068004219655194\n",
      "EPOCH: 4765 LOSS: 41.067989271693605\n",
      "EPOCH: 4766 LOSS: 41.06797432704623\n",
      "EPOCH: 4767 LOSS: 41.06795938571172\n",
      "EPOCH: 4768 LOSS: 41.0679444476888\n",
      "EPOCH: 4769 LOSS: 41.06792951297611\n",
      "EPOCH: 4770 LOSS: 41.067914581572346\n",
      "EPOCH: 4771 LOSS: 41.067899653476175\n",
      "EPOCH: 4772 LOSS: 41.0678847286863\n",
      "EPOCH: 4773 LOSS: 41.067869807201376\n",
      "EPOCH: 4774 LOSS: 41.06785488902008\n",
      "EPOCH: 4775 LOSS: 41.067839974141165\n",
      "EPOCH: 4776 LOSS: 41.06782506256323\n",
      "EPOCH: 4777 LOSS: 41.067810154284984\n",
      "EPOCH: 4778 LOSS: 41.06779524930516\n",
      "EPOCH: 4779 LOSS: 41.06778034762238\n",
      "EPOCH: 4780 LOSS: 41.067765449235374\n",
      "EPOCH: 4781 LOSS: 41.06775055414282\n",
      "EPOCH: 4782 LOSS: 41.06773566234341\n",
      "EPOCH: 4783 LOSS: 41.06772077383585\n",
      "EPOCH: 4784 LOSS: 41.067705888618804\n",
      "EPOCH: 4785 LOSS: 41.067691006690985\n",
      "EPOCH: 4786 LOSS: 41.06767612805108\n",
      "EPOCH: 4787 LOSS: 41.06766125269782\n",
      "EPOCH: 4788 LOSS: 41.06764638062982\n",
      "EPOCH: 4789 LOSS: 41.06763151184585\n",
      "EPOCH: 4790 LOSS: 41.06761664634459\n",
      "EPOCH: 4791 LOSS: 41.067601784124726\n",
      "EPOCH: 4792 LOSS: 41.06758692518498\n",
      "EPOCH: 4793 LOSS: 41.06757206952403\n",
      "EPOCH: 4794 LOSS: 41.0675572171406\n",
      "EPOCH: 4795 LOSS: 41.06754236803337\n",
      "EPOCH: 4796 LOSS: 41.06752752220107\n",
      "EPOCH: 4797 LOSS: 41.06751267964239\n",
      "EPOCH: 4798 LOSS: 41.06749784035604\n",
      "EPOCH: 4799 LOSS: 41.06748300434071\n",
      "EPOCH: 4800 LOSS: 41.06746817159515\n",
      "EPOCH: 4801 LOSS: 41.06745334211804\n",
      "EPOCH: 4802 LOSS: 41.06743851590808\n",
      "EPOCH: 4803 LOSS: 41.067423692964\n",
      "EPOCH: 4804 LOSS: 41.06740887328449\n",
      "EPOCH: 4805 LOSS: 41.06739405686831\n",
      "EPOCH: 4806 LOSS: 41.06737924371414\n",
      "EPOCH: 4807 LOSS: 41.067364433820686\n",
      "EPOCH: 4808 LOSS: 41.06734962718669\n",
      "EPOCH: 4809 LOSS: 41.067334823810825\n",
      "EPOCH: 4810 LOSS: 41.06732002369188\n",
      "EPOCH: 4811 LOSS: 41.06730522682851\n",
      "EPOCH: 4812 LOSS: 41.067290433219455\n",
      "EPOCH: 4813 LOSS: 41.06727564286346\n",
      "EPOCH: 4814 LOSS: 41.06726085575921\n",
      "EPOCH: 4815 LOSS: 41.06724607190544\n",
      "EPOCH: 4816 LOSS: 41.067231291300864\n",
      "EPOCH: 4817 LOSS: 41.06721651394422\n",
      "EPOCH: 4818 LOSS: 41.06720173983426\n",
      "EPOCH: 4819 LOSS: 41.06718696896966\n",
      "EPOCH: 4820 LOSS: 41.06717220134918\n",
      "EPOCH: 4821 LOSS: 41.06715743697152\n",
      "EPOCH: 4822 LOSS: 41.067142675835434\n",
      "EPOCH: 4823 LOSS: 41.06712791793966\n",
      "EPOCH: 4824 LOSS: 41.06711316328289\n",
      "EPOCH: 4825 LOSS: 41.067098411863896\n",
      "EPOCH: 4826 LOSS: 41.06708366368138\n",
      "EPOCH: 4827 LOSS: 41.067068918734094\n",
      "EPOCH: 4828 LOSS: 41.06705417702077\n",
      "EPOCH: 4829 LOSS: 41.067039438540135\n",
      "EPOCH: 4830 LOSS: 41.067024703290926\n",
      "EPOCH: 4831 LOSS: 41.0670099712719\n",
      "EPOCH: 4832 LOSS: 41.06699524248178\n",
      "EPOCH: 4833 LOSS: 41.066980516919315\n",
      "EPOCH: 4834 LOSS: 41.066965794583204\n",
      "EPOCH: 4835 LOSS: 41.06695107547225\n",
      "EPOCH: 4836 LOSS: 41.066936359585156\n",
      "EPOCH: 4837 LOSS: 41.06692164692068\n",
      "EPOCH: 4838 LOSS: 41.066906937477555\n",
      "EPOCH: 4839 LOSS: 41.066892231254535\n",
      "EPOCH: 4840 LOSS: 41.06687752825036\n",
      "EPOCH: 4841 LOSS: 41.06686282846379\n",
      "EPOCH: 4842 LOSS: 41.06684813189355\n",
      "EPOCH: 4843 LOSS: 41.0668334385384\n",
      "EPOCH: 4844 LOSS: 41.0668187483971\n",
      "EPOCH: 4845 LOSS: 41.06680406146838\n",
      "EPOCH: 4846 LOSS: 41.06678937775099\n",
      "EPOCH: 4847 LOSS: 41.0667746972437\n",
      "EPOCH: 4848 LOSS: 41.06676001994528\n",
      "EPOCH: 4849 LOSS: 41.066745345854414\n",
      "EPOCH: 4850 LOSS: 41.06673067496994\n",
      "EPOCH: 4851 LOSS: 41.066716007290566\n",
      "EPOCH: 4852 LOSS: 41.06670134281505\n",
      "EPOCH: 4853 LOSS: 41.06668668154218\n",
      "EPOCH: 4854 LOSS: 41.066672023470666\n",
      "EPOCH: 4855 LOSS: 41.0666573685993\n",
      "EPOCH: 4856 LOSS: 41.06664271692685\n",
      "EPOCH: 4857 LOSS: 41.06662806845205\n",
      "EPOCH: 4858 LOSS: 41.06661342317368\n",
      "EPOCH: 4859 LOSS: 41.06659878109049\n",
      "EPOCH: 4860 LOSS: 41.06658414220126\n",
      "EPOCH: 4861 LOSS: 41.06656950650475\n",
      "EPOCH: 4862 LOSS: 41.06655487399972\n",
      "EPOCH: 4863 LOSS: 41.06654024468493\n",
      "EPOCH: 4864 LOSS: 41.06652561855917\n",
      "EPOCH: 4865 LOSS: 41.06651099562118\n",
      "EPOCH: 4866 LOSS: 41.06649637586975\n",
      "EPOCH: 4867 LOSS: 41.066481759303656\n",
      "EPOCH: 4868 LOSS: 41.066467145921635\n",
      "EPOCH: 4869 LOSS: 41.06645253572248\n",
      "EPOCH: 4870 LOSS: 41.066437928704985\n",
      "EPOCH: 4871 LOSS: 41.06642332486787\n",
      "EPOCH: 4872 LOSS: 41.066408724209964\n",
      "EPOCH: 4873 LOSS: 41.06639412673\n",
      "EPOCH: 4874 LOSS: 41.066379532426794\n",
      "EPOCH: 4875 LOSS: 41.06636494129911\n",
      "EPOCH: 4876 LOSS: 41.06635035334571\n",
      "EPOCH: 4877 LOSS: 41.06633576856538\n",
      "EPOCH: 4878 LOSS: 41.0663211869569\n",
      "EPOCH: 4879 LOSS: 41.06630660851905\n",
      "EPOCH: 4880 LOSS: 41.06629203325062\n",
      "EPOCH: 4881 LOSS: 41.066277461150385\n",
      "EPOCH: 4882 LOSS: 41.06626289221712\n",
      "EPOCH: 4883 LOSS: 41.06624832644964\n",
      "EPOCH: 4884 LOSS: 41.0662337638467\n",
      "EPOCH: 4885 LOSS: 41.06621920440707\n",
      "EPOCH: 4886 LOSS: 41.06620464812959\n",
      "EPOCH: 4887 LOSS: 41.066190095013\n",
      "EPOCH: 4888 LOSS: 41.066175545056126\n",
      "EPOCH: 4889 LOSS: 41.06616099825772\n",
      "EPOCH: 4890 LOSS: 41.0661464546166\n",
      "EPOCH: 4891 LOSS: 41.06613191413155\n",
      "EPOCH: 4892 LOSS: 41.06611737680135\n",
      "EPOCH: 4893 LOSS: 41.06610284262481\n",
      "EPOCH: 4894 LOSS: 41.06608831160071\n",
      "EPOCH: 4895 LOSS: 41.066073783727845\n",
      "EPOCH: 4896 LOSS: 41.06605925900502\n",
      "EPOCH: 4897 LOSS: 41.06604473743105\n",
      "EPOCH: 4898 LOSS: 41.06603021900467\n",
      "EPOCH: 4899 LOSS: 41.06601570372473\n",
      "EPOCH: 4900 LOSS: 41.06600119159003\n",
      "EPOCH: 4901 LOSS: 41.065986682599345\n",
      "EPOCH: 4902 LOSS: 41.06597217675149\n",
      "EPOCH: 4903 LOSS: 41.06595767404524\n",
      "EPOCH: 4904 LOSS: 41.06594317447945\n",
      "EPOCH: 4905 LOSS: 41.06592867805286\n",
      "EPOCH: 4906 LOSS: 41.06591418476434\n",
      "EPOCH: 4907 LOSS: 41.06589969461262\n",
      "EPOCH: 4908 LOSS: 41.065885207596565\n",
      "EPOCH: 4909 LOSS: 41.06587072371498\n",
      "EPOCH: 4910 LOSS: 41.06585624296664\n",
      "EPOCH: 4911 LOSS: 41.06584176535037\n",
      "EPOCH: 4912 LOSS: 41.065827290864966\n",
      "EPOCH: 4913 LOSS: 41.06581281950925\n",
      "EPOCH: 4914 LOSS: 41.06579835128203\n",
      "EPOCH: 4915 LOSS: 41.06578388618214\n",
      "EPOCH: 4916 LOSS: 41.06576942420835\n",
      "EPOCH: 4917 LOSS: 41.06575496535948\n",
      "EPOCH: 4918 LOSS: 41.06574050963439\n",
      "EPOCH: 4919 LOSS: 41.065726057031846\n",
      "EPOCH: 4920 LOSS: 41.06571160755068\n",
      "EPOCH: 4921 LOSS: 41.0656971611897\n",
      "EPOCH: 4922 LOSS: 41.06568271794775\n",
      "EPOCH: 4923 LOSS: 41.06566827782361\n",
      "EPOCH: 4924 LOSS: 41.06565384081614\n",
      "EPOCH: 4925 LOSS: 41.06563940692412\n",
      "EPOCH: 4926 LOSS: 41.06562497614641\n",
      "EPOCH: 4927 LOSS: 41.06561054848179\n",
      "EPOCH: 4928 LOSS: 41.06559612392911\n",
      "EPOCH: 4929 LOSS: 41.065581702487194\n",
      "EPOCH: 4930 LOSS: 41.06556728415485\n",
      "EPOCH: 4931 LOSS: 41.06555286893091\n",
      "EPOCH: 4932 LOSS: 41.06553845681421\n",
      "EPOCH: 4933 LOSS: 41.06552404780356\n",
      "EPOCH: 4934 LOSS: 41.06550964189779\n",
      "EPOCH: 4935 LOSS: 41.06549523909573\n",
      "EPOCH: 4936 LOSS: 41.06548083939622\n",
      "EPOCH: 4937 LOSS: 41.065466442798076\n",
      "EPOCH: 4938 LOSS: 41.06545204930015\n",
      "EPOCH: 4939 LOSS: 41.06543765890122\n",
      "EPOCH: 4940 LOSS: 41.06542327160018\n",
      "EPOCH: 4941 LOSS: 41.06540888739585\n",
      "EPOCH: 4942 LOSS: 41.06539450628703\n",
      "EPOCH: 4943 LOSS: 41.06538012827257\n",
      "EPOCH: 4944 LOSS: 41.06536575335132\n",
      "EPOCH: 4945 LOSS: 41.065351381522106\n",
      "EPOCH: 4946 LOSS: 41.06533701278377\n",
      "EPOCH: 4947 LOSS: 41.065322647135154\n",
      "EPOCH: 4948 LOSS: 41.06530828457507\n",
      "EPOCH: 4949 LOSS: 41.065293925102395\n",
      "EPOCH: 4950 LOSS: 41.06527956871595\n",
      "EPOCH: 4951 LOSS: 41.06526521541457\n",
      "EPOCH: 4952 LOSS: 41.065250865197086\n",
      "EPOCH: 4953 LOSS: 41.06523651806239\n",
      "EPOCH: 4954 LOSS: 41.065222174009264\n",
      "EPOCH: 4955 LOSS: 41.06520783303661\n",
      "EPOCH: 4956 LOSS: 41.065193495143234\n",
      "EPOCH: 4957 LOSS: 41.06517916032799\n",
      "EPOCH: 4958 LOSS: 41.065164828589744\n",
      "EPOCH: 4959 LOSS: 41.0651504999273\n",
      "EPOCH: 4960 LOSS: 41.06513617433955\n",
      "EPOCH: 4961 LOSS: 41.065121851825324\n",
      "EPOCH: 4962 LOSS: 41.06510753238348\n",
      "EPOCH: 4963 LOSS: 41.06509321601285\n",
      "EPOCH: 4964 LOSS: 41.0650789027123\n",
      "EPOCH: 4965 LOSS: 41.06506459248069\n",
      "EPOCH: 4966 LOSS: 41.065050285316865\n",
      "EPOCH: 4967 LOSS: 41.065035981219665\n",
      "EPOCH: 4968 LOSS: 41.06502168018798\n",
      "EPOCH: 4969 LOSS: 41.0650073822206\n",
      "EPOCH: 4970 LOSS: 41.06499308731647\n",
      "EPOCH: 4971 LOSS: 41.06497879547438\n",
      "EPOCH: 4972 LOSS: 41.064964506693215\n",
      "EPOCH: 4973 LOSS: 41.064950220971824\n",
      "EPOCH: 4974 LOSS: 41.06493593830908\n",
      "EPOCH: 4975 LOSS: 41.064921658703824\n",
      "EPOCH: 4976 LOSS: 41.06490738215492\n",
      "EPOCH: 4977 LOSS: 41.064893108661245\n",
      "EPOCH: 4978 LOSS: 41.06487883822165\n",
      "EPOCH: 4979 LOSS: 41.064864570835\n",
      "EPOCH: 4980 LOSS: 41.064850306500155\n",
      "EPOCH: 4981 LOSS: 41.064836045216\n",
      "EPOCH: 4982 LOSS: 41.064821786981376\n",
      "EPOCH: 4983 LOSS: 41.064807531795154\n",
      "EPOCH: 4984 LOSS: 41.06479327965621\n",
      "EPOCH: 4985 LOSS: 41.0647790305634\n",
      "EPOCH: 4986 LOSS: 41.0647647845156\n",
      "EPOCH: 4987 LOSS: 41.064750541511685\n",
      "EPOCH: 4988 LOSS: 41.064736301550525\n",
      "EPOCH: 4989 LOSS: 41.064722064630985\n",
      "EPOCH: 4990 LOSS: 41.06470783075193\n",
      "EPOCH: 4991 LOSS: 41.06469359991225\n",
      "EPOCH: 4992 LOSS: 41.06467937211082\n",
      "EPOCH: 4993 LOSS: 41.06466514734648\n",
      "EPOCH: 4994 LOSS: 41.064650925618125\n",
      "EPOCH: 4995 LOSS: 41.064636706924645\n",
      "EPOCH: 4996 LOSS: 41.06462249126492\n",
      "EPOCH: 4997 LOSS: 41.064608278637806\n",
      "EPOCH: 4998 LOSS: 41.064594069042165\n",
      "EPOCH: 4999 LOSS: 41.06457986247692\n",
      "EPOCH: 5000 LOSS: 41.06456565894093\n",
      "EPOCH: 5001 LOSS: 41.064551458433066\n",
      "EPOCH: 5002 LOSS: 41.06453726095222\n",
      "EPOCH: 5003 LOSS: 41.06452306649726\n",
      "EPOCH: 5004 LOSS: 41.06450887506709\n",
      "EPOCH: 5005 LOSS: 41.06449468666058\n",
      "EPOCH: 5006 LOSS: 41.06448050127662\n",
      "EPOCH: 5007 LOSS: 41.064466318914086\n",
      "EPOCH: 5008 LOSS: 41.06445213957188\n",
      "EPOCH: 5009 LOSS: 41.06443796324887\n",
      "EPOCH: 5010 LOSS: 41.064423789943945\n",
      "EPOCH: 5011 LOSS: 41.064409619656004\n",
      "EPOCH: 5012 LOSS: 41.064395452383934\n",
      "EPOCH: 5013 LOSS: 41.06438128812662\n",
      "EPOCH: 5014 LOSS: 41.06436712688295\n",
      "EPOCH: 5015 LOSS: 41.06435296865182\n",
      "EPOCH: 5016 LOSS: 41.064338813432116\n",
      "EPOCH: 5017 LOSS: 41.06432466122274\n",
      "EPOCH: 5018 LOSS: 41.06431051202257\n",
      "EPOCH: 5019 LOSS: 41.064296365830515\n",
      "EPOCH: 5020 LOSS: 41.06428222264546\n",
      "EPOCH: 5021 LOSS: 41.0642680824663\n",
      "EPOCH: 5022 LOSS: 41.064253945291945\n",
      "EPOCH: 5023 LOSS: 41.064239811121276\n",
      "EPOCH: 5024 LOSS: 41.064225679953196\n",
      "EPOCH: 5025 LOSS: 41.0642115517866\n",
      "EPOCH: 5026 LOSS: 41.064197426620396\n",
      "EPOCH: 5027 LOSS: 41.06418330445348\n",
      "EPOCH: 5028 LOSS: 41.064169185284754\n",
      "EPOCH: 5029 LOSS: 41.064155069113106\n",
      "EPOCH: 5030 LOSS: 41.064140955937454\n",
      "EPOCH: 5031 LOSS: 41.06412684575668\n",
      "EPOCH: 5032 LOSS: 41.06411273856972\n",
      "EPOCH: 5033 LOSS: 41.06409863437547\n",
      "EPOCH: 5034 LOSS: 41.0640845331728\n",
      "EPOCH: 5035 LOSS: 41.06407043496066\n",
      "EPOCH: 5036 LOSS: 41.064056339737945\n",
      "EPOCH: 5037 LOSS: 41.06404224750354\n",
      "EPOCH: 5038 LOSS: 41.06402815825637\n",
      "EPOCH: 5039 LOSS: 41.064014071995345\n",
      "EPOCH: 5040 LOSS: 41.06399998871936\n",
      "EPOCH: 5041 LOSS: 41.063985908427355\n",
      "EPOCH: 5042 LOSS: 41.06397183111821\n",
      "EPOCH: 5043 LOSS: 41.06395775679086\n",
      "EPOCH: 5044 LOSS: 41.0639436854442\n",
      "EPOCH: 5045 LOSS: 41.063929617077136\n",
      "EPOCH: 5046 LOSS: 41.06391555168861\n",
      "EPOCH: 5047 LOSS: 41.06390148927753\n",
      "EPOCH: 5048 LOSS: 41.063887429842794\n",
      "EPOCH: 5049 LOSS: 41.063873373383316\n",
      "EPOCH: 5050 LOSS: 41.06385931989803\n",
      "EPOCH: 5051 LOSS: 41.06384526938585\n",
      "EPOCH: 5052 LOSS: 41.06383122184571\n",
      "EPOCH: 5053 LOSS: 41.06381717727648\n",
      "EPOCH: 5054 LOSS: 41.06380313567711\n",
      "EPOCH: 5055 LOSS: 41.06378909704654\n",
      "EPOCH: 5056 LOSS: 41.063775061383666\n",
      "EPOCH: 5057 LOSS: 41.063761028687395\n",
      "EPOCH: 5058 LOSS: 41.06374699895669\n",
      "EPOCH: 5059 LOSS: 41.06373297219045\n",
      "EPOCH: 5060 LOSS: 41.06371894838759\n",
      "EPOCH: 5061 LOSS: 41.06370492754706\n",
      "EPOCH: 5062 LOSS: 41.063690909667756\n",
      "EPOCH: 5063 LOSS: 41.063676894748625\n",
      "EPOCH: 5064 LOSS: 41.063662882788606\n",
      "EPOCH: 5065 LOSS: 41.06364887378659\n",
      "EPOCH: 5066 LOSS: 41.06363486774153\n",
      "EPOCH: 5067 LOSS: 41.063620864652336\n",
      "EPOCH: 5068 LOSS: 41.06360686451798\n",
      "EPOCH: 5069 LOSS: 41.06359286733733\n",
      "EPOCH: 5070 LOSS: 41.063578873109364\n",
      "EPOCH: 5071 LOSS: 41.063564881832995\n",
      "EPOCH: 5072 LOSS: 41.06355089350717\n",
      "EPOCH: 5073 LOSS: 41.06353690813081\n",
      "EPOCH: 5074 LOSS: 41.063522925702834\n",
      "EPOCH: 5075 LOSS: 41.063508946222214\n",
      "EPOCH: 5076 LOSS: 41.06349496968785\n",
      "EPOCH: 5077 LOSS: 41.0634809960987\n",
      "EPOCH: 5078 LOSS: 41.06346702545368\n",
      "EPOCH: 5079 LOSS: 41.06345305775176\n",
      "EPOCH: 5080 LOSS: 41.063439092991835\n",
      "EPOCH: 5081 LOSS: 41.063425131172885\n",
      "EPOCH: 5082 LOSS: 41.063411172293854\n",
      "EPOCH: 5083 LOSS: 41.063397216353614\n",
      "EPOCH: 5084 LOSS: 41.06338326335116\n",
      "EPOCH: 5085 LOSS: 41.06336931328545\n",
      "EPOCH: 5086 LOSS: 41.06335536615538\n",
      "EPOCH: 5087 LOSS: 41.06334142195991\n",
      "EPOCH: 5088 LOSS: 41.063327480697986\n",
      "EPOCH: 5089 LOSS: 41.063313542368576\n",
      "EPOCH: 5090 LOSS: 41.063299606970595\n",
      "EPOCH: 5091 LOSS: 41.06328567450298\n",
      "EPOCH: 5092 LOSS: 41.06327174496471\n",
      "EPOCH: 5093 LOSS: 41.063257818354714\n",
      "EPOCH: 5094 LOSS: 41.06324389467193\n",
      "EPOCH: 5095 LOSS: 41.063229973915334\n",
      "EPOCH: 5096 LOSS: 41.06321605608384\n",
      "EPOCH: 5097 LOSS: 41.06320214117644\n",
      "EPOCH: 5098 LOSS: 41.063188229192036\n",
      "EPOCH: 5099 LOSS: 41.06317432012962\n",
      "EPOCH: 5100 LOSS: 41.06316041398812\n",
      "EPOCH: 5101 LOSS: 41.063146510766515\n",
      "EPOCH: 5102 LOSS: 41.06313261046371\n",
      "EPOCH: 5103 LOSS: 41.06311871307873\n",
      "EPOCH: 5104 LOSS: 41.063104818610455\n",
      "EPOCH: 5105 LOSS: 41.063090927057885\n",
      "EPOCH: 5106 LOSS: 41.06307703841996\n",
      "EPOCH: 5107 LOSS: 41.06306315269565\n",
      "EPOCH: 5108 LOSS: 41.063049269883905\n",
      "EPOCH: 5109 LOSS: 41.06303538998367\n",
      "EPOCH: 5110 LOSS: 41.063021512993934\n",
      "EPOCH: 5111 LOSS: 41.06300763891362\n",
      "EPOCH: 5112 LOSS: 41.06299376774171\n",
      "EPOCH: 5113 LOSS: 41.06297989947716\n",
      "EPOCH: 5114 LOSS: 41.06296603411896\n",
      "EPOCH: 5115 LOSS: 41.062952171666005\n",
      "EPOCH: 5116 LOSS: 41.06293831211732\n",
      "EPOCH: 5117 LOSS: 41.062924455471816\n",
      "EPOCH: 5118 LOSS: 41.06291060172852\n",
      "EPOCH: 5119 LOSS: 41.06289675088635\n",
      "EPOCH: 5120 LOSS: 41.062882902944295\n",
      "EPOCH: 5121 LOSS: 41.062869057901295\n",
      "EPOCH: 5122 LOSS: 41.06285521575633\n",
      "EPOCH: 5123 LOSS: 41.06284137650839\n",
      "EPOCH: 5124 LOSS: 41.0628275401564\n",
      "EPOCH: 5125 LOSS: 41.062813706699366\n",
      "EPOCH: 5126 LOSS: 41.06279987613625\n",
      "EPOCH: 5127 LOSS: 41.062786048465995\n",
      "EPOCH: 5128 LOSS: 41.06277222368762\n",
      "EPOCH: 5129 LOSS: 41.062758401800046\n",
      "EPOCH: 5130 LOSS: 41.062744582802274\n",
      "EPOCH: 5131 LOSS: 41.06273076669327\n",
      "EPOCH: 5132 LOSS: 41.062716953472005\n",
      "EPOCH: 5133 LOSS: 41.062703143137455\n",
      "EPOCH: 5134 LOSS: 41.0626893356886\n",
      "EPOCH: 5135 LOSS: 41.06267553112441\n",
      "EPOCH: 5136 LOSS: 41.062661729443874\n",
      "EPOCH: 5137 LOSS: 41.062647930645966\n",
      "EPOCH: 5138 LOSS: 41.06263413472962\n",
      "EPOCH: 5139 LOSS: 41.062620341693865\n",
      "EPOCH: 5140 LOSS: 41.062606551537655\n",
      "EPOCH: 5141 LOSS: 41.06259276425999\n",
      "EPOCH: 5142 LOSS: 41.06257897985984\n",
      "EPOCH: 5143 LOSS: 41.062565198336166\n",
      "EPOCH: 5144 LOSS: 41.062551419687985\n",
      "EPOCH: 5145 LOSS: 41.06253764391425\n",
      "EPOCH: 5146 LOSS: 41.06252387101396\n",
      "EPOCH: 5147 LOSS: 41.062510100986096\n",
      "EPOCH: 5148 LOSS: 41.06249633382963\n",
      "EPOCH: 5149 LOSS: 41.062482569543555\n",
      "EPOCH: 5150 LOSS: 41.06246880812686\n",
      "EPOCH: 5151 LOSS: 41.06245504957852\n",
      "EPOCH: 5152 LOSS: 41.062441293897535\n",
      "EPOCH: 5153 LOSS: 41.06242754108289\n",
      "EPOCH: 5154 LOSS: 41.06241379113356\n",
      "EPOCH: 5155 LOSS: 41.06240004404856\n",
      "EPOCH: 5156 LOSS: 41.06238629982684\n",
      "EPOCH: 5157 LOSS: 41.062372558467416\n",
      "EPOCH: 5158 LOSS: 41.06235881996928\n",
      "EPOCH: 5159 LOSS: 41.06234508433141\n",
      "EPOCH: 5160 LOSS: 41.062331351552814\n",
      "EPOCH: 5161 LOSS: 41.06231762163247\n",
      "EPOCH: 5162 LOSS: 41.06230389456937\n",
      "EPOCH: 5163 LOSS: 41.06229017036252\n",
      "EPOCH: 5164 LOSS: 41.06227644901091\n",
      "EPOCH: 5165 LOSS: 41.062262730513524\n",
      "EPOCH: 5166 LOSS: 41.06224901486938\n",
      "EPOCH: 5167 LOSS: 41.06223530207745\n",
      "EPOCH: 5168 LOSS: 41.062221592136744\n",
      "EPOCH: 5169 LOSS: 41.06220788504625\n",
      "EPOCH: 5170 LOSS: 41.06219418080497\n",
      "EPOCH: 5171 LOSS: 41.06218047941192\n",
      "EPOCH: 5172 LOSS: 41.06216678086608\n",
      "EPOCH: 5173 LOSS: 41.062153085166464\n",
      "EPOCH: 5174 LOSS: 41.06213939231205\n",
      "EPOCH: 5175 LOSS: 41.06212570230186\n",
      "EPOCH: 5176 LOSS: 41.062112015134886\n",
      "EPOCH: 5177 LOSS: 41.062098330810144\n",
      "EPOCH: 5178 LOSS: 41.062084649326614\n",
      "EPOCH: 5179 LOSS: 41.062070970683315\n",
      "EPOCH: 5180 LOSS: 41.062057294879246\n",
      "EPOCH: 5181 LOSS: 41.062043621913425\n",
      "EPOCH: 5182 LOSS: 41.06202995178484\n",
      "EPOCH: 5183 LOSS: 41.06201628449252\n",
      "EPOCH: 5184 LOSS: 41.06200262003543\n",
      "EPOCH: 5185 LOSS: 41.06198895841263\n",
      "EPOCH: 5186 LOSS: 41.061975299623086\n",
      "EPOCH: 5187 LOSS: 41.06196164366584\n",
      "EPOCH: 5188 LOSS: 41.06194799053986\n",
      "EPOCH: 5189 LOSS: 41.06193434024421\n",
      "EPOCH: 5190 LOSS: 41.06192069277785\n",
      "EPOCH: 5191 LOSS: 41.06190704813982\n",
      "EPOCH: 5192 LOSS: 41.061893406329126\n",
      "EPOCH: 5193 LOSS: 41.06187976734479\n",
      "EPOCH: 5194 LOSS: 41.0618661311858\n",
      "EPOCH: 5195 LOSS: 41.0618524978512\n",
      "EPOCH: 5196 LOSS: 41.061838867339986\n",
      "EPOCH: 5197 LOSS: 41.06182523965117\n",
      "EPOCH: 5198 LOSS: 41.06181161478378\n",
      "EPOCH: 5199 LOSS: 41.061797992736814\n",
      "EPOCH: 5200 LOSS: 41.061784373509326\n",
      "EPOCH: 5201 LOSS: 41.061770757100305\n",
      "EPOCH: 5202 LOSS: 41.06175714350875\n",
      "EPOCH: 5203 LOSS: 41.06174353273373\n",
      "EPOCH: 5204 LOSS: 41.061729924774205\n",
      "EPOCH: 5205 LOSS: 41.061716319629255\n",
      "EPOCH: 5206 LOSS: 41.06170271729786\n",
      "EPOCH: 5207 LOSS: 41.06168911777907\n",
      "EPOCH: 5208 LOSS: 41.06167552107187\n",
      "EPOCH: 5209 LOSS: 41.06166192717532\n",
      "EPOCH: 5210 LOSS: 41.06164833608842\n",
      "EPOCH: 5211 LOSS: 41.0616347478102\n",
      "EPOCH: 5212 LOSS: 41.061621162339684\n",
      "EPOCH: 5213 LOSS: 41.06160757967591\n",
      "EPOCH: 5214 LOSS: 41.06159399981787\n",
      "EPOCH: 5215 LOSS: 41.06158042276462\n",
      "EPOCH: 5216 LOSS: 41.06156684851519\n",
      "EPOCH: 5217 LOSS: 41.06155327706859\n",
      "EPOCH: 5218 LOSS: 41.06153970842386\n",
      "EPOCH: 5219 LOSS: 41.06152614258001\n",
      "EPOCH: 5220 LOSS: 41.06151257953608\n",
      "EPOCH: 5221 LOSS: 41.061499019291105\n",
      "EPOCH: 5222 LOSS: 41.0614854618441\n",
      "EPOCH: 5223 LOSS: 41.061471907194125\n",
      "EPOCH: 5224 LOSS: 41.06145835534018\n",
      "EPOCH: 5225 LOSS: 41.06144480628133\n",
      "EPOCH: 5226 LOSS: 41.06143126001656\n",
      "EPOCH: 5227 LOSS: 41.06141771654495\n",
      "EPOCH: 5228 LOSS: 41.06140417586552\n",
      "EPOCH: 5229 LOSS: 41.0613906379773\n",
      "EPOCH: 5230 LOSS: 41.06137710287932\n",
      "EPOCH: 5231 LOSS: 41.06136357057062\n",
      "EPOCH: 5232 LOSS: 41.06135004105023\n",
      "EPOCH: 5233 LOSS: 41.06133651431722\n",
      "EPOCH: 5234 LOSS: 41.06132299037059\n",
      "EPOCH: 5235 LOSS: 41.061309469209384\n",
      "EPOCH: 5236 LOSS: 41.06129595083265\n",
      "EPOCH: 5237 LOSS: 41.061282435239434\n",
      "EPOCH: 5238 LOSS: 41.06126892242875\n",
      "EPOCH: 5239 LOSS: 41.06125541239966\n",
      "EPOCH: 5240 LOSS: 41.06124190515122\n",
      "EPOCH: 5241 LOSS: 41.061228400682424\n",
      "EPOCH: 5242 LOSS: 41.061214898992354\n",
      "EPOCH: 5243 LOSS: 41.061201400080044\n",
      "EPOCH: 5244 LOSS: 41.06118790394454\n",
      "EPOCH: 5245 LOSS: 41.06117441058488\n",
      "EPOCH: 5246 LOSS: 41.06116092000009\n",
      "EPOCH: 5247 LOSS: 41.06114743218926\n",
      "EPOCH: 5248 LOSS: 41.0611339471514\n",
      "EPOCH: 5249 LOSS: 41.06112046488558\n",
      "EPOCH: 5250 LOSS: 41.06110698539082\n",
      "EPOCH: 5251 LOSS: 41.06109350866618\n",
      "EPOCH: 5252 LOSS: 41.061080034710706\n",
      "EPOCH: 5253 LOSS: 41.06106656352347\n",
      "EPOCH: 5254 LOSS: 41.06105309510349\n",
      "EPOCH: 5255 LOSS: 41.06103962944984\n",
      "EPOCH: 5256 LOSS: 41.06102616656155\n",
      "EPOCH: 5257 LOSS: 41.06101270643767\n",
      "EPOCH: 5258 LOSS: 41.06099924907727\n",
      "EPOCH: 5259 LOSS: 41.06098579447939\n",
      "EPOCH: 5260 LOSS: 41.060972342643105\n",
      "EPOCH: 5261 LOSS: 41.06095889356743\n",
      "EPOCH: 5262 LOSS: 41.06094544725144\n",
      "EPOCH: 5263 LOSS: 41.06093200369419\n",
      "EPOCH: 5264 LOSS: 41.06091856289475\n",
      "EPOCH: 5265 LOSS: 41.060905124852155\n",
      "EPOCH: 5266 LOSS: 41.060891689565466\n",
      "EPOCH: 5267 LOSS: 41.060878257033735\n",
      "EPOCH: 5268 LOSS: 41.06086482725602\n",
      "EPOCH: 5269 LOSS: 41.060851400231385\n",
      "EPOCH: 5270 LOSS: 41.0608379759589\n",
      "EPOCH: 5271 LOSS: 41.060824554437595\n",
      "EPOCH: 5272 LOSS: 41.06081113566656\n",
      "EPOCH: 5273 LOSS: 41.06079771964484\n",
      "EPOCH: 5274 LOSS: 41.06078430637149\n",
      "EPOCH: 5275 LOSS: 41.06077089584558\n",
      "EPOCH: 5276 LOSS: 41.06075748806619\n",
      "EPOCH: 5277 LOSS: 41.06074408303235\n",
      "EPOCH: 5278 LOSS: 41.06073068074312\n",
      "EPOCH: 5279 LOSS: 41.06071728119761\n",
      "EPOCH: 5280 LOSS: 41.06070388439484\n",
      "EPOCH: 5281 LOSS: 41.06069049033389\n",
      "EPOCH: 5282 LOSS: 41.060677099013844\n",
      "EPOCH: 5283 LOSS: 41.06066371043373\n",
      "EPOCH: 5284 LOSS: 41.06065032459264\n",
      "EPOCH: 5285 LOSS: 41.06063694148963\n",
      "EPOCH: 5286 LOSS: 41.06062356112378\n",
      "EPOCH: 5287 LOSS: 41.06061018349416\n",
      "EPOCH: 5288 LOSS: 41.060596808599826\n",
      "EPOCH: 5289 LOSS: 41.060583436439856\n",
      "EPOCH: 5290 LOSS: 41.060570067013316\n",
      "EPOCH: 5291 LOSS: 41.06055670031928\n",
      "EPOCH: 5292 LOSS: 41.0605433363568\n",
      "EPOCH: 5293 LOSS: 41.06052997512497\n",
      "EPOCH: 5294 LOSS: 41.06051661662286\n",
      "EPOCH: 5295 LOSS: 41.06050326084955\n",
      "EPOCH: 5296 LOSS: 41.06048990780409\n",
      "EPOCH: 5297 LOSS: 41.06047655748557\n",
      "EPOCH: 5298 LOSS: 41.06046320989306\n",
      "EPOCH: 5299 LOSS: 41.06044986502563\n",
      "EPOCH: 5300 LOSS: 41.06043652288237\n",
      "EPOCH: 5301 LOSS: 41.06042318346236\n",
      "EPOCH: 5302 LOSS: 41.06040984676465\n",
      "EPOCH: 5303 LOSS: 41.060396512788344\n",
      "EPOCH: 5304 LOSS: 41.060383181532494\n",
      "EPOCH: 5305 LOSS: 41.06036985299619\n",
      "EPOCH: 5306 LOSS: 41.06035652717854\n",
      "EPOCH: 5307 LOSS: 41.06034320407857\n",
      "EPOCH: 5308 LOSS: 41.060329883695395\n",
      "EPOCH: 5309 LOSS: 41.060316566028085\n",
      "EPOCH: 5310 LOSS: 41.060303251075744\n",
      "EPOCH: 5311 LOSS: 41.06028993883742\n",
      "EPOCH: 5312 LOSS: 41.0602766293122\n",
      "EPOCH: 5313 LOSS: 41.06026332249919\n",
      "EPOCH: 5314 LOSS: 41.06025001839747\n",
      "EPOCH: 5315 LOSS: 41.060236717006084\n",
      "EPOCH: 5316 LOSS: 41.06022341832417\n",
      "EPOCH: 5317 LOSS: 41.06021012235077\n",
      "EPOCH: 5318 LOSS: 41.060196829085\n",
      "EPOCH: 5319 LOSS: 41.06018353852594\n",
      "EPOCH: 5320 LOSS: 41.06017025067266\n",
      "EPOCH: 5321 LOSS: 41.06015696552427\n",
      "EPOCH: 5322 LOSS: 41.06014368307984\n",
      "EPOCH: 5323 LOSS: 41.06013040333847\n",
      "EPOCH: 5324 LOSS: 41.06011712629925\n",
      "EPOCH: 5325 LOSS: 41.060103851961244\n",
      "EPOCH: 5326 LOSS: 41.06009058032358\n",
      "EPOCH: 5327 LOSS: 41.060077311385314\n",
      "EPOCH: 5328 LOSS: 41.06006404514558\n",
      "EPOCH: 5329 LOSS: 41.06005078160343\n",
      "EPOCH: 5330 LOSS: 41.06003752075796\n",
      "EPOCH: 5331 LOSS: 41.06002426260827\n",
      "EPOCH: 5332 LOSS: 41.06001100715347\n",
      "EPOCH: 5333 LOSS: 41.05999775439263\n",
      "EPOCH: 5334 LOSS: 41.05998450432485\n",
      "EPOCH: 5335 LOSS: 41.059971256949225\n",
      "EPOCH: 5336 LOSS: 41.05995801226487\n",
      "EPOCH: 5337 LOSS: 41.05994477027085\n",
      "EPOCH: 5338 LOSS: 41.05993153096629\n",
      "EPOCH: 5339 LOSS: 41.059918294350254\n",
      "EPOCH: 5340 LOSS: 41.059905060421876\n",
      "EPOCH: 5341 LOSS: 41.05989182918023\n",
      "EPOCH: 5342 LOSS: 41.05987860062441\n",
      "EPOCH: 5343 LOSS: 41.05986537475354\n",
      "EPOCH: 5344 LOSS: 41.0598521515667\n",
      "EPOCH: 5345 LOSS: 41.05983893106301\n",
      "EPOCH: 5346 LOSS: 41.05982571324155\n",
      "EPOCH: 5347 LOSS: 41.059812498101415\n",
      "EPOCH: 5348 LOSS: 41.05979928564173\n",
      "EPOCH: 5349 LOSS: 41.05978607586158\n",
      "EPOCH: 5350 LOSS: 41.0597728687601\n",
      "EPOCH: 5351 LOSS: 41.05975966433635\n",
      "EPOCH: 5352 LOSS: 41.05974646258945\n",
      "EPOCH: 5353 LOSS: 41.059733263518524\n",
      "EPOCH: 5354 LOSS: 41.05972006712264\n",
      "EPOCH: 5355 LOSS: 41.05970687340094\n",
      "EPOCH: 5356 LOSS: 41.0596936823525\n",
      "EPOCH: 5357 LOSS: 41.05968049397646\n",
      "EPOCH: 5358 LOSS: 41.05966730827189\n",
      "EPOCH: 5359 LOSS: 41.05965412523792\n",
      "EPOCH: 5360 LOSS: 41.059640944873664\n",
      "EPOCH: 5361 LOSS: 41.05962776717821\n",
      "EPOCH: 5362 LOSS: 41.05961459215068\n",
      "EPOCH: 5363 LOSS: 41.05960141979018\n",
      "EPOCH: 5364 LOSS: 41.059588250095835\n",
      "EPOCH: 5365 LOSS: 41.059575083066726\n",
      "EPOCH: 5366 LOSS: 41.05956191870198\n",
      "EPOCH: 5367 LOSS: 41.05954875700073\n",
      "EPOCH: 5368 LOSS: 41.05953559796204\n",
      "EPOCH: 5369 LOSS: 41.059522441585074\n",
      "EPOCH: 5370 LOSS: 41.05950928786892\n",
      "EPOCH: 5371 LOSS: 41.0594961368127\n",
      "EPOCH: 5372 LOSS: 41.0594829884155\n",
      "EPOCH: 5373 LOSS: 41.05946984267647\n",
      "EPOCH: 5374 LOSS: 41.05945669959471\n",
      "EPOCH: 5375 LOSS: 41.05944355916935\n",
      "EPOCH: 5376 LOSS: 41.05943042139949\n",
      "EPOCH: 5377 LOSS: 41.05941728628426\n",
      "EPOCH: 5378 LOSS: 41.05940415382277\n",
      "EPOCH: 5379 LOSS: 41.05939102401411\n",
      "EPOCH: 5380 LOSS: 41.05937789685748\n",
      "EPOCH: 5381 LOSS: 41.05936477235191\n",
      "EPOCH: 5382 LOSS: 41.05935165049655\n",
      "EPOCH: 5383 LOSS: 41.05933853129056\n",
      "EPOCH: 5384 LOSS: 41.059325414733\n",
      "EPOCH: 5385 LOSS: 41.05931230082304\n",
      "EPOCH: 5386 LOSS: 41.05929918955977\n",
      "EPOCH: 5387 LOSS: 41.05928608094233\n",
      "EPOCH: 5388 LOSS: 41.05927297496982\n",
      "EPOCH: 5389 LOSS: 41.05925987164139\n",
      "EPOCH: 5390 LOSS: 41.05924677095615\n",
      "EPOCH: 5391 LOSS: 41.05923367291322\n",
      "EPOCH: 5392 LOSS: 41.05922057751174\n",
      "EPOCH: 5393 LOSS: 41.05920748475082\n",
      "EPOCH: 5394 LOSS: 41.059194394629586\n",
      "EPOCH: 5395 LOSS: 41.059181307147185\n",
      "EPOCH: 5396 LOSS: 41.05916822230273\n",
      "EPOCH: 5397 LOSS: 41.05915514009535\n",
      "EPOCH: 5398 LOSS: 41.05914206052415\n",
      "EPOCH: 5399 LOSS: 41.05912898358829\n",
      "EPOCH: 5400 LOSS: 41.05911590928691\n",
      "EPOCH: 5401 LOSS: 41.05910283761909\n",
      "EPOCH: 5402 LOSS: 41.059089768583995\n",
      "EPOCH: 5403 LOSS: 41.05907670218076\n",
      "EPOCH: 5404 LOSS: 41.05906363840849\n",
      "EPOCH: 5405 LOSS: 41.05905057726633\n",
      "EPOCH: 5406 LOSS: 41.05903751875342\n",
      "EPOCH: 5407 LOSS: 41.059024462868884\n",
      "EPOCH: 5408 LOSS: 41.05901140961185\n",
      "EPOCH: 5409 LOSS: 41.058998358981455\n",
      "EPOCH: 5410 LOSS: 41.05898531097684\n",
      "EPOCH: 5411 LOSS: 41.05897226559712\n",
      "EPOCH: 5412 LOSS: 41.058959222841466\n",
      "EPOCH: 5413 LOSS: 41.05894618270898\n",
      "EPOCH: 5414 LOSS: 41.05893314519881\n",
      "EPOCH: 5415 LOSS: 41.0589201103101\n",
      "EPOCH: 5416 LOSS: 41.058907078041955\n",
      "EPOCH: 5417 LOSS: 41.05889404839357\n",
      "EPOCH: 5418 LOSS: 41.058881021364016\n",
      "EPOCH: 5419 LOSS: 41.058867996952486\n",
      "EPOCH: 5420 LOSS: 41.05885497515809\n",
      "EPOCH: 5421 LOSS: 41.05884195597996\n",
      "EPOCH: 5422 LOSS: 41.05882893941728\n",
      "EPOCH: 5423 LOSS: 41.05881592546914\n",
      "EPOCH: 5424 LOSS: 41.058802914134716\n",
      "EPOCH: 5425 LOSS: 41.05878990541312\n",
      "EPOCH: 5426 LOSS: 41.05877689930352\n",
      "EPOCH: 5427 LOSS: 41.05876389580505\n",
      "EPOCH: 5428 LOSS: 41.05875089491685\n",
      "EPOCH: 5429 LOSS: 41.058737896638036\n",
      "EPOCH: 5430 LOSS: 41.058724900967796\n",
      "EPOCH: 5431 LOSS: 41.05871190790529\n",
      "EPOCH: 5432 LOSS: 41.0586989174496\n",
      "EPOCH: 5433 LOSS: 41.058685929599896\n",
      "EPOCH: 5434 LOSS: 41.05867294435534\n",
      "EPOCH: 5435 LOSS: 41.05865996171508\n",
      "EPOCH: 5436 LOSS: 41.05864698167823\n",
      "EPOCH: 5437 LOSS: 41.05863400424397\n",
      "EPOCH: 5438 LOSS: 41.05862102941143\n",
      "EPOCH: 5439 LOSS: 41.05860805717977\n",
      "EPOCH: 5440 LOSS: 41.058595087548134\n",
      "EPOCH: 5441 LOSS: 41.05858212051565\n",
      "EPOCH: 5442 LOSS: 41.05856915608152\n",
      "EPOCH: 5443 LOSS: 41.05855619424485\n",
      "EPOCH: 5444 LOSS: 41.05854323500479\n",
      "EPOCH: 5445 LOSS: 41.05853027836052\n",
      "EPOCH: 5446 LOSS: 41.05851732431117\n",
      "EPOCH: 5447 LOSS: 41.0585043728559\n",
      "EPOCH: 5448 LOSS: 41.058491423993864\n",
      "EPOCH: 5449 LOSS: 41.05847847772421\n",
      "EPOCH: 5450 LOSS: 41.05846553404609\n",
      "EPOCH: 5451 LOSS: 41.05845259295866\n",
      "EPOCH: 5452 LOSS: 41.05843965446108\n",
      "EPOCH: 5453 LOSS: 41.05842671855249\n",
      "EPOCH: 5454 LOSS: 41.05841378523208\n",
      "EPOCH: 5455 LOSS: 41.058400854498956\n",
      "EPOCH: 5456 LOSS: 41.05838792635231\n",
      "EPOCH: 5457 LOSS: 41.0583750007913\n",
      "EPOCH: 5458 LOSS: 41.058362077815076\n",
      "EPOCH: 5459 LOSS: 41.058349157422775\n",
      "EPOCH: 5460 LOSS: 41.058336239613595\n",
      "EPOCH: 5461 LOSS: 41.058323324386656\n",
      "EPOCH: 5462 LOSS: 41.058310411741154\n",
      "EPOCH: 5463 LOSS: 41.05829750167622\n",
      "EPOCH: 5464 LOSS: 41.058284594191015\n",
      "EPOCH: 5465 LOSS: 41.05827168928471\n",
      "EPOCH: 5466 LOSS: 41.05825878695648\n",
      "EPOCH: 5467 LOSS: 41.05824588720547\n",
      "EPOCH: 5468 LOSS: 41.05823299003085\n",
      "EPOCH: 5469 LOSS: 41.058220095431764\n",
      "EPOCH: 5470 LOSS: 41.05820720340738\n",
      "EPOCH: 5471 LOSS: 41.05819431395689\n",
      "EPOCH: 5472 LOSS: 41.05818142707944\n",
      "EPOCH: 5473 LOSS: 41.058168542774176\n",
      "EPOCH: 5474 LOSS: 41.0581556610403\n",
      "EPOCH: 5475 LOSS: 41.05814278187694\n",
      "EPOCH: 5476 LOSS: 41.05812990528328\n",
      "EPOCH: 5477 LOSS: 41.058117031258504\n",
      "EPOCH: 5478 LOSS: 41.05810415980174\n",
      "EPOCH: 5479 LOSS: 41.05809129091219\n",
      "EPOCH: 5480 LOSS: 41.058078424589006\n",
      "EPOCH: 5481 LOSS: 41.058065560831366\n",
      "EPOCH: 5482 LOSS: 41.05805269963842\n",
      "EPOCH: 5483 LOSS: 41.058039841009354\n",
      "EPOCH: 5484 LOSS: 41.058026984943325\n",
      "EPOCH: 5485 LOSS: 41.05801413143951\n",
      "EPOCH: 5486 LOSS: 41.058001280497095\n",
      "EPOCH: 5487 LOSS: 41.057988432115245\n",
      "EPOCH: 5488 LOSS: 41.057975586293104\n",
      "EPOCH: 5489 LOSS: 41.05796274302987\n",
      "EPOCH: 5490 LOSS: 41.057949902324694\n",
      "EPOCH: 5491 LOSS: 41.05793706417679\n",
      "EPOCH: 5492 LOSS: 41.05792422858528\n",
      "EPOCH: 5493 LOSS: 41.0579113955494\n",
      "EPOCH: 5494 LOSS: 41.05789856506826\n",
      "EPOCH: 5495 LOSS: 41.05788573714106\n",
      "EPOCH: 5496 LOSS: 41.057872911767\n",
      "EPOCH: 5497 LOSS: 41.05786008894522\n",
      "EPOCH: 5498 LOSS: 41.05784726867492\n",
      "EPOCH: 5499 LOSS: 41.05783445095526\n",
      "EPOCH: 5500 LOSS: 41.057821635785416\n",
      "EPOCH: 5501 LOSS: 41.05780882316459\n",
      "EPOCH: 5502 LOSS: 41.05779601309196\n",
      "EPOCH: 5503 LOSS: 41.057783205566665\n",
      "EPOCH: 5504 LOSS: 41.05777040058792\n",
      "EPOCH: 5505 LOSS: 41.05775759815488\n",
      "EPOCH: 5506 LOSS: 41.05774479826676\n",
      "EPOCH: 5507 LOSS: 41.057732000922684\n",
      "EPOCH: 5508 LOSS: 41.05771920612189\n",
      "EPOCH: 5509 LOSS: 41.05770641386354\n",
      "EPOCH: 5510 LOSS: 41.05769362414679\n",
      "EPOCH: 5511 LOSS: 41.057680836970874\n",
      "EPOCH: 5512 LOSS: 41.057668052334925\n",
      "EPOCH: 5513 LOSS: 41.057655270238165\n",
      "EPOCH: 5514 LOSS: 41.057642490679754\n",
      "EPOCH: 5515 LOSS: 41.05762971365887\n",
      "EPOCH: 5516 LOSS: 41.057616939174714\n",
      "EPOCH: 5517 LOSS: 41.057604167226465\n",
      "EPOCH: 5518 LOSS: 41.057591397813304\n",
      "EPOCH: 5519 LOSS: 41.057578630934444\n",
      "EPOCH: 5520 LOSS: 41.05756586658903\n",
      "EPOCH: 5521 LOSS: 41.05755310477629\n",
      "EPOCH: 5522 LOSS: 41.05754034549536\n",
      "EPOCH: 5523 LOSS: 41.05752758874547\n",
      "EPOCH: 5524 LOSS: 41.05751483452581\n",
      "EPOCH: 5525 LOSS: 41.05750208283554\n",
      "EPOCH: 5526 LOSS: 41.05748933367387\n",
      "EPOCH: 5527 LOSS: 41.057476587039986\n",
      "EPOCH: 5528 LOSS: 41.05746384293305\n",
      "EPOCH: 5529 LOSS: 41.0574511013523\n",
      "EPOCH: 5530 LOSS: 41.05743836229693\n",
      "EPOCH: 5531 LOSS: 41.05742562576606\n",
      "EPOCH: 5532 LOSS: 41.05741289175894\n",
      "EPOCH: 5533 LOSS: 41.05740016027475\n",
      "EPOCH: 5534 LOSS: 41.057387431312705\n",
      "EPOCH: 5535 LOSS: 41.05737470487194\n",
      "EPOCH: 5536 LOSS: 41.057361980951704\n",
      "EPOCH: 5537 LOSS: 41.057349259551174\n",
      "EPOCH: 5538 LOSS: 41.05733654066954\n",
      "EPOCH: 5539 LOSS: 41.05732382430599\n",
      "EPOCH: 5540 LOSS: 41.057311110459736\n",
      "EPOCH: 5541 LOSS: 41.05729839912996\n",
      "EPOCH: 5542 LOSS: 41.05728569031588\n",
      "EPOCH: 5543 LOSS: 41.05727298401665\n",
      "EPOCH: 5544 LOSS: 41.05726028023152\n",
      "EPOCH: 5545 LOSS: 41.05724757895964\n",
      "EPOCH: 5546 LOSS: 41.05723488020025\n",
      "EPOCH: 5547 LOSS: 41.05722218395251\n",
      "EPOCH: 5548 LOSS: 41.05720949021565\n",
      "EPOCH: 5549 LOSS: 41.05719679898885\n",
      "EPOCH: 5550 LOSS: 41.05718411027132\n",
      "EPOCH: 5551 LOSS: 41.05717142406225\n",
      "EPOCH: 5552 LOSS: 41.05715874036085\n",
      "EPOCH: 5553 LOSS: 41.0571460591663\n",
      "EPOCH: 5554 LOSS: 41.05713338047785\n",
      "EPOCH: 5555 LOSS: 41.05712070429466\n",
      "EPOCH: 5556 LOSS: 41.05710803061594\n",
      "EPOCH: 5557 LOSS: 41.0570953594409\n",
      "EPOCH: 5558 LOSS: 41.05708269076874\n",
      "EPOCH: 5559 LOSS: 41.057070024598666\n",
      "EPOCH: 5560 LOSS: 41.05705736092987\n",
      "EPOCH: 5561 LOSS: 41.057044699761576\n",
      "EPOCH: 5562 LOSS: 41.05703204109297\n",
      "EPOCH: 5563 LOSS: 41.05701938492327\n",
      "EPOCH: 5564 LOSS: 41.05700673125168\n",
      "EPOCH: 5565 LOSS: 41.05699408007741\n",
      "EPOCH: 5566 LOSS: 41.05698143139967\n",
      "EPOCH: 5567 LOSS: 41.056968785217656\n",
      "EPOCH: 5568 LOSS: 41.05695614153056\n",
      "EPOCH: 5569 LOSS: 41.05694350033763\n",
      "EPOCH: 5570 LOSS: 41.05693086163805\n",
      "EPOCH: 5571 LOSS: 41.05691822543103\n",
      "EPOCH: 5572 LOSS: 41.056905591715775\n",
      "EPOCH: 5573 LOSS: 41.05689296049151\n",
      "EPOCH: 5574 LOSS: 41.05688033175744\n",
      "EPOCH: 5575 LOSS: 41.05686770551276\n",
      "EPOCH: 5576 LOSS: 41.056855081756694\n",
      "EPOCH: 5577 LOSS: 41.05684246048847\n",
      "EPOCH: 5578 LOSS: 41.05682984170728\n",
      "EPOCH: 5579 LOSS: 41.05681722541232\n",
      "EPOCH: 5580 LOSS: 41.05680461160285\n",
      "EPOCH: 5581 LOSS: 41.05679200027805\n",
      "EPOCH: 5582 LOSS: 41.056779391437125\n",
      "EPOCH: 5583 LOSS: 41.056766785079326\n",
      "EPOCH: 5584 LOSS: 41.05675418120382\n",
      "EPOCH: 5585 LOSS: 41.05674157980985\n",
      "EPOCH: 5586 LOSS: 41.05672898089665\n",
      "EPOCH: 5587 LOSS: 41.0567163844634\n",
      "EPOCH: 5588 LOSS: 41.056703790509346\n",
      "EPOCH: 5589 LOSS: 41.05669119903366\n",
      "EPOCH: 5590 LOSS: 41.05667861003561\n",
      "EPOCH: 5591 LOSS: 41.05666602351439\n",
      "EPOCH: 5592 LOSS: 41.056653439469216\n",
      "EPOCH: 5593 LOSS: 41.0566408578993\n",
      "EPOCH: 5594 LOSS: 41.05662827880389\n",
      "EPOCH: 5595 LOSS: 41.056615702182185\n",
      "EPOCH: 5596 LOSS: 41.056603128033395\n",
      "EPOCH: 5597 LOSS: 41.05659055635677\n",
      "EPOCH: 5598 LOSS: 41.05657798715149\n",
      "EPOCH: 5599 LOSS: 41.0565654204168\n",
      "EPOCH: 5600 LOSS: 41.056552856151924\n",
      "EPOCH: 5601 LOSS: 41.0565402943561\n",
      "EPOCH: 5602 LOSS: 41.0565277350285\n",
      "EPOCH: 5603 LOSS: 41.05651517816838\n",
      "EPOCH: 5604 LOSS: 41.056502623774975\n",
      "EPOCH: 5605 LOSS: 41.056490071847485\n",
      "EPOCH: 5606 LOSS: 41.056477522385144\n",
      "EPOCH: 5607 LOSS: 41.056464975387165\n",
      "EPOCH: 5608 LOSS: 41.05645243085279\n",
      "EPOCH: 5609 LOSS: 41.05643988878123\n",
      "EPOCH: 5610 LOSS: 41.0564273491717\n",
      "EPOCH: 5611 LOSS: 41.05641481202346\n",
      "EPOCH: 5612 LOSS: 41.05640227733572\n",
      "EPOCH: 5613 LOSS: 41.0563897451077\n",
      "EPOCH: 5614 LOSS: 41.05637721533863\n",
      "EPOCH: 5615 LOSS: 41.05636468802773\n",
      "EPOCH: 5616 LOSS: 41.05635216317425\n",
      "EPOCH: 5617 LOSS: 41.056339640777395\n",
      "EPOCH: 5618 LOSS: 41.05632712083643\n",
      "EPOCH: 5619 LOSS: 41.05631460335054\n",
      "EPOCH: 5620 LOSS: 41.05630208831898\n",
      "EPOCH: 5621 LOSS: 41.056289575740976\n",
      "EPOCH: 5622 LOSS: 41.056277065615745\n",
      "EPOCH: 5623 LOSS: 41.05626455794254\n",
      "EPOCH: 5624 LOSS: 41.05625205272058\n",
      "EPOCH: 5625 LOSS: 41.0562395499491\n",
      "EPOCH: 5626 LOSS: 41.056227049627324\n",
      "EPOCH: 5627 LOSS: 41.05621455175451\n",
      "EPOCH: 5628 LOSS: 41.05620205632985\n",
      "EPOCH: 5629 LOSS: 41.05618956335262\n",
      "EPOCH: 5630 LOSS: 41.05617707282203\n",
      "EPOCH: 5631 LOSS: 41.056164584737296\n",
      "EPOCH: 5632 LOSS: 41.056152099097694\n",
      "EPOCH: 5633 LOSS: 41.056139615902424\n",
      "EPOCH: 5634 LOSS: 41.05612713515076\n",
      "EPOCH: 5635 LOSS: 41.05611465684191\n",
      "EPOCH: 5636 LOSS: 41.0561021809751\n",
      "EPOCH: 5637 LOSS: 41.056089707549596\n",
      "EPOCH: 5638 LOSS: 41.05607723656462\n",
      "EPOCH: 5639 LOSS: 41.05606476801941\n",
      "EPOCH: 5640 LOSS: 41.056052301913184\n",
      "EPOCH: 5641 LOSS: 41.056039838245226\n",
      "EPOCH: 5642 LOSS: 41.05602737701475\n",
      "EPOCH: 5643 LOSS: 41.05601491822098\n",
      "EPOCH: 5644 LOSS: 41.05600246186318\n",
      "EPOCH: 5645 LOSS: 41.05599000794059\n",
      "EPOCH: 5646 LOSS: 41.055977556452426\n",
      "EPOCH: 5647 LOSS: 41.05596510739795\n",
      "EPOCH: 5648 LOSS: 41.0559526607764\n",
      "EPOCH: 5649 LOSS: 41.055940216587004\n",
      "EPOCH: 5650 LOSS: 41.055927774829016\n",
      "EPOCH: 5651 LOSS: 41.05591533550168\n",
      "EPOCH: 5652 LOSS: 41.05590289860424\n",
      "EPOCH: 5653 LOSS: 41.05589046413593\n",
      "EPOCH: 5654 LOSS: 41.055878032096004\n",
      "EPOCH: 5655 LOSS: 41.05586560248369\n",
      "EPOCH: 5656 LOSS: 41.05585317529823\n",
      "EPOCH: 5657 LOSS: 41.055840750538906\n",
      "EPOCH: 5658 LOSS: 41.055828328204925\n",
      "EPOCH: 5659 LOSS: 41.05581590829555\n",
      "EPOCH: 5660 LOSS: 41.05580349081002\n",
      "EPOCH: 5661 LOSS: 41.05579107574759\n",
      "EPOCH: 5662 LOSS: 41.055778663107496\n",
      "EPOCH: 5663 LOSS: 41.055766252889\n",
      "EPOCH: 5664 LOSS: 41.05575384509134\n",
      "EPOCH: 5665 LOSS: 41.055741439713756\n",
      "EPOCH: 5666 LOSS: 41.0557290367555\n",
      "EPOCH: 5667 LOSS: 41.05571663621583\n",
      "EPOCH: 5668 LOSS: 41.055704238093995\n",
      "EPOCH: 5669 LOSS: 41.05569184238922\n",
      "EPOCH: 5670 LOSS: 41.05567944910081\n",
      "EPOCH: 5671 LOSS: 41.05566705822795\n",
      "EPOCH: 5672 LOSS: 41.055654669769936\n",
      "EPOCH: 5673 LOSS: 41.055642283726\n",
      "EPOCH: 5674 LOSS: 41.05562990009539\n",
      "EPOCH: 5675 LOSS: 41.05561751887738\n",
      "EPOCH: 5676 LOSS: 41.05560514007121\n",
      "EPOCH: 5677 LOSS: 41.0555927636761\n",
      "EPOCH: 5678 LOSS: 41.05558038969137\n",
      "EPOCH: 5679 LOSS: 41.055568018116226\n",
      "EPOCH: 5680 LOSS: 41.05555564894994\n",
      "EPOCH: 5681 LOSS: 41.05554328219175\n",
      "EPOCH: 5682 LOSS: 41.05553091784092\n",
      "EPOCH: 5683 LOSS: 41.055518555896704\n",
      "EPOCH: 5684 LOSS: 41.05550619635836\n",
      "EPOCH: 5685 LOSS: 41.05549383922515\n",
      "EPOCH: 5686 LOSS: 41.055481484496326\n",
      "EPOCH: 5687 LOSS: 41.05546913217112\n",
      "EPOCH: 5688 LOSS: 41.055456782248825\n",
      "EPOCH: 5689 LOSS: 41.055444434728685\n",
      "EPOCH: 5690 LOSS: 41.055432089609944\n",
      "EPOCH: 5691 LOSS: 41.055419746891886\n",
      "EPOCH: 5692 LOSS: 41.05540740657375\n",
      "EPOCH: 5693 LOSS: 41.055395068654825\n",
      "EPOCH: 5694 LOSS: 41.05538273313432\n",
      "EPOCH: 5695 LOSS: 41.05537040001155\n",
      "EPOCH: 5696 LOSS: 41.055358069285724\n",
      "EPOCH: 5697 LOSS: 41.05534574095612\n",
      "EPOCH: 5698 LOSS: 41.05533341502202\n",
      "EPOCH: 5699 LOSS: 41.05532109148267\n",
      "EPOCH: 5700 LOSS: 41.055308770337334\n",
      "EPOCH: 5701 LOSS: 41.055296451585264\n",
      "EPOCH: 5702 LOSS: 41.05528413522572\n",
      "EPOCH: 5703 LOSS: 41.055271821257996\n",
      "EPOCH: 5704 LOSS: 41.05525950968132\n",
      "EPOCH: 5705 LOSS: 41.05524720049497\n",
      "EPOCH: 5706 LOSS: 41.05523489369823\n",
      "EPOCH: 5707 LOSS: 41.055222589290324\n",
      "EPOCH: 5708 LOSS: 41.05521028727054\n",
      "EPOCH: 5709 LOSS: 41.05519798763815\n",
      "EPOCH: 5710 LOSS: 41.055185690392406\n",
      "EPOCH: 5711 LOSS: 41.05517339553258\n",
      "EPOCH: 5712 LOSS: 41.055161103057934\n",
      "EPOCH: 5713 LOSS: 41.055148812967744\n",
      "EPOCH: 5714 LOSS: 41.05513652526127\n",
      "EPOCH: 5715 LOSS: 41.05512423993777\n",
      "EPOCH: 5716 LOSS: 41.05511195699651\n",
      "EPOCH: 5717 LOSS: 41.05509967643678\n",
      "EPOCH: 5718 LOSS: 41.05508739825786\n",
      "EPOCH: 5719 LOSS: 41.05507512245898\n",
      "EPOCH: 5720 LOSS: 41.05506284903942\n",
      "EPOCH: 5721 LOSS: 41.05505057799847\n",
      "EPOCH: 5722 LOSS: 41.05503830933538\n",
      "EPOCH: 5723 LOSS: 41.05502604304944\n",
      "EPOCH: 5724 LOSS: 41.05501377913989\n",
      "EPOCH: 5725 LOSS: 41.05500151760603\n",
      "EPOCH: 5726 LOSS: 41.05498925844711\n",
      "EPOCH: 5727 LOSS: 41.054977001662415\n",
      "EPOCH: 5728 LOSS: 41.054964747251226\n",
      "EPOCH: 5729 LOSS: 41.0549524952128\n",
      "EPOCH: 5730 LOSS: 41.054940245546405\n",
      "EPOCH: 5731 LOSS: 41.05492799825136\n",
      "EPOCH: 5732 LOSS: 41.05491575332687\n",
      "EPOCH: 5733 LOSS: 41.05490351077226\n",
      "EPOCH: 5734 LOSS: 41.054891270586786\n",
      "EPOCH: 5735 LOSS: 41.05487903276971\n",
      "EPOCH: 5736 LOSS: 41.054866797320344\n",
      "EPOCH: 5737 LOSS: 41.05485456423793\n",
      "EPOCH: 5738 LOSS: 41.05484233352175\n",
      "EPOCH: 5739 LOSS: 41.05483010517109\n",
      "EPOCH: 5740 LOSS: 41.05481787918523\n",
      "EPOCH: 5741 LOSS: 41.05480565556344\n",
      "EPOCH: 5742 LOSS: 41.05479343430498\n",
      "EPOCH: 5743 LOSS: 41.05478121540918\n",
      "EPOCH: 5744 LOSS: 41.05476899887528\n",
      "EPOCH: 5745 LOSS: 41.05475678470255\n",
      "EPOCH: 5746 LOSS: 41.05474457289028\n",
      "EPOCH: 5747 LOSS: 41.054732363437765\n",
      "EPOCH: 5748 LOSS: 41.05472015634425\n",
      "EPOCH: 5749 LOSS: 41.05470795160908\n",
      "EPOCH: 5750 LOSS: 41.05469574923147\n",
      "EPOCH: 5751 LOSS: 41.05468354921072\n",
      "EPOCH: 5752 LOSS: 41.054671351546105\n",
      "EPOCH: 5753 LOSS: 41.05465915623694\n",
      "EPOCH: 5754 LOSS: 41.05464696328247\n",
      "EPOCH: 5755 LOSS: 41.05463477268201\n",
      "EPOCH: 5756 LOSS: 41.05462258443481\n",
      "EPOCH: 5757 LOSS: 41.05461039854017\n",
      "EPOCH: 5758 LOSS: 41.05459821499738\n",
      "EPOCH: 5759 LOSS: 41.054586033805705\n",
      "EPOCH: 5760 LOSS: 41.05457385496445\n",
      "EPOCH: 5761 LOSS: 41.05456167847288\n",
      "EPOCH: 5762 LOSS: 41.054549504330296\n",
      "EPOCH: 5763 LOSS: 41.05453733253598\n",
      "EPOCH: 5764 LOSS: 41.05452516308921\n",
      "EPOCH: 5765 LOSS: 41.05451299598927\n",
      "EPOCH: 5766 LOSS: 41.054500831235465\n",
      "EPOCH: 5767 LOSS: 41.05448866882706\n",
      "EPOCH: 5768 LOSS: 41.054476508763365\n",
      "EPOCH: 5769 LOSS: 41.054464351043656\n",
      "EPOCH: 5770 LOSS: 41.05445219566721\n",
      "EPOCH: 5771 LOSS: 41.054440042633345\n",
      "EPOCH: 5772 LOSS: 41.05442789194131\n",
      "EPOCH: 5773 LOSS: 41.054415743590425\n",
      "EPOCH: 5774 LOSS: 41.054403597579956\n",
      "EPOCH: 5775 LOSS: 41.05439145390922\n",
      "EPOCH: 5776 LOSS: 41.054379312577495\n",
      "EPOCH: 5777 LOSS: 41.05436717358406\n",
      "EPOCH: 5778 LOSS: 41.054355036928214\n",
      "EPOCH: 5779 LOSS: 41.054342902609264\n",
      "EPOCH: 5780 LOSS: 41.05433077062648\n",
      "EPOCH: 5781 LOSS: 41.054318640979155\n",
      "EPOCH: 5782 LOSS: 41.05430651366659\n",
      "EPOCH: 5783 LOSS: 41.05429438868808\n",
      "EPOCH: 5784 LOSS: 41.05428226604292\n",
      "EPOCH: 5785 LOSS: 41.05427014573037\n",
      "EPOCH: 5786 LOSS: 41.05425802774977\n",
      "EPOCH: 5787 LOSS: 41.05424591210039\n",
      "EPOCH: 5788 LOSS: 41.05423379878154\n",
      "EPOCH: 5789 LOSS: 41.0542216877925\n",
      "EPOCH: 5790 LOSS: 41.05420957913256\n",
      "EPOCH: 5791 LOSS: 41.054197472801036\n",
      "EPOCH: 5792 LOSS: 41.0541853687972\n",
      "EPOCH: 5793 LOSS: 41.05417326712037\n",
      "EPOCH: 5794 LOSS: 41.05416116776983\n",
      "EPOCH: 5795 LOSS: 41.05414907074487\n",
      "EPOCH: 5796 LOSS: 41.05413697604483\n",
      "EPOCH: 5797 LOSS: 41.05412488366895\n",
      "EPOCH: 5798 LOSS: 41.054112793616554\n",
      "EPOCH: 5799 LOSS: 41.05410070588694\n",
      "EPOCH: 5800 LOSS: 41.05408862047941\n",
      "EPOCH: 5801 LOSS: 41.054076537393264\n",
      "EPOCH: 5802 LOSS: 41.0540644566278\n",
      "EPOCH: 5803 LOSS: 41.05405237818232\n",
      "EPOCH: 5804 LOSS: 41.05404030205611\n",
      "EPOCH: 5805 LOSS: 41.05402822824847\n",
      "EPOCH: 5806 LOSS: 41.054016156758735\n",
      "EPOCH: 5807 LOSS: 41.05400408758616\n",
      "EPOCH: 5808 LOSS: 41.05399202073008\n",
      "EPOCH: 5809 LOSS: 41.0539799561898\n",
      "EPOCH: 5810 LOSS: 41.053967893964575\n",
      "EPOCH: 5811 LOSS: 41.05395583405377\n",
      "EPOCH: 5812 LOSS: 41.05394377645664\n",
      "EPOCH: 5813 LOSS: 41.05393172117252\n",
      "EPOCH: 5814 LOSS: 41.05391966820068\n",
      "EPOCH: 5815 LOSS: 41.05390761754047\n",
      "EPOCH: 5816 LOSS: 41.05389556919115\n",
      "EPOCH: 5817 LOSS: 41.05388352315207\n",
      "EPOCH: 5818 LOSS: 41.053871479422504\n",
      "EPOCH: 5819 LOSS: 41.05385943800173\n",
      "EPOCH: 5820 LOSS: 41.05384739888912\n",
      "EPOCH: 5821 LOSS: 41.05383536208393\n",
      "EPOCH: 5822 LOSS: 41.053823327585484\n",
      "EPOCH: 5823 LOSS: 41.0538112953931\n",
      "EPOCH: 5824 LOSS: 41.05379926550607\n",
      "EPOCH: 5825 LOSS: 41.0537872379237\n",
      "EPOCH: 5826 LOSS: 41.053775212645306\n",
      "EPOCH: 5827 LOSS: 41.05376318967018\n",
      "EPOCH: 5828 LOSS: 41.053751168997664\n",
      "EPOCH: 5829 LOSS: 41.05373915062703\n",
      "EPOCH: 5830 LOSS: 41.053727134557626\n",
      "EPOCH: 5831 LOSS: 41.05371512078871\n",
      "EPOCH: 5832 LOSS: 41.05370310931964\n",
      "EPOCH: 5833 LOSS: 41.053691100149706\n",
      "EPOCH: 5834 LOSS: 41.05367909327823\n",
      "EPOCH: 5835 LOSS: 41.05366708870449\n",
      "EPOCH: 5836 LOSS: 41.05365508642784\n",
      "EPOCH: 5837 LOSS: 41.053643086447565\n",
      "EPOCH: 5838 LOSS: 41.053631088762984\n",
      "EPOCH: 5839 LOSS: 41.05361909337342\n",
      "EPOCH: 5840 LOSS: 41.05360710027817\n",
      "EPOCH: 5841 LOSS: 41.05359510947655\n",
      "EPOCH: 5842 LOSS: 41.05358312096789\n",
      "EPOCH: 5843 LOSS: 41.053571134751465\n",
      "EPOCH: 5844 LOSS: 41.05355915082663\n",
      "EPOCH: 5845 LOSS: 41.0535471691927\n",
      "EPOCH: 5846 LOSS: 41.05353518984895\n",
      "EPOCH: 5847 LOSS: 41.053523212794715\n",
      "EPOCH: 5848 LOSS: 41.05351123802934\n",
      "EPOCH: 5849 LOSS: 41.05349926555209\n",
      "EPOCH: 5850 LOSS: 41.05348729536232\n",
      "EPOCH: 5851 LOSS: 41.05347532745934\n",
      "EPOCH: 5852 LOSS: 41.05346336184243\n",
      "EPOCH: 5853 LOSS: 41.053451398510965\n",
      "EPOCH: 5854 LOSS: 41.05343943746425\n",
      "EPOCH: 5855 LOSS: 41.05342747870155\n",
      "EPOCH: 5856 LOSS: 41.05341552222223\n",
      "EPOCH: 5857 LOSS: 41.0534035680256\n",
      "EPOCH: 5858 LOSS: 41.05339161611099\n",
      "EPOCH: 5859 LOSS: 41.053379666477696\n",
      "EPOCH: 5860 LOSS: 41.05336771912506\n",
      "EPOCH: 5861 LOSS: 41.05335577405238\n",
      "EPOCH: 5862 LOSS: 41.053343831259\n",
      "EPOCH: 5863 LOSS: 41.053331890744204\n",
      "EPOCH: 5864 LOSS: 41.05331995250735\n",
      "EPOCH: 5865 LOSS: 41.05330801654776\n",
      "EPOCH: 5866 LOSS: 41.053296082864726\n",
      "EPOCH: 5867 LOSS: 41.05328415145758\n",
      "EPOCH: 5868 LOSS: 41.05327222232567\n",
      "EPOCH: 5869 LOSS: 41.05326029546828\n",
      "EPOCH: 5870 LOSS: 41.05324837088476\n",
      "EPOCH: 5871 LOSS: 41.053236448574424\n",
      "EPOCH: 5872 LOSS: 41.05322452853658\n",
      "EPOCH: 5873 LOSS: 41.05321261077059\n",
      "EPOCH: 5874 LOSS: 41.05320069527575\n",
      "EPOCH: 5875 LOSS: 41.05318878205138\n",
      "EPOCH: 5876 LOSS: 41.05317687109684\n",
      "EPOCH: 5877 LOSS: 41.05316496241141\n",
      "EPOCH: 5878 LOSS: 41.05315305599444\n",
      "EPOCH: 5879 LOSS: 41.05314115184526\n",
      "EPOCH: 5880 LOSS: 41.053129249963185\n",
      "EPOCH: 5881 LOSS: 41.05311735034755\n",
      "EPOCH: 5882 LOSS: 41.05310545299767\n",
      "EPOCH: 5883 LOSS: 41.05309355791289\n",
      "EPOCH: 5884 LOSS: 41.05308166509251\n",
      "EPOCH: 5885 LOSS: 41.0530697745359\n",
      "EPOCH: 5886 LOSS: 41.05305788624235\n",
      "EPOCH: 5887 LOSS: 41.0530460002112\n",
      "EPOCH: 5888 LOSS: 41.053034116441786\n",
      "EPOCH: 5889 LOSS: 41.05302223493342\n",
      "EPOCH: 5890 LOSS: 41.053010355685466\n",
      "EPOCH: 5891 LOSS: 41.05299847869722\n",
      "EPOCH: 5892 LOSS: 41.05298660396803\n",
      "EPOCH: 5893 LOSS: 41.052974731497216\n",
      "EPOCH: 5894 LOSS: 41.05296286128411\n",
      "EPOCH: 5895 LOSS: 41.05295099332805\n",
      "EPOCH: 5896 LOSS: 41.05293912762836\n",
      "EPOCH: 5897 LOSS: 41.05292726418439\n",
      "EPOCH: 5898 LOSS: 41.05291540299546\n",
      "EPOCH: 5899 LOSS: 41.05290354406089\n",
      "EPOCH: 5900 LOSS: 41.052891687380026\n",
      "EPOCH: 5901 LOSS: 41.05287983295221\n",
      "EPOCH: 5902 LOSS: 41.05286798077674\n",
      "EPOCH: 5903 LOSS: 41.05285613085301\n",
      "EPOCH: 5904 LOSS: 41.0528442831803\n",
      "EPOCH: 5905 LOSS: 41.05283243775797\n",
      "EPOCH: 5906 LOSS: 41.05282059458534\n",
      "EPOCH: 5907 LOSS: 41.05280875366176\n",
      "EPOCH: 5908 LOSS: 41.05279691498655\n",
      "EPOCH: 5909 LOSS: 41.05278507855906\n",
      "EPOCH: 5910 LOSS: 41.05277324437862\n",
      "EPOCH: 5911 LOSS: 41.05276141244458\n",
      "EPOCH: 5912 LOSS: 41.05274958275626\n",
      "EPOCH: 5913 LOSS: 41.05273775531299\n",
      "EPOCH: 5914 LOSS: 41.05272593011413\n",
      "EPOCH: 5915 LOSS: 41.052714107159\n",
      "EPOCH: 5916 LOSS: 41.052702286446944\n",
      "EPOCH: 5917 LOSS: 41.05269046797731\n",
      "EPOCH: 5918 LOSS: 41.052678651749424\n",
      "EPOCH: 5919 LOSS: 41.05266683776264\n",
      "EPOCH: 5920 LOSS: 41.052655026016275\n",
      "EPOCH: 5921 LOSS: 41.05264321650968\n",
      "EPOCH: 5922 LOSS: 41.052631409242196\n",
      "EPOCH: 5923 LOSS: 41.05261960421315\n",
      "EPOCH: 5924 LOSS: 41.05260780142192\n",
      "EPOCH: 5925 LOSS: 41.05259600086781\n",
      "EPOCH: 5926 LOSS: 41.05258420255018\n",
      "EPOCH: 5927 LOSS: 41.05257240646834\n",
      "EPOCH: 5928 LOSS: 41.05256061262169\n",
      "EPOCH: 5929 LOSS: 41.05254882100954\n",
      "EPOCH: 5930 LOSS: 41.0525370316312\n",
      "EPOCH: 5931 LOSS: 41.05252524448607\n",
      "EPOCH: 5932 LOSS: 41.05251345957345\n",
      "EPOCH: 5933 LOSS: 41.052501676892724\n",
      "EPOCH: 5934 LOSS: 41.052489896443205\n",
      "EPOCH: 5935 LOSS: 41.05247811822425\n",
      "EPOCH: 5936 LOSS: 41.05246634223519\n",
      "EPOCH: 5937 LOSS: 41.0524545684754\n",
      "EPOCH: 5938 LOSS: 41.05244279694417\n",
      "EPOCH: 5939 LOSS: 41.0524310276409\n",
      "EPOCH: 5940 LOSS: 41.052419260564925\n",
      "EPOCH: 5941 LOSS: 41.05240749571556\n",
      "EPOCH: 5942 LOSS: 41.05239573309218\n",
      "EPOCH: 5943 LOSS: 41.052383972694145\n",
      "EPOCH: 5944 LOSS: 41.05237221452076\n",
      "EPOCH: 5945 LOSS: 41.05236045857141\n",
      "EPOCH: 5946 LOSS: 41.052348704845414\n",
      "EPOCH: 5947 LOSS: 41.052336953342135\n",
      "EPOCH: 5948 LOSS: 41.05232520406092\n",
      "EPOCH: 5949 LOSS: 41.05231345700113\n",
      "EPOCH: 5950 LOSS: 41.052301712162084\n",
      "EPOCH: 5951 LOSS: 41.05228996954316\n",
      "EPOCH: 5952 LOSS: 41.05227822914368\n",
      "EPOCH: 5953 LOSS: 41.05226649096302\n",
      "EPOCH: 5954 LOSS: 41.052254755000526\n",
      "EPOCH: 5955 LOSS: 41.052243021255535\n",
      "EPOCH: 5956 LOSS: 41.05223128972741\n",
      "EPOCH: 5957 LOSS: 41.052219560415494\n",
      "EPOCH: 5958 LOSS: 41.052207833319144\n",
      "EPOCH: 5959 LOSS: 41.05219610843771\n",
      "EPOCH: 5960 LOSS: 41.052184385770545\n",
      "EPOCH: 5961 LOSS: 41.052172665317\n",
      "EPOCH: 5962 LOSS: 41.05216094707642\n",
      "EPOCH: 5963 LOSS: 41.05214923104816\n",
      "EPOCH: 5964 LOSS: 41.05213751723161\n",
      "EPOCH: 5965 LOSS: 41.05212580562606\n",
      "EPOCH: 5966 LOSS: 41.05211409623092\n",
      "EPOCH: 5967 LOSS: 41.05210238904551\n",
      "EPOCH: 5968 LOSS: 41.0520906840692\n",
      "EPOCH: 5969 LOSS: 41.05207898130134\n",
      "EPOCH: 5970 LOSS: 41.052067280741284\n",
      "EPOCH: 5971 LOSS: 41.05205558238838\n",
      "EPOCH: 5972 LOSS: 41.05204388624201\n",
      "EPOCH: 5973 LOSS: 41.05203219230151\n",
      "EPOCH: 5974 LOSS: 41.05202050056622\n",
      "EPOCH: 5975 LOSS: 41.05200881103554\n",
      "EPOCH: 5976 LOSS: 41.051997123708794\n",
      "EPOCH: 5977 LOSS: 41.05198543858535\n",
      "EPOCH: 5978 LOSS: 41.05197375566456\n",
      "EPOCH: 5979 LOSS: 41.0519620749458\n",
      "EPOCH: 5980 LOSS: 41.0519503964284\n",
      "EPOCH: 5981 LOSS: 41.05193872011174\n",
      "EPOCH: 5982 LOSS: 41.05192704599518\n",
      "EPOCH: 5983 LOSS: 41.05191537407806\n",
      "EPOCH: 5984 LOSS: 41.051903704359745\n",
      "EPOCH: 5985 LOSS: 41.05189203683961\n",
      "EPOCH: 5986 LOSS: 41.051880371517015\n",
      "EPOCH: 5987 LOSS: 41.051868708391304\n",
      "EPOCH: 5988 LOSS: 41.05185704746184\n",
      "EPOCH: 5989 LOSS: 41.05184538872798\n",
      "EPOCH: 5990 LOSS: 41.05183373218911\n",
      "EPOCH: 5991 LOSS: 41.05182207784459\n",
      "EPOCH: 5992 LOSS: 41.051810425693745\n",
      "EPOCH: 5993 LOSS: 41.05179877573596\n",
      "EPOCH: 5994 LOSS: 41.05178712797061\n",
      "EPOCH: 5995 LOSS: 41.05177548239704\n",
      "EPOCH: 5996 LOSS: 41.05176383901462\n",
      "EPOCH: 5997 LOSS: 41.05175219782272\n",
      "EPOCH: 5998 LOSS: 41.051740558820676\n",
      "EPOCH: 5999 LOSS: 41.05172892200789\n",
      "EPOCH: 6000 LOSS: 41.05171728738371\n",
      "EPOCH: 6001 LOSS: 41.05170565494748\n",
      "EPOCH: 6002 LOSS: 41.0516940246986\n",
      "EPOCH: 6003 LOSS: 41.05168239663642\n",
      "EPOCH: 6004 LOSS: 41.05167077076031\n",
      "EPOCH: 6005 LOSS: 41.05165914706962\n",
      "EPOCH: 6006 LOSS: 41.05164752556372\n",
      "EPOCH: 6007 LOSS: 41.051635906242005\n",
      "EPOCH: 6008 LOSS: 41.05162428910382\n",
      "EPOCH: 6009 LOSS: 41.051612674148515\n",
      "EPOCH: 6010 LOSS: 41.05160106137549\n",
      "EPOCH: 6011 LOSS: 41.051589450784085\n",
      "EPOCH: 6012 LOSS: 41.05157784237368\n",
      "EPOCH: 6013 LOSS: 41.05156623614366\n",
      "EPOCH: 6014 LOSS: 41.05155463209337\n",
      "EPOCH: 6015 LOSS: 41.05154303022218\n",
      "EPOCH: 6016 LOSS: 41.05153143052948\n",
      "EPOCH: 6017 LOSS: 41.05151983301462\n",
      "EPOCH: 6018 LOSS: 41.05150823767697\n",
      "EPOCH: 6019 LOSS: 41.05149664451592\n",
      "EPOCH: 6020 LOSS: 41.05148505353081\n",
      "EPOCH: 6021 LOSS: 41.05147346472102\n",
      "EPOCH: 6022 LOSS: 41.051461878085945\n",
      "EPOCH: 6023 LOSS: 41.05145029362494\n",
      "EPOCH: 6024 LOSS: 41.051438711337354\n",
      "EPOCH: 6025 LOSS: 41.0514271312226\n",
      "EPOCH: 6026 LOSS: 41.05141555328002\n",
      "EPOCH: 6027 LOSS: 41.05140397750901\n",
      "EPOCH: 6028 LOSS: 41.05139240390892\n",
      "EPOCH: 6029 LOSS: 41.051380832479126\n",
      "EPOCH: 6030 LOSS: 41.05136926321902\n",
      "EPOCH: 6031 LOSS: 41.051357696127965\n",
      "EPOCH: 6032 LOSS: 41.051346131205335\n",
      "EPOCH: 6033 LOSS: 41.051334568450486\n",
      "EPOCH: 6034 LOSS: 41.05132300786282\n",
      "EPOCH: 6035 LOSS: 41.05131144944171\n",
      "EPOCH: 6036 LOSS: 41.051299893186496\n",
      "EPOCH: 6037 LOSS: 41.051288339096615\n",
      "EPOCH: 6038 LOSS: 41.05127678717139\n",
      "EPOCH: 6039 LOSS: 41.05126523741022\n",
      "EPOCH: 6040 LOSS: 41.05125368981248\n",
      "EPOCH: 6041 LOSS: 41.051242144377525\n",
      "EPOCH: 6042 LOSS: 41.05123060110474\n",
      "EPOCH: 6043 LOSS: 41.05121905999354\n",
      "EPOCH: 6044 LOSS: 41.051207521043274\n",
      "EPOCH: 6045 LOSS: 41.051195984253305\n",
      "EPOCH: 6046 LOSS: 41.051184449623044\n",
      "EPOCH: 6047 LOSS: 41.051172917151824\n",
      "EPOCH: 6048 LOSS: 41.05116138683908\n",
      "EPOCH: 6049 LOSS: 41.05114985868415\n",
      "EPOCH: 6050 LOSS: 41.05113833268642\n",
      "EPOCH: 6051 LOSS: 41.05112680884528\n",
      "EPOCH: 6052 LOSS: 41.05111528716011\n",
      "EPOCH: 6053 LOSS: 41.05110376763028\n",
      "EPOCH: 6054 LOSS: 41.05109225025518\n",
      "EPOCH: 6055 LOSS: 41.05108073503417\n",
      "EPOCH: 6056 LOSS: 41.05106922196667\n",
      "EPOCH: 6057 LOSS: 41.051057711052025\n",
      "EPOCH: 6058 LOSS: 41.05104620228961\n",
      "EPOCH: 6059 LOSS: 41.05103469567887\n",
      "EPOCH: 6060 LOSS: 41.051023191219116\n",
      "EPOCH: 6061 LOSS: 41.051011688909774\n",
      "EPOCH: 6062 LOSS: 41.051000188750194\n",
      "EPOCH: 6063 LOSS: 41.050988690739786\n",
      "EPOCH: 6064 LOSS: 41.05097719487791\n",
      "EPOCH: 6065 LOSS: 41.05096570116398\n",
      "EPOCH: 6066 LOSS: 41.050954209597364\n",
      "EPOCH: 6067 LOSS: 41.05094272017743\n",
      "EPOCH: 6068 LOSS: 41.05093123290358\n",
      "EPOCH: 6069 LOSS: 41.0509197477752\n",
      "EPOCH: 6070 LOSS: 41.05090826479167\n",
      "EPOCH: 6071 LOSS: 41.050896783952396\n",
      "EPOCH: 6072 LOSS: 41.05088530525672\n",
      "EPOCH: 6073 LOSS: 41.050873828704056\n",
      "EPOCH: 6074 LOSS: 41.050862354293784\n",
      "EPOCH: 6075 LOSS: 41.05085088202531\n",
      "EPOCH: 6076 LOSS: 41.050839411897975\n",
      "EPOCH: 6077 LOSS: 41.05082794391121\n",
      "EPOCH: 6078 LOSS: 41.05081647806439\n",
      "EPOCH: 6079 LOSS: 41.050805014356904\n",
      "EPOCH: 6080 LOSS: 41.05079355278812\n",
      "EPOCH: 6081 LOSS: 41.050782093357455\n",
      "EPOCH: 6082 LOSS: 41.05077063606428\n",
      "EPOCH: 6083 LOSS: 41.05075918090799\n",
      "EPOCH: 6084 LOSS: 41.05074772788797\n",
      "EPOCH: 6085 LOSS: 41.0507362770036\n",
      "EPOCH: 6086 LOSS: 41.050724828254296\n",
      "EPOCH: 6087 LOSS: 41.05071338163942\n",
      "EPOCH: 6088 LOSS: 41.05070193715839\n",
      "EPOCH: 6089 LOSS: 41.05069049481056\n",
      "EPOCH: 6090 LOSS: 41.05067905459535\n",
      "EPOCH: 6091 LOSS: 41.05066761651214\n",
      "EPOCH: 6092 LOSS: 41.05065618056035\n",
      "EPOCH: 6093 LOSS: 41.05064474673932\n",
      "EPOCH: 6094 LOSS: 41.050633315048486\n",
      "EPOCH: 6095 LOSS: 41.0506218854872\n",
      "EPOCH: 6096 LOSS: 41.05061045805488\n",
      "EPOCH: 6097 LOSS: 41.050599032750924\n",
      "EPOCH: 6098 LOSS: 41.05058760957471\n",
      "EPOCH: 6099 LOSS: 41.05057618852564\n",
      "EPOCH: 6100 LOSS: 41.0505647696031\n",
      "EPOCH: 6101 LOSS: 41.050553352806496\n",
      "EPOCH: 6102 LOSS: 41.05054193813521\n",
      "EPOCH: 6103 LOSS: 41.05053052558864\n",
      "EPOCH: 6104 LOSS: 41.050519115166196\n",
      "EPOCH: 6105 LOSS: 41.050507706867236\n",
      "EPOCH: 6106 LOSS: 41.050496300691194\n",
      "EPOCH: 6107 LOSS: 41.050484896637435\n",
      "EPOCH: 6108 LOSS: 41.05047349470537\n",
      "EPOCH: 6109 LOSS: 41.05046209489441\n",
      "EPOCH: 6110 LOSS: 41.05045069720392\n",
      "EPOCH: 6111 LOSS: 41.050439301633325\n",
      "EPOCH: 6112 LOSS: 41.05042790818201\n",
      "EPOCH: 6113 LOSS: 41.05041651684935\n",
      "EPOCH: 6114 LOSS: 41.05040512763479\n",
      "EPOCH: 6115 LOSS: 41.050393740537686\n",
      "EPOCH: 6116 LOSS: 41.05038235555745\n",
      "EPOCH: 6117 LOSS: 41.050370972693486\n",
      "EPOCH: 6118 LOSS: 41.050359591945195\n",
      "EPOCH: 6119 LOSS: 41.05034821331196\n",
      "EPOCH: 6120 LOSS: 41.0503368367932\n",
      "EPOCH: 6121 LOSS: 41.050325462388294\n",
      "EPOCH: 6122 LOSS: 41.05031409009665\n",
      "EPOCH: 6123 LOSS: 41.05030271991768\n",
      "EPOCH: 6124 LOSS: 41.05029135185076\n",
      "EPOCH: 6125 LOSS: 41.05027998589531\n",
      "EPOCH: 6126 LOSS: 41.05026862205072\n",
      "EPOCH: 6127 LOSS: 41.0502572603164\n",
      "EPOCH: 6128 LOSS: 41.05024590069175\n",
      "EPOCH: 6129 LOSS: 41.05023454317615\n",
      "EPOCH: 6130 LOSS: 41.05022318776905\n",
      "EPOCH: 6131 LOSS: 41.05021183446981\n",
      "EPOCH: 6132 LOSS: 41.05020048327785\n",
      "EPOCH: 6133 LOSS: 41.050189134192564\n",
      "EPOCH: 6134 LOSS: 41.05017778721336\n",
      "EPOCH: 6135 LOSS: 41.05016644233963\n",
      "EPOCH: 6136 LOSS: 41.0501550995708\n",
      "EPOCH: 6137 LOSS: 41.05014375890625\n",
      "EPOCH: 6138 LOSS: 41.05013242034541\n",
      "EPOCH: 6139 LOSS: 41.05012108388766\n",
      "EPOCH: 6140 LOSS: 41.050109749532425\n",
      "EPOCH: 6141 LOSS: 41.05009841727909\n",
      "EPOCH: 6142 LOSS: 41.05008708712707\n",
      "EPOCH: 6143 LOSS: 41.05007575907577\n",
      "EPOCH: 6144 LOSS: 41.05006443312459\n",
      "EPOCH: 6145 LOSS: 41.05005310927296\n",
      "EPOCH: 6146 LOSS: 41.05004178752024\n",
      "EPOCH: 6147 LOSS: 41.050030467865895\n",
      "EPOCH: 6148 LOSS: 41.05001915030928\n",
      "EPOCH: 6149 LOSS: 41.050007834849836\n",
      "EPOCH: 6150 LOSS: 41.04999652148694\n",
      "EPOCH: 6151 LOSS: 41.049985210220036\n",
      "EPOCH: 6152 LOSS: 41.0499739010485\n",
      "EPOCH: 6153 LOSS: 41.04996259397177\n",
      "EPOCH: 6154 LOSS: 41.049951288989206\n",
      "EPOCH: 6155 LOSS: 41.049939986100284\n",
      "EPOCH: 6156 LOSS: 41.049928685304366\n",
      "EPOCH: 6157 LOSS: 41.04991738660086\n",
      "EPOCH: 6158 LOSS: 41.04990608998919\n",
      "EPOCH: 6159 LOSS: 41.04989479546877\n",
      "EPOCH: 6160 LOSS: 41.04988350303901\n",
      "EPOCH: 6161 LOSS: 41.0498722126993\n",
      "EPOCH: 6162 LOSS: 41.04986092444908\n",
      "EPOCH: 6163 LOSS: 41.04984963828773\n",
      "EPOCH: 6164 LOSS: 41.049838354214685\n",
      "EPOCH: 6165 LOSS: 41.049827072229355\n",
      "EPOCH: 6166 LOSS: 41.04981579233113\n",
      "EPOCH: 6167 LOSS: 41.049804514519444\n",
      "EPOCH: 6168 LOSS: 41.049793238793704\n",
      "EPOCH: 6169 LOSS: 41.0497819651533\n",
      "EPOCH: 6170 LOSS: 41.049770693597694\n",
      "EPOCH: 6171 LOSS: 41.04975942412624\n",
      "EPOCH: 6172 LOSS: 41.0497481567384\n",
      "EPOCH: 6173 LOSS: 41.04973689143356\n",
      "EPOCH: 6174 LOSS: 41.04972562821116\n",
      "EPOCH: 6175 LOSS: 41.049714367070585\n",
      "EPOCH: 6176 LOSS: 41.04970310801125\n",
      "EPOCH: 6177 LOSS: 41.04969185103259\n",
      "EPOCH: 6178 LOSS: 41.04968059613401\n",
      "EPOCH: 6179 LOSS: 41.049669343314925\n",
      "EPOCH: 6180 LOSS: 41.049658092574745\n",
      "EPOCH: 6181 LOSS: 41.049646843912896\n",
      "EPOCH: 6182 LOSS: 41.04963559732877\n",
      "EPOCH: 6183 LOSS: 41.04962435282182\n",
      "EPOCH: 6184 LOSS: 41.04961311039146\n",
      "EPOCH: 6185 LOSS: 41.04960187003707\n",
      "EPOCH: 6186 LOSS: 41.04959063175809\n",
      "EPOCH: 6187 LOSS: 41.04957939555394\n",
      "EPOCH: 6188 LOSS: 41.049568161424034\n",
      "EPOCH: 6189 LOSS: 41.04955692936779\n",
      "EPOCH: 6190 LOSS: 41.0495456993846\n",
      "EPOCH: 6191 LOSS: 41.04953447147395\n",
      "EPOCH: 6192 LOSS: 41.04952324563518\n",
      "EPOCH: 6193 LOSS: 41.04951202186774\n",
      "EPOCH: 6194 LOSS: 41.04950080017108\n",
      "EPOCH: 6195 LOSS: 41.04948958054457\n",
      "EPOCH: 6196 LOSS: 41.04947836298767\n",
      "EPOCH: 6197 LOSS: 41.04946714749977\n",
      "EPOCH: 6198 LOSS: 41.049455934080285\n",
      "EPOCH: 6199 LOSS: 41.04944472272868\n",
      "EPOCH: 6200 LOSS: 41.04943351344435\n",
      "EPOCH: 6201 LOSS: 41.0494223062267\n",
      "EPOCH: 6202 LOSS: 41.04941110107516\n",
      "EPOCH: 6203 LOSS: 41.049399897989176\n",
      "EPOCH: 6204 LOSS: 41.04938869696813\n",
      "EPOCH: 6205 LOSS: 41.04937749801147\n",
      "EPOCH: 6206 LOSS: 41.04936630111861\n",
      "EPOCH: 6207 LOSS: 41.04935510628897\n",
      "EPOCH: 6208 LOSS: 41.04934391352199\n",
      "EPOCH: 6209 LOSS: 41.04933272281707\n",
      "EPOCH: 6210 LOSS: 41.04932153417366\n",
      "EPOCH: 6211 LOSS: 41.04931034759114\n",
      "EPOCH: 6212 LOSS: 41.04929916306897\n",
      "EPOCH: 6213 LOSS: 41.04928798060657\n",
      "EPOCH: 6214 LOSS: 41.04927680020336\n",
      "EPOCH: 6215 LOSS: 41.04926562185876\n",
      "EPOCH: 6216 LOSS: 41.04925444557219\n",
      "EPOCH: 6217 LOSS: 41.04924327134309\n",
      "EPOCH: 6218 LOSS: 41.049232099170865\n",
      "EPOCH: 6219 LOSS: 41.04922092905497\n",
      "EPOCH: 6220 LOSS: 41.04920976099482\n",
      "EPOCH: 6221 LOSS: 41.04919859498982\n",
      "EPOCH: 6222 LOSS: 41.04918743103943\n",
      "EPOCH: 6223 LOSS: 41.04917626914303\n",
      "EPOCH: 6224 LOSS: 41.0491651093001\n",
      "EPOCH: 6225 LOSS: 41.04915395151003\n",
      "EPOCH: 6226 LOSS: 41.04914279577225\n",
      "EPOCH: 6227 LOSS: 41.04913164208622\n",
      "EPOCH: 6228 LOSS: 41.04912049045133\n",
      "EPOCH: 6229 LOSS: 41.04910934086703\n",
      "EPOCH: 6230 LOSS: 41.04909819333274\n",
      "EPOCH: 6231 LOSS: 41.049087047847884\n",
      "EPOCH: 6232 LOSS: 41.0490759044119\n",
      "EPOCH: 6233 LOSS: 41.04906476302422\n",
      "EPOCH: 6234 LOSS: 41.04905362368427\n",
      "EPOCH: 6235 LOSS: 41.04904248639146\n",
      "EPOCH: 6236 LOSS: 41.049031351145246\n",
      "EPOCH: 6237 LOSS: 41.049020217945056\n",
      "EPOCH: 6238 LOSS: 41.049009086790306\n",
      "EPOCH: 6239 LOSS: 41.04899795768043\n",
      "EPOCH: 6240 LOSS: 41.048986830614865\n",
      "EPOCH: 6241 LOSS: 41.048975705593065\n",
      "EPOCH: 6242 LOSS: 41.0489645826144\n",
      "EPOCH: 6243 LOSS: 41.048953461678344\n",
      "EPOCH: 6244 LOSS: 41.048942342784336\n",
      "EPOCH: 6245 LOSS: 41.048931225931796\n",
      "EPOCH: 6246 LOSS: 41.04892011112016\n",
      "EPOCH: 6247 LOSS: 41.04890899834885\n",
      "EPOCH: 6248 LOSS: 41.048897887617294\n",
      "EPOCH: 6249 LOSS: 41.04888677892494\n",
      "EPOCH: 6250 LOSS: 41.04887567227122\n",
      "EPOCH: 6251 LOSS: 41.04886456765557\n",
      "EPOCH: 6252 LOSS: 41.048853465077414\n",
      "EPOCH: 6253 LOSS: 41.048842364536185\n",
      "EPOCH: 6254 LOSS: 41.04883126603135\n",
      "EPOCH: 6255 LOSS: 41.04882016956229\n",
      "EPOCH: 6256 LOSS: 41.04880907512849\n",
      "EPOCH: 6257 LOSS: 41.04879798272935\n",
      "EPOCH: 6258 LOSS: 41.04878689236432\n",
      "EPOCH: 6259 LOSS: 41.048775804032836\n",
      "EPOCH: 6260 LOSS: 41.04876471773432\n",
      "EPOCH: 6261 LOSS: 41.04875363346823\n",
      "EPOCH: 6262 LOSS: 41.048742551234\n",
      "EPOCH: 6263 LOSS: 41.04873147103105\n",
      "EPOCH: 6264 LOSS: 41.048720392858826\n",
      "EPOCH: 6265 LOSS: 41.04870931671676\n",
      "EPOCH: 6266 LOSS: 41.0486982426043\n",
      "EPOCH: 6267 LOSS: 41.04868717052089\n",
      "EPOCH: 6268 LOSS: 41.04867610046594\n",
      "EPOCH: 6269 LOSS: 41.048665032438905\n",
      "EPOCH: 6270 LOSS: 41.04865396643923\n",
      "EPOCH: 6271 LOSS: 41.04864290246634\n",
      "EPOCH: 6272 LOSS: 41.0486318405197\n",
      "EPOCH: 6273 LOSS: 41.048620780598704\n",
      "EPOCH: 6274 LOSS: 41.04860972270283\n",
      "EPOCH: 6275 LOSS: 41.0485986668315\n",
      "EPOCH: 6276 LOSS: 41.04858761298416\n",
      "EPOCH: 6277 LOSS: 41.048576561160246\n",
      "EPOCH: 6278 LOSS: 41.048565511359214\n",
      "EPOCH: 6279 LOSS: 41.04855446358048\n",
      "EPOCH: 6280 LOSS: 41.048543417823495\n",
      "EPOCH: 6281 LOSS: 41.048532374087706\n",
      "EPOCH: 6282 LOSS: 41.048521332372566\n",
      "EPOCH: 6283 LOSS: 41.04851029267747\n",
      "EPOCH: 6284 LOSS: 41.048499255001914\n",
      "EPOCH: 6285 LOSS: 41.0484882193453\n",
      "EPOCH: 6286 LOSS: 41.0484771857071\n",
      "EPOCH: 6287 LOSS: 41.04846615408674\n",
      "EPOCH: 6288 LOSS: 41.04845512448367\n",
      "EPOCH: 6289 LOSS: 41.04844409689733\n",
      "EPOCH: 6290 LOSS: 41.04843307132715\n",
      "EPOCH: 6291 LOSS: 41.04842204777259\n",
      "EPOCH: 6292 LOSS: 41.04841102623308\n",
      "EPOCH: 6293 LOSS: 41.04840000670811\n",
      "EPOCH: 6294 LOSS: 41.04838898919707\n",
      "EPOCH: 6295 LOSS: 41.04837797369942\n",
      "EPOCH: 6296 LOSS: 41.04836696021461\n",
      "EPOCH: 6297 LOSS: 41.0483559487421\n",
      "EPOCH: 6298 LOSS: 41.0483449392813\n",
      "EPOCH: 6299 LOSS: 41.04833393183168\n",
      "EPOCH: 6300 LOSS: 41.04832292639267\n",
      "EPOCH: 6301 LOSS: 41.048311922963734\n",
      "EPOCH: 6302 LOSS: 41.04830092154431\n",
      "EPOCH: 6303 LOSS: 41.04828992213385\n",
      "EPOCH: 6304 LOSS: 41.04827892473179\n",
      "EPOCH: 6305 LOSS: 41.04826792933757\n",
      "EPOCH: 6306 LOSS: 41.048256935950675\n",
      "EPOCH: 6307 LOSS: 41.04824594457052\n",
      "EPOCH: 6308 LOSS: 41.04823495519654\n",
      "EPOCH: 6309 LOSS: 41.04822396782822\n",
      "EPOCH: 6310 LOSS: 41.048212982465\n",
      "EPOCH: 6311 LOSS: 41.04820199910632\n",
      "EPOCH: 6312 LOSS: 41.04819101775161\n",
      "EPOCH: 6313 LOSS: 41.04818003840033\n",
      "EPOCH: 6314 LOSS: 41.048169061051965\n",
      "EPOCH: 6315 LOSS: 41.04815808570592\n",
      "EPOCH: 6316 LOSS: 41.048147112361676\n",
      "EPOCH: 6317 LOSS: 41.04813614101866\n",
      "EPOCH: 6318 LOSS: 41.04812517167632\n",
      "EPOCH: 6319 LOSS: 41.04811420433411\n",
      "EPOCH: 6320 LOSS: 41.0481032389915\n",
      "EPOCH: 6321 LOSS: 41.04809227564793\n",
      "EPOCH: 6322 LOSS: 41.04808131430285\n",
      "EPOCH: 6323 LOSS: 41.0480703549557\n",
      "EPOCH: 6324 LOSS: 41.04805939760594\n",
      "EPOCH: 6325 LOSS: 41.04804844225302\n",
      "EPOCH: 6326 LOSS: 41.04803748889641\n",
      "EPOCH: 6327 LOSS: 41.048026537535534\n",
      "EPOCH: 6328 LOSS: 41.048015588169875\n",
      "EPOCH: 6329 LOSS: 41.04800464079886\n",
      "EPOCH: 6330 LOSS: 41.04799369542195\n",
      "EPOCH: 6331 LOSS: 41.04798275203859\n",
      "EPOCH: 6332 LOSS: 41.04797181064826\n",
      "EPOCH: 6333 LOSS: 41.04796087125038\n",
      "EPOCH: 6334 LOSS: 41.04794993384442\n",
      "EPOCH: 6335 LOSS: 41.047938998429856\n",
      "EPOCH: 6336 LOSS: 41.047928065006104\n",
      "EPOCH: 6337 LOSS: 41.047917133572625\n",
      "EPOCH: 6338 LOSS: 41.047906204128914\n",
      "EPOCH: 6339 LOSS: 41.04789527667438\n",
      "EPOCH: 6340 LOSS: 41.047884351208495\n",
      "EPOCH: 6341 LOSS: 41.04787342773071\n",
      "EPOCH: 6342 LOSS: 41.04786250624049\n",
      "EPOCH: 6343 LOSS: 41.04785158673728\n",
      "EPOCH: 6344 LOSS: 41.047840669220555\n",
      "EPOCH: 6345 LOSS: 41.047829753689754\n",
      "EPOCH: 6346 LOSS: 41.04781884014434\n",
      "EPOCH: 6347 LOSS: 41.04780792858377\n",
      "EPOCH: 6348 LOSS: 41.0477970190075\n",
      "EPOCH: 6349 LOSS: 41.04778611141499\n",
      "EPOCH: 6350 LOSS: 41.04777520580568\n",
      "EPOCH: 6351 LOSS: 41.04776430217906\n",
      "EPOCH: 6352 LOSS: 41.047753400534575\n",
      "EPOCH: 6353 LOSS: 41.04774250087167\n",
      "EPOCH: 6354 LOSS: 41.04773160318981\n",
      "EPOCH: 6355 LOSS: 41.04772070748848\n",
      "EPOCH: 6356 LOSS: 41.047709813767085\n",
      "EPOCH: 6357 LOSS: 41.047698922025134\n",
      "EPOCH: 6358 LOSS: 41.04768803226207\n",
      "EPOCH: 6359 LOSS: 41.047677144477355\n",
      "EPOCH: 6360 LOSS: 41.04766625867044\n",
      "EPOCH: 6361 LOSS: 41.047655374840794\n",
      "EPOCH: 6362 LOSS: 41.04764449298787\n",
      "EPOCH: 6363 LOSS: 41.04763361311114\n",
      "EPOCH: 6364 LOSS: 41.04762273521004\n",
      "EPOCH: 6365 LOSS: 41.04761185928406\n",
      "EPOCH: 6366 LOSS: 41.04760098533265\n",
      "EPOCH: 6367 LOSS: 41.047590113355284\n",
      "EPOCH: 6368 LOSS: 41.04757924335142\n",
      "EPOCH: 6369 LOSS: 41.04756837532049\n",
      "EPOCH: 6370 LOSS: 41.04755750926199\n",
      "EPOCH: 6371 LOSS: 41.04754664517537\n",
      "EPOCH: 6372 LOSS: 41.04753578306009\n",
      "EPOCH: 6373 LOSS: 41.04752492291562\n",
      "EPOCH: 6374 LOSS: 41.04751406474143\n",
      "EPOCH: 6375 LOSS: 41.047503208536966\n",
      "EPOCH: 6376 LOSS: 41.04749235430171\n",
      "EPOCH: 6377 LOSS: 41.0474815020351\n",
      "EPOCH: 6378 LOSS: 41.04747065173663\n",
      "EPOCH: 6379 LOSS: 41.04745980340575\n",
      "EPOCH: 6380 LOSS: 41.047448957041915\n",
      "EPOCH: 6381 LOSS: 41.0474381126446\n",
      "EPOCH: 6382 LOSS: 41.047427270213284\n",
      "EPOCH: 6383 LOSS: 41.047416429747415\n",
      "EPOCH: 6384 LOSS: 41.04740559124647\n",
      "EPOCH: 6385 LOSS: 41.04739475470989\n",
      "EPOCH: 6386 LOSS: 41.047383920137186\n",
      "EPOCH: 6387 LOSS: 41.04737308752778\n",
      "EPOCH: 6388 LOSS: 41.047362256881144\n",
      "EPOCH: 6389 LOSS: 41.04735142819678\n",
      "EPOCH: 6390 LOSS: 41.04734060147412\n",
      "EPOCH: 6391 LOSS: 41.04732977671264\n",
      "EPOCH: 6392 LOSS: 41.04731895391181\n",
      "EPOCH: 6393 LOSS: 41.0473081330711\n",
      "EPOCH: 6394 LOSS: 41.047297314189976\n",
      "EPOCH: 6395 LOSS: 41.047286497267905\n",
      "EPOCH: 6396 LOSS: 41.047275682304345\n",
      "EPOCH: 6397 LOSS: 41.04726486929881\n",
      "EPOCH: 6398 LOSS: 41.04725405825071\n",
      "EPOCH: 6399 LOSS: 41.047243249159536\n",
      "EPOCH: 6400 LOSS: 41.047232442024765\n",
      "EPOCH: 6401 LOSS: 41.04722163684587\n",
      "EPOCH: 6402 LOSS: 41.0472108336223\n",
      "EPOCH: 6403 LOSS: 41.047200032353516\n",
      "EPOCH: 6404 LOSS: 41.04718923303905\n",
      "EPOCH: 6405 LOSS: 41.04717843567832\n",
      "EPOCH: 6406 LOSS: 41.0471676402708\n",
      "EPOCH: 6407 LOSS: 41.04715684681597\n",
      "EPOCH: 6408 LOSS: 41.047146055313306\n",
      "EPOCH: 6409 LOSS: 41.04713526576227\n",
      "EPOCH: 6410 LOSS: 41.047124478162345\n",
      "EPOCH: 6411 LOSS: 41.04711369251299\n",
      "EPOCH: 6412 LOSS: 41.04710290881367\n",
      "EPOCH: 6413 LOSS: 41.04709212706387\n",
      "EPOCH: 6414 LOSS: 41.04708134726306\n",
      "EPOCH: 6415 LOSS: 41.047070569410735\n",
      "EPOCH: 6416 LOSS: 41.04705979350634\n",
      "EPOCH: 6417 LOSS: 41.047049019549334\n",
      "EPOCH: 6418 LOSS: 41.047038247539234\n",
      "EPOCH: 6419 LOSS: 41.04702747747549\n",
      "EPOCH: 6420 LOSS: 41.047016709357564\n",
      "EPOCH: 6421 LOSS: 41.047005943184956\n",
      "EPOCH: 6422 LOSS: 41.04699517895712\n",
      "EPOCH: 6423 LOSS: 41.04698441667351\n",
      "EPOCH: 6424 LOSS: 41.04697365633367\n",
      "EPOCH: 6425 LOSS: 41.04696289793702\n",
      "EPOCH: 6426 LOSS: 41.04695214148305\n",
      "EPOCH: 6427 LOSS: 41.04694138697122\n",
      "EPOCH: 6428 LOSS: 41.046930634401015\n",
      "EPOCH: 6429 LOSS: 41.04691988377194\n",
      "EPOCH: 6430 LOSS: 41.04690913508344\n",
      "EPOCH: 6431 LOSS: 41.04689838833499\n",
      "EPOCH: 6432 LOSS: 41.046887643526055\n",
      "EPOCH: 6433 LOSS: 41.04687690065615\n",
      "EPOCH: 6434 LOSS: 41.04686615972473\n",
      "EPOCH: 6435 LOSS: 41.046855420731276\n",
      "EPOCH: 6436 LOSS: 41.04684468367526\n",
      "EPOCH: 6437 LOSS: 41.046833948556156\n",
      "EPOCH: 6438 LOSS: 41.046823215373465\n",
      "EPOCH: 6439 LOSS: 41.04681248412664\n",
      "EPOCH: 6440 LOSS: 41.04680175481515\n",
      "EPOCH: 6441 LOSS: 41.04679102743851\n",
      "EPOCH: 6442 LOSS: 41.04678030199619\n",
      "EPOCH: 6443 LOSS: 41.04676957848764\n",
      "EPOCH: 6444 LOSS: 41.04675885691236\n",
      "EPOCH: 6445 LOSS: 41.046748137269844\n",
      "EPOCH: 6446 LOSS: 41.046737419559534\n",
      "EPOCH: 6447 LOSS: 41.046726703780934\n",
      "EPOCH: 6448 LOSS: 41.04671598993353\n",
      "EPOCH: 6449 LOSS: 41.04670527801679\n",
      "EPOCH: 6450 LOSS: 41.04669456803018\n",
      "EPOCH: 6451 LOSS: 41.04668385997323\n",
      "EPOCH: 6452 LOSS: 41.04667315384535\n",
      "EPOCH: 6453 LOSS: 41.04666244964609\n",
      "EPOCH: 6454 LOSS: 41.046651747374895\n",
      "EPOCH: 6455 LOSS: 41.046641047031244\n",
      "EPOCH: 6456 LOSS: 41.04663034861464\n",
      "EPOCH: 6457 LOSS: 41.046619652124534\n",
      "EPOCH: 6458 LOSS: 41.046608957560444\n",
      "EPOCH: 6459 LOSS: 41.046598264921826\n",
      "EPOCH: 6460 LOSS: 41.046587574208175\n",
      "EPOCH: 6461 LOSS: 41.04657688541897\n",
      "EPOCH: 6462 LOSS: 41.04656619855369\n",
      "EPOCH: 6463 LOSS: 41.04655551361182\n",
      "EPOCH: 6464 LOSS: 41.046544830592836\n",
      "EPOCH: 6465 LOSS: 41.04653414949625\n",
      "EPOCH: 6466 LOSS: 41.04652347032153\n",
      "EPOCH: 6467 LOSS: 41.046512793068146\n",
      "EPOCH: 6468 LOSS: 41.046502117735606\n",
      "EPOCH: 6469 LOSS: 41.046491444323365\n",
      "EPOCH: 6470 LOSS: 41.04648077283095\n",
      "EPOCH: 6471 LOSS: 41.04647010325779\n",
      "EPOCH: 6472 LOSS: 41.046459435603424\n",
      "EPOCH: 6473 LOSS: 41.04644876986731\n",
      "EPOCH: 6474 LOSS: 41.04643810604893\n",
      "EPOCH: 6475 LOSS: 41.04642744414778\n",
      "EPOCH: 6476 LOSS: 41.04641678416336\n",
      "EPOCH: 6477 LOSS: 41.046406126095135\n",
      "EPOCH: 6478 LOSS: 41.046395469942574\n",
      "EPOCH: 6479 LOSS: 41.04638481570521\n",
      "EPOCH: 6480 LOSS: 41.04637416338251\n",
      "EPOCH: 6481 LOSS: 41.04636351297395\n",
      "EPOCH: 6482 LOSS: 41.04635286447902\n",
      "EPOCH: 6483 LOSS: 41.04634221789722\n",
      "EPOCH: 6484 LOSS: 41.046331573228024\n",
      "EPOCH: 6485 LOSS: 41.04632093047093\n",
      "EPOCH: 6486 LOSS: 41.04631028962541\n",
      "EPOCH: 6487 LOSS: 41.046299650691\n",
      "EPOCH: 6488 LOSS: 41.046289013667135\n",
      "EPOCH: 6489 LOSS: 41.04627837855333\n",
      "EPOCH: 6490 LOSS: 41.046267745349056\n",
      "EPOCH: 6491 LOSS: 41.0462571140538\n",
      "EPOCH: 6492 LOSS: 41.046246484667094\n",
      "EPOCH: 6493 LOSS: 41.04623585718839\n",
      "EPOCH: 6494 LOSS: 41.04622523161718\n",
      "EPOCH: 6495 LOSS: 41.04621460795296\n",
      "EPOCH: 6496 LOSS: 41.046203986195216\n",
      "EPOCH: 6497 LOSS: 41.04619336634346\n",
      "EPOCH: 6498 LOSS: 41.046182748397136\n",
      "EPOCH: 6499 LOSS: 41.0461721323558\n",
      "EPOCH: 6500 LOSS: 41.0461615182189\n",
      "EPOCH: 6501 LOSS: 41.046150905985925\n",
      "EPOCH: 6502 LOSS: 41.046140295656386\n",
      "EPOCH: 6503 LOSS: 41.046129687229765\n",
      "EPOCH: 6504 LOSS: 41.04611908070555\n",
      "EPOCH: 6505 LOSS: 41.04610847608325\n",
      "EPOCH: 6506 LOSS: 41.04609787336233\n",
      "EPOCH: 6507 LOSS: 41.04608727254231\n",
      "EPOCH: 6508 LOSS: 41.04607667362268\n",
      "EPOCH: 6509 LOSS: 41.0460660766029\n",
      "EPOCH: 6510 LOSS: 41.04605548148251\n",
      "EPOCH: 6511 LOSS: 41.046044888260965\n",
      "EPOCH: 6512 LOSS: 41.0460342969378\n",
      "EPOCH: 6513 LOSS: 41.04602370751246\n",
      "EPOCH: 6514 LOSS: 41.046013119984465\n",
      "EPOCH: 6515 LOSS: 41.04600253435332\n",
      "EPOCH: 6516 LOSS: 41.04599195061851\n",
      "EPOCH: 6517 LOSS: 41.04598136877951\n",
      "EPOCH: 6518 LOSS: 41.04597078883583\n",
      "EPOCH: 6519 LOSS: 41.045960210786994\n",
      "EPOCH: 6520 LOSS: 41.04594963463246\n",
      "EPOCH: 6521 LOSS: 41.04593906037174\n",
      "EPOCH: 6522 LOSS: 41.04592848800431\n",
      "EPOCH: 6523 LOSS: 41.04591791752968\n",
      "EPOCH: 6524 LOSS: 41.045907348947345\n",
      "EPOCH: 6525 LOSS: 41.04589678225681\n",
      "EPOCH: 6526 LOSS: 41.045886217457564\n",
      "EPOCH: 6527 LOSS: 41.045875654549114\n",
      "EPOCH: 6528 LOSS: 41.045865093530935\n",
      "EPOCH: 6529 LOSS: 41.04585453440254\n",
      "EPOCH: 6530 LOSS: 41.045843977163436\n",
      "EPOCH: 6531 LOSS: 41.04583342181309\n",
      "EPOCH: 6532 LOSS: 41.04582286835103\n",
      "EPOCH: 6533 LOSS: 41.04581231677674\n",
      "EPOCH: 6534 LOSS: 41.04580176708971\n",
      "EPOCH: 6535 LOSS: 41.045791219289455\n",
      "EPOCH: 6536 LOSS: 41.04578067337549\n",
      "EPOCH: 6537 LOSS: 41.04577012934725\n",
      "EPOCH: 6538 LOSS: 41.04575958720431\n",
      "EPOCH: 6539 LOSS: 41.04574904694613\n",
      "EPOCH: 6540 LOSS: 41.0457385085722\n",
      "EPOCH: 6541 LOSS: 41.04572797208205\n",
      "EPOCH: 6542 LOSS: 41.04571743747515\n",
      "EPOCH: 6543 LOSS: 41.04570690475103\n",
      "EPOCH: 6544 LOSS: 41.045696373909166\n",
      "EPOCH: 6545 LOSS: 41.04568584494907\n",
      "EPOCH: 6546 LOSS: 41.04567531787024\n",
      "EPOCH: 6547 LOSS: 41.045664792672184\n",
      "EPOCH: 6548 LOSS: 41.0456542693544\n",
      "EPOCH: 6549 LOSS: 41.04564374791639\n",
      "EPOCH: 6550 LOSS: 41.04563322835762\n",
      "EPOCH: 6551 LOSS: 41.045622710677655\n",
      "EPOCH: 6552 LOSS: 41.04561219487594\n",
      "EPOCH: 6553 LOSS: 41.045601680952046\n",
      "EPOCH: 6554 LOSS: 41.04559116890541\n",
      "EPOCH: 6555 LOSS: 41.04558065873555\n",
      "EPOCH: 6556 LOSS: 41.04557015044199\n",
      "EPOCH: 6557 LOSS: 41.045559644024195\n",
      "EPOCH: 6558 LOSS: 41.045549139481714\n",
      "EPOCH: 6559 LOSS: 41.045538636814044\n",
      "EPOCH: 6560 LOSS: 41.04552813602063\n",
      "EPOCH: 6561 LOSS: 41.04551763710106\n",
      "EPOCH: 6562 LOSS: 41.04550714005478\n",
      "EPOCH: 6563 LOSS: 41.045496644881304\n",
      "EPOCH: 6564 LOSS: 41.045486151580164\n",
      "EPOCH: 6565 LOSS: 41.045475660150835\n",
      "EPOCH: 6566 LOSS: 41.045465170592834\n",
      "EPOCH: 6567 LOSS: 41.045454682905664\n",
      "EPOCH: 6568 LOSS: 41.04544419708883\n",
      "EPOCH: 6569 LOSS: 41.04543371314183\n",
      "EPOCH: 6570 LOSS: 41.04542323106418\n",
      "EPOCH: 6571 LOSS: 41.045412750855405\n",
      "EPOCH: 6572 LOSS: 41.04540227251498\n",
      "EPOCH: 6573 LOSS: 41.04539179604241\n",
      "EPOCH: 6574 LOSS: 41.045381321437226\n",
      "EPOCH: 6575 LOSS: 41.04537084869891\n",
      "EPOCH: 6576 LOSS: 41.045360377826995\n",
      "EPOCH: 6577 LOSS: 41.04534990882095\n",
      "EPOCH: 6578 LOSS: 41.04533944168033\n",
      "EPOCH: 6579 LOSS: 41.045328976404605\n",
      "EPOCH: 6580 LOSS: 41.0453185129933\n",
      "EPOCH: 6581 LOSS: 41.04530805144593\n",
      "EPOCH: 6582 LOSS: 41.045297591761994\n",
      "EPOCH: 6583 LOSS: 41.045287133940974\n",
      "EPOCH: 6584 LOSS: 41.045276677982415\n",
      "EPOCH: 6585 LOSS: 41.04526622388582\n",
      "EPOCH: 6586 LOSS: 41.04525577165069\n",
      "EPOCH: 6587 LOSS: 41.045245321276525\n",
      "EPOCH: 6588 LOSS: 41.04523487276285\n",
      "EPOCH: 6589 LOSS: 41.04522442610918\n",
      "EPOCH: 6590 LOSS: 41.04521398131502\n",
      "EPOCH: 6591 LOSS: 41.04520353837985\n",
      "EPOCH: 6592 LOSS: 41.04519309730324\n",
      "EPOCH: 6593 LOSS: 41.04518265808464\n",
      "EPOCH: 6594 LOSS: 41.045172220723586\n",
      "EPOCH: 6595 LOSS: 41.0451617852196\n",
      "EPOCH: 6596 LOSS: 41.04515135157218\n",
      "EPOCH: 6597 LOSS: 41.04514091978083\n",
      "EPOCH: 6598 LOSS: 41.04513048984507\n",
      "EPOCH: 6599 LOSS: 41.04512006176442\n",
      "EPOCH: 6600 LOSS: 41.04510963553838\n",
      "EPOCH: 6601 LOSS: 41.04509921116646\n",
      "EPOCH: 6602 LOSS: 41.0450887886482\n",
      "EPOCH: 6603 LOSS: 41.04507836798305\n",
      "EPOCH: 6604 LOSS: 41.045067949170594\n",
      "EPOCH: 6605 LOSS: 41.04505753221029\n",
      "EPOCH: 6606 LOSS: 41.0450471171017\n",
      "EPOCH: 6607 LOSS: 41.0450367038443\n",
      "EPOCH: 6608 LOSS: 41.04502629243761\n",
      "EPOCH: 6609 LOSS: 41.045015882881145\n",
      "EPOCH: 6610 LOSS: 41.04500547517442\n",
      "EPOCH: 6611 LOSS: 41.044995069316954\n",
      "EPOCH: 6612 LOSS: 41.04498466530828\n",
      "EPOCH: 6613 LOSS: 41.044974263147864\n",
      "EPOCH: 6614 LOSS: 41.04496386283525\n",
      "EPOCH: 6615 LOSS: 41.04495346436997\n",
      "EPOCH: 6616 LOSS: 41.04494306775149\n",
      "EPOCH: 6617 LOSS: 41.044932672979385\n",
      "EPOCH: 6618 LOSS: 41.044922280053115\n",
      "EPOCH: 6619 LOSS: 41.04491188897222\n",
      "EPOCH: 6620 LOSS: 41.04490149973621\n",
      "EPOCH: 6621 LOSS: 41.044891112344615\n",
      "EPOCH: 6622 LOSS: 41.04488072679695\n",
      "EPOCH: 6623 LOSS: 41.044870343092704\n",
      "EPOCH: 6624 LOSS: 41.04485996123143\n",
      "EPOCH: 6625 LOSS: 41.04484958121261\n",
      "EPOCH: 6626 LOSS: 41.04483920303581\n",
      "EPOCH: 6627 LOSS: 41.044828826700495\n",
      "EPOCH: 6628 LOSS: 41.0448184522062\n",
      "EPOCH: 6629 LOSS: 41.04480807955244\n",
      "EPOCH: 6630 LOSS: 41.04479770873874\n",
      "EPOCH: 6631 LOSS: 41.044787339764625\n",
      "EPOCH: 6632 LOSS: 41.04477697262959\n",
      "EPOCH: 6633 LOSS: 41.04476660733318\n",
      "EPOCH: 6634 LOSS: 41.0447562438749\n",
      "EPOCH: 6635 LOSS: 41.044745882254276\n",
      "EPOCH: 6636 LOSS: 41.044735522470795\n",
      "EPOCH: 6637 LOSS: 41.04472516452401\n",
      "EPOCH: 6638 LOSS: 41.04471480841344\n",
      "EPOCH: 6639 LOSS: 41.04470445413859\n",
      "EPOCH: 6640 LOSS: 41.044694101698994\n",
      "EPOCH: 6641 LOSS: 41.04468375109415\n",
      "EPOCH: 6642 LOSS: 41.044673402323596\n",
      "EPOCH: 6643 LOSS: 41.04466305538685\n",
      "EPOCH: 6644 LOSS: 41.044652710283415\n",
      "EPOCH: 6645 LOSS: 41.04464236701284\n",
      "EPOCH: 6646 LOSS: 41.044632025574636\n",
      "EPOCH: 6647 LOSS: 41.0446216859683\n",
      "EPOCH: 6648 LOSS: 41.04461134819339\n",
      "EPOCH: 6649 LOSS: 41.0446010122494\n",
      "EPOCH: 6650 LOSS: 41.044590678135876\n",
      "EPOCH: 6651 LOSS: 41.044580345852324\n",
      "EPOCH: 6652 LOSS: 41.04457001539824\n",
      "EPOCH: 6653 LOSS: 41.0445596867732\n",
      "EPOCH: 6654 LOSS: 41.044549359976685\n",
      "EPOCH: 6655 LOSS: 41.04453903500824\n",
      "EPOCH: 6656 LOSS: 41.04452871186737\n",
      "EPOCH: 6657 LOSS: 41.04451839055362\n",
      "EPOCH: 6658 LOSS: 41.0445080710665\n",
      "EPOCH: 6659 LOSS: 41.044497753405544\n",
      "EPOCH: 6660 LOSS: 41.044487437570254\n",
      "EPOCH: 6661 LOSS: 41.044477123560156\n",
      "EPOCH: 6662 LOSS: 41.0444668113748\n",
      "EPOCH: 6663 LOSS: 41.044456501013684\n",
      "EPOCH: 6664 LOSS: 41.04444619247634\n",
      "EPOCH: 6665 LOSS: 41.0444358857623\n",
      "EPOCH: 6666 LOSS: 41.04442558087107\n",
      "EPOCH: 6667 LOSS: 41.044415277802194\n",
      "EPOCH: 6668 LOSS: 41.04440497655519\n",
      "EPOCH: 6669 LOSS: 41.04439467712959\n",
      "EPOCH: 6670 LOSS: 41.044384379524914\n",
      "EPOCH: 6671 LOSS: 41.044374083740664\n",
      "EPOCH: 6672 LOSS: 41.04436378977642\n",
      "EPOCH: 6673 LOSS: 41.04435349763165\n",
      "EPOCH: 6674 LOSS: 41.04434320730593\n",
      "EPOCH: 6675 LOSS: 41.04433291879874\n",
      "EPOCH: 6676 LOSS: 41.044322632109626\n",
      "EPOCH: 6677 LOSS: 41.04431234723815\n",
      "EPOCH: 6678 LOSS: 41.044302064183775\n",
      "EPOCH: 6679 LOSS: 41.04429178294606\n",
      "EPOCH: 6680 LOSS: 41.04428150352455\n",
      "EPOCH: 6681 LOSS: 41.04427122591875\n",
      "EPOCH: 6682 LOSS: 41.04426095012819\n",
      "EPOCH: 6683 LOSS: 41.044250676152394\n",
      "EPOCH: 6684 LOSS: 41.04424040399089\n",
      "EPOCH: 6685 LOSS: 41.044230133643225\n",
      "EPOCH: 6686 LOSS: 41.044219865108914\n",
      "EPOCH: 6687 LOSS: 41.04420959838748\n",
      "EPOCH: 6688 LOSS: 41.04419933347846\n",
      "EPOCH: 6689 LOSS: 41.04418907038138\n",
      "EPOCH: 6690 LOSS: 41.044178809095776\n",
      "EPOCH: 6691 LOSS: 41.04416854962116\n",
      "EPOCH: 6692 LOSS: 41.044158291957075\n",
      "EPOCH: 6693 LOSS: 41.04414803610305\n",
      "EPOCH: 6694 LOSS: 41.044137782058606\n",
      "EPOCH: 6695 LOSS: 41.0441275298233\n",
      "EPOCH: 6696 LOSS: 41.04411727939662\n",
      "EPOCH: 6697 LOSS: 41.04410703077814\n",
      "EPOCH: 6698 LOSS: 41.044096783967355\n",
      "EPOCH: 6699 LOSS: 41.044086538963825\n",
      "EPOCH: 6700 LOSS: 41.044076295767056\n",
      "EPOCH: 6701 LOSS: 41.04406605437659\n",
      "EPOCH: 6702 LOSS: 41.04405581479195\n",
      "EPOCH: 6703 LOSS: 41.0440455770127\n",
      "EPOCH: 6704 LOSS: 41.044035341038324\n",
      "EPOCH: 6705 LOSS: 41.0440251068684\n",
      "EPOCH: 6706 LOSS: 41.04401487450241\n",
      "EPOCH: 6707 LOSS: 41.04400464393993\n",
      "EPOCH: 6708 LOSS: 41.04399441518048\n",
      "EPOCH: 6709 LOSS: 41.043984188223575\n",
      "EPOCH: 6710 LOSS: 41.043973963068765\n",
      "EPOCH: 6711 LOSS: 41.04396373971559\n",
      "EPOCH: 6712 LOSS: 41.043953518163576\n",
      "EPOCH: 6713 LOSS: 41.04394329841225\n",
      "EPOCH: 6714 LOSS: 41.04393308046116\n",
      "EPOCH: 6715 LOSS: 41.04392286430979\n",
      "EPOCH: 6716 LOSS: 41.043912649957754\n",
      "EPOCH: 6717 LOSS: 41.043902437404526\n",
      "EPOCH: 6718 LOSS: 41.04389222664966\n",
      "EPOCH: 6719 LOSS: 41.04388201769271\n",
      "EPOCH: 6720 LOSS: 41.04387181053316\n",
      "EPOCH: 6721 LOSS: 41.04386160517059\n",
      "EPOCH: 6722 LOSS: 41.04385140160453\n",
      "EPOCH: 6723 LOSS: 41.0438411998345\n",
      "EPOCH: 6724 LOSS: 41.04383099986005\n",
      "EPOCH: 6725 LOSS: 41.04382080168069\n",
      "EPOCH: 6726 LOSS: 41.043810605295974\n",
      "EPOCH: 6727 LOSS: 41.04380041070546\n",
      "EPOCH: 6728 LOSS: 41.04379021790864\n",
      "EPOCH: 6729 LOSS: 41.043780026905075\n",
      "EPOCH: 6730 LOSS: 41.04376983769431\n",
      "EPOCH: 6731 LOSS: 41.04375965027586\n",
      "EPOCH: 6732 LOSS: 41.04374946464927\n",
      "EPOCH: 6733 LOSS: 41.043739280814094\n",
      "EPOCH: 6734 LOSS: 41.04372909876984\n",
      "EPOCH: 6735 LOSS: 41.04371891851606\n",
      "EPOCH: 6736 LOSS: 41.04370874005231\n",
      "EPOCH: 6737 LOSS: 41.043698563378086\n",
      "EPOCH: 6738 LOSS: 41.04368838849295\n",
      "EPOCH: 6739 LOSS: 41.04367821539647\n",
      "EPOCH: 6740 LOSS: 41.04366804408813\n",
      "EPOCH: 6741 LOSS: 41.04365787456751\n",
      "EPOCH: 6742 LOSS: 41.04364770683411\n",
      "EPOCH: 6743 LOSS: 41.0436375408875\n",
      "EPOCH: 6744 LOSS: 41.04362737672721\n",
      "EPOCH: 6745 LOSS: 41.04361721435278\n",
      "EPOCH: 6746 LOSS: 41.04360705376376\n",
      "EPOCH: 6747 LOSS: 41.04359689495966\n",
      "EPOCH: 6748 LOSS: 41.04358673794003\n",
      "EPOCH: 6749 LOSS: 41.043576582704446\n",
      "EPOCH: 6750 LOSS: 41.043566429252394\n",
      "EPOCH: 6751 LOSS: 41.043556277583455\n",
      "EPOCH: 6752 LOSS: 41.04354612769715\n",
      "EPOCH: 6753 LOSS: 41.04353597959304\n",
      "EPOCH: 6754 LOSS: 41.043525833270635\n",
      "EPOCH: 6755 LOSS: 41.043515688729485\n",
      "EPOCH: 6756 LOSS: 41.04350554596917\n",
      "EPOCH: 6757 LOSS: 41.043495404989166\n",
      "EPOCH: 6758 LOSS: 41.043485265789066\n",
      "EPOCH: 6759 LOSS: 41.0434751283684\n",
      "EPOCH: 6760 LOSS: 41.04346499272669\n",
      "EPOCH: 6761 LOSS: 41.0434548588635\n",
      "EPOCH: 6762 LOSS: 41.043444726778354\n",
      "EPOCH: 6763 LOSS: 41.04343459647082\n",
      "EPOCH: 6764 LOSS: 41.043424467940426\n",
      "EPOCH: 6765 LOSS: 41.04341434118672\n",
      "EPOCH: 6766 LOSS: 41.04340421620924\n",
      "EPOCH: 6767 LOSS: 41.04339409300751\n",
      "EPOCH: 6768 LOSS: 41.04338397158111\n",
      "EPOCH: 6769 LOSS: 41.04337385192955\n",
      "EPOCH: 6770 LOSS: 41.043363734052406\n",
      "EPOCH: 6771 LOSS: 41.043353617949215\n",
      "EPOCH: 6772 LOSS: 41.04334350361948\n",
      "EPOCH: 6773 LOSS: 41.04333339106282\n",
      "EPOCH: 6774 LOSS: 41.043323280278706\n",
      "EPOCH: 6775 LOSS: 41.043313171266725\n",
      "EPOCH: 6776 LOSS: 41.043303064026404\n",
      "EPOCH: 6777 LOSS: 41.04329295855731\n",
      "EPOCH: 6778 LOSS: 41.043282854858965\n",
      "EPOCH: 6779 LOSS: 41.043272752930925\n",
      "EPOCH: 6780 LOSS: 41.04326265277274\n",
      "EPOCH: 6781 LOSS: 41.04325255438394\n",
      "EPOCH: 6782 LOSS: 41.043242457764094\n",
      "EPOCH: 6783 LOSS: 41.043232362912704\n",
      "EPOCH: 6784 LOSS: 41.04322226982937\n",
      "EPOCH: 6785 LOSS: 41.04321217851361\n",
      "EPOCH: 6786 LOSS: 41.04320208896499\n",
      "EPOCH: 6787 LOSS: 41.04319200118302\n",
      "EPOCH: 6788 LOSS: 41.04318191516728\n",
      "EPOCH: 6789 LOSS: 41.0431718309173\n",
      "EPOCH: 6790 LOSS: 41.04316174843264\n",
      "EPOCH: 6791 LOSS: 41.043151667712856\n",
      "EPOCH: 6792 LOSS: 41.04314158875746\n",
      "EPOCH: 6793 LOSS: 41.04313151156603\n",
      "EPOCH: 6794 LOSS: 41.04312143613811\n",
      "EPOCH: 6795 LOSS: 41.043111362473255\n",
      "EPOCH: 6796 LOSS: 41.04310129057098\n",
      "EPOCH: 6797 LOSS: 41.04309122043086\n",
      "EPOCH: 6798 LOSS: 41.04308115205245\n",
      "EPOCH: 6799 LOSS: 41.04307108543529\n",
      "EPOCH: 6800 LOSS: 41.043061020578904\n",
      "EPOCH: 6801 LOSS: 41.04305095748289\n",
      "EPOCH: 6802 LOSS: 41.04304089614676\n",
      "EPOCH: 6803 LOSS: 41.04303083657008\n",
      "EPOCH: 6804 LOSS: 41.0430207787524\n",
      "EPOCH: 6805 LOSS: 41.04301072269326\n",
      "EPOCH: 6806 LOSS: 41.043000668392224\n",
      "EPOCH: 6807 LOSS: 41.04299061584884\n",
      "EPOCH: 6808 LOSS: 41.042980565062635\n",
      "EPOCH: 6809 LOSS: 41.042970516033165\n",
      "EPOCH: 6810 LOSS: 41.04296046876004\n",
      "EPOCH: 6811 LOSS: 41.04295042324274\n",
      "EPOCH: 6812 LOSS: 41.04294037948084\n",
      "EPOCH: 6813 LOSS: 41.04293033747388\n",
      "EPOCH: 6814 LOSS: 41.04292029722144\n",
      "EPOCH: 6815 LOSS: 41.04291025872306\n",
      "EPOCH: 6816 LOSS: 41.042900221978286\n",
      "EPOCH: 6817 LOSS: 41.04289018698667\n",
      "EPOCH: 6818 LOSS: 41.04288015374777\n",
      "EPOCH: 6819 LOSS: 41.04287012226112\n",
      "EPOCH: 6820 LOSS: 41.042860092526304\n",
      "EPOCH: 6821 LOSS: 41.042850064542854\n",
      "EPOCH: 6822 LOSS: 41.042840038310324\n",
      "EPOCH: 6823 LOSS: 41.042830013828265\n",
      "EPOCH: 6824 LOSS: 41.04281999109625\n",
      "EPOCH: 6825 LOSS: 41.04280997011381\n",
      "EPOCH: 6826 LOSS: 41.04279995088049\n",
      "EPOCH: 6827 LOSS: 41.04278993339589\n",
      "EPOCH: 6828 LOSS: 41.04277991765952\n",
      "EPOCH: 6829 LOSS: 41.042769903670944\n",
      "EPOCH: 6830 LOSS: 41.04275989142973\n",
      "EPOCH: 6831 LOSS: 41.042749880935425\n",
      "EPOCH: 6832 LOSS: 41.04273987218758\n",
      "EPOCH: 6833 LOSS: 41.042729865185756\n",
      "EPOCH: 6834 LOSS: 41.04271985992949\n",
      "EPOCH: 6835 LOSS: 41.04270985641837\n",
      "EPOCH: 6836 LOSS: 41.04269985465193\n",
      "EPOCH: 6837 LOSS: 41.0426898546297\n",
      "EPOCH: 6838 LOSS: 41.042679856351306\n",
      "EPOCH: 6839 LOSS: 41.04266985981623\n",
      "EPOCH: 6840 LOSS: 41.04265986502409\n",
      "EPOCH: 6841 LOSS: 41.04264987197439\n",
      "EPOCH: 6842 LOSS: 41.04263988066671\n",
      "EPOCH: 6843 LOSS: 41.04262989110063\n",
      "EPOCH: 6844 LOSS: 41.04261990327565\n",
      "EPOCH: 6845 LOSS: 41.04260991719138\n",
      "EPOCH: 6846 LOSS: 41.04259993284735\n",
      "EPOCH: 6847 LOSS: 41.04258995024311\n",
      "EPOCH: 6848 LOSS: 41.04257996937826\n",
      "EPOCH: 6849 LOSS: 41.04256999025231\n",
      "EPOCH: 6850 LOSS: 41.04256001286484\n",
      "EPOCH: 6851 LOSS: 41.0425500372154\n",
      "EPOCH: 6852 LOSS: 41.04254006330355\n",
      "EPOCH: 6853 LOSS: 41.04253009112887\n",
      "EPOCH: 6854 LOSS: 41.04252012069088\n",
      "EPOCH: 6855 LOSS: 41.04251015198918\n",
      "EPOCH: 6856 LOSS: 41.042500185023286\n",
      "EPOCH: 6857 LOSS: 41.04249021979279\n",
      "EPOCH: 6858 LOSS: 41.04248025629724\n",
      "EPOCH: 6859 LOSS: 41.04247029453618\n",
      "EPOCH: 6860 LOSS: 41.04246033450919\n",
      "EPOCH: 6861 LOSS: 41.042450376215825\n",
      "EPOCH: 6862 LOSS: 41.042440419655655\n",
      "EPOCH: 6863 LOSS: 41.0424304648282\n",
      "EPOCH: 6864 LOSS: 41.042420511733084\n",
      "EPOCH: 6865 LOSS: 41.042410560369795\n",
      "EPOCH: 6866 LOSS: 41.04240061073797\n",
      "EPOCH: 6867 LOSS: 41.04239066283711\n",
      "EPOCH: 6868 LOSS: 41.04238071666679\n",
      "EPOCH: 6869 LOSS: 41.04237077222658\n",
      "EPOCH: 6870 LOSS: 41.042360829516035\n",
      "EPOCH: 6871 LOSS: 41.04235088853471\n",
      "EPOCH: 6872 LOSS: 41.04234094928222\n",
      "EPOCH: 6873 LOSS: 41.04233101175804\n",
      "EPOCH: 6874 LOSS: 41.04232107596179\n",
      "EPOCH: 6875 LOSS: 41.04231114189301\n",
      "EPOCH: 6876 LOSS: 41.042301209551276\n",
      "EPOCH: 6877 LOSS: 41.04229127893615\n",
      "EPOCH: 6878 LOSS: 41.042281350047176\n",
      "EPOCH: 6879 LOSS: 41.04227142288394\n",
      "EPOCH: 6880 LOSS: 41.04226149744596\n",
      "EPOCH: 6881 LOSS: 41.04225157373286\n",
      "EPOCH: 6882 LOSS: 41.042241651744185\n",
      "EPOCH: 6883 LOSS: 41.04223173147947\n",
      "EPOCH: 6884 LOSS: 41.042221812938294\n",
      "EPOCH: 6885 LOSS: 41.042211896120236\n",
      "EPOCH: 6886 LOSS: 41.04220198102484\n",
      "EPOCH: 6887 LOSS: 41.04219206765169\n",
      "EPOCH: 6888 LOSS: 41.04218215600033\n",
      "EPOCH: 6889 LOSS: 41.04217224607034\n",
      "EPOCH: 6890 LOSS: 41.04216233786126\n",
      "EPOCH: 6891 LOSS: 41.04215243137269\n",
      "EPOCH: 6892 LOSS: 41.04214252660417\n",
      "EPOCH: 6893 LOSS: 41.04213262355527\n",
      "EPOCH: 6894 LOSS: 41.042122722225564\n",
      "EPOCH: 6895 LOSS: 41.04211282261459\n",
      "EPOCH: 6896 LOSS: 41.042102924721945\n",
      "EPOCH: 6897 LOSS: 41.0420930285472\n",
      "EPOCH: 6898 LOSS: 41.04208313408988\n",
      "EPOCH: 6899 LOSS: 41.042073241349584\n",
      "EPOCH: 6900 LOSS: 41.042063350325876\n",
      "EPOCH: 6901 LOSS: 41.04205346101831\n",
      "EPOCH: 6902 LOSS: 41.04204357342647\n",
      "EPOCH: 6903 LOSS: 41.04203368754989\n",
      "EPOCH: 6904 LOSS: 41.04202380338817\n",
      "EPOCH: 6905 LOSS: 41.04201392094086\n",
      "EPOCH: 6906 LOSS: 41.042004040207544\n",
      "EPOCH: 6907 LOSS: 41.04199416118777\n",
      "EPOCH: 6908 LOSS: 41.04198428388111\n",
      "EPOCH: 6909 LOSS: 41.04197440828714\n",
      "EPOCH: 6910 LOSS: 41.04196453440541\n",
      "EPOCH: 6911 LOSS: 41.041954662235504\n",
      "EPOCH: 6912 LOSS: 41.041944791777006\n",
      "EPOCH: 6913 LOSS: 41.041934923029444\n",
      "EPOCH: 6914 LOSS: 41.04192505599241\n",
      "EPOCH: 6915 LOSS: 41.04191519066549\n",
      "EPOCH: 6916 LOSS: 41.04190532704821\n",
      "EPOCH: 6917 LOSS: 41.04189546514017\n",
      "EPOCH: 6918 LOSS: 41.04188560494094\n",
      "EPOCH: 6919 LOSS: 41.041875746450074\n",
      "EPOCH: 6920 LOSS: 41.04186588966715\n",
      "EPOCH: 6921 LOSS: 41.04185603459172\n",
      "EPOCH: 6922 LOSS: 41.041846181223384\n",
      "EPOCH: 6923 LOSS: 41.041836329561704\n",
      "EPOCH: 6924 LOSS: 41.04182647960623\n",
      "EPOCH: 6925 LOSS: 41.04181663135656\n",
      "EPOCH: 6926 LOSS: 41.04180678481224\n",
      "EPOCH: 6927 LOSS: 41.041796939972855\n",
      "EPOCH: 6928 LOSS: 41.04178709683797\n",
      "EPOCH: 6929 LOSS: 41.041777255407155\n",
      "EPOCH: 6930 LOSS: 41.041767415679985\n",
      "EPOCH: 6931 LOSS: 41.04175757765603\n",
      "EPOCH: 6932 LOSS: 41.041747741334866\n",
      "EPOCH: 6933 LOSS: 41.041737906716065\n",
      "EPOCH: 6934 LOSS: 41.04172807379918\n",
      "EPOCH: 6935 LOSS: 41.0417182425838\n",
      "EPOCH: 6936 LOSS: 41.041708413069514\n",
      "EPOCH: 6937 LOSS: 41.04169858525585\n",
      "EPOCH: 6938 LOSS: 41.041688759142424\n",
      "EPOCH: 6939 LOSS: 41.041678934728765\n",
      "EPOCH: 6940 LOSS: 41.041669112014475\n",
      "EPOCH: 6941 LOSS: 41.041659290999135\n",
      "EPOCH: 6942 LOSS: 41.0416494716823\n",
      "EPOCH: 6943 LOSS: 41.04163965406355\n",
      "EPOCH: 6944 LOSS: 41.041629838142455\n",
      "EPOCH: 6945 LOSS: 41.0416200239186\n",
      "EPOCH: 6946 LOSS: 41.04161021139153\n",
      "EPOCH: 6947 LOSS: 41.04160040056086\n",
      "EPOCH: 6948 LOSS: 41.04159059142612\n",
      "EPOCH: 6949 LOSS: 41.0415807839869\n",
      "EPOCH: 6950 LOSS: 41.0415709782428\n",
      "EPOCH: 6951 LOSS: 41.04156117419337\n",
      "EPOCH: 6952 LOSS: 41.041551371838196\n",
      "EPOCH: 6953 LOSS: 41.04154157117684\n",
      "EPOCH: 6954 LOSS: 41.04153177220889\n",
      "EPOCH: 6955 LOSS: 41.0415219749339\n",
      "EPOCH: 6956 LOSS: 41.041512179351464\n",
      "EPOCH: 6957 LOSS: 41.04150238546117\n",
      "EPOCH: 6958 LOSS: 41.04149259326255\n",
      "EPOCH: 6959 LOSS: 41.041482802755226\n",
      "EPOCH: 6960 LOSS: 41.04147301393874\n",
      "EPOCH: 6961 LOSS: 41.041463226812695\n",
      "EPOCH: 6962 LOSS: 41.041453441376646\n",
      "EPOCH: 6963 LOSS: 41.041443657630204\n",
      "EPOCH: 6964 LOSS: 41.04143387557289\n",
      "EPOCH: 6965 LOSS: 41.04142409520432\n",
      "EPOCH: 6966 LOSS: 41.04141431652407\n",
      "EPOCH: 6967 LOSS: 41.041404539531705\n",
      "EPOCH: 6968 LOSS: 41.0413947642268\n",
      "EPOCH: 6969 LOSS: 41.04138499060895\n",
      "EPOCH: 6970 LOSS: 41.041375218677715\n",
      "EPOCH: 6971 LOSS: 41.04136544843267\n",
      "EPOCH: 6972 LOSS: 41.041355679873405\n",
      "EPOCH: 6973 LOSS: 41.041345912999496\n",
      "EPOCH: 6974 LOSS: 41.041336147810526\n",
      "EPOCH: 6975 LOSS: 41.04132638430606\n",
      "EPOCH: 6976 LOSS: 41.041316622485695\n",
      "EPOCH: 6977 LOSS: 41.041306862349\n",
      "EPOCH: 6978 LOSS: 41.04129710389553\n",
      "EPOCH: 6979 LOSS: 41.04128734712491\n",
      "EPOCH: 6980 LOSS: 41.04127759203668\n",
      "EPOCH: 6981 LOSS: 41.04126783863044\n",
      "EPOCH: 6982 LOSS: 41.041258086905756\n",
      "EPOCH: 6983 LOSS: 41.041248336862225\n",
      "EPOCH: 6984 LOSS: 41.041238588499425\n",
      "EPOCH: 6985 LOSS: 41.04122884181692\n",
      "EPOCH: 6986 LOSS: 41.04121909681429\n",
      "EPOCH: 6987 LOSS: 41.04120935349114\n",
      "EPOCH: 6988 LOSS: 41.041199611847006\n",
      "EPOCH: 6989 LOSS: 41.04118987188153\n",
      "EPOCH: 6990 LOSS: 41.04118013359424\n",
      "EPOCH: 6991 LOSS: 41.04117039698474\n",
      "EPOCH: 6992 LOSS: 41.041160662052604\n",
      "EPOCH: 6993 LOSS: 41.04115092879742\n",
      "EPOCH: 6994 LOSS: 41.04114119721877\n",
      "EPOCH: 6995 LOSS: 41.041131467316234\n",
      "EPOCH: 6996 LOSS: 41.04112173908938\n",
      "EPOCH: 6997 LOSS: 41.041112012537795\n",
      "EPOCH: 6998 LOSS: 41.04110228766108\n",
      "EPOCH: 6999 LOSS: 41.04109256445881\n",
      "EPOCH: 7000 LOSS: 41.04108284293055\n",
      "EPOCH: 7001 LOSS: 41.0410731230759\n",
      "EPOCH: 7002 LOSS: 41.04106340489443\n",
      "EPOCH: 7003 LOSS: 41.04105368838572\n",
      "EPOCH: 7004 LOSS: 41.04104397354939\n",
      "EPOCH: 7005 LOSS: 41.04103426038496\n",
      "EPOCH: 7006 LOSS: 41.04102454889208\n",
      "EPOCH: 7007 LOSS: 41.04101483907027\n",
      "EPOCH: 7008 LOSS: 41.041005130919174\n",
      "EPOCH: 7009 LOSS: 41.04099542443834\n",
      "EPOCH: 7010 LOSS: 41.04098571962734\n",
      "EPOCH: 7011 LOSS: 41.0409760164858\n",
      "EPOCH: 7012 LOSS: 41.040966315013264\n",
      "EPOCH: 7013 LOSS: 41.04095661520934\n",
      "EPOCH: 7014 LOSS: 41.0409469170736\n",
      "EPOCH: 7015 LOSS: 41.04093722060565\n",
      "EPOCH: 7016 LOSS: 41.04092752580503\n",
      "EPOCH: 7017 LOSS: 41.04091783267138\n",
      "EPOCH: 7018 LOSS: 41.040908141204255\n",
      "EPOCH: 7019 LOSS: 41.04089845140324\n",
      "EPOCH: 7020 LOSS: 41.04088876326792\n",
      "EPOCH: 7021 LOSS: 41.04087907679788\n",
      "EPOCH: 7022 LOSS: 41.04086939199273\n",
      "EPOCH: 7023 LOSS: 41.04085970885203\n",
      "EPOCH: 7024 LOSS: 41.04085002737537\n",
      "EPOCH: 7025 LOSS: 41.04084034756233\n",
      "EPOCH: 7026 LOSS: 41.040830669412514\n",
      "EPOCH: 7027 LOSS: 41.040820992925504\n",
      "EPOCH: 7028 LOSS: 41.040811318100864\n",
      "EPOCH: 7029 LOSS: 41.040801644938206\n",
      "EPOCH: 7030 LOSS: 41.04079197343711\n",
      "EPOCH: 7031 LOSS: 41.04078230359718\n",
      "EPOCH: 7032 LOSS: 41.04077263541797\n",
      "EPOCH: 7033 LOSS: 41.04076296889908\n",
      "EPOCH: 7034 LOSS: 41.04075330404011\n",
      "EPOCH: 7035 LOSS: 41.04074364084063\n",
      "EPOCH: 7036 LOSS: 41.040733979300256\n",
      "EPOCH: 7037 LOSS: 41.04072431941853\n",
      "EPOCH: 7038 LOSS: 41.04071466119508\n",
      "EPOCH: 7039 LOSS: 41.04070500462949\n",
      "EPOCH: 7040 LOSS: 41.04069534972133\n",
      "EPOCH: 7041 LOSS: 41.040685696470206\n",
      "EPOCH: 7042 LOSS: 41.04067604487568\n",
      "EPOCH: 7043 LOSS: 41.04066639493737\n",
      "EPOCH: 7044 LOSS: 41.04065674665486\n",
      "EPOCH: 7045 LOSS: 41.04064710002773\n",
      "EPOCH: 7046 LOSS: 41.04063745505556\n",
      "EPOCH: 7047 LOSS: 41.04062781173798\n",
      "EPOCH: 7048 LOSS: 41.04061817007454\n",
      "EPOCH: 7049 LOSS: 41.04060853006484\n",
      "EPOCH: 7050 LOSS: 41.04059889170848\n",
      "EPOCH: 7051 LOSS: 41.04058925500503\n",
      "EPOCH: 7052 LOSS: 41.0405796199541\n",
      "EPOCH: 7053 LOSS: 41.04056998655528\n",
      "EPOCH: 7054 LOSS: 41.04056035480815\n",
      "EPOCH: 7055 LOSS: 41.04055072471229\n",
      "EPOCH: 7056 LOSS: 41.040541096267326\n",
      "EPOCH: 7057 LOSS: 41.04053146947282\n",
      "EPOCH: 7058 LOSS: 41.04052184432837\n",
      "EPOCH: 7059 LOSS: 41.04051222083358\n",
      "EPOCH: 7060 LOSS: 41.04050259898801\n",
      "EPOCH: 7061 LOSS: 41.04049297879129\n",
      "EPOCH: 7062 LOSS: 41.04048336024298\n",
      "EPOCH: 7063 LOSS: 41.04047374334269\n",
      "EPOCH: 7064 LOSS: 41.04046412809002\n",
      "EPOCH: 7065 LOSS: 41.04045451448455\n",
      "EPOCH: 7066 LOSS: 41.04044490252586\n",
      "EPOCH: 7067 LOSS: 41.04043529221356\n",
      "EPOCH: 7068 LOSS: 41.040425683547234\n",
      "EPOCH: 7069 LOSS: 41.04041607652649\n",
      "EPOCH: 7070 LOSS: 41.040406471150895\n",
      "EPOCH: 7071 LOSS: 41.04039686742007\n",
      "EPOCH: 7072 LOSS: 41.04038726533359\n",
      "EPOCH: 7073 LOSS: 41.04037766489106\n",
      "EPOCH: 7074 LOSS: 41.040368066092064\n",
      "EPOCH: 7075 LOSS: 41.04035846893618\n",
      "EPOCH: 7076 LOSS: 41.04034887342304\n",
      "EPOCH: 7077 LOSS: 41.04033927955223\n",
      "EPOCH: 7078 LOSS: 41.04032968732333\n",
      "EPOCH: 7079 LOSS: 41.040320096735925\n",
      "EPOCH: 7080 LOSS: 41.04031050778963\n",
      "EPOCH: 7081 LOSS: 41.040300920484015\n",
      "EPOCH: 7082 LOSS: 41.04029133481872\n",
      "EPOCH: 7083 LOSS: 41.040281750793284\n",
      "EPOCH: 7084 LOSS: 41.04027216840734\n",
      "EPOCH: 7085 LOSS: 41.04026258766048\n",
      "EPOCH: 7086 LOSS: 41.04025300855228\n",
      "EPOCH: 7087 LOSS: 41.04024343108236\n",
      "EPOCH: 7088 LOSS: 41.04023385525029\n",
      "EPOCH: 7089 LOSS: 41.04022428105569\n",
      "EPOCH: 7090 LOSS: 41.04021470849814\n",
      "EPOCH: 7091 LOSS: 41.04020513757726\n",
      "EPOCH: 7092 LOSS: 41.0401955682926\n",
      "EPOCH: 7093 LOSS: 41.040186000643814\n",
      "EPOCH: 7094 LOSS: 41.040176434630446\n",
      "EPOCH: 7095 LOSS: 41.04016687025212\n",
      "EPOCH: 7096 LOSS: 41.04015730750844\n",
      "EPOCH: 7097 LOSS: 41.04014774639897\n",
      "EPOCH: 7098 LOSS: 41.04013818692334\n",
      "EPOCH: 7099 LOSS: 41.04012862908114\n",
      "EPOCH: 7100 LOSS: 41.04011907287196\n",
      "EPOCH: 7101 LOSS: 41.04010951829541\n",
      "EPOCH: 7102 LOSS: 41.04009996535106\n",
      "EPOCH: 7103 LOSS: 41.04009041403854\n",
      "EPOCH: 7104 LOSS: 41.040080864357435\n",
      "EPOCH: 7105 LOSS: 41.04007131630733\n",
      "EPOCH: 7106 LOSS: 41.040061769887856\n",
      "EPOCH: 7107 LOSS: 41.04005222509858\n",
      "EPOCH: 7108 LOSS: 41.04004268193911\n",
      "EPOCH: 7109 LOSS: 41.04003314040905\n",
      "EPOCH: 7110 LOSS: 41.04002360050799\n",
      "EPOCH: 7111 LOSS: 41.04001406223558\n",
      "EPOCH: 7112 LOSS: 41.04000452559131\n",
      "EPOCH: 7113 LOSS: 41.03999499057487\n",
      "EPOCH: 7114 LOSS: 41.039985457185836\n",
      "EPOCH: 7115 LOSS: 41.03997592542382\n",
      "EPOCH: 7116 LOSS: 41.03996639528839\n",
      "EPOCH: 7117 LOSS: 41.03995686677916\n",
      "EPOCH: 7118 LOSS: 41.03994733989573\n",
      "EPOCH: 7119 LOSS: 41.039937814637725\n",
      "EPOCH: 7120 LOSS: 41.03992829100471\n",
      "EPOCH: 7121 LOSS: 41.0399187689963\n",
      "EPOCH: 7122 LOSS: 41.03990924861209\n",
      "EPOCH: 7123 LOSS: 41.03989972985168\n",
      "EPOCH: 7124 LOSS: 41.039890212714695\n",
      "EPOCH: 7125 LOSS: 41.03988069720071\n",
      "EPOCH: 7126 LOSS: 41.039871183309344\n",
      "EPOCH: 7127 LOSS: 41.03986167104017\n",
      "EPOCH: 7128 LOSS: 41.03985216039282\n",
      "EPOCH: 7129 LOSS: 41.03984265136689\n",
      "EPOCH: 7130 LOSS: 41.03983314396196\n",
      "EPOCH: 7131 LOSS: 41.03982363817767\n",
      "EPOCH: 7132 LOSS: 41.03981413401358\n",
      "EPOCH: 7133 LOSS: 41.03980463146932\n",
      "EPOCH: 7134 LOSS: 41.03979513054448\n",
      "EPOCH: 7135 LOSS: 41.03978563123868\n",
      "EPOCH: 7136 LOSS: 41.0397761335515\n",
      "EPOCH: 7137 LOSS: 41.03976663748256\n",
      "EPOCH: 7138 LOSS: 41.03975714303144\n",
      "EPOCH: 7139 LOSS: 41.03974765019777\n",
      "EPOCH: 7140 LOSS: 41.039738158981145\n",
      "EPOCH: 7141 LOSS: 41.03972866938117\n",
      "EPOCH: 7142 LOSS: 41.03971918139743\n",
      "EPOCH: 7143 LOSS: 41.03970969502956\n",
      "EPOCH: 7144 LOSS: 41.03970021027713\n",
      "EPOCH: 7145 LOSS: 41.03969072713978\n",
      "EPOCH: 7146 LOSS: 41.03968124561708\n",
      "EPOCH: 7147 LOSS: 41.03967176570865\n",
      "EPOCH: 7148 LOSS: 41.0396622874141\n",
      "EPOCH: 7149 LOSS: 41.03965281073303\n",
      "EPOCH: 7150 LOSS: 41.03964333566503\n",
      "EPOCH: 7151 LOSS: 41.03963386220974\n",
      "EPOCH: 7152 LOSS: 41.03962439036674\n",
      "EPOCH: 7153 LOSS: 41.03961492013564\n",
      "EPOCH: 7154 LOSS: 41.03960545151604\n",
      "EPOCH: 7155 LOSS: 41.03959598450753\n",
      "EPOCH: 7156 LOSS: 41.03958651910976\n",
      "EPOCH: 7157 LOSS: 41.03957705532231\n",
      "EPOCH: 7158 LOSS: 41.03956759314477\n",
      "EPOCH: 7159 LOSS: 41.039558132576786\n",
      "EPOCH: 7160 LOSS: 41.03954867361794\n",
      "EPOCH: 7161 LOSS: 41.039539216267805\n",
      "EPOCH: 7162 LOSS: 41.03952976052605\n",
      "EPOCH: 7163 LOSS: 41.03952030639225\n",
      "EPOCH: 7164 LOSS: 41.03951085386602\n",
      "EPOCH: 7165 LOSS: 41.039501402946954\n",
      "EPOCH: 7166 LOSS: 41.039491953634666\n",
      "EPOCH: 7167 LOSS: 41.039482505928774\n",
      "EPOCH: 7168 LOSS: 41.03947305982887\n",
      "EPOCH: 7169 LOSS: 41.03946361533456\n",
      "EPOCH: 7170 LOSS: 41.039454172445474\n",
      "EPOCH: 7171 LOSS: 41.03944473116118\n",
      "EPOCH: 7172 LOSS: 41.03943529148134\n",
      "EPOCH: 7173 LOSS: 41.039425853405504\n",
      "EPOCH: 7174 LOSS: 41.03941641693333\n",
      "EPOCH: 7175 LOSS: 41.0394069820644\n",
      "EPOCH: 7176 LOSS: 41.03939754879833\n",
      "EPOCH: 7177 LOSS: 41.03938811713472\n",
      "EPOCH: 7178 LOSS: 41.03937868707318\n",
      "EPOCH: 7179 LOSS: 41.039369258613334\n",
      "EPOCH: 7180 LOSS: 41.03935983175477\n",
      "EPOCH: 7181 LOSS: 41.03935040649712\n",
      "EPOCH: 7182 LOSS: 41.03934098283998\n",
      "EPOCH: 7183 LOSS: 41.039331560782955\n",
      "EPOCH: 7184 LOSS: 41.039322140325666\n",
      "EPOCH: 7185 LOSS: 41.03931272146771\n",
      "EPOCH: 7186 LOSS: 41.03930330420871\n",
      "EPOCH: 7187 LOSS: 41.03929388854826\n",
      "EPOCH: 7188 LOSS: 41.039284474485996\n",
      "EPOCH: 7189 LOSS: 41.03927506202151\n",
      "EPOCH: 7190 LOSS: 41.0392656511544\n",
      "EPOCH: 7191 LOSS: 41.0392562418843\n",
      "EPOCH: 7192 LOSS: 41.039246834210815\n",
      "EPOCH: 7193 LOSS: 41.039237428133546\n",
      "EPOCH: 7194 LOSS: 41.039228023652115\n",
      "EPOCH: 7195 LOSS: 41.039218620766135\n",
      "EPOCH: 7196 LOSS: 41.03920921947519\n",
      "EPOCH: 7197 LOSS: 41.039199819778936\n",
      "EPOCH: 7198 LOSS: 41.03919042167696\n",
      "EPOCH: 7199 LOSS: 41.03918102516886\n",
      "EPOCH: 7200 LOSS: 41.03917163025427\n",
      "EPOCH: 7201 LOSS: 41.03916223693281\n",
      "EPOCH: 7202 LOSS: 41.03915284520406\n",
      "EPOCH: 7203 LOSS: 41.039143455067645\n",
      "EPOCH: 7204 LOSS: 41.0391340665232\n",
      "EPOCH: 7205 LOSS: 41.0391246795703\n",
      "EPOCH: 7206 LOSS: 41.039115294208585\n",
      "EPOCH: 7207 LOSS: 41.03910591043767\n",
      "EPOCH: 7208 LOSS: 41.039096528257154\n",
      "EPOCH: 7209 LOSS: 41.03908714766664\n",
      "EPOCH: 7210 LOSS: 41.03907776866576\n",
      "EPOCH: 7211 LOSS: 41.039068391254126\n",
      "EPOCH: 7212 LOSS: 41.03905901543135\n",
      "EPOCH: 7213 LOSS: 41.03904964119703\n",
      "EPOCH: 7214 LOSS: 41.03904026855081\n",
      "EPOCH: 7215 LOSS: 41.03903089749228\n",
      "EPOCH: 7216 LOSS: 41.03902152802105\n",
      "EPOCH: 7217 LOSS: 41.03901216013677\n",
      "EPOCH: 7218 LOSS: 41.03900279383902\n",
      "EPOCH: 7219 LOSS: 41.03899342912743\n",
      "EPOCH: 7220 LOSS: 41.03898406600159\n",
      "EPOCH: 7221 LOSS: 41.038974704461154\n",
      "EPOCH: 7222 LOSS: 41.03896534450571\n",
      "EPOCH: 7223 LOSS: 41.03895598613488\n",
      "EPOCH: 7224 LOSS: 41.03894662934827\n",
      "EPOCH: 7225 LOSS: 41.03893727414551\n",
      "EPOCH: 7226 LOSS: 41.038927920526206\n",
      "EPOCH: 7227 LOSS: 41.038918568489976\n",
      "EPOCH: 7228 LOSS: 41.038909218036444\n",
      "EPOCH: 7229 LOSS: 41.03889986916522\n",
      "EPOCH: 7230 LOSS: 41.03889052187591\n",
      "EPOCH: 7231 LOSS: 41.03888117616816\n",
      "EPOCH: 7232 LOSS: 41.03887183204155\n",
      "EPOCH: 7233 LOSS: 41.0388624894957\n",
      "EPOCH: 7234 LOSS: 41.03885314853026\n",
      "EPOCH: 7235 LOSS: 41.038843809144815\n",
      "EPOCH: 7236 LOSS: 41.03883447133899\n",
      "EPOCH: 7237 LOSS: 41.038825135112404\n",
      "EPOCH: 7238 LOSS: 41.03881580046467\n",
      "EPOCH: 7239 LOSS: 41.03880646739542\n",
      "EPOCH: 7240 LOSS: 41.03879713590426\n",
      "EPOCH: 7241 LOSS: 41.03878780599079\n",
      "EPOCH: 7242 LOSS: 41.03877847765465\n",
      "EPOCH: 7243 LOSS: 41.038769150895476\n",
      "EPOCH: 7244 LOSS: 41.038759825712845\n",
      "EPOCH: 7245 LOSS: 41.03875050210638\n",
      "EPOCH: 7246 LOSS: 41.038741180075746\n",
      "EPOCH: 7247 LOSS: 41.0387318596205\n",
      "EPOCH: 7248 LOSS: 41.038722540740295\n",
      "EPOCH: 7249 LOSS: 41.03871322343477\n",
      "EPOCH: 7250 LOSS: 41.03870390770348\n",
      "EPOCH: 7251 LOSS: 41.03869459354608\n",
      "EPOCH: 7252 LOSS: 41.038685280962206\n",
      "EPOCH: 7253 LOSS: 41.03867596995147\n",
      "EPOCH: 7254 LOSS: 41.03866666051346\n",
      "EPOCH: 7255 LOSS: 41.03865735264783\n",
      "EPOCH: 7256 LOSS: 41.03864804635419\n",
      "EPOCH: 7257 LOSS: 41.03863874163215\n",
      "EPOCH: 7258 LOSS: 41.03862943848134\n",
      "EPOCH: 7259 LOSS: 41.038620136901365\n",
      "EPOCH: 7260 LOSS: 41.03861083689186\n",
      "EPOCH: 7261 LOSS: 41.03860153845246\n",
      "EPOCH: 7262 LOSS: 41.038592241582734\n",
      "EPOCH: 7263 LOSS: 41.03858294628237\n",
      "EPOCH: 7264 LOSS: 41.03857365255094\n",
      "EPOCH: 7265 LOSS: 41.03856436038808\n",
      "EPOCH: 7266 LOSS: 41.0385550697934\n",
      "EPOCH: 7267 LOSS: 41.038545780766526\n",
      "EPOCH: 7268 LOSS: 41.038536493307106\n",
      "EPOCH: 7269 LOSS: 41.03852720741472\n",
      "EPOCH: 7270 LOSS: 41.03851792308903\n",
      "EPOCH: 7271 LOSS: 41.038508640329624\n",
      "EPOCH: 7272 LOSS: 41.03849935913613\n",
      "EPOCH: 7273 LOSS: 41.038490079508186\n",
      "EPOCH: 7274 LOSS: 41.0384808014454\n",
      "EPOCH: 7275 LOSS: 41.0384715249474\n",
      "EPOCH: 7276 LOSS: 41.03846225001381\n",
      "EPOCH: 7277 LOSS: 41.038452976644244\n",
      "EPOCH: 7278 LOSS: 41.038443704838315\n",
      "EPOCH: 7279 LOSS: 41.03843443459568\n",
      "EPOCH: 7280 LOSS: 41.03842516591594\n",
      "EPOCH: 7281 LOSS: 41.0384158987987\n",
      "EPOCH: 7282 LOSS: 41.038406633243625\n",
      "EPOCH: 7283 LOSS: 41.038397369250305\n",
      "EPOCH: 7284 LOSS: 41.03838810681839\n",
      "EPOCH: 7285 LOSS: 41.038378845947456\n",
      "EPOCH: 7286 LOSS: 41.03836958663718\n",
      "EPOCH: 7287 LOSS: 41.03836032888716\n",
      "EPOCH: 7288 LOSS: 41.038351072697026\n",
      "EPOCH: 7289 LOSS: 41.03834181806639\n",
      "EPOCH: 7290 LOSS: 41.0383325649949\n",
      "EPOCH: 7291 LOSS: 41.03832331348217\n",
      "EPOCH: 7292 LOSS: 41.0383140635278\n",
      "EPOCH: 7293 LOSS: 41.03830481513145\n",
      "EPOCH: 7294 LOSS: 41.038295568292725\n",
      "EPOCH: 7295 LOSS: 41.03828632301126\n",
      "EPOCH: 7296 LOSS: 41.038277079286644\n",
      "EPOCH: 7297 LOSS: 41.03826783711857\n",
      "EPOCH: 7298 LOSS: 41.038258596506616\n",
      "EPOCH: 7299 LOSS: 41.03824935745041\n",
      "EPOCH: 7300 LOSS: 41.03824011994959\n",
      "EPOCH: 7301 LOSS: 41.03823088400377\n",
      "EPOCH: 7302 LOSS: 41.03822164961258\n",
      "EPOCH: 7303 LOSS: 41.03821241677566\n",
      "EPOCH: 7304 LOSS: 41.03820318549261\n",
      "EPOCH: 7305 LOSS: 41.03819395576308\n",
      "EPOCH: 7306 LOSS: 41.03818472758667\n",
      "EPOCH: 7307 LOSS: 41.03817550096304\n",
      "EPOCH: 7308 LOSS: 41.0381662758918\n",
      "EPOCH: 7309 LOSS: 41.038157052372554\n",
      "EPOCH: 7310 LOSS: 41.03814783040497\n",
      "EPOCH: 7311 LOSS: 41.03813860998865\n",
      "EPOCH: 7312 LOSS: 41.03812939112322\n",
      "EPOCH: 7313 LOSS: 41.03812017380832\n",
      "EPOCH: 7314 LOSS: 41.03811095804356\n",
      "EPOCH: 7315 LOSS: 41.03810174382859\n",
      "EPOCH: 7316 LOSS: 41.038092531163024\n",
      "EPOCH: 7317 LOSS: 41.038083320046496\n",
      "EPOCH: 7318 LOSS: 41.03807411047862\n",
      "EPOCH: 7319 LOSS: 41.03806490245901\n",
      "EPOCH: 7320 LOSS: 41.03805569598736\n",
      "EPOCH: 7321 LOSS: 41.03804649106323\n",
      "EPOCH: 7322 LOSS: 41.03803728768629\n",
      "EPOCH: 7323 LOSS: 41.03802808585614\n",
      "EPOCH: 7324 LOSS: 41.03801888557242\n",
      "EPOCH: 7325 LOSS: 41.038009686834755\n",
      "EPOCH: 7326 LOSS: 41.03800048964278\n",
      "EPOCH: 7327 LOSS: 41.03799129399614\n",
      "EPOCH: 7328 LOSS: 41.037982099894435\n",
      "EPOCH: 7329 LOSS: 41.03797290733732\n",
      "EPOCH: 7330 LOSS: 41.037963716324384\n",
      "EPOCH: 7331 LOSS: 41.03795452685529\n",
      "EPOCH: 7332 LOSS: 41.03794533892967\n",
      "EPOCH: 7333 LOSS: 41.037936152547125\n",
      "EPOCH: 7334 LOSS: 41.03792696770732\n",
      "EPOCH: 7335 LOSS: 41.03791778440986\n",
      "EPOCH: 7336 LOSS: 41.037908602654404\n",
      "EPOCH: 7337 LOSS: 41.037899422440546\n",
      "EPOCH: 7338 LOSS: 41.03789024376793\n",
      "EPOCH: 7339 LOSS: 41.037881066636196\n",
      "EPOCH: 7340 LOSS: 41.037871891044965\n",
      "EPOCH: 7341 LOSS: 41.03786271699387\n",
      "EPOCH: 7342 LOSS: 41.037853544482545\n",
      "EPOCH: 7343 LOSS: 41.03784437351062\n",
      "EPOCH: 7344 LOSS: 41.03783520407774\n",
      "EPOCH: 7345 LOSS: 41.0378260361835\n",
      "EPOCH: 7346 LOSS: 41.03781686982756\n",
      "EPOCH: 7347 LOSS: 41.03780770500955\n",
      "EPOCH: 7348 LOSS: 41.03779854172908\n",
      "EPOCH: 7349 LOSS: 41.03778937998581\n",
      "EPOCH: 7350 LOSS: 41.037780219779364\n",
      "EPOCH: 7351 LOSS: 41.03777106110937\n",
      "EPOCH: 7352 LOSS: 41.03776190397545\n",
      "EPOCH: 7353 LOSS: 41.03775274837725\n",
      "EPOCH: 7354 LOSS: 41.037743594314406\n",
      "EPOCH: 7355 LOSS: 41.03773444178653\n",
      "EPOCH: 7356 LOSS: 41.03772529079329\n",
      "EPOCH: 7357 LOSS: 41.03771614133428\n",
      "EPOCH: 7358 LOSS: 41.03770699340916\n",
      "EPOCH: 7359 LOSS: 41.037697847017554\n",
      "EPOCH: 7360 LOSS: 41.0376887021591\n",
      "EPOCH: 7361 LOSS: 41.0376795588334\n",
      "EPOCH: 7362 LOSS: 41.03767041704013\n",
      "EPOCH: 7363 LOSS: 41.03766127677892\n",
      "EPOCH: 7364 LOSS: 41.03765213804938\n",
      "EPOCH: 7365 LOSS: 41.037643000851176\n",
      "EPOCH: 7366 LOSS: 41.03763386518389\n",
      "EPOCH: 7367 LOSS: 41.0376247310472\n",
      "EPOCH: 7368 LOSS: 41.03761559844072\n",
      "EPOCH: 7369 LOSS: 41.037606467364114\n",
      "EPOCH: 7370 LOSS: 41.037597337816976\n",
      "EPOCH: 7371 LOSS: 41.03758820979897\n",
      "EPOCH: 7372 LOSS: 41.037579083309716\n",
      "EPOCH: 7373 LOSS: 41.037569958348854\n",
      "EPOCH: 7374 LOSS: 41.03756083491601\n",
      "EPOCH: 7375 LOSS: 41.037551713010835\n",
      "EPOCH: 7376 LOSS: 41.03754259263296\n",
      "EPOCH: 7377 LOSS: 41.03753347378202\n",
      "EPOCH: 7378 LOSS: 41.03752435645764\n",
      "EPOCH: 7379 LOSS: 41.03751524065946\n",
      "EPOCH: 7380 LOSS: 41.03750612638713\n",
      "EPOCH: 7381 LOSS: 41.03749701364026\n",
      "EPOCH: 7382 LOSS: 41.03748790241852\n",
      "EPOCH: 7383 LOSS: 41.03747879272151\n",
      "EPOCH: 7384 LOSS: 41.037469684548896\n",
      "EPOCH: 7385 LOSS: 41.037460577900305\n",
      "EPOCH: 7386 LOSS: 41.03745147277537\n",
      "EPOCH: 7387 LOSS: 41.03744236917373\n",
      "EPOCH: 7388 LOSS: 41.03743326709501\n",
      "EPOCH: 7389 LOSS: 41.03742416653887\n",
      "EPOCH: 7390 LOSS: 41.037415067504924\n",
      "EPOCH: 7391 LOSS: 41.03740596999282\n",
      "EPOCH: 7392 LOSS: 41.03739687400219\n",
      "EPOCH: 7393 LOSS: 41.0373877795327\n",
      "EPOCH: 7394 LOSS: 41.03737868658395\n",
      "EPOCH: 7395 LOSS: 41.03736959515559\n",
      "EPOCH: 7396 LOSS: 41.037360505247264\n",
      "EPOCH: 7397 LOSS: 41.0373514168586\n",
      "EPOCH: 7398 LOSS: 41.03734232998923\n",
      "EPOCH: 7399 LOSS: 41.03733324463884\n",
      "EPOCH: 7400 LOSS: 41.03732416080701\n",
      "EPOCH: 7401 LOSS: 41.03731507849339\n",
      "EPOCH: 7402 LOSS: 41.03730599769766\n",
      "EPOCH: 7403 LOSS: 41.03729691841941\n",
      "EPOCH: 7404 LOSS: 41.037287840658294\n",
      "EPOCH: 7405 LOSS: 41.037278764413955\n",
      "EPOCH: 7406 LOSS: 41.03726968968605\n",
      "EPOCH: 7407 LOSS: 41.03726061647417\n",
      "EPOCH: 7408 LOSS: 41.037251544778\n",
      "EPOCH: 7409 LOSS: 41.037242474597164\n",
      "EPOCH: 7410 LOSS: 41.0372334059313\n",
      "EPOCH: 7411 LOSS: 41.03722433878006\n",
      "EPOCH: 7412 LOSS: 41.03721527314306\n",
      "EPOCH: 7413 LOSS: 41.03720620901994\n",
      "EPOCH: 7414 LOSS: 41.03719714641037\n",
      "EPOCH: 7415 LOSS: 41.037188085313964\n",
      "EPOCH: 7416 LOSS: 41.03717902573038\n",
      "EPOCH: 7417 LOSS: 41.03716996765925\n",
      "EPOCH: 7418 LOSS: 41.03716091110021\n",
      "EPOCH: 7419 LOSS: 41.0371518560529\n",
      "EPOCH: 7420 LOSS: 41.037142802516975\n",
      "EPOCH: 7421 LOSS: 41.03713375049206\n",
      "EPOCH: 7422 LOSS: 41.03712469997781\n",
      "EPOCH: 7423 LOSS: 41.03711565097383\n",
      "EPOCH: 7424 LOSS: 41.037106603479835\n",
      "EPOCH: 7425 LOSS: 41.0370975574954\n",
      "EPOCH: 7426 LOSS: 41.03708851302019\n",
      "EPOCH: 7427 LOSS: 41.03707947005385\n",
      "EPOCH: 7428 LOSS: 41.03707042859602\n",
      "EPOCH: 7429 LOSS: 41.03706138864632\n",
      "EPOCH: 7430 LOSS: 41.03705235020443\n",
      "EPOCH: 7431 LOSS: 41.037043313269976\n",
      "EPOCH: 7432 LOSS: 41.03703427784258\n",
      "EPOCH: 7433 LOSS: 41.03702524392192\n",
      "EPOCH: 7434 LOSS: 41.037016211507606\n",
      "EPOCH: 7435 LOSS: 41.03700718059931\n",
      "EPOCH: 7436 LOSS: 41.036998151196656\n",
      "EPOCH: 7437 LOSS: 41.03698912329928\n",
      "EPOCH: 7438 LOSS: 41.036980096906845\n",
      "EPOCH: 7439 LOSS: 41.036971072018986\n",
      "EPOCH: 7440 LOSS: 41.036962048635345\n",
      "EPOCH: 7441 LOSS: 41.03695302675558\n",
      "EPOCH: 7442 LOSS: 41.0369440063793\n",
      "EPOCH: 7443 LOSS: 41.03693498750617\n",
      "EPOCH: 7444 LOSS: 41.03692597013584\n",
      "EPOCH: 7445 LOSS: 41.036916954267966\n",
      "EPOCH: 7446 LOSS: 41.03690793990215\n",
      "EPOCH: 7447 LOSS: 41.036898927038074\n",
      "EPOCH: 7448 LOSS: 41.03688991567536\n",
      "EPOCH: 7449 LOSS: 41.03688090581365\n",
      "EPOCH: 7450 LOSS: 41.03687189745261\n",
      "EPOCH: 7451 LOSS: 41.03686289059187\n",
      "EPOCH: 7452 LOSS: 41.036853885231096\n",
      "EPOCH: 7453 LOSS: 41.0368448813699\n",
      "EPOCH: 7454 LOSS: 41.03683587900795\n",
      "EPOCH: 7455 LOSS: 41.03682687814487\n",
      "EPOCH: 7456 LOSS: 41.03681787878032\n",
      "EPOCH: 7457 LOSS: 41.03680888091396\n",
      "EPOCH: 7458 LOSS: 41.03679988454541\n",
      "EPOCH: 7459 LOSS: 41.03679088967433\n",
      "EPOCH: 7460 LOSS: 41.03678189630036\n",
      "EPOCH: 7461 LOSS: 41.03677290442315\n",
      "EPOCH: 7462 LOSS: 41.036763914042325\n",
      "EPOCH: 7463 LOSS: 41.03675492515758\n",
      "EPOCH: 7464 LOSS: 41.03674593776851\n",
      "EPOCH: 7465 LOSS: 41.036736951874786\n",
      "EPOCH: 7466 LOSS: 41.03672796747604\n",
      "EPOCH: 7467 LOSS: 41.036718984571955\n",
      "EPOCH: 7468 LOSS: 41.036710003162135\n",
      "EPOCH: 7469 LOSS: 41.03670102324625\n",
      "EPOCH: 7470 LOSS: 41.03669204482393\n",
      "EPOCH: 7471 LOSS: 41.03668306789485\n",
      "EPOCH: 7472 LOSS: 41.03667409245862\n",
      "EPOCH: 7473 LOSS: 41.036665118514925\n",
      "EPOCH: 7474 LOSS: 41.03665614606339\n",
      "EPOCH: 7475 LOSS: 41.03664717510367\n",
      "EPOCH: 7476 LOSS: 41.0366382056354\n",
      "EPOCH: 7477 LOSS: 41.036629237658246\n",
      "EPOCH: 7478 LOSS: 41.03662027117184\n",
      "EPOCH: 7479 LOSS: 41.03661130617584\n",
      "EPOCH: 7480 LOSS: 41.03660234266991\n",
      "EPOCH: 7481 LOSS: 41.03659338065367\n",
      "EPOCH: 7482 LOSS: 41.036584420126786\n",
      "EPOCH: 7483 LOSS: 41.03657546108887\n",
      "EPOCH: 7484 LOSS: 41.03656650353963\n",
      "EPOCH: 7485 LOSS: 41.03655754747869\n",
      "EPOCH: 7486 LOSS: 41.036548592905675\n",
      "EPOCH: 7487 LOSS: 41.03653963982025\n",
      "EPOCH: 7488 LOSS: 41.036530688222086\n",
      "EPOCH: 7489 LOSS: 41.03652173811081\n",
      "EPOCH: 7490 LOSS: 41.03651278948607\n",
      "EPOCH: 7491 LOSS: 41.03650384234753\n",
      "EPOCH: 7492 LOSS: 41.036494896694805\n",
      "EPOCH: 7493 LOSS: 41.0364859525276\n",
      "EPOCH: 7494 LOSS: 41.03647700984551\n",
      "EPOCH: 7495 LOSS: 41.03646806864823\n",
      "EPOCH: 7496 LOSS: 41.036459128935384\n",
      "EPOCH: 7497 LOSS: 41.0364501907066\n",
      "EPOCH: 7498 LOSS: 41.03644125396161\n",
      "EPOCH: 7499 LOSS: 41.03643231869997\n",
      "EPOCH: 7500 LOSS: 41.0364233849214\n",
      "EPOCH: 7501 LOSS: 41.03641445262551\n",
      "EPOCH: 7502 LOSS: 41.03640552181197\n",
      "EPOCH: 7503 LOSS: 41.0363965924804\n",
      "EPOCH: 7504 LOSS: 41.036387664630496\n",
      "EPOCH: 7505 LOSS: 41.03637873826189\n",
      "EPOCH: 7506 LOSS: 41.03636981337422\n",
      "EPOCH: 7507 LOSS: 41.03636088996715\n",
      "EPOCH: 7508 LOSS: 41.036351968040336\n",
      "EPOCH: 7509 LOSS: 41.036343047593434\n",
      "EPOCH: 7510 LOSS: 41.03633412862608\n",
      "EPOCH: 7511 LOSS: 41.036325211137935\n",
      "EPOCH: 7512 LOSS: 41.036316295128636\n",
      "EPOCH: 7513 LOSS: 41.03630738059786\n",
      "EPOCH: 7514 LOSS: 41.03629846754522\n",
      "EPOCH: 7515 LOSS: 41.03628955597044\n",
      "EPOCH: 7516 LOSS: 41.0362806458731\n",
      "EPOCH: 7517 LOSS: 41.03627173725289\n",
      "EPOCH: 7518 LOSS: 41.036262830109436\n",
      "EPOCH: 7519 LOSS: 41.03625392444242\n",
      "EPOCH: 7520 LOSS: 41.0362450202515\n",
      "EPOCH: 7521 LOSS: 41.03623611753629\n",
      "EPOCH: 7522 LOSS: 41.03622721629647\n",
      "EPOCH: 7523 LOSS: 41.03621831653168\n",
      "EPOCH: 7524 LOSS: 41.03620941824161\n",
      "EPOCH: 7525 LOSS: 41.03620052142584\n",
      "EPOCH: 7526 LOSS: 41.036191626084104\n",
      "EPOCH: 7527 LOSS: 41.03618273221603\n",
      "EPOCH: 7528 LOSS: 41.03617383982124\n",
      "EPOCH: 7529 LOSS: 41.03616494889941\n",
      "EPOCH: 7530 LOSS: 41.0361560594502\n",
      "EPOCH: 7531 LOSS: 41.03614717147326\n",
      "EPOCH: 7532 LOSS: 41.03613828496825\n",
      "EPOCH: 7533 LOSS: 41.03612939993482\n",
      "EPOCH: 7534 LOSS: 41.03612051637262\n",
      "EPOCH: 7535 LOSS: 41.0361116342813\n",
      "EPOCH: 7536 LOSS: 41.03610275366053\n",
      "EPOCH: 7537 LOSS: 41.03609387450995\n",
      "EPOCH: 7538 LOSS: 41.03608499682923\n",
      "EPOCH: 7539 LOSS: 41.03607612061802\n",
      "EPOCH: 7540 LOSS: 41.03606724587597\n",
      "EPOCH: 7541 LOSS: 41.03605837260273\n",
      "EPOCH: 7542 LOSS: 41.036049500797986\n",
      "EPOCH: 7543 LOSS: 41.03604063046135\n",
      "EPOCH: 7544 LOSS: 41.0360317615925\n",
      "EPOCH: 7545 LOSS: 41.0360228941911\n",
      "EPOCH: 7546 LOSS: 41.0360140282568\n",
      "EPOCH: 7547 LOSS: 41.03600516378925\n",
      "EPOCH: 7548 LOSS: 41.03599630078811\n",
      "EPOCH: 7549 LOSS: 41.03598743925304\n",
      "EPOCH: 7550 LOSS: 41.0359785791837\n",
      "EPOCH: 7551 LOSS: 41.03596972057972\n",
      "EPOCH: 7552 LOSS: 41.03596086344079\n",
      "EPOCH: 7553 LOSS: 41.035952007766554\n",
      "EPOCH: 7554 LOSS: 41.035943153556666\n",
      "EPOCH: 7555 LOSS: 41.035934300810794\n",
      "EPOCH: 7556 LOSS: 41.03592544952856\n",
      "EPOCH: 7557 LOSS: 41.035916599709665\n",
      "EPOCH: 7558 LOSS: 41.035907751353754\n",
      "EPOCH: 7559 LOSS: 41.03589890446047\n",
      "EPOCH: 7560 LOSS: 41.03589005902947\n",
      "EPOCH: 7561 LOSS: 41.035881215060456\n",
      "EPOCH: 7562 LOSS: 41.03587237255302\n",
      "EPOCH: 7563 LOSS: 41.035863531506884\n",
      "EPOCH: 7564 LOSS: 41.03585469192166\n",
      "EPOCH: 7565 LOSS: 41.03584585379699\n",
      "EPOCH: 7566 LOSS: 41.03583701713261\n",
      "EPOCH: 7567 LOSS: 41.035828181928096\n",
      "EPOCH: 7568 LOSS: 41.03581934818317\n",
      "EPOCH: 7569 LOSS: 41.03581051589744\n",
      "EPOCH: 7570 LOSS: 41.03580168507059\n",
      "EPOCH: 7571 LOSS: 41.03579285570227\n",
      "EPOCH: 7572 LOSS: 41.03578402779216\n",
      "EPOCH: 7573 LOSS: 41.035775201339916\n",
      "EPOCH: 7574 LOSS: 41.03576637634518\n",
      "EPOCH: 7575 LOSS: 41.035757552807596\n",
      "EPOCH: 7576 LOSS: 41.03574873072685\n",
      "EPOCH: 7577 LOSS: 41.035739910102606\n",
      "EPOCH: 7578 LOSS: 41.03573109093452\n",
      "EPOCH: 7579 LOSS: 41.035722273222234\n",
      "EPOCH: 7580 LOSS: 41.03571345696544\n",
      "EPOCH: 7581 LOSS: 41.035704642163765\n",
      "EPOCH: 7582 LOSS: 41.03569582881686\n",
      "EPOCH: 7583 LOSS: 41.03568701692443\n",
      "EPOCH: 7584 LOSS: 41.03567820648611\n",
      "EPOCH: 7585 LOSS: 41.035669397501565\n",
      "EPOCH: 7586 LOSS: 41.03566058997046\n",
      "EPOCH: 7587 LOSS: 41.03565178389243\n",
      "EPOCH: 7588 LOSS: 41.035642979267166\n",
      "EPOCH: 7589 LOSS: 41.03563417609432\n",
      "EPOCH: 7590 LOSS: 41.03562537437356\n",
      "EPOCH: 7591 LOSS: 41.03561657410453\n",
      "EPOCH: 7592 LOSS: 41.035607775286906\n",
      "EPOCH: 7593 LOSS: 41.03559897792034\n",
      "EPOCH: 7594 LOSS: 41.03559018200448\n",
      "EPOCH: 7595 LOSS: 41.035581387539025\n",
      "EPOCH: 7596 LOSS: 41.03557259452362\n",
      "EPOCH: 7597 LOSS: 41.035563802957924\n",
      "EPOCH: 7598 LOSS: 41.0355550128416\n",
      "EPOCH: 7599 LOSS: 41.0355462241743\n",
      "EPOCH: 7600 LOSS: 41.03553743695569\n",
      "EPOCH: 7601 LOSS: 41.035528651185444\n",
      "EPOCH: 7602 LOSS: 41.035519866863226\n",
      "EPOCH: 7603 LOSS: 41.03551108398868\n",
      "EPOCH: 7604 LOSS: 41.03550230256148\n",
      "EPOCH: 7605 LOSS: 41.03549352258129\n",
      "EPOCH: 7606 LOSS: 41.03548474404778\n",
      "EPOCH: 7607 LOSS: 41.0354759669606\n",
      "EPOCH: 7608 LOSS: 41.0354671913194\n",
      "EPOCH: 7609 LOSS: 41.03545841712388\n",
      "EPOCH: 7610 LOSS: 41.03544964437367\n",
      "EPOCH: 7611 LOSS: 41.03544087306847\n",
      "EPOCH: 7612 LOSS: 41.035432103207896\n",
      "EPOCH: 7613 LOSS: 41.03542333479166\n",
      "EPOCH: 7614 LOSS: 41.03541456781939\n",
      "EPOCH: 7615 LOSS: 41.035405802290754\n",
      "EPOCH: 7616 LOSS: 41.03539703820543\n",
      "EPOCH: 7617 LOSS: 41.03538827556309\n",
      "EPOCH: 7618 LOSS: 41.03537951436337\n",
      "EPOCH: 7619 LOSS: 41.03537075460596\n",
      "EPOCH: 7620 LOSS: 41.03536199629051\n",
      "EPOCH: 7621 LOSS: 41.03535323941669\n",
      "EPOCH: 7622 LOSS: 41.03534448398416\n",
      "EPOCH: 7623 LOSS: 41.03533572999259\n",
      "EPOCH: 7624 LOSS: 41.035326977441635\n",
      "EPOCH: 7625 LOSS: 41.035318226330986\n",
      "EPOCH: 7626 LOSS: 41.03530947666029\n",
      "EPOCH: 7627 LOSS: 41.035300728429185\n",
      "EPOCH: 7628 LOSS: 41.03529198163737\n",
      "EPOCH: 7629 LOSS: 41.03528323628454\n",
      "EPOCH: 7630 LOSS: 41.03527449237028\n",
      "EPOCH: 7631 LOSS: 41.035265749894336\n",
      "EPOCH: 7632 LOSS: 41.035257008856334\n",
      "EPOCH: 7633 LOSS: 41.03524826925593\n",
      "EPOCH: 7634 LOSS: 41.035239531092806\n",
      "EPOCH: 7635 LOSS: 41.03523079436663\n",
      "EPOCH: 7636 LOSS: 41.03522205907707\n",
      "EPOCH: 7637 LOSS: 41.035213325223786\n",
      "EPOCH: 7638 LOSS: 41.03520459280645\n",
      "EPOCH: 7639 LOSS: 41.03519586182471\n",
      "EPOCH: 7640 LOSS: 41.03518713227827\n",
      "EPOCH: 7641 LOSS: 41.035178404166764\n",
      "EPOCH: 7642 LOSS: 41.03516967748986\n",
      "EPOCH: 7643 LOSS: 41.03516095224725\n",
      "EPOCH: 7644 LOSS: 41.035152228438584\n",
      "EPOCH: 7645 LOSS: 41.035143506063534\n",
      "EPOCH: 7646 LOSS: 41.03513478512175\n",
      "EPOCH: 7647 LOSS: 41.03512606561293\n",
      "EPOCH: 7648 LOSS: 41.0351173475367\n",
      "EPOCH: 7649 LOSS: 41.03510863089278\n",
      "EPOCH: 7650 LOSS: 41.035099915680796\n",
      "EPOCH: 7651 LOSS: 41.03509120190044\n",
      "EPOCH: 7652 LOSS: 41.035082489551364\n",
      "EPOCH: 7653 LOSS: 41.03507377863325\n",
      "EPOCH: 7654 LOSS: 41.035065069145745\n",
      "EPOCH: 7655 LOSS: 41.03505636108856\n",
      "EPOCH: 7656 LOSS: 41.03504765446132\n",
      "EPOCH: 7657 LOSS: 41.03503894926371\n",
      "EPOCH: 7658 LOSS: 41.0350302454954\n",
      "EPOCH: 7659 LOSS: 41.035021543156056\n",
      "EPOCH: 7660 LOSS: 41.03501284224535\n",
      "EPOCH: 7661 LOSS: 41.03500414276294\n",
      "EPOCH: 7662 LOSS: 41.034995444708514\n",
      "EPOCH: 7663 LOSS: 41.034986748081735\n",
      "EPOCH: 7664 LOSS: 41.03497805288224\n",
      "EPOCH: 7665 LOSS: 41.03496935910976\n",
      "EPOCH: 7666 LOSS: 41.03496066676392\n",
      "EPOCH: 7667 LOSS: 41.034951975844415\n",
      "EPOCH: 7668 LOSS: 41.034943286350874\n",
      "EPOCH: 7669 LOSS: 41.03493459828303\n",
      "EPOCH: 7670 LOSS: 41.03492591164049\n",
      "EPOCH: 7671 LOSS: 41.03491722642296\n",
      "EPOCH: 7672 LOSS: 41.034908542630106\n",
      "EPOCH: 7673 LOSS: 41.03489986026158\n",
      "EPOCH: 7674 LOSS: 41.03489117931708\n",
      "EPOCH: 7675 LOSS: 41.034882499796254\n",
      "EPOCH: 7676 LOSS: 41.03487382169879\n",
      "EPOCH: 7677 LOSS: 41.03486514502436\n",
      "EPOCH: 7678 LOSS: 41.03485646977261\n",
      "EPOCH: 7679 LOSS: 41.03484779594324\n",
      "EPOCH: 7680 LOSS: 41.034839123535896\n",
      "EPOCH: 7681 LOSS: 41.03483045255025\n",
      "EPOCH: 7682 LOSS: 41.03482178298602\n",
      "EPOCH: 7683 LOSS: 41.03481311484283\n",
      "EPOCH: 7684 LOSS: 41.03480444812035\n",
      "EPOCH: 7685 LOSS: 41.03479578281828\n",
      "EPOCH: 7686 LOSS: 41.03478711893627\n",
      "EPOCH: 7687 LOSS: 41.03477845647401\n",
      "EPOCH: 7688 LOSS: 41.03476979543114\n",
      "EPOCH: 7689 LOSS: 41.03476113580737\n",
      "EPOCH: 7690 LOSS: 41.03475247760235\n",
      "EPOCH: 7691 LOSS: 41.03474382081578\n",
      "EPOCH: 7692 LOSS: 41.03473516544727\n",
      "EPOCH: 7693 LOSS: 41.03472651149656\n",
      "EPOCH: 7694 LOSS: 41.03471785896329\n",
      "EPOCH: 7695 LOSS: 41.034709207847136\n",
      "EPOCH: 7696 LOSS: 41.03470055814779\n",
      "EPOCH: 7697 LOSS: 41.034691909864875\n",
      "EPOCH: 7698 LOSS: 41.03468326299813\n",
      "EPOCH: 7699 LOSS: 41.03467461754718\n",
      "EPOCH: 7700 LOSS: 41.034665973511714\n",
      "EPOCH: 7701 LOSS: 41.03465733089141\n",
      "EPOCH: 7702 LOSS: 41.03464868968595\n",
      "EPOCH: 7703 LOSS: 41.034640049894975\n",
      "EPOCH: 7704 LOSS: 41.034631411518184\n",
      "EPOCH: 7705 LOSS: 41.03462277455526\n",
      "EPOCH: 7706 LOSS: 41.034614139005825\n",
      "EPOCH: 7707 LOSS: 41.03460550486962\n",
      "EPOCH: 7708 LOSS: 41.034596872146295\n",
      "EPOCH: 7709 LOSS: 41.034588240835504\n",
      "EPOCH: 7710 LOSS: 41.03457961093694\n",
      "EPOCH: 7711 LOSS: 41.03457098245028\n",
      "EPOCH: 7712 LOSS: 41.03456235537519\n",
      "EPOCH: 7713 LOSS: 41.03455372971135\n",
      "EPOCH: 7714 LOSS: 41.03454510545842\n",
      "EPOCH: 7715 LOSS: 41.0345364826161\n",
      "EPOCH: 7716 LOSS: 41.03452786118403\n",
      "EPOCH: 7717 LOSS: 41.03451924116194\n",
      "EPOCH: 7718 LOSS: 41.03451062254945\n",
      "EPOCH: 7719 LOSS: 41.03450200534626\n",
      "EPOCH: 7720 LOSS: 41.03449338955204\n",
      "EPOCH: 7721 LOSS: 41.03448477516649\n",
      "EPOCH: 7722 LOSS: 41.03447616218925\n",
      "EPOCH: 7723 LOSS: 41.03446755062002\n",
      "EPOCH: 7724 LOSS: 41.03445894045846\n",
      "EPOCH: 7725 LOSS: 41.03445033170424\n",
      "EPOCH: 7726 LOSS: 41.034441724357066\n",
      "EPOCH: 7727 LOSS: 41.034433118416594\n",
      "EPOCH: 7728 LOSS: 41.03442451388249\n",
      "EPOCH: 7729 LOSS: 41.034415910754475\n",
      "EPOCH: 7730 LOSS: 41.03440730903216\n",
      "EPOCH: 7731 LOSS: 41.03439870871526\n",
      "EPOCH: 7732 LOSS: 41.034390109803454\n",
      "EPOCH: 7733 LOSS: 41.034381512296434\n",
      "EPOCH: 7734 LOSS: 41.034372916193824\n",
      "EPOCH: 7735 LOSS: 41.034364321495346\n",
      "EPOCH: 7736 LOSS: 41.034355728200666\n",
      "EPOCH: 7737 LOSS: 41.03434713630945\n",
      "EPOCH: 7738 LOSS: 41.034338545821385\n",
      "EPOCH: 7739 LOSS: 41.03432995673616\n",
      "EPOCH: 7740 LOSS: 41.03432136905343\n",
      "EPOCH: 7741 LOSS: 41.03431278277288\n",
      "EPOCH: 7742 LOSS: 41.0343041978942\n",
      "EPOCH: 7743 LOSS: 41.03429561441707\n",
      "EPOCH: 7744 LOSS: 41.03428703234113\n",
      "EPOCH: 7745 LOSS: 41.0342784516661\n",
      "EPOCH: 7746 LOSS: 41.03426987239165\n",
      "EPOCH: 7747 LOSS: 41.034261294517435\n",
      "EPOCH: 7748 LOSS: 41.03425271804315\n",
      "EPOCH: 7749 LOSS: 41.03424414296849\n",
      "EPOCH: 7750 LOSS: 41.0342355692931\n",
      "EPOCH: 7751 LOSS: 41.03422699701669\n",
      "EPOCH: 7752 LOSS: 41.03421842613893\n",
      "EPOCH: 7753 LOSS: 41.03420985665947\n",
      "EPOCH: 7754 LOSS: 41.034201288578046\n",
      "EPOCH: 7755 LOSS: 41.03419272189427\n",
      "EPOCH: 7756 LOSS: 41.034184156607886\n",
      "EPOCH: 7757 LOSS: 41.03417559271851\n",
      "EPOCH: 7758 LOSS: 41.03416703022589\n",
      "EPOCH: 7759 LOSS: 41.03415846912965\n",
      "EPOCH: 7760 LOSS: 41.03414990942949\n",
      "EPOCH: 7761 LOSS: 41.0341413511251\n",
      "EPOCH: 7762 LOSS: 41.034132794216134\n",
      "EPOCH: 7763 LOSS: 41.03412423870229\n",
      "EPOCH: 7764 LOSS: 41.034115684583256\n",
      "EPOCH: 7765 LOSS: 41.034107131858704\n",
      "EPOCH: 7766 LOSS: 41.0340985805283\n",
      "EPOCH: 7767 LOSS: 41.03409003059175\n",
      "EPOCH: 7768 LOSS: 41.03408148204872\n",
      "EPOCH: 7769 LOSS: 41.03407293489887\n",
      "EPOCH: 7770 LOSS: 41.03406438914193\n",
      "EPOCH: 7771 LOSS: 41.034055844777555\n",
      "EPOCH: 7772 LOSS: 41.0340473018054\n",
      "EPOCH: 7773 LOSS: 41.03403876022518\n",
      "EPOCH: 7774 LOSS: 41.03403022003658\n",
      "EPOCH: 7775 LOSS: 41.03402168123926\n",
      "EPOCH: 7776 LOSS: 41.03401314383291\n",
      "EPOCH: 7777 LOSS: 41.03400460781721\n",
      "EPOCH: 7778 LOSS: 41.033996073191844\n",
      "EPOCH: 7779 LOSS: 41.033987539956485\n",
      "EPOCH: 7780 LOSS: 41.03397900811083\n",
      "EPOCH: 7781 LOSS: 41.033970477654556\n",
      "EPOCH: 7782 LOSS: 41.03396194858734\n",
      "EPOCH: 7783 LOSS: 41.03395342090887\n",
      "EPOCH: 7784 LOSS: 41.03394489461881\n",
      "EPOCH: 7785 LOSS: 41.03393636971687\n",
      "EPOCH: 7786 LOSS: 41.033927846202715\n",
      "EPOCH: 7787 LOSS: 41.033919324076024\n",
      "EPOCH: 7788 LOSS: 41.033910803336504\n",
      "EPOCH: 7789 LOSS: 41.03390228398381\n",
      "EPOCH: 7790 LOSS: 41.03389376601764\n",
      "EPOCH: 7791 LOSS: 41.033885249437674\n",
      "EPOCH: 7792 LOSS: 41.03387673424359\n",
      "EPOCH: 7793 LOSS: 41.03386822043508\n",
      "EPOCH: 7794 LOSS: 41.03385970801182\n",
      "EPOCH: 7795 LOSS: 41.03385119697349\n",
      "EPOCH: 7796 LOSS: 41.0338426873198\n",
      "EPOCH: 7797 LOSS: 41.0338341790504\n",
      "EPOCH: 7798 LOSS: 41.03382567216498\n",
      "EPOCH: 7799 LOSS: 41.033817166663226\n",
      "EPOCH: 7800 LOSS: 41.03380866254484\n",
      "EPOCH: 7801 LOSS: 41.03380015980948\n",
      "EPOCH: 7802 LOSS: 41.033791658456856\n",
      "EPOCH: 7803 LOSS: 41.033783158486635\n",
      "EPOCH: 7804 LOSS: 41.0337746598985\n",
      "EPOCH: 7805 LOSS: 41.033766162692146\n",
      "EPOCH: 7806 LOSS: 41.033757666867245\n",
      "EPOCH: 7807 LOSS: 41.03374917242349\n",
      "EPOCH: 7808 LOSS: 41.03374067936057\n",
      "EPOCH: 7809 LOSS: 41.033732187678154\n",
      "EPOCH: 7810 LOSS: 41.03372369737595\n",
      "EPOCH: 7811 LOSS: 41.03371520845362\n",
      "EPOCH: 7812 LOSS: 41.03370672091087\n",
      "EPOCH: 7813 LOSS: 41.03369823474736\n",
      "EPOCH: 7814 LOSS: 41.033689749962804\n",
      "EPOCH: 7815 LOSS: 41.033681266556854\n",
      "EPOCH: 7816 LOSS: 41.03367278452922\n",
      "EPOCH: 7817 LOSS: 41.03366430387958\n",
      "EPOCH: 7818 LOSS: 41.033655824607635\n",
      "EPOCH: 7819 LOSS: 41.03364734671305\n",
      "EPOCH: 7820 LOSS: 41.033638870195524\n",
      "EPOCH: 7821 LOSS: 41.033630395054736\n",
      "EPOCH: 7822 LOSS: 41.03362192129036\n",
      "EPOCH: 7823 LOSS: 41.033613448902116\n",
      "EPOCH: 7824 LOSS: 41.03360497788965\n",
      "EPOCH: 7825 LOSS: 41.03359650825268\n",
      "EPOCH: 7826 LOSS: 41.03358803999088\n",
      "EPOCH: 7827 LOSS: 41.03357957310394\n",
      "EPOCH: 7828 LOSS: 41.033571107591534\n",
      "EPOCH: 7829 LOSS: 41.033562643453365\n",
      "EPOCH: 7830 LOSS: 41.03355418068913\n",
      "EPOCH: 7831 LOSS: 41.03354571929848\n",
      "EPOCH: 7832 LOSS: 41.03353725928113\n",
      "EPOCH: 7833 LOSS: 41.03352880063676\n",
      "EPOCH: 7834 LOSS: 41.033520343365055\n",
      "EPOCH: 7835 LOSS: 41.03351188746571\n",
      "EPOCH: 7836 LOSS: 41.03350343293842\n",
      "EPOCH: 7837 LOSS: 41.03349497978282\n",
      "EPOCH: 7838 LOSS: 41.03348652799867\n",
      "EPOCH: 7839 LOSS: 41.03347807758563\n",
      "EPOCH: 7840 LOSS: 41.03346962854336\n",
      "EPOCH: 7841 LOSS: 41.033461180871576\n",
      "EPOCH: 7842 LOSS: 41.03345273456997\n",
      "EPOCH: 7843 LOSS: 41.03344428963821\n",
      "EPOCH: 7844 LOSS: 41.03343584607602\n",
      "EPOCH: 7845 LOSS: 41.03342740388305\n",
      "EPOCH: 7846 LOSS: 41.033418963059\n",
      "EPOCH: 7847 LOSS: 41.03341052360357\n",
      "EPOCH: 7848 LOSS: 41.033402085516435\n",
      "EPOCH: 7849 LOSS: 41.033393648797286\n",
      "EPOCH: 7850 LOSS: 41.03338521344583\n",
      "EPOCH: 7851 LOSS: 41.03337677946173\n",
      "EPOCH: 7852 LOSS: 41.03336834684469\n",
      "EPOCH: 7853 LOSS: 41.0333599155944\n",
      "EPOCH: 7854 LOSS: 41.03335148571054\n",
      "EPOCH: 7855 LOSS: 41.0333430571928\n",
      "EPOCH: 7856 LOSS: 41.03333463004088\n",
      "EPOCH: 7857 LOSS: 41.03332620425447\n",
      "EPOCH: 7858 LOSS: 41.03331777983324\n",
      "EPOCH: 7859 LOSS: 41.033309356776904\n",
      "EPOCH: 7860 LOSS: 41.033300935085144\n",
      "EPOCH: 7861 LOSS: 41.03329251475764\n",
      "EPOCH: 7862 LOSS: 41.0332840957941\n",
      "EPOCH: 7863 LOSS: 41.0332756781942\n",
      "EPOCH: 7864 LOSS: 41.03326726195763\n",
      "EPOCH: 7865 LOSS: 41.0332588470841\n",
      "EPOCH: 7866 LOSS: 41.03325043357328\n",
      "EPOCH: 7867 LOSS: 41.03324202142484\n",
      "EPOCH: 7868 LOSS: 41.03323361063852\n",
      "EPOCH: 7869 LOSS: 41.03322520121399\n",
      "EPOCH: 7870 LOSS: 41.03321679315094\n",
      "EPOCH: 7871 LOSS: 41.033208386449054\n",
      "EPOCH: 7872 LOSS: 41.03319998110804\n",
      "EPOCH: 7873 LOSS: 41.03319157712757\n",
      "EPOCH: 7874 LOSS: 41.03318317450733\n",
      "EPOCH: 7875 LOSS: 41.03317477324704\n",
      "EPOCH: 7876 LOSS: 41.03316637334638\n",
      "EPOCH: 7877 LOSS: 41.03315797480505\n",
      "EPOCH: 7878 LOSS: 41.03314957762271\n",
      "EPOCH: 7879 LOSS: 41.033141181799074\n",
      "EPOCH: 7880 LOSS: 41.03313278733383\n",
      "EPOCH: 7881 LOSS: 41.03312439422668\n",
      "EPOCH: 7882 LOSS: 41.033116002477314\n",
      "EPOCH: 7883 LOSS: 41.03310761208541\n",
      "EPOCH: 7884 LOSS: 41.03309922305067\n",
      "EPOCH: 7885 LOSS: 41.03309083537278\n",
      "EPOCH: 7886 LOSS: 41.03308244905145\n",
      "EPOCH: 7887 LOSS: 41.03307406408636\n",
      "EPOCH: 7888 LOSS: 41.0330656804772\n",
      "EPOCH: 7889 LOSS: 41.03305729822366\n",
      "EPOCH: 7890 LOSS: 41.033048917325445\n",
      "EPOCH: 7891 LOSS: 41.033040537782256\n",
      "EPOCH: 7892 LOSS: 41.03303215959375\n",
      "EPOCH: 7893 LOSS: 41.03302378275964\n",
      "EPOCH: 7894 LOSS: 41.03301540727965\n",
      "EPOCH: 7895 LOSS: 41.033007033153424\n",
      "EPOCH: 7896 LOSS: 41.03299866038069\n",
      "EPOCH: 7897 LOSS: 41.032990288961116\n",
      "EPOCH: 7898 LOSS: 41.03298191889441\n",
      "EPOCH: 7899 LOSS: 41.03297355018027\n",
      "EPOCH: 7900 LOSS: 41.032965182818394\n",
      "EPOCH: 7901 LOSS: 41.032956816808465\n",
      "EPOCH: 7902 LOSS: 41.03294845215016\n",
      "EPOCH: 7903 LOSS: 41.03294008884319\n",
      "EPOCH: 7904 LOSS: 41.03293172688727\n",
      "EPOCH: 7905 LOSS: 41.032923366282056\n",
      "EPOCH: 7906 LOSS: 41.032915007027285\n",
      "EPOCH: 7907 LOSS: 41.03290664912262\n",
      "EPOCH: 7908 LOSS: 41.03289829256776\n",
      "EPOCH: 7909 LOSS: 41.032889937362405\n",
      "EPOCH: 7910 LOSS: 41.03288158350625\n",
      "EPOCH: 7911 LOSS: 41.03287323099899\n",
      "EPOCH: 7912 LOSS: 41.03286487984032\n",
      "EPOCH: 7913 LOSS: 41.03285653002993\n",
      "EPOCH: 7914 LOSS: 41.03284818156753\n",
      "EPOCH: 7915 LOSS: 41.0328398344528\n",
      "EPOCH: 7916 LOSS: 41.03283148868543\n",
      "EPOCH: 7917 LOSS: 41.03282314426514\n",
      "EPOCH: 7918 LOSS: 41.032814801191606\n",
      "EPOCH: 7919 LOSS: 41.032806459464545\n",
      "EPOCH: 7920 LOSS: 41.03279811908361\n",
      "EPOCH: 7921 LOSS: 41.032789780048546\n",
      "EPOCH: 7922 LOSS: 41.032781442359024\n",
      "EPOCH: 7923 LOSS: 41.03277310601474\n",
      "EPOCH: 7924 LOSS: 41.0327647710154\n",
      "EPOCH: 7925 LOSS: 41.03275643736069\n",
      "EPOCH: 7926 LOSS: 41.03274810505031\n",
      "EPOCH: 7927 LOSS: 41.03273977408395\n",
      "EPOCH: 7928 LOSS: 41.03273144446132\n",
      "EPOCH: 7929 LOSS: 41.032723116182126\n",
      "EPOCH: 7930 LOSS: 41.032714789246036\n",
      "EPOCH: 7931 LOSS: 41.03270646365278\n",
      "EPOCH: 7932 LOSS: 41.032698139402\n",
      "EPOCH: 7933 LOSS: 41.03268981649346\n",
      "EPOCH: 7934 LOSS: 41.032681494926805\n",
      "EPOCH: 7935 LOSS: 41.03267317470178\n",
      "EPOCH: 7936 LOSS: 41.03266485581804\n",
      "EPOCH: 7937 LOSS: 41.0326565382753\n",
      "EPOCH: 7938 LOSS: 41.032648222073256\n",
      "EPOCH: 7939 LOSS: 41.0326399072116\n",
      "EPOCH: 7940 LOSS: 41.03263159369004\n",
      "EPOCH: 7941 LOSS: 41.03262328150828\n",
      "EPOCH: 7942 LOSS: 41.032614970666\n",
      "EPOCH: 7943 LOSS: 41.032606661162916\n",
      "EPOCH: 7944 LOSS: 41.03259835299869\n",
      "EPOCH: 7945 LOSS: 41.03259004617307\n",
      "EPOCH: 7946 LOSS: 41.03258174068572\n",
      "EPOCH: 7947 LOSS: 41.032573436536346\n",
      "EPOCH: 7948 LOSS: 41.032565133724674\n",
      "EPOCH: 7949 LOSS: 41.03255683225035\n",
      "EPOCH: 7950 LOSS: 41.03254853211313\n",
      "EPOCH: 7951 LOSS: 41.03254023331266\n",
      "EPOCH: 7952 LOSS: 41.03253193584869\n",
      "EPOCH: 7953 LOSS: 41.03252363972087\n",
      "EPOCH: 7954 LOSS: 41.03251534492892\n",
      "EPOCH: 7955 LOSS: 41.03250705147256\n",
      "EPOCH: 7956 LOSS: 41.03249875935146\n",
      "EPOCH: 7957 LOSS: 41.03249046856532\n",
      "EPOCH: 7958 LOSS: 41.03248217911386\n",
      "EPOCH: 7959 LOSS: 41.03247389099678\n",
      "EPOCH: 7960 LOSS: 41.032465604213755\n",
      "EPOCH: 7961 LOSS: 41.03245731876451\n",
      "EPOCH: 7962 LOSS: 41.032449034648714\n",
      "EPOCH: 7963 LOSS: 41.032440751866105\n",
      "EPOCH: 7964 LOSS: 41.032432470416346\n",
      "EPOCH: 7965 LOSS: 41.03242419029918\n",
      "EPOCH: 7966 LOSS: 41.03241591151427\n",
      "EPOCH: 7967 LOSS: 41.03240763406133\n",
      "EPOCH: 7968 LOSS: 41.03239935794005\n",
      "EPOCH: 7969 LOSS: 41.03239108315017\n",
      "EPOCH: 7970 LOSS: 41.03238280969134\n",
      "EPOCH: 7971 LOSS: 41.03237453756328\n",
      "EPOCH: 7972 LOSS: 41.03236626676569\n",
      "EPOCH: 7973 LOSS: 41.032357997298305\n",
      "EPOCH: 7974 LOSS: 41.03234972916078\n",
      "EPOCH: 7975 LOSS: 41.03234146235281\n",
      "EPOCH: 7976 LOSS: 41.03233319687415\n",
      "EPOCH: 7977 LOSS: 41.03232493272445\n",
      "EPOCH: 7978 LOSS: 41.03231666990343\n",
      "EPOCH: 7979 LOSS: 41.03230840841081\n",
      "EPOCH: 7980 LOSS: 41.03230014824624\n",
      "EPOCH: 7981 LOSS: 41.03229188940949\n",
      "EPOCH: 7982 LOSS: 41.03228363190022\n",
      "EPOCH: 7983 LOSS: 41.03227537571813\n",
      "EPOCH: 7984 LOSS: 41.03226712086293\n",
      "EPOCH: 7985 LOSS: 41.032258867334335\n",
      "EPOCH: 7986 LOSS: 41.032250615132035\n",
      "EPOCH: 7987 LOSS: 41.03224236425574\n",
      "EPOCH: 7988 LOSS: 41.03223411470512\n",
      "EPOCH: 7989 LOSS: 41.032225866479926\n",
      "EPOCH: 7990 LOSS: 41.032217619579825\n",
      "EPOCH: 7991 LOSS: 41.03220937400452\n",
      "EPOCH: 7992 LOSS: 41.03220112975376\n",
      "EPOCH: 7993 LOSS: 41.03219288682719\n",
      "EPOCH: 7994 LOSS: 41.03218464522456\n",
      "EPOCH: 7995 LOSS: 41.032176404945524\n",
      "EPOCH: 7996 LOSS: 41.03216816598982\n",
      "EPOCH: 7997 LOSS: 41.03215992835715\n",
      "EPOCH: 7998 LOSS: 41.03215169204721\n",
      "EPOCH: 7999 LOSS: 41.03214345705969\n",
      "EPOCH: 8000 LOSS: 41.03213522339432\n",
      "EPOCH: 8001 LOSS: 41.032126991050774\n",
      "EPOCH: 8002 LOSS: 41.03211876002879\n",
      "EPOCH: 8003 LOSS: 41.03211053032804\n",
      "EPOCH: 8004 LOSS: 41.03210230194824\n",
      "EPOCH: 8005 LOSS: 41.032094074889116\n",
      "EPOCH: 8006 LOSS: 41.032085849150356\n",
      "EPOCH: 8007 LOSS: 41.032077624731635\n",
      "EPOCH: 8008 LOSS: 41.0320694016327\n",
      "EPOCH: 8009 LOSS: 41.03206117985323\n",
      "EPOCH: 8010 LOSS: 41.032052959392935\n",
      "EPOCH: 8011 LOSS: 41.032044740251536\n",
      "EPOCH: 8012 LOSS: 41.032036522428726\n",
      "EPOCH: 8013 LOSS: 41.032028305924186\n",
      "EPOCH: 8014 LOSS: 41.032020090737646\n",
      "EPOCH: 8015 LOSS: 41.032011876868815\n",
      "EPOCH: 8016 LOSS: 41.032003664317386\n",
      "EPOCH: 8017 LOSS: 41.03199545308307\n",
      "EPOCH: 8018 LOSS: 41.031987243165574\n",
      "EPOCH: 8019 LOSS: 41.0319790345646\n",
      "EPOCH: 8020 LOSS: 41.03197082727985\n",
      "EPOCH: 8021 LOSS: 41.03196262131104\n",
      "EPOCH: 8022 LOSS: 41.031954416657854\n",
      "EPOCH: 8023 LOSS: 41.03194621332001\n",
      "EPOCH: 8024 LOSS: 41.031938011297235\n",
      "EPOCH: 8025 LOSS: 41.031929810589205\n",
      "EPOCH: 8026 LOSS: 41.03192161119564\n",
      "EPOCH: 8027 LOSS: 41.03191341311624\n",
      "EPOCH: 8028 LOSS: 41.03190521635071\n",
      "EPOCH: 8029 LOSS: 41.03189702089878\n",
      "EPOCH: 8030 LOSS: 41.03188882676012\n",
      "EPOCH: 8031 LOSS: 41.031880633934456\n",
      "EPOCH: 8032 LOSS: 41.03187244242149\n",
      "EPOCH: 8033 LOSS: 41.031864252220934\n",
      "EPOCH: 8034 LOSS: 41.031856063332484\n",
      "EPOCH: 8035 LOSS: 41.03184787575586\n",
      "EPOCH: 8036 LOSS: 41.031839689490745\n",
      "EPOCH: 8037 LOSS: 41.031831504536896\n",
      "EPOCH: 8038 LOSS: 41.03182332089396\n",
      "EPOCH: 8039 LOSS: 41.031815138561676\n",
      "EPOCH: 8040 LOSS: 41.03180695753976\n",
      "EPOCH: 8041 LOSS: 41.031798777827895\n",
      "EPOCH: 8042 LOSS: 41.0317905994258\n",
      "EPOCH: 8043 LOSS: 41.031782422333194\n",
      "EPOCH: 8044 LOSS: 41.03177424654976\n",
      "EPOCH: 8045 LOSS: 41.03176607207522\n",
      "EPOCH: 8046 LOSS: 41.03175789890929\n",
      "EPOCH: 8047 LOSS: 41.03174972705166\n",
      "EPOCH: 8048 LOSS: 41.031741556502055\n",
      "EPOCH: 8049 LOSS: 41.03173338726016\n",
      "EPOCH: 8050 LOSS: 41.03172521932571\n",
      "EPOCH: 8051 LOSS: 41.0317170526984\n",
      "EPOCH: 8052 LOSS: 41.03170888737793\n",
      "EPOCH: 8053 LOSS: 41.03170072336401\n",
      "EPOCH: 8054 LOSS: 41.031692560656374\n",
      "EPOCH: 8055 LOSS: 41.0316843992547\n",
      "EPOCH: 8056 LOSS: 41.031676239158735\n",
      "EPOCH: 8057 LOSS: 41.03166808036813\n",
      "EPOCH: 8058 LOSS: 41.03165992288265\n",
      "EPOCH: 8059 LOSS: 41.03165176670197\n",
      "EPOCH: 8060 LOSS: 41.031643611825814\n",
      "EPOCH: 8061 LOSS: 41.03163545825387\n",
      "EPOCH: 8062 LOSS: 41.031627305985886\n",
      "EPOCH: 8063 LOSS: 41.03161915502153\n",
      "EPOCH: 8064 LOSS: 41.031611005360546\n",
      "EPOCH: 8065 LOSS: 41.031602857002625\n",
      "EPOCH: 8066 LOSS: 41.03159470994748\n",
      "EPOCH: 8067 LOSS: 41.03158656419482\n",
      "EPOCH: 8068 LOSS: 41.03157841974435\n",
      "EPOCH: 8069 LOSS: 41.031570276595794\n",
      "EPOCH: 8070 LOSS: 41.03156213474884\n",
      "EPOCH: 8071 LOSS: 41.03155399420322\n",
      "EPOCH: 8072 LOSS: 41.03154585495864\n",
      "EPOCH: 8073 LOSS: 41.031537717014785\n",
      "EPOCH: 8074 LOSS: 41.03152958037141\n",
      "EPOCH: 8075 LOSS: 41.03152144502819\n",
      "EPOCH: 8076 LOSS: 41.03151331098485\n",
      "EPOCH: 8077 LOSS: 41.031505178241105\n",
      "EPOCH: 8078 LOSS: 41.031497046796645\n",
      "EPOCH: 8079 LOSS: 41.0314889166512\n",
      "EPOCH: 8080 LOSS: 41.03148078780449\n",
      "EPOCH: 8081 LOSS: 41.0314726602562\n",
      "EPOCH: 8082 LOSS: 41.03146453400604\n",
      "EPOCH: 8083 LOSS: 41.031456409053746\n",
      "EPOCH: 8084 LOSS: 41.03144828539902\n",
      "EPOCH: 8085 LOSS: 41.03144016304155\n",
      "EPOCH: 8086 LOSS: 41.03143204198108\n",
      "EPOCH: 8087 LOSS: 41.031423922217314\n",
      "EPOCH: 8088 LOSS: 41.03141580374996\n",
      "EPOCH: 8089 LOSS: 41.03140768657872\n",
      "EPOCH: 8090 LOSS: 41.03139957070333\n",
      "EPOCH: 8091 LOSS: 41.03139145612346\n",
      "EPOCH: 8092 LOSS: 41.031383342838865\n",
      "EPOCH: 8093 LOSS: 41.03137523084924\n",
      "EPOCH: 8094 LOSS: 41.0313671201543\n",
      "EPOCH: 8095 LOSS: 41.03135901075374\n",
      "EPOCH: 8096 LOSS: 41.031350902647304\n",
      "EPOCH: 8097 LOSS: 41.03134279583469\n",
      "EPOCH: 8098 LOSS: 41.03133469031559\n",
      "EPOCH: 8099 LOSS: 41.03132658608974\n",
      "EPOCH: 8100 LOSS: 41.03131848315685\n",
      "EPOCH: 8101 LOSS: 41.03131038151663\n",
      "EPOCH: 8102 LOSS: 41.03130228116879\n",
      "EPOCH: 8103 LOSS: 41.03129418211306\n",
      "EPOCH: 8104 LOSS: 41.03128608434912\n",
      "EPOCH: 8105 LOSS: 41.031277987876706\n",
      "EPOCH: 8106 LOSS: 41.03126989269553\n",
      "EPOCH: 8107 LOSS: 41.0312617988053\n",
      "EPOCH: 8108 LOSS: 41.03125370620575\n",
      "EPOCH: 8109 LOSS: 41.03124561489656\n",
      "EPOCH: 8110 LOSS: 41.031237524877454\n",
      "EPOCH: 8111 LOSS: 41.031229436148166\n",
      "EPOCH: 8112 LOSS: 41.03122134870839\n",
      "EPOCH: 8113 LOSS: 41.03121326255784\n",
      "EPOCH: 8114 LOSS: 41.03120517769623\n",
      "EPOCH: 8115 LOSS: 41.031197094123286\n",
      "EPOCH: 8116 LOSS: 41.03118901183873\n",
      "EPOCH: 8117 LOSS: 41.03118093084224\n",
      "EPOCH: 8118 LOSS: 41.03117285113355\n",
      "EPOCH: 8119 LOSS: 41.03116477271237\n",
      "EPOCH: 8120 LOSS: 41.031156695578446\n",
      "EPOCH: 8121 LOSS: 41.031148619731454\n",
      "EPOCH: 8122 LOSS: 41.03114054517111\n",
      "EPOCH: 8123 LOSS: 41.03113247189716\n",
      "EPOCH: 8124 LOSS: 41.03112439990929\n",
      "EPOCH: 8125 LOSS: 41.031116329207215\n",
      "EPOCH: 8126 LOSS: 41.03110825979067\n",
      "EPOCH: 8127 LOSS: 41.03110019165936\n",
      "EPOCH: 8128 LOSS: 41.031092124813\n",
      "EPOCH: 8129 LOSS: 41.03108405925129\n",
      "EPOCH: 8130 LOSS: 41.03107599497396\n",
      "EPOCH: 8131 LOSS: 41.03106793198076\n",
      "EPOCH: 8132 LOSS: 41.031059870271335\n",
      "EPOCH: 8133 LOSS: 41.03105180984545\n",
      "EPOCH: 8134 LOSS: 41.03104375070281\n",
      "EPOCH: 8135 LOSS: 41.03103569284312\n",
      "EPOCH: 8136 LOSS: 41.0310276362661\n",
      "EPOCH: 8137 LOSS: 41.03101958097149\n",
      "EPOCH: 8138 LOSS: 41.03101152695896\n",
      "EPOCH: 8139 LOSS: 41.03100347422827\n",
      "EPOCH: 8140 LOSS: 41.03099542277912\n",
      "EPOCH: 8141 LOSS: 41.030987372611214\n",
      "EPOCH: 8142 LOSS: 41.03097932372428\n",
      "EPOCH: 8143 LOSS: 41.03097127611804\n",
      "EPOCH: 8144 LOSS: 41.0309632297922\n",
      "EPOCH: 8145 LOSS: 41.0309551847465\n",
      "EPOCH: 8146 LOSS: 41.030947140980615\n",
      "EPOCH: 8147 LOSS: 41.030939098494294\n",
      "EPOCH: 8148 LOSS: 41.03093105728723\n",
      "EPOCH: 8149 LOSS: 41.030923017359186\n",
      "EPOCH: 8150 LOSS: 41.030914978709816\n",
      "EPOCH: 8151 LOSS: 41.0309069413389\n",
      "EPOCH: 8152 LOSS: 41.03089890524609\n",
      "EPOCH: 8153 LOSS: 41.030890870431165\n",
      "EPOCH: 8154 LOSS: 41.030882836893795\n",
      "EPOCH: 8155 LOSS: 41.03087480463373\n",
      "EPOCH: 8156 LOSS: 41.030866773650686\n",
      "EPOCH: 8157 LOSS: 41.03085874394435\n",
      "EPOCH: 8158 LOSS: 41.03085071551447\n",
      "EPOCH: 8159 LOSS: 41.03084268836075\n",
      "EPOCH: 8160 LOSS: 41.0308346624829\n",
      "EPOCH: 8161 LOSS: 41.03082663788069\n",
      "EPOCH: 8162 LOSS: 41.03081861455377\n",
      "EPOCH: 8163 LOSS: 41.03081059250188\n",
      "EPOCH: 8164 LOSS: 41.03080257172476\n",
      "EPOCH: 8165 LOSS: 41.030794552222105\n",
      "EPOCH: 8166 LOSS: 41.03078653399365\n",
      "EPOCH: 8167 LOSS: 41.030778517039096\n",
      "EPOCH: 8168 LOSS: 41.03077050135817\n",
      "EPOCH: 8169 LOSS: 41.03076248695061\n",
      "EPOCH: 8170 LOSS: 41.03075447381611\n",
      "EPOCH: 8171 LOSS: 41.03074646195439\n",
      "EPOCH: 8172 LOSS: 41.03073845136518\n",
      "EPOCH: 8173 LOSS: 41.03073044204819\n",
      "EPOCH: 8174 LOSS: 41.03072243400315\n",
      "EPOCH: 8175 LOSS: 41.03071442722976\n",
      "EPOCH: 8176 LOSS: 41.030706421727764\n",
      "EPOCH: 8177 LOSS: 41.03069841749686\n",
      "EPOCH: 8178 LOSS: 41.03069041453679\n",
      "EPOCH: 8179 LOSS: 41.03068241284724\n",
      "EPOCH: 8180 LOSS: 41.030674412427956\n",
      "EPOCH: 8181 LOSS: 41.03066641327868\n",
      "EPOCH: 8182 LOSS: 41.03065841539907\n",
      "EPOCH: 8183 LOSS: 41.03065041878891\n",
      "EPOCH: 8184 LOSS: 41.03064242344787\n",
      "EPOCH: 8185 LOSS: 41.030634429375695\n",
      "EPOCH: 8186 LOSS: 41.03062643657209\n",
      "EPOCH: 8187 LOSS: 41.03061844503681\n",
      "EPOCH: 8188 LOSS: 41.03061045476953\n",
      "EPOCH: 8189 LOSS: 41.03060246577001\n",
      "EPOCH: 8190 LOSS: 41.03059447803795\n",
      "EPOCH: 8191 LOSS: 41.03058649157307\n",
      "EPOCH: 8192 LOSS: 41.030578506375086\n",
      "EPOCH: 8193 LOSS: 41.03057052244373\n",
      "EPOCH: 8194 LOSS: 41.030562539778714\n",
      "EPOCH: 8195 LOSS: 41.03055455837977\n",
      "EPOCH: 8196 LOSS: 41.03054657824663\n",
      "EPOCH: 8197 LOSS: 41.030538599378986\n",
      "EPOCH: 8198 LOSS: 41.030530621776585\n",
      "EPOCH: 8199 LOSS: 41.03052264543912\n",
      "EPOCH: 8200 LOSS: 41.030514670366344\n",
      "EPOCH: 8201 LOSS: 41.03050669655795\n",
      "EPOCH: 8202 LOSS: 41.03049872401366\n",
      "EPOCH: 8203 LOSS: 41.03049075273323\n",
      "EPOCH: 8204 LOSS: 41.030482782716355\n",
      "EPOCH: 8205 LOSS: 41.03047481396276\n",
      "EPOCH: 8206 LOSS: 41.03046684647218\n",
      "EPOCH: 8207 LOSS: 41.03045888024432\n",
      "EPOCH: 8208 LOSS: 41.03045091527892\n",
      "EPOCH: 8209 LOSS: 41.030442951575665\n",
      "EPOCH: 8210 LOSS: 41.03043498913431\n",
      "EPOCH: 8211 LOSS: 41.03042702795457\n",
      "EPOCH: 8212 LOSS: 41.030419068036174\n",
      "EPOCH: 8213 LOSS: 41.03041110937885\n",
      "EPOCH: 8214 LOSS: 41.030403151982284\n",
      "EPOCH: 8215 LOSS: 41.030395195846246\n",
      "EPOCH: 8216 LOSS: 41.03038724097042\n",
      "EPOCH: 8217 LOSS: 41.030379287354556\n",
      "EPOCH: 8218 LOSS: 41.030371334998364\n",
      "EPOCH: 8219 LOSS: 41.03036338390157\n",
      "EPOCH: 8220 LOSS: 41.03035543406389\n",
      "EPOCH: 8221 LOSS: 41.030347485485066\n",
      "EPOCH: 8222 LOSS: 41.030339538164796\n",
      "EPOCH: 8223 LOSS: 41.03033159210285\n",
      "EPOCH: 8224 LOSS: 41.03032364729887\n",
      "EPOCH: 8225 LOSS: 41.03031570375267\n",
      "EPOCH: 8226 LOSS: 41.03030776146392\n",
      "EPOCH: 8227 LOSS: 41.03029982043233\n",
      "EPOCH: 8228 LOSS: 41.03029188065767\n",
      "EPOCH: 8229 LOSS: 41.03028394213965\n",
      "EPOCH: 8230 LOSS: 41.03027600487797\n",
      "EPOCH: 8231 LOSS: 41.030268068872374\n",
      "EPOCH: 8232 LOSS: 41.03026013412261\n",
      "EPOCH: 8233 LOSS: 41.03025220062834\n",
      "EPOCH: 8234 LOSS: 41.03024426838934\n",
      "EPOCH: 8235 LOSS: 41.03023633740532\n",
      "EPOCH: 8236 LOSS: 41.030228407675985\n",
      "EPOCH: 8237 LOSS: 41.03022047920111\n",
      "EPOCH: 8238 LOSS: 41.030212551980355\n",
      "EPOCH: 8239 LOSS: 41.0302046260135\n",
      "EPOCH: 8240 LOSS: 41.03019670130024\n",
      "EPOCH: 8241 LOSS: 41.03018877784032\n",
      "EPOCH: 8242 LOSS: 41.03018085563343\n",
      "EPOCH: 8243 LOSS: 41.03017293467933\n",
      "EPOCH: 8244 LOSS: 41.03016501497772\n",
      "EPOCH: 8245 LOSS: 41.030157096528356\n",
      "EPOCH: 8246 LOSS: 41.03014917933093\n",
      "EPOCH: 8247 LOSS: 41.0301412633852\n",
      "EPOCH: 8248 LOSS: 41.03013334869086\n",
      "EPOCH: 8249 LOSS: 41.03012543524764\n",
      "EPOCH: 8250 LOSS: 41.03011752305529\n",
      "EPOCH: 8251 LOSS: 41.03010961211353\n",
      "EPOCH: 8252 LOSS: 41.03010170242205\n",
      "EPOCH: 8253 LOSS: 41.03009379398063\n",
      "EPOCH: 8254 LOSS: 41.03008588678895\n",
      "EPOCH: 8255 LOSS: 41.03007798084677\n",
      "EPOCH: 8256 LOSS: 41.03007007615379\n",
      "EPOCH: 8257 LOSS: 41.03006217270974\n",
      "EPOCH: 8258 LOSS: 41.03005427051438\n",
      "EPOCH: 8259 LOSS: 41.030046369567394\n",
      "EPOCH: 8260 LOSS: 41.03003846986853\n",
      "EPOCH: 8261 LOSS: 41.03003057141751\n",
      "EPOCH: 8262 LOSS: 41.030022674214045\n",
      "EPOCH: 8263 LOSS: 41.03001477825789\n",
      "EPOCH: 8264 LOSS: 41.030006883548765\n",
      "EPOCH: 8265 LOSS: 41.02999899008638\n",
      "EPOCH: 8266 LOSS: 41.02999109787047\n",
      "EPOCH: 8267 LOSS: 41.02998320690077\n",
      "EPOCH: 8268 LOSS: 41.029975317177005\n",
      "EPOCH: 8269 LOSS: 41.02996742869891\n",
      "EPOCH: 8270 LOSS: 41.0299595414662\n",
      "EPOCH: 8271 LOSS: 41.029951655478584\n",
      "EPOCH: 8272 LOSS: 41.02994377073582\n",
      "EPOCH: 8273 LOSS: 41.029935887237635\n",
      "EPOCH: 8274 LOSS: 41.02992800498373\n",
      "EPOCH: 8275 LOSS: 41.02992012397386\n",
      "EPOCH: 8276 LOSS: 41.029912244207736\n",
      "EPOCH: 8277 LOSS: 41.02990436568511\n",
      "EPOCH: 8278 LOSS: 41.029896488405676\n",
      "EPOCH: 8279 LOSS: 41.02988861236919\n",
      "EPOCH: 8280 LOSS: 41.029880737575354\n",
      "EPOCH: 8281 LOSS: 41.02987286402393\n",
      "EPOCH: 8282 LOSS: 41.029864991714625\n",
      "EPOCH: 8283 LOSS: 41.029857120647165\n",
      "EPOCH: 8284 LOSS: 41.02984925082127\n",
      "EPOCH: 8285 LOSS: 41.029841382236704\n",
      "EPOCH: 8286 LOSS: 41.02983351489317\n",
      "EPOCH: 8287 LOSS: 41.02982564879039\n",
      "EPOCH: 8288 LOSS: 41.02981778392811\n",
      "EPOCH: 8289 LOSS: 41.02980992030605\n",
      "EPOCH: 8290 LOSS: 41.029802057923966\n",
      "EPOCH: 8291 LOSS: 41.02979419678152\n",
      "EPOCH: 8292 LOSS: 41.02978633687852\n",
      "EPOCH: 8293 LOSS: 41.02977847821464\n",
      "EPOCH: 8294 LOSS: 41.029770620789634\n",
      "EPOCH: 8295 LOSS: 41.02976276460323\n",
      "EPOCH: 8296 LOSS: 41.02975490965515\n",
      "EPOCH: 8297 LOSS: 41.02974705594512\n",
      "EPOCH: 8298 LOSS: 41.02973920347289\n",
      "EPOCH: 8299 LOSS: 41.02973135223817\n",
      "EPOCH: 8300 LOSS: 41.029723502240714\n",
      "EPOCH: 8301 LOSS: 41.02971565348021\n",
      "EPOCH: 8302 LOSS: 41.029707805956406\n",
      "EPOCH: 8303 LOSS: 41.02969995966905\n",
      "EPOCH: 8304 LOSS: 41.02969211461787\n",
      "EPOCH: 8305 LOSS: 41.029684270802576\n",
      "EPOCH: 8306 LOSS: 41.02967642822293\n",
      "EPOCH: 8307 LOSS: 41.02966858687862\n",
      "EPOCH: 8308 LOSS: 41.02966074676941\n",
      "EPOCH: 8309 LOSS: 41.029652907895\n",
      "EPOCH: 8310 LOSS: 41.02964507025516\n",
      "EPOCH: 8311 LOSS: 41.0296372338496\n",
      "EPOCH: 8312 LOSS: 41.02962939867804\n",
      "EPOCH: 8313 LOSS: 41.029621564740225\n",
      "EPOCH: 8314 LOSS: 41.029613732035884\n",
      "EPOCH: 8315 LOSS: 41.02960590056474\n",
      "EPOCH: 8316 LOSS: 41.02959807032654\n",
      "EPOCH: 8317 LOSS: 41.02959024132102\n",
      "EPOCH: 8318 LOSS: 41.029582413547864\n",
      "EPOCH: 8319 LOSS: 41.02957458700686\n",
      "EPOCH: 8320 LOSS: 41.02956676169771\n",
      "EPOCH: 8321 LOSS: 41.02955893762016\n",
      "EPOCH: 8322 LOSS: 41.02955111477392\n",
      "EPOCH: 8323 LOSS: 41.02954329315875\n",
      "EPOCH: 8324 LOSS: 41.02953547277437\n",
      "EPOCH: 8325 LOSS: 41.02952765362049\n",
      "EPOCH: 8326 LOSS: 41.029519835696874\n",
      "EPOCH: 8327 LOSS: 41.029512019003235\n",
      "EPOCH: 8328 LOSS: 41.029504203539325\n",
      "EPOCH: 8329 LOSS: 41.02949638930485\n",
      "EPOCH: 8330 LOSS: 41.029488576299556\n",
      "EPOCH: 8331 LOSS: 41.02948076452317\n",
      "EPOCH: 8332 LOSS: 41.029472953975436\n",
      "EPOCH: 8333 LOSS: 41.029465144656086\n",
      "EPOCH: 8334 LOSS: 41.02945733656484\n",
      "EPOCH: 8335 LOSS: 41.02944952970143\n",
      "EPOCH: 8336 LOSS: 41.02944172406559\n",
      "EPOCH: 8337 LOSS: 41.02943391965708\n",
      "EPOCH: 8338 LOSS: 41.02942611647559\n",
      "EPOCH: 8339 LOSS: 41.029418314520896\n",
      "EPOCH: 8340 LOSS: 41.02941051379268\n",
      "EPOCH: 8341 LOSS: 41.02940271429074\n",
      "EPOCH: 8342 LOSS: 41.02939491601474\n",
      "EPOCH: 8343 LOSS: 41.029387118964465\n",
      "EPOCH: 8344 LOSS: 41.02937932313961\n",
      "EPOCH: 8345 LOSS: 41.02937152853996\n",
      "EPOCH: 8346 LOSS: 41.029363735165205\n",
      "EPOCH: 8347 LOSS: 41.0293559430151\n",
      "EPOCH: 8348 LOSS: 41.02934815208935\n",
      "EPOCH: 8349 LOSS: 41.029340362387714\n",
      "EPOCH: 8350 LOSS: 41.02933257390991\n",
      "EPOCH: 8351 LOSS: 41.02932478665571\n",
      "EPOCH: 8352 LOSS: 41.02931700062481\n",
      "EPOCH: 8353 LOSS: 41.02930921581695\n",
      "EPOCH: 8354 LOSS: 41.029301432231875\n",
      "EPOCH: 8355 LOSS: 41.0292936498693\n",
      "EPOCH: 8356 LOSS: 41.029285868729005\n",
      "EPOCH: 8357 LOSS: 41.029278088810656\n",
      "EPOCH: 8358 LOSS: 41.02927031011404\n",
      "EPOCH: 8359 LOSS: 41.029262532638874\n",
      "EPOCH: 8360 LOSS: 41.029254756384894\n",
      "EPOCH: 8361 LOSS: 41.02924698135183\n",
      "EPOCH: 8362 LOSS: 41.029239207539426\n",
      "EPOCH: 8363 LOSS: 41.02923143494741\n",
      "EPOCH: 8364 LOSS: 41.029223663575515\n",
      "EPOCH: 8365 LOSS: 41.0292158934235\n",
      "EPOCH: 8366 LOSS: 41.029208124491056\n",
      "EPOCH: 8367 LOSS: 41.02920035677796\n",
      "EPOCH: 8368 LOSS: 41.02919259028392\n",
      "EPOCH: 8369 LOSS: 41.0291848250087\n",
      "EPOCH: 8370 LOSS: 41.029177060951994\n",
      "EPOCH: 8371 LOSS: 41.02916929811356\n",
      "EPOCH: 8372 LOSS: 41.02916153649315\n",
      "EPOCH: 8373 LOSS: 41.02915377609048\n",
      "EPOCH: 8374 LOSS: 41.0291460169053\n",
      "EPOCH: 8375 LOSS: 41.02913825893734\n",
      "EPOCH: 8376 LOSS: 41.029130502186305\n",
      "EPOCH: 8377 LOSS: 41.02912274665198\n",
      "EPOCH: 8378 LOSS: 41.029114992334065\n",
      "EPOCH: 8379 LOSS: 41.02910723923232\n",
      "EPOCH: 8380 LOSS: 41.029099487346464\n",
      "EPOCH: 8381 LOSS: 41.02909173667624\n",
      "EPOCH: 8382 LOSS: 41.0290839872214\n",
      "EPOCH: 8383 LOSS: 41.02907623898165\n",
      "EPOCH: 8384 LOSS: 41.02906849195675\n",
      "EPOCH: 8385 LOSS: 41.02906074614643\n",
      "EPOCH: 8386 LOSS: 41.02905300155042\n",
      "EPOCH: 8387 LOSS: 41.029045258168466\n",
      "EPOCH: 8388 LOSS: 41.02903751600033\n",
      "EPOCH: 8389 LOSS: 41.02902977504567\n",
      "EPOCH: 8390 LOSS: 41.029022035304315\n",
      "EPOCH: 8391 LOSS: 41.02901429677594\n",
      "EPOCH: 8392 LOSS: 41.0290065594603\n",
      "EPOCH: 8393 LOSS: 41.028998823357156\n",
      "EPOCH: 8394 LOSS: 41.02899108846621\n",
      "EPOCH: 8395 LOSS: 41.02898335478723\n",
      "EPOCH: 8396 LOSS: 41.02897562231992\n",
      "EPOCH: 8397 LOSS: 41.02896789106404\n",
      "EPOCH: 8398 LOSS: 41.02896016101933\n",
      "EPOCH: 8399 LOSS: 41.02895243218552\n",
      "EPOCH: 8400 LOSS: 41.028944704562335\n",
      "EPOCH: 8401 LOSS: 41.02893697814954\n",
      "EPOCH: 8402 LOSS: 41.02892925294687\n",
      "EPOCH: 8403 LOSS: 41.02892152895403\n",
      "EPOCH: 8404 LOSS: 41.0289138061708\n",
      "EPOCH: 8405 LOSS: 41.02890608459689\n",
      "EPOCH: 8406 LOSS: 41.02889836423205\n",
      "EPOCH: 8407 LOSS: 41.02889064507602\n",
      "EPOCH: 8408 LOSS: 41.02888292712853\n",
      "EPOCH: 8409 LOSS: 41.02887521038932\n",
      "EPOCH: 8410 LOSS: 41.02886749485813\n",
      "EPOCH: 8411 LOSS: 41.02885978053471\n",
      "EPOCH: 8412 LOSS: 41.028852067418796\n",
      "EPOCH: 8413 LOSS: 41.02884435551011\n",
      "EPOCH: 8414 LOSS: 41.0288366448084\n",
      "EPOCH: 8415 LOSS: 41.02882893531342\n",
      "EPOCH: 8416 LOSS: 41.028821227024885\n",
      "EPOCH: 8417 LOSS: 41.028813519942545\n",
      "EPOCH: 8418 LOSS: 41.02880581406614\n",
      "EPOCH: 8419 LOSS: 41.0287981093954\n",
      "EPOCH: 8420 LOSS: 41.02879040593009\n",
      "EPOCH: 8421 LOSS: 41.02878270366992\n",
      "EPOCH: 8422 LOSS: 41.02877500261466\n",
      "EPOCH: 8423 LOSS: 41.02876730276401\n",
      "EPOCH: 8424 LOSS: 41.02875960411773\n",
      "EPOCH: 8425 LOSS: 41.028751906675566\n",
      "EPOCH: 8426 LOSS: 41.02874421043727\n",
      "EPOCH: 8427 LOSS: 41.02873651540254\n",
      "EPOCH: 8428 LOSS: 41.02872882157115\n",
      "EPOCH: 8429 LOSS: 41.02872112894285\n",
      "EPOCH: 8430 LOSS: 41.02871343751734\n",
      "EPOCH: 8431 LOSS: 41.02870574729439\n",
      "EPOCH: 8432 LOSS: 41.02869805827372\n",
      "EPOCH: 8433 LOSS: 41.02869037045511\n",
      "EPOCH: 8434 LOSS: 41.02868268383825\n",
      "EPOCH: 8435 LOSS: 41.0286749984229\n",
      "EPOCH: 8436 LOSS: 41.028667314208825\n",
      "EPOCH: 8437 LOSS: 41.02865963119572\n",
      "EPOCH: 8438 LOSS: 41.028651949383374\n",
      "EPOCH: 8439 LOSS: 41.02864426877149\n",
      "EPOCH: 8440 LOSS: 41.028636589359834\n",
      "EPOCH: 8441 LOSS: 41.02862891114814\n",
      "EPOCH: 8442 LOSS: 41.028621234136125\n",
      "EPOCH: 8443 LOSS: 41.02861355832358\n",
      "EPOCH: 8444 LOSS: 41.0286058837102\n",
      "EPOCH: 8445 LOSS: 41.02859821029575\n",
      "EPOCH: 8446 LOSS: 41.028590538079946\n",
      "EPOCH: 8447 LOSS: 41.02858286706257\n",
      "EPOCH: 8448 LOSS: 41.028575197243335\n",
      "EPOCH: 8449 LOSS: 41.028567528621984\n",
      "EPOCH: 8450 LOSS: 41.028559861198275\n",
      "EPOCH: 8451 LOSS: 41.028552194971944\n",
      "EPOCH: 8452 LOSS: 41.02854452994272\n",
      "EPOCH: 8453 LOSS: 41.02853686611036\n",
      "EPOCH: 8454 LOSS: 41.02852920347458\n",
      "EPOCH: 8455 LOSS: 41.028521542035165\n",
      "EPOCH: 8456 LOSS: 41.02851388179182\n",
      "EPOCH: 8457 LOSS: 41.02850622274431\n",
      "EPOCH: 8458 LOSS: 41.02849856489235\n",
      "EPOCH: 8459 LOSS: 41.028490908235725\n",
      "EPOCH: 8460 LOSS: 41.028483252774144\n",
      "EPOCH: 8461 LOSS: 41.02847559850737\n",
      "EPOCH: 8462 LOSS: 41.02846794543511\n",
      "EPOCH: 8463 LOSS: 41.028460293557146\n",
      "EPOCH: 8464 LOSS: 41.02845264287322\n",
      "EPOCH: 8465 LOSS: 41.02844499338305\n",
      "EPOCH: 8466 LOSS: 41.02843734508638\n",
      "EPOCH: 8467 LOSS: 41.028429697982965\n",
      "EPOCH: 8468 LOSS: 41.02842205207256\n",
      "EPOCH: 8469 LOSS: 41.02841440735489\n",
      "EPOCH: 8470 LOSS: 41.02840676382969\n",
      "EPOCH: 8471 LOSS: 41.028399121496726\n",
      "EPOCH: 8472 LOSS: 41.02839148035574\n",
      "EPOCH: 8473 LOSS: 41.02838384040646\n",
      "EPOCH: 8474 LOSS: 41.02837620164863\n",
      "EPOCH: 8475 LOSS: 41.02836856408201\n",
      "EPOCH: 8476 LOSS: 41.02836092770633\n",
      "EPOCH: 8477 LOSS: 41.02835329252134\n",
      "EPOCH: 8478 LOSS: 41.028345658526774\n",
      "EPOCH: 8479 LOSS: 41.028338025722384\n",
      "EPOCH: 8480 LOSS: 41.028330394107925\n",
      "EPOCH: 8481 LOSS: 41.02832276368313\n",
      "EPOCH: 8482 LOSS: 41.02831513444773\n",
      "EPOCH: 8483 LOSS: 41.02830750640149\n",
      "EPOCH: 8484 LOSS: 41.02829987954416\n",
      "EPOCH: 8485 LOSS: 41.02829225387545\n",
      "EPOCH: 8486 LOSS: 41.028284629395145\n",
      "EPOCH: 8487 LOSS: 41.028277006102954\n",
      "EPOCH: 8488 LOSS: 41.028269383998634\n",
      "EPOCH: 8489 LOSS: 41.02826176308195\n",
      "EPOCH: 8490 LOSS: 41.02825414335263\n",
      "EPOCH: 8491 LOSS: 41.02824652481041\n",
      "EPOCH: 8492 LOSS: 41.02823890745505\n",
      "EPOCH: 8493 LOSS: 41.02823129128629\n",
      "EPOCH: 8494 LOSS: 41.02822367630387\n",
      "EPOCH: 8495 LOSS: 41.02821606250754\n",
      "EPOCH: 8496 LOSS: 41.028208449897036\n",
      "EPOCH: 8497 LOSS: 41.02820083847213\n",
      "EPOCH: 8498 LOSS: 41.028193228232546\n",
      "EPOCH: 8499 LOSS: 41.02818561917802\n",
      "EPOCH: 8500 LOSS: 41.02817801130831\n",
      "EPOCH: 8501 LOSS: 41.028170404623175\n",
      "EPOCH: 8502 LOSS: 41.02816279912234\n",
      "EPOCH: 8503 LOSS: 41.02815519480557\n",
      "EPOCH: 8504 LOSS: 41.02814759167259\n",
      "EPOCH: 8505 LOSS: 41.02813998972315\n",
      "EPOCH: 8506 LOSS: 41.028132388957026\n",
      "EPOCH: 8507 LOSS: 41.028124789373905\n",
      "EPOCH: 8508 LOSS: 41.0281171909736\n",
      "EPOCH: 8509 LOSS: 41.02810959375579\n",
      "EPOCH: 8510 LOSS: 41.02810199772028\n",
      "EPOCH: 8511 LOSS: 41.028094402866785\n",
      "EPOCH: 8512 LOSS: 41.02808680919507\n",
      "EPOCH: 8513 LOSS: 41.02807921670486\n",
      "EPOCH: 8514 LOSS: 41.02807162539592\n",
      "EPOCH: 8515 LOSS: 41.028064035267974\n",
      "EPOCH: 8516 LOSS: 41.0280564463208\n",
      "EPOCH: 8517 LOSS: 41.02804885855411\n",
      "EPOCH: 8518 LOSS: 41.028041271967695\n",
      "EPOCH: 8519 LOSS: 41.02803368656126\n",
      "EPOCH: 8520 LOSS: 41.02802610233458\n",
      "EPOCH: 8521 LOSS: 41.02801851928736\n",
      "EPOCH: 8522 LOSS: 41.0280109374194\n",
      "EPOCH: 8523 LOSS: 41.02800335673042\n",
      "EPOCH: 8524 LOSS: 41.027995777220184\n",
      "EPOCH: 8525 LOSS: 41.027988198888416\n",
      "EPOCH: 8526 LOSS: 41.027980621734876\n",
      "EPOCH: 8527 LOSS: 41.02797304575932\n",
      "EPOCH: 8528 LOSS: 41.02796547096148\n",
      "EPOCH: 8529 LOSS: 41.027957897341096\n",
      "EPOCH: 8530 LOSS: 41.02795032489795\n",
      "EPOCH: 8531 LOSS: 41.027942753631756\n",
      "EPOCH: 8532 LOSS: 41.02793518354229\n",
      "EPOCH: 8533 LOSS: 41.02792761462928\n",
      "EPOCH: 8534 LOSS: 41.02792004689248\n",
      "EPOCH: 8535 LOSS: 41.027912480331615\n",
      "EPOCH: 8536 LOSS: 41.0279049149465\n",
      "EPOCH: 8537 LOSS: 41.0278973507368\n",
      "EPOCH: 8538 LOSS: 41.02788978770232\n",
      "EPOCH: 8539 LOSS: 41.027882225842795\n",
      "EPOCH: 8540 LOSS: 41.02787466515797\n",
      "EPOCH: 8541 LOSS: 41.02786710564757\n",
      "EPOCH: 8542 LOSS: 41.027859547311394\n",
      "EPOCH: 8543 LOSS: 41.02785199014916\n",
      "EPOCH: 8544 LOSS: 41.02784443416063\n",
      "EPOCH: 8545 LOSS: 41.0278368793455\n",
      "EPOCH: 8546 LOSS: 41.02782932570361\n",
      "EPOCH: 8547 LOSS: 41.02782177323464\n",
      "EPOCH: 8548 LOSS: 41.027814221938364\n",
      "EPOCH: 8549 LOSS: 41.02780667181452\n",
      "EPOCH: 8550 LOSS: 41.02779912286289\n",
      "EPOCH: 8551 LOSS: 41.027791575083164\n",
      "EPOCH: 8552 LOSS: 41.02778402847515\n",
      "EPOCH: 8553 LOSS: 41.02777648303857\n",
      "EPOCH: 8554 LOSS: 41.02776893877317\n",
      "EPOCH: 8555 LOSS: 41.02776139567872\n",
      "EPOCH: 8556 LOSS: 41.027753853754945\n",
      "EPOCH: 8557 LOSS: 41.02774631300161\n",
      "EPOCH: 8558 LOSS: 41.02773877341846\n",
      "EPOCH: 8559 LOSS: 41.02773123500525\n",
      "EPOCH: 8560 LOSS: 41.02772369776171\n",
      "EPOCH: 8561 LOSS: 41.02771616168763\n",
      "EPOCH: 8562 LOSS: 41.027708626782704\n",
      "EPOCH: 8563 LOSS: 41.02770109304676\n",
      "EPOCH: 8564 LOSS: 41.02769356047946\n",
      "EPOCH: 8565 LOSS: 41.02768602908062\n",
      "EPOCH: 8566 LOSS: 41.027678498849966\n",
      "EPOCH: 8567 LOSS: 41.02767096978724\n",
      "EPOCH: 8568 LOSS: 41.02766344189221\n",
      "EPOCH: 8569 LOSS: 41.02765591516461\n",
      "EPOCH: 8570 LOSS: 41.0276483896042\n",
      "EPOCH: 8571 LOSS: 41.02764086521075\n",
      "EPOCH: 8572 LOSS: 41.02763334198398\n",
      "EPOCH: 8573 LOSS: 41.02762581992366\n",
      "EPOCH: 8574 LOSS: 41.02761829902953\n",
      "EPOCH: 8575 LOSS: 41.027610779301334\n",
      "EPOCH: 8576 LOSS: 41.027603260738836\n",
      "EPOCH: 8577 LOSS: 41.02759574334179\n",
      "EPOCH: 8578 LOSS: 41.027588227109945\n",
      "EPOCH: 8579 LOSS: 41.02758071204305\n",
      "EPOCH: 8580 LOSS: 41.02757319814086\n",
      "EPOCH: 8581 LOSS: 41.027565685403104\n",
      "EPOCH: 8582 LOSS: 41.027558173829576\n",
      "EPOCH: 8583 LOSS: 41.02755066341999\n",
      "EPOCH: 8584 LOSS: 41.02754315417412\n",
      "EPOCH: 8585 LOSS: 41.02753564609171\n",
      "EPOCH: 8586 LOSS: 41.0275281391725\n",
      "EPOCH: 8587 LOSS: 41.02752063341625\n",
      "EPOCH: 8588 LOSS: 41.02751312882274\n",
      "EPOCH: 8589 LOSS: 41.02750562539167\n",
      "EPOCH: 8590 LOSS: 41.02749812312284\n",
      "EPOCH: 8591 LOSS: 41.02749062201599\n",
      "EPOCH: 8592 LOSS: 41.02748312207085\n",
      "EPOCH: 8593 LOSS: 41.027475623287174\n",
      "EPOCH: 8594 LOSS: 41.02746812566477\n",
      "EPOCH: 8595 LOSS: 41.0274606292033\n",
      "EPOCH: 8596 LOSS: 41.02745313390258\n",
      "EPOCH: 8597 LOSS: 41.02744563976236\n",
      "EPOCH: 8598 LOSS: 41.02743814678238\n",
      "EPOCH: 8599 LOSS: 41.02743065496237\n",
      "EPOCH: 8600 LOSS: 41.02742316430212\n",
      "EPOCH: 8601 LOSS: 41.02741567480139\n",
      "EPOCH: 8602 LOSS: 41.02740818645989\n",
      "EPOCH: 8603 LOSS: 41.027400699277386\n",
      "EPOCH: 8604 LOSS: 41.02739321325365\n",
      "EPOCH: 8605 LOSS: 41.02738572838843\n",
      "EPOCH: 8606 LOSS: 41.02737824468147\n",
      "EPOCH: 8607 LOSS: 41.027370762132534\n",
      "EPOCH: 8608 LOSS: 41.02736328074137\n",
      "EPOCH: 8609 LOSS: 41.02735580050773\n",
      "EPOCH: 8610 LOSS: 41.02734832143136\n",
      "EPOCH: 8611 LOSS: 41.02734084351203\n",
      "EPOCH: 8612 LOSS: 41.027333366749474\n",
      "EPOCH: 8613 LOSS: 41.02732589114348\n",
      "EPOCH: 8614 LOSS: 41.027318416693774\n",
      "EPOCH: 8615 LOSS: 41.02731094340011\n",
      "EPOCH: 8616 LOSS: 41.02730347126226\n",
      "EPOCH: 8617 LOSS: 41.027296000279954\n",
      "EPOCH: 8618 LOSS: 41.02728853045295\n",
      "EPOCH: 8619 LOSS: 41.02728106178103\n",
      "EPOCH: 8620 LOSS: 41.027273594263924\n",
      "EPOCH: 8621 LOSS: 41.0272661279014\n",
      "EPOCH: 8622 LOSS: 41.027258662693185\n",
      "EPOCH: 8623 LOSS: 41.027251198639064\n",
      "EPOCH: 8624 LOSS: 41.02724373573878\n",
      "EPOCH: 8625 LOSS: 41.02723627399209\n",
      "EPOCH: 8626 LOSS: 41.02722881339874\n",
      "EPOCH: 8627 LOSS: 41.02722135395848\n",
      "EPOCH: 8628 LOSS: 41.0272138956711\n",
      "EPOCH: 8629 LOSS: 41.027206438536325\n",
      "EPOCH: 8630 LOSS: 41.02719898255391\n",
      "EPOCH: 8631 LOSS: 41.027191527723616\n",
      "EPOCH: 8632 LOSS: 41.0271840740452\n",
      "EPOCH: 8633 LOSS: 41.02717662151843\n",
      "EPOCH: 8634 LOSS: 41.02716917014305\n",
      "EPOCH: 8635 LOSS: 41.02716171991879\n",
      "EPOCH: 8636 LOSS: 41.02715427084544\n",
      "EPOCH: 8637 LOSS: 41.027146822922745\n",
      "EPOCH: 8638 LOSS: 41.02713937615047\n",
      "EPOCH: 8639 LOSS: 41.027131930528334\n",
      "EPOCH: 8640 LOSS: 41.02712448605613\n",
      "EPOCH: 8641 LOSS: 41.02711704273362\n",
      "EPOCH: 8642 LOSS: 41.027109600560536\n",
      "EPOCH: 8643 LOSS: 41.027102159536646\n",
      "EPOCH: 8644 LOSS: 41.027094719661676\n",
      "EPOCH: 8645 LOSS: 41.02708728093542\n",
      "EPOCH: 8646 LOSS: 41.027079843357626\n",
      "EPOCH: 8647 LOSS: 41.027072406928035\n",
      "EPOCH: 8648 LOSS: 41.027064971646425\n",
      "EPOCH: 8649 LOSS: 41.02705753751253\n",
      "EPOCH: 8650 LOSS: 41.027050104526154\n",
      "EPOCH: 8651 LOSS: 41.02704267268697\n",
      "EPOCH: 8652 LOSS: 41.027035241994795\n",
      "EPOCH: 8653 LOSS: 41.02702781244938\n",
      "EPOCH: 8654 LOSS: 41.02702038405047\n",
      "EPOCH: 8655 LOSS: 41.02701295679785\n",
      "EPOCH: 8656 LOSS: 41.02700553069123\n",
      "EPOCH: 8657 LOSS: 41.02699810573038\n",
      "EPOCH: 8658 LOSS: 41.02699068191508\n",
      "EPOCH: 8659 LOSS: 41.026983259245085\n",
      "EPOCH: 8660 LOSS: 41.02697583772013\n",
      "EPOCH: 8661 LOSS: 41.02696841733998\n",
      "EPOCH: 8662 LOSS: 41.0269609981044\n",
      "EPOCH: 8663 LOSS: 41.02695358001315\n",
      "EPOCH: 8664 LOSS: 41.02694616306597\n",
      "EPOCH: 8665 LOSS: 41.02693874726263\n",
      "EPOCH: 8666 LOSS: 41.0269313326029\n",
      "EPOCH: 8667 LOSS: 41.026923919086514\n",
      "EPOCH: 8668 LOSS: 41.026916506713235\n",
      "EPOCH: 8669 LOSS: 41.026909095482836\n",
      "EPOCH: 8670 LOSS: 41.02690168539505\n",
      "EPOCH: 8671 LOSS: 41.02689427644967\n",
      "EPOCH: 8672 LOSS: 41.0268868686464\n",
      "EPOCH: 8673 LOSS: 41.02687946198507\n",
      "EPOCH: 8674 LOSS: 41.02687205646537\n",
      "EPOCH: 8675 LOSS: 41.026864652087106\n",
      "EPOCH: 8676 LOSS: 41.02685724885001\n",
      "EPOCH: 8677 LOSS: 41.026849846753855\n",
      "EPOCH: 8678 LOSS: 41.02684244579838\n",
      "EPOCH: 8679 LOSS: 41.02683504598336\n",
      "EPOCH: 8680 LOSS: 41.02682764730855\n",
      "EPOCH: 8681 LOSS: 41.026820249773714\n",
      "EPOCH: 8682 LOSS: 41.026812853378615\n",
      "EPOCH: 8683 LOSS: 41.02680545812298\n",
      "EPOCH: 8684 LOSS: 41.02679806400659\n",
      "EPOCH: 8685 LOSS: 41.026790671029225\n",
      "EPOCH: 8686 LOSS: 41.0267832791906\n",
      "EPOCH: 8687 LOSS: 41.02677588849052\n",
      "EPOCH: 8688 LOSS: 41.02676849892872\n",
      "EPOCH: 8689 LOSS: 41.026761110504935\n",
      "EPOCH: 8690 LOSS: 41.026753723218974\n",
      "EPOCH: 8691 LOSS: 41.02674633707057\n",
      "EPOCH: 8692 LOSS: 41.026738952059475\n",
      "EPOCH: 8693 LOSS: 41.026731568185454\n",
      "EPOCH: 8694 LOSS: 41.02672418544827\n",
      "EPOCH: 8695 LOSS: 41.0267168038477\n",
      "EPOCH: 8696 LOSS: 41.02670942338347\n",
      "EPOCH: 8697 LOSS: 41.02670204405537\n",
      "EPOCH: 8698 LOSS: 41.02669466586315\n",
      "EPOCH: 8699 LOSS: 41.02668728880655\n",
      "EPOCH: 8700 LOSS: 41.026679912885356\n",
      "EPOCH: 8701 LOSS: 41.02667253809932\n",
      "EPOCH: 8702 LOSS: 41.02666516444819\n",
      "EPOCH: 8703 LOSS: 41.02665779193173\n",
      "EPOCH: 8704 LOSS: 41.02665042054973\n",
      "EPOCH: 8705 LOSS: 41.026643050301914\n",
      "EPOCH: 8706 LOSS: 41.02663568118805\n",
      "EPOCH: 8707 LOSS: 41.02662831320792\n",
      "EPOCH: 8708 LOSS: 41.02662094636126\n",
      "EPOCH: 8709 LOSS: 41.026613580647826\n",
      "EPOCH: 8710 LOSS: 41.026606216067414\n",
      "EPOCH: 8711 LOSS: 41.02659885261975\n",
      "EPOCH: 8712 LOSS: 41.02659149030462\n",
      "EPOCH: 8713 LOSS: 41.02658412912176\n",
      "EPOCH: 8714 LOSS: 41.02657676907095\n",
      "EPOCH: 8715 LOSS: 41.02656941015194\n",
      "EPOCH: 8716 LOSS: 41.0265620523645\n",
      "EPOCH: 8717 LOSS: 41.02655469570838\n",
      "EPOCH: 8718 LOSS: 41.02654734018335\n",
      "EPOCH: 8719 LOSS: 41.02653998578918\n",
      "EPOCH: 8720 LOSS: 41.0265326325256\n",
      "EPOCH: 8721 LOSS: 41.026525280392406\n",
      "EPOCH: 8722 LOSS: 41.02651792938933\n",
      "EPOCH: 8723 LOSS: 41.02651057951614\n",
      "EPOCH: 8724 LOSS: 41.02650323077264\n",
      "EPOCH: 8725 LOSS: 41.026495883158546\n",
      "EPOCH: 8726 LOSS: 41.02648853667363\n",
      "EPOCH: 8727 LOSS: 41.02648119131766\n",
      "EPOCH: 8728 LOSS: 41.02647384709038\n",
      "EPOCH: 8729 LOSS: 41.02646650399156\n",
      "EPOCH: 8730 LOSS: 41.026459162020984\n",
      "EPOCH: 8731 LOSS: 41.0264518211784\n",
      "EPOCH: 8732 LOSS: 41.026444481463564\n",
      "EPOCH: 8733 LOSS: 41.02643714287623\n",
      "EPOCH: 8734 LOSS: 41.026429805416186\n",
      "EPOCH: 8735 LOSS: 41.02642246908319\n",
      "EPOCH: 8736 LOSS: 41.02641513387698\n",
      "EPOCH: 8737 LOSS: 41.02640779979733\n",
      "EPOCH: 8738 LOSS: 41.02640046684401\n",
      "EPOCH: 8739 LOSS: 41.02639313501679\n",
      "EPOCH: 8740 LOSS: 41.0263858043154\n",
      "EPOCH: 8741 LOSS: 41.02637847473964\n",
      "EPOCH: 8742 LOSS: 41.02637114628926\n",
      "EPOCH: 8743 LOSS: 41.02636381896401\n",
      "EPOCH: 8744 LOSS: 41.02635649276368\n",
      "EPOCH: 8745 LOSS: 41.02634916768801\n",
      "EPOCH: 8746 LOSS: 41.02634184373676\n",
      "EPOCH: 8747 LOSS: 41.02633452090971\n",
      "EPOCH: 8748 LOSS: 41.026327199206605\n",
      "EPOCH: 8749 LOSS: 41.02631987862722\n",
      "EPOCH: 8750 LOSS: 41.02631255917132\n",
      "EPOCH: 8751 LOSS: 41.02630524083868\n",
      "EPOCH: 8752 LOSS: 41.026297923629045\n",
      "EPOCH: 8753 LOSS: 41.026290607542165\n",
      "EPOCH: 8754 LOSS: 41.026283292577844\n",
      "EPOCH: 8755 LOSS: 41.02627597873582\n",
      "EPOCH: 8756 LOSS: 41.02626866601585\n",
      "EPOCH: 8757 LOSS: 41.02626135441771\n",
      "EPOCH: 8758 LOSS: 41.02625404394116\n",
      "EPOCH: 8759 LOSS: 41.02624673458598\n",
      "EPOCH: 8760 LOSS: 41.02623942635191\n",
      "EPOCH: 8761 LOSS: 41.02623211923873\n",
      "EPOCH: 8762 LOSS: 41.02622481324619\n",
      "EPOCH: 8763 LOSS: 41.02621750837406\n",
      "EPOCH: 8764 LOSS: 41.02621020462212\n",
      "EPOCH: 8765 LOSS: 41.02620290199012\n",
      "EPOCH: 8766 LOSS: 41.02619560047781\n",
      "EPOCH: 8767 LOSS: 41.026188300084996\n",
      "EPOCH: 8768 LOSS: 41.0261810008114\n",
      "EPOCH: 8769 LOSS: 41.02617370265682\n",
      "EPOCH: 8770 LOSS: 41.026166405620984\n",
      "EPOCH: 8771 LOSS: 41.026159109703684\n",
      "EPOCH: 8772 LOSS: 41.026151814904686\n",
      "EPOCH: 8773 LOSS: 41.02614452122374\n",
      "EPOCH: 8774 LOSS: 41.02613722866062\n",
      "EPOCH: 8775 LOSS: 41.02612993721509\n",
      "EPOCH: 8776 LOSS: 41.026122646886925\n",
      "EPOCH: 8777 LOSS: 41.02611535767587\n",
      "EPOCH: 8778 LOSS: 41.0261080695817\n",
      "EPOCH: 8779 LOSS: 41.02610078260418\n",
      "EPOCH: 8780 LOSS: 41.02609349674309\n",
      "EPOCH: 8781 LOSS: 41.02608621199815\n",
      "EPOCH: 8782 LOSS: 41.02607892836918\n",
      "EPOCH: 8783 LOSS: 41.02607164585593\n",
      "EPOCH: 8784 LOSS: 41.026064364458136\n",
      "EPOCH: 8785 LOSS: 41.026057084175584\n",
      "EPOCH: 8786 LOSS: 41.02604980500807\n",
      "EPOCH: 8787 LOSS: 41.02604252695532\n",
      "EPOCH: 8788 LOSS: 41.0260352500171\n",
      "EPOCH: 8789 LOSS: 41.02602797419319\n",
      "EPOCH: 8790 LOSS: 41.02602069948337\n",
      "EPOCH: 8791 LOSS: 41.02601342588737\n",
      "EPOCH: 8792 LOSS: 41.02600615340499\n",
      "EPOCH: 8793 LOSS: 41.02599888203598\n",
      "EPOCH: 8794 LOSS: 41.0259916117801\n",
      "EPOCH: 8795 LOSS: 41.02598434263713\n",
      "EPOCH: 8796 LOSS: 41.02597707460682\n",
      "EPOCH: 8797 LOSS: 41.02596980768898\n",
      "EPOCH: 8798 LOSS: 41.02596254188332\n",
      "EPOCH: 8799 LOSS: 41.025955277189645\n",
      "EPOCH: 8800 LOSS: 41.02594801360769\n",
      "EPOCH: 8801 LOSS: 41.025940751137256\n",
      "EPOCH: 8802 LOSS: 41.02593348977809\n",
      "EPOCH: 8803 LOSS: 41.02592622952996\n",
      "EPOCH: 8804 LOSS: 41.02591897039265\n",
      "EPOCH: 8805 LOSS: 41.02591171236588\n",
      "EPOCH: 8806 LOSS: 41.02590445544948\n",
      "EPOCH: 8807 LOSS: 41.02589719964319\n",
      "EPOCH: 8808 LOSS: 41.025889944946755\n",
      "EPOCH: 8809 LOSS: 41.02588269135997\n",
      "EPOCH: 8810 LOSS: 41.02587543888259\n",
      "EPOCH: 8811 LOSS: 41.0258681875144\n",
      "EPOCH: 8812 LOSS: 41.025860937255146\n",
      "EPOCH: 8813 LOSS: 41.025853688104604\n",
      "EPOCH: 8814 LOSS: 41.02584644006254\n",
      "EPOCH: 8815 LOSS: 41.02583919312872\n",
      "EPOCH: 8816 LOSS: 41.02583194730292\n",
      "EPOCH: 8817 LOSS: 41.02582470258491\n",
      "EPOCH: 8818 LOSS: 41.025817458974444\n",
      "EPOCH: 8819 LOSS: 41.0258102164713\n",
      "EPOCH: 8820 LOSS: 41.025802975075244\n",
      "EPOCH: 8821 LOSS: 41.02579573478603\n",
      "EPOCH: 8822 LOSS: 41.02578849560345\n",
      "EPOCH: 8823 LOSS: 41.02578125752727\n",
      "EPOCH: 8824 LOSS: 41.02577402055726\n",
      "EPOCH: 8825 LOSS: 41.02576678469315\n",
      "EPOCH: 8826 LOSS: 41.02575954993475\n",
      "EPOCH: 8827 LOSS: 41.0257523162818\n",
      "EPOCH: 8828 LOSS: 41.0257450837341\n",
      "EPOCH: 8829 LOSS: 41.0257378522914\n",
      "EPOCH: 8830 LOSS: 41.02573062195347\n",
      "EPOCH: 8831 LOSS: 41.025723392720096\n",
      "EPOCH: 8832 LOSS: 41.025716164591\n",
      "EPOCH: 8833 LOSS: 41.02570893756601\n",
      "EPOCH: 8834 LOSS: 41.025701711644864\n",
      "EPOCH: 8835 LOSS: 41.02569448682732\n",
      "EPOCH: 8836 LOSS: 41.02568726311317\n",
      "EPOCH: 8837 LOSS: 41.02568004050218\n",
      "EPOCH: 8838 LOSS: 41.0256728189941\n",
      "EPOCH: 8839 LOSS: 41.025665598588716\n",
      "EPOCH: 8840 LOSS: 41.025658379285815\n",
      "EPOCH: 8841 LOSS: 41.02565116108512\n",
      "EPOCH: 8842 LOSS: 41.02564394398644\n",
      "EPOCH: 8843 LOSS: 41.02563672798952\n",
      "EPOCH: 8844 LOSS: 41.02562951309416\n",
      "EPOCH: 8845 LOSS: 41.02562229930009\n",
      "EPOCH: 8846 LOSS: 41.02561508660712\n",
      "EPOCH: 8847 LOSS: 41.02560787501498\n",
      "EPOCH: 8848 LOSS: 41.02560066452347\n",
      "EPOCH: 8849 LOSS: 41.02559345513235\n",
      "EPOCH: 8850 LOSS: 41.0255862468414\n",
      "EPOCH: 8851 LOSS: 41.025579039650346\n",
      "EPOCH: 8852 LOSS: 41.025571833559034\n",
      "EPOCH: 8853 LOSS: 41.02556462856717\n",
      "EPOCH: 8854 LOSS: 41.02555742467455\n",
      "EPOCH: 8855 LOSS: 41.02555022188094\n",
      "EPOCH: 8856 LOSS: 41.02554302018612\n",
      "EPOCH: 8857 LOSS: 41.025535819589834\n",
      "EPOCH: 8858 LOSS: 41.02552862009189\n",
      "EPOCH: 8859 LOSS: 41.02552142169204\n",
      "EPOCH: 8860 LOSS: 41.025514224390044\n",
      "EPOCH: 8861 LOSS: 41.025507028185686\n",
      "EPOCH: 8862 LOSS: 41.02549983307872\n",
      "EPOCH: 8863 LOSS: 41.02549263906894\n",
      "EPOCH: 8864 LOSS: 41.02548544615612\n",
      "EPOCH: 8865 LOSS: 41.02547825434\n",
      "EPOCH: 8866 LOSS: 41.02547106362037\n",
      "EPOCH: 8867 LOSS: 41.02546387399701\n",
      "EPOCH: 8868 LOSS: 41.02545668546969\n",
      "EPOCH: 8869 LOSS: 41.025449498038164\n",
      "EPOCH: 8870 LOSS: 41.02544231170221\n",
      "EPOCH: 8871 LOSS: 41.0254351264616\n",
      "EPOCH: 8872 LOSS: 41.0254279423161\n",
      "EPOCH: 8873 LOSS: 41.0254207592655\n",
      "EPOCH: 8874 LOSS: 41.025413577309564\n",
      "EPOCH: 8875 LOSS: 41.02540639644806\n",
      "EPOCH: 8876 LOSS: 41.02539921668075\n",
      "EPOCH: 8877 LOSS: 41.02539203800742\n",
      "EPOCH: 8878 LOSS: 41.02538486042785\n",
      "EPOCH: 8879 LOSS: 41.02537768394176\n",
      "EPOCH: 8880 LOSS: 41.025370508548995\n",
      "EPOCH: 8881 LOSS: 41.025363334249285\n",
      "EPOCH: 8882 LOSS: 41.02535616104243\n",
      "EPOCH: 8883 LOSS: 41.02534898892816\n",
      "EPOCH: 8884 LOSS: 41.02534181790628\n",
      "EPOCH: 8885 LOSS: 41.02533464797654\n",
      "EPOCH: 8886 LOSS: 41.025327479138724\n",
      "EPOCH: 8887 LOSS: 41.02532031139261\n",
      "EPOCH: 8888 LOSS: 41.025313144737964\n",
      "EPOCH: 8889 LOSS: 41.025305979174576\n",
      "EPOCH: 8890 LOSS: 41.02529881470218\n",
      "EPOCH: 8891 LOSS: 41.025291651320586\n",
      "EPOCH: 8892 LOSS: 41.025284489029545\n",
      "EPOCH: 8893 LOSS: 41.025277327828825\n",
      "EPOCH: 8894 LOSS: 41.02527016771823\n",
      "EPOCH: 8895 LOSS: 41.02526300869751\n",
      "EPOCH: 8896 LOSS: 41.02525585076645\n",
      "EPOCH: 8897 LOSS: 41.0252486939248\n",
      "EPOCH: 8898 LOSS: 41.025241538172345\n",
      "EPOCH: 8899 LOSS: 41.02523438350887\n",
      "EPOCH: 8900 LOSS: 41.025227229934146\n",
      "EPOCH: 8901 LOSS: 41.025220077447926\n",
      "EPOCH: 8902 LOSS: 41.02521292605\n",
      "EPOCH: 8903 LOSS: 41.02520577574014\n",
      "EPOCH: 8904 LOSS: 41.02519862651812\n",
      "EPOCH: 8905 LOSS: 41.02519147838372\n",
      "EPOCH: 8906 LOSS: 41.02518433133669\n",
      "EPOCH: 8907 LOSS: 41.02517718537682\n",
      "EPOCH: 8908 LOSS: 41.025170040503895\n",
      "EPOCH: 8909 LOSS: 41.02516289671766\n",
      "EPOCH: 8910 LOSS: 41.025155754017916\n",
      "EPOCH: 8911 LOSS: 41.02514861240443\n",
      "EPOCH: 8912 LOSS: 41.025141471876964\n",
      "EPOCH: 8913 LOSS: 41.025134332435286\n",
      "EPOCH: 8914 LOSS: 41.02512719407921\n",
      "EPOCH: 8915 LOSS: 41.025120056808476\n",
      "EPOCH: 8916 LOSS: 41.02511292062286\n",
      "EPOCH: 8917 LOSS: 41.02510578552216\n",
      "EPOCH: 8918 LOSS: 41.02509865150613\n",
      "EPOCH: 8919 LOSS: 41.02509151857454\n",
      "EPOCH: 8920 LOSS: 41.02508438672717\n",
      "EPOCH: 8921 LOSS: 41.025077255963794\n",
      "EPOCH: 8922 LOSS: 41.02507012628421\n",
      "EPOCH: 8923 LOSS: 41.02506299768816\n",
      "EPOCH: 8924 LOSS: 41.025055870175436\n",
      "EPOCH: 8925 LOSS: 41.0250487437458\n",
      "EPOCH: 8926 LOSS: 41.025041618399044\n",
      "EPOCH: 8927 LOSS: 41.02503449413494\n",
      "EPOCH: 8928 LOSS: 41.02502737095324\n",
      "EPOCH: 8929 LOSS: 41.02502024885374\n",
      "EPOCH: 8930 LOSS: 41.02501312783623\n",
      "EPOCH: 8931 LOSS: 41.025006007900465\n",
      "EPOCH: 8932 LOSS: 41.0249988890462\n",
      "EPOCH: 8933 LOSS: 41.02499177127325\n",
      "EPOCH: 8934 LOSS: 41.02498465458137\n",
      "EPOCH: 8935 LOSS: 41.02497753897033\n",
      "EPOCH: 8936 LOSS: 41.02497042443991\n",
      "EPOCH: 8937 LOSS: 41.02496331098992\n",
      "EPOCH: 8938 LOSS: 41.02495619862006\n",
      "EPOCH: 8939 LOSS: 41.024949087330185\n",
      "EPOCH: 8940 LOSS: 41.02494197712002\n",
      "EPOCH: 8941 LOSS: 41.024934867989366\n",
      "EPOCH: 8942 LOSS: 41.02492775993799\n",
      "EPOCH: 8943 LOSS: 41.02492065296566\n",
      "EPOCH: 8944 LOSS: 41.02491354707219\n",
      "EPOCH: 8945 LOSS: 41.0249064422573\n",
      "EPOCH: 8946 LOSS: 41.02489933852078\n",
      "EPOCH: 8947 LOSS: 41.02489223586244\n",
      "EPOCH: 8948 LOSS: 41.02488513428203\n",
      "EPOCH: 8949 LOSS: 41.02487803377934\n",
      "EPOCH: 8950 LOSS: 41.02487093435413\n",
      "EPOCH: 8951 LOSS: 41.024863836006176\n",
      "EPOCH: 8952 LOSS: 41.02485673873528\n",
      "EPOCH: 8953 LOSS: 41.024849642541184\n",
      "EPOCH: 8954 LOSS: 41.0248425474237\n",
      "EPOCH: 8955 LOSS: 41.02483545338257\n",
      "EPOCH: 8956 LOSS: 41.0248283604176\n",
      "EPOCH: 8957 LOSS: 41.02482126852856\n",
      "EPOCH: 8958 LOSS: 41.02481417771521\n",
      "EPOCH: 8959 LOSS: 41.024807087977344\n",
      "EPOCH: 8960 LOSS: 41.024799999314716\n",
      "EPOCH: 8961 LOSS: 41.02479291172713\n",
      "EPOCH: 8962 LOSS: 41.02478582521437\n",
      "EPOCH: 8963 LOSS: 41.024778739776195\n",
      "EPOCH: 8964 LOSS: 41.024771655412366\n",
      "EPOCH: 8965 LOSS: 41.0247645721227\n",
      "EPOCH: 8966 LOSS: 41.02475748990694\n",
      "EPOCH: 8967 LOSS: 41.024750408764874\n",
      "EPOCH: 8968 LOSS: 41.024743328696296\n",
      "EPOCH: 8969 LOSS: 41.02473624970096\n",
      "EPOCH: 8970 LOSS: 41.024729171778645\n",
      "EPOCH: 8971 LOSS: 41.02472209492916\n",
      "EPOCH: 8972 LOSS: 41.02471501915224\n",
      "EPOCH: 8973 LOSS: 41.0247079444477\n",
      "EPOCH: 8974 LOSS: 41.02470087081528\n",
      "EPOCH: 8975 LOSS: 41.02469379825478\n",
      "EPOCH: 8976 LOSS: 41.024686726766\n",
      "EPOCH: 8977 LOSS: 41.024679656348674\n",
      "EPOCH: 8978 LOSS: 41.02467258700262\n",
      "EPOCH: 8979 LOSS: 41.02466551872758\n",
      "EPOCH: 8980 LOSS: 41.024658451523344\n",
      "EPOCH: 8981 LOSS: 41.02465138538971\n",
      "EPOCH: 8982 LOSS: 41.02464432032644\n",
      "EPOCH: 8983 LOSS: 41.02463725633332\n",
      "EPOCH: 8984 LOSS: 41.02463019341011\n",
      "EPOCH: 8985 LOSS: 41.02462313155661\n",
      "EPOCH: 8986 LOSS: 41.02461607077259\n",
      "EPOCH: 8987 LOSS: 41.02460901105783\n",
      "EPOCH: 8988 LOSS: 41.0246019524121\n",
      "EPOCH: 8989 LOSS: 41.02459489483519\n",
      "EPOCH: 8990 LOSS: 41.02458783832688\n",
      "EPOCH: 8991 LOSS: 41.02458078288694\n",
      "EPOCH: 8992 LOSS: 41.024573728515165\n",
      "EPOCH: 8993 LOSS: 41.02456667521132\n",
      "EPOCH: 8994 LOSS: 41.02455962297516\n",
      "EPOCH: 8995 LOSS: 41.024552571806524\n",
      "EPOCH: 8996 LOSS: 41.02454552170514\n",
      "EPOCH: 8997 LOSS: 41.02453847267083\n",
      "EPOCH: 8998 LOSS: 41.02453142470332\n",
      "EPOCH: 8999 LOSS: 41.024524377802436\n",
      "EPOCH: 9000 LOSS: 41.02451733196793\n",
      "EPOCH: 9001 LOSS: 41.0245102871996\n",
      "EPOCH: 9002 LOSS: 41.02450324349721\n",
      "EPOCH: 9003 LOSS: 41.024496200860554\n",
      "EPOCH: 9004 LOSS: 41.02448915928939\n",
      "EPOCH: 9005 LOSS: 41.024482118783524\n",
      "EPOCH: 9006 LOSS: 41.024475079342714\n",
      "EPOCH: 9007 LOSS: 41.02446804096678\n",
      "EPOCH: 9008 LOSS: 41.024461003655446\n",
      "EPOCH: 9009 LOSS: 41.024453967408526\n",
      "EPOCH: 9010 LOSS: 41.024446932225786\n",
      "EPOCH: 9011 LOSS: 41.02443989810702\n",
      "EPOCH: 9012 LOSS: 41.024432865052006\n",
      "EPOCH: 9013 LOSS: 41.02442583306049\n",
      "EPOCH: 9014 LOSS: 41.024418802132324\n",
      "EPOCH: 9015 LOSS: 41.02441177226722\n",
      "EPOCH: 9016 LOSS: 41.02440474346499\n",
      "EPOCH: 9017 LOSS: 41.02439771572541\n",
      "EPOCH: 9018 LOSS: 41.02439068904826\n",
      "EPOCH: 9019 LOSS: 41.02438366343332\n",
      "EPOCH: 9020 LOSS: 41.02437663888036\n",
      "EPOCH: 9021 LOSS: 41.02436961538919\n",
      "EPOCH: 9022 LOSS: 41.02436259295956\n",
      "EPOCH: 9023 LOSS: 41.02435557159127\n",
      "EPOCH: 9024 LOSS: 41.024348551284106\n",
      "EPOCH: 9025 LOSS: 41.024341532037816\n",
      "EPOCH: 9026 LOSS: 41.024334513852224\n",
      "EPOCH: 9027 LOSS: 41.024327496727075\n",
      "EPOCH: 9028 LOSS: 41.02432048066217\n",
      "EPOCH: 9029 LOSS: 41.02431346565728\n",
      "EPOCH: 9030 LOSS: 41.024306451712185\n",
      "EPOCH: 9031 LOSS: 41.02429943882668\n",
      "EPOCH: 9032 LOSS: 41.02429242700056\n",
      "EPOCH: 9033 LOSS: 41.02428541623355\n",
      "EPOCH: 9034 LOSS: 41.0242784065255\n",
      "EPOCH: 9035 LOSS: 41.02427139787615\n",
      "EPOCH: 9036 LOSS: 41.02426439028528\n",
      "EPOCH: 9037 LOSS: 41.0242573837527\n",
      "EPOCH: 9038 LOSS: 41.024250378278154\n",
      "EPOCH: 9039 LOSS: 41.02424337386146\n",
      "EPOCH: 9040 LOSS: 41.02423637050238\n",
      "EPOCH: 9041 LOSS: 41.02422936820071\n",
      "EPOCH: 9042 LOSS: 41.0242223669562\n",
      "EPOCH: 9043 LOSS: 41.02421536676867\n",
      "EPOCH: 9044 LOSS: 41.02420836763788\n",
      "EPOCH: 9045 LOSS: 41.02420136956363\n",
      "EPOCH: 9046 LOSS: 41.02419437254569\n",
      "EPOCH: 9047 LOSS: 41.02418737658384\n",
      "EPOCH: 9048 LOSS: 41.02418038167785\n",
      "EPOCH: 9049 LOSS: 41.02417338782754\n",
      "EPOCH: 9050 LOSS: 41.02416639503266\n",
      "EPOCH: 9051 LOSS: 41.02415940329301\n",
      "EPOCH: 9052 LOSS: 41.02415241260837\n",
      "EPOCH: 9053 LOSS: 41.02414542297852\n",
      "EPOCH: 9054 LOSS: 41.02413843440323\n",
      "EPOCH: 9055 LOSS: 41.02413144688231\n",
      "EPOCH: 9056 LOSS: 41.02412446041551\n",
      "EPOCH: 9057 LOSS: 41.02411747500265\n",
      "EPOCH: 9058 LOSS: 41.024110490643466\n",
      "EPOCH: 9059 LOSS: 41.0241035073378\n",
      "EPOCH: 9060 LOSS: 41.0240965250854\n",
      "EPOCH: 9061 LOSS: 41.024089543886035\n",
      "EPOCH: 9062 LOSS: 41.02408256373952\n",
      "EPOCH: 9063 LOSS: 41.02407558464561\n",
      "EPOCH: 9064 LOSS: 41.02406860660411\n",
      "EPOCH: 9065 LOSS: 41.024061629614806\n",
      "EPOCH: 9066 LOSS: 41.02405465367747\n",
      "EPOCH: 9067 LOSS: 41.02404767879189\n",
      "EPOCH: 9068 LOSS: 41.024040704957834\n",
      "EPOCH: 9069 LOSS: 41.0240337321751\n",
      "EPOCH: 9070 LOSS: 41.024026760443476\n",
      "EPOCH: 9071 LOSS: 41.02401978976275\n",
      "EPOCH: 9072 LOSS: 41.02401282013268\n",
      "EPOCH: 9073 LOSS: 41.02400585155307\n",
      "EPOCH: 9074 LOSS: 41.023998884023726\n",
      "EPOCH: 9075 LOSS: 41.02399191754438\n",
      "EPOCH: 9076 LOSS: 41.02398495211485\n",
      "EPOCH: 9077 LOSS: 41.023977987734895\n",
      "EPOCH: 9078 LOSS: 41.02397102440434\n",
      "EPOCH: 9079 LOSS: 41.02396406212294\n",
      "EPOCH: 9080 LOSS: 41.023957100890485\n",
      "EPOCH: 9081 LOSS: 41.02395014070676\n",
      "EPOCH: 9082 LOSS: 41.023943181571546\n",
      "EPOCH: 9083 LOSS: 41.02393622348463\n",
      "EPOCH: 9084 LOSS: 41.0239292664458\n",
      "EPOCH: 9085 LOSS: 41.023922310454836\n",
      "EPOCH: 9086 LOSS: 41.02391535551153\n",
      "EPOCH: 9087 LOSS: 41.02390840161566\n",
      "EPOCH: 9088 LOSS: 41.02390144876702\n",
      "EPOCH: 9089 LOSS: 41.02389449696537\n",
      "EPOCH: 9090 LOSS: 41.02388754621053\n",
      "EPOCH: 9091 LOSS: 41.023880596502245\n",
      "EPOCH: 9092 LOSS: 41.02387364784033\n",
      "EPOCH: 9093 LOSS: 41.02386670022457\n",
      "EPOCH: 9094 LOSS: 41.02385975365473\n",
      "EPOCH: 9095 LOSS: 41.02385280813063\n",
      "EPOCH: 9096 LOSS: 41.02384586365203\n",
      "EPOCH: 9097 LOSS: 41.02383892021871\n",
      "EPOCH: 9098 LOSS: 41.02383197783044\n",
      "EPOCH: 9099 LOSS: 41.023825036487054\n",
      "EPOCH: 9100 LOSS: 41.02381809618831\n",
      "EPOCH: 9101 LOSS: 41.023811156933995\n",
      "EPOCH: 9102 LOSS: 41.02380421872391\n",
      "EPOCH: 9103 LOSS: 41.023797281557805\n",
      "EPOCH: 9104 LOSS: 41.0237903454355\n",
      "EPOCH: 9105 LOSS: 41.02378341035675\n",
      "EPOCH: 9106 LOSS: 41.02377647632137\n",
      "EPOCH: 9107 LOSS: 41.02376954332915\n",
      "EPOCH: 9108 LOSS: 41.02376261137984\n",
      "EPOCH: 9109 LOSS: 41.02375568047326\n",
      "EPOCH: 9110 LOSS: 41.02374875060919\n",
      "EPOCH: 9111 LOSS: 41.02374182178738\n",
      "EPOCH: 9112 LOSS: 41.02373489400768\n",
      "EPOCH: 9113 LOSS: 41.02372796726982\n",
      "EPOCH: 9114 LOSS: 41.023721041573616\n",
      "EPOCH: 9115 LOSS: 41.02371411691883\n",
      "EPOCH: 9116 LOSS: 41.02370719330529\n",
      "EPOCH: 9117 LOSS: 41.023700270732746\n",
      "EPOCH: 9118 LOSS: 41.023693349201004\n",
      "EPOCH: 9119 LOSS: 41.02368642870983\n",
      "EPOCH: 9120 LOSS: 41.02367950925903\n",
      "EPOCH: 9121 LOSS: 41.02367259084838\n",
      "EPOCH: 9122 LOSS: 41.02366567347767\n",
      "EPOCH: 9123 LOSS: 41.02365875714669\n",
      "EPOCH: 9124 LOSS: 41.023651841855234\n",
      "EPOCH: 9125 LOSS: 41.02364492760308\n",
      "EPOCH: 9126 LOSS: 41.02363801439\n",
      "EPOCH: 9127 LOSS: 41.02363110221581\n",
      "EPOCH: 9128 LOSS: 41.02362419108027\n",
      "EPOCH: 9129 LOSS: 41.02361728098319\n",
      "EPOCH: 9130 LOSS: 41.02361037192435\n",
      "EPOCH: 9131 LOSS: 41.02360346390353\n",
      "EPOCH: 9132 LOSS: 41.0235965569205\n",
      "EPOCH: 9133 LOSS: 41.02358965097511\n",
      "EPOCH: 9134 LOSS: 41.023582746067085\n",
      "EPOCH: 9135 LOSS: 41.02357584219624\n",
      "EPOCH: 9136 LOSS: 41.02356893936236\n",
      "EPOCH: 9137 LOSS: 41.02356203756522\n",
      "EPOCH: 9138 LOSS: 41.02355513680463\n",
      "EPOCH: 9139 LOSS: 41.02354823708036\n",
      "EPOCH: 9140 LOSS: 41.0235413383922\n",
      "EPOCH: 9141 LOSS: 41.02353444073994\n",
      "EPOCH: 9142 LOSS: 41.02352754412338\n",
      "EPOCH: 9143 LOSS: 41.023520648542295\n",
      "EPOCH: 9144 LOSS: 41.02351375399647\n",
      "EPOCH: 9145 LOSS: 41.023506860485696\n",
      "EPOCH: 9146 LOSS: 41.02349996800978\n",
      "EPOCH: 9147 LOSS: 41.02349307656849\n",
      "EPOCH: 9148 LOSS: 41.023486186161605\n",
      "EPOCH: 9149 LOSS: 41.02347929678892\n",
      "EPOCH: 9150 LOSS: 41.02347240845026\n",
      "EPOCH: 9151 LOSS: 41.023465521145376\n",
      "EPOCH: 9152 LOSS: 41.023458634874046\n",
      "EPOCH: 9153 LOSS: 41.023451749636095\n",
      "EPOCH: 9154 LOSS: 41.02344486543129\n",
      "EPOCH: 9155 LOSS: 41.023437982259416\n",
      "EPOCH: 9156 LOSS: 41.02343110012027\n",
      "EPOCH: 9157 LOSS: 41.02342421901364\n",
      "EPOCH: 9158 LOSS: 41.02341733893934\n",
      "EPOCH: 9159 LOSS: 41.02341045989709\n",
      "EPOCH: 9160 LOSS: 41.023403581886754\n",
      "EPOCH: 9161 LOSS: 41.02339670490808\n",
      "EPOCH: 9162 LOSS: 41.02338982896087\n",
      "EPOCH: 9163 LOSS: 41.02338295404492\n",
      "EPOCH: 9164 LOSS: 41.02337608015999\n",
      "EPOCH: 9165 LOSS: 41.023369207305905\n",
      "EPOCH: 9166 LOSS: 41.02336233548243\n",
      "EPOCH: 9167 LOSS: 41.02335546468936\n",
      "EPOCH: 9168 LOSS: 41.0233485949265\n",
      "EPOCH: 9169 LOSS: 41.023341726193614\n",
      "EPOCH: 9170 LOSS: 41.02333485849051\n",
      "EPOCH: 9171 LOSS: 41.02332799181697\n",
      "EPOCH: 9172 LOSS: 41.02332112617279\n",
      "EPOCH: 9173 LOSS: 41.02331426155774\n",
      "EPOCH: 9174 LOSS: 41.023307397971635\n",
      "EPOCH: 9175 LOSS: 41.02330053541427\n",
      "EPOCH: 9176 LOSS: 41.0232936738854\n",
      "EPOCH: 9177 LOSS: 41.02328681338484\n",
      "EPOCH: 9178 LOSS: 41.02327995391238\n",
      "EPOCH: 9179 LOSS: 41.0232730954678\n",
      "EPOCH: 9180 LOSS: 41.0232662380509\n",
      "EPOCH: 9181 LOSS: 41.023259381661454\n",
      "EPOCH: 9182 LOSS: 41.02325252629929\n",
      "EPOCH: 9183 LOSS: 41.02324567196416\n",
      "EPOCH: 9184 LOSS: 41.02323881865585\n",
      "EPOCH: 9185 LOSS: 41.02323196637417\n",
      "EPOCH: 9186 LOSS: 41.023225115118926\n",
      "EPOCH: 9187 LOSS: 41.02321826488989\n",
      "EPOCH: 9188 LOSS: 41.023211415686845\n",
      "EPOCH: 9189 LOSS: 41.02320456750957\n",
      "EPOCH: 9190 LOSS: 41.02319772035791\n",
      "EPOCH: 9191 LOSS: 41.02319087423159\n",
      "EPOCH: 9192 LOSS: 41.02318402913047\n",
      "EPOCH: 9193 LOSS: 41.023177185054266\n",
      "EPOCH: 9194 LOSS: 41.023170342002814\n",
      "EPOCH: 9195 LOSS: 41.0231634999759\n",
      "EPOCH: 9196 LOSS: 41.02315665897332\n",
      "EPOCH: 9197 LOSS: 41.023149818994845\n",
      "EPOCH: 9198 LOSS: 41.023142980040284\n",
      "EPOCH: 9199 LOSS: 41.02313614210942\n",
      "EPOCH: 9200 LOSS: 41.02312930520205\n",
      "EPOCH: 9201 LOSS: 41.023122469317954\n",
      "EPOCH: 9202 LOSS: 41.023115634456936\n",
      "EPOCH: 9203 LOSS: 41.02310880061878\n",
      "EPOCH: 9204 LOSS: 41.0231019678033\n",
      "EPOCH: 9205 LOSS: 41.023095136010234\n",
      "EPOCH: 9206 LOSS: 41.023088305239426\n",
      "EPOCH: 9207 LOSS: 41.023081475490656\n",
      "EPOCH: 9208 LOSS: 41.0230746467637\n",
      "EPOCH: 9209 LOSS: 41.02306781905836\n",
      "EPOCH: 9210 LOSS: 41.02306099237443\n",
      "EPOCH: 9211 LOSS: 41.023054166711695\n",
      "EPOCH: 9212 LOSS: 41.02304734206996\n",
      "EPOCH: 9213 LOSS: 41.023040518448994\n",
      "EPOCH: 9214 LOSS: 41.02303369584861\n",
      "EPOCH: 9215 LOSS: 41.023026874268595\n",
      "EPOCH: 9216 LOSS: 41.02302005370873\n",
      "EPOCH: 9217 LOSS: 41.02301323416883\n",
      "EPOCH: 9218 LOSS: 41.02300641564865\n",
      "EPOCH: 9219 LOSS: 41.02299959814803\n",
      "EPOCH: 9220 LOSS: 41.02299278166673\n",
      "EPOCH: 9221 LOSS: 41.02298596620457\n",
      "EPOCH: 9222 LOSS: 41.022979151761284\n",
      "EPOCH: 9223 LOSS: 41.02297233833673\n",
      "EPOCH: 9224 LOSS: 41.02296552593067\n",
      "EPOCH: 9225 LOSS: 41.022958714542895\n",
      "EPOCH: 9226 LOSS: 41.02295190417321\n",
      "EPOCH: 9227 LOSS: 41.02294509482141\n",
      "EPOCH: 9228 LOSS: 41.022938286487275\n",
      "EPOCH: 9229 LOSS: 41.022931479170595\n",
      "EPOCH: 9230 LOSS: 41.022924672871184\n",
      "EPOCH: 9231 LOSS: 41.02291786758881\n",
      "EPOCH: 9232 LOSS: 41.02291106332328\n",
      "EPOCH: 9233 LOSS: 41.0229042600744\n",
      "EPOCH: 9234 LOSS: 41.02289745784193\n",
      "EPOCH: 9235 LOSS: 41.02289065662569\n",
      "EPOCH: 9236 LOSS: 41.022883856425466\n",
      "EPOCH: 9237 LOSS: 41.02287705724105\n",
      "EPOCH: 9238 LOSS: 41.02287025907222\n",
      "EPOCH: 9239 LOSS: 41.0228634619188\n",
      "EPOCH: 9240 LOSS: 41.02285666578057\n",
      "EPOCH: 9241 LOSS: 41.022849870657325\n",
      "EPOCH: 9242 LOSS: 41.02284307654885\n",
      "EPOCH: 9243 LOSS: 41.022836283454936\n",
      "EPOCH: 9244 LOSS: 41.02282949137541\n",
      "EPOCH: 9245 LOSS: 41.022822700310016\n",
      "EPOCH: 9246 LOSS: 41.02281591025859\n",
      "EPOCH: 9247 LOSS: 41.022809121220924\n",
      "EPOCH: 9248 LOSS: 41.02280233319675\n",
      "EPOCH: 9249 LOSS: 41.02279554618596\n",
      "EPOCH: 9250 LOSS: 41.02278876018826\n",
      "EPOCH: 9251 LOSS: 41.022781975203515\n",
      "EPOCH: 9252 LOSS: 41.02277519123146\n",
      "EPOCH: 9253 LOSS: 41.02276840827193\n",
      "EPOCH: 9254 LOSS: 41.02276162632468\n",
      "EPOCH: 9255 LOSS: 41.02275484538956\n",
      "EPOCH: 9256 LOSS: 41.02274806546631\n",
      "EPOCH: 9257 LOSS: 41.02274128655476\n",
      "EPOCH: 9258 LOSS: 41.02273450865469\n",
      "EPOCH: 9259 LOSS: 41.0227277317659\n",
      "EPOCH: 9260 LOSS: 41.022720955888175\n",
      "EPOCH: 9261 LOSS: 41.022714181021335\n",
      "EPOCH: 9262 LOSS: 41.022707407165136\n",
      "EPOCH: 9263 LOSS: 41.02270063431939\n",
      "EPOCH: 9264 LOSS: 41.02269386248391\n",
      "EPOCH: 9265 LOSS: 41.022687091658476\n",
      "EPOCH: 9266 LOSS: 41.02268032184288\n",
      "EPOCH: 9267 LOSS: 41.02267355303691\n",
      "EPOCH: 9268 LOSS: 41.022666785240375\n",
      "EPOCH: 9269 LOSS: 41.02266001845307\n",
      "EPOCH: 9270 LOSS: 41.022653252674786\n",
      "EPOCH: 9271 LOSS: 41.02264648790532\n",
      "EPOCH: 9272 LOSS: 41.02263972414447\n",
      "EPOCH: 9273 LOSS: 41.02263296139201\n",
      "EPOCH: 9274 LOSS: 41.02262619964776\n",
      "EPOCH: 9275 LOSS: 41.02261943891151\n",
      "EPOCH: 9276 LOSS: 41.02261267918306\n",
      "EPOCH: 9277 LOSS: 41.0226059204622\n",
      "EPOCH: 9278 LOSS: 41.02259916274872\n",
      "EPOCH: 9279 LOSS: 41.022592406042406\n",
      "EPOCH: 9280 LOSS: 41.022585650343096\n",
      "EPOCH: 9281 LOSS: 41.02257889565055\n",
      "EPOCH: 9282 LOSS: 41.02257214196456\n",
      "EPOCH: 9283 LOSS: 41.02256538928494\n",
      "EPOCH: 9284 LOSS: 41.022558637611475\n",
      "EPOCH: 9285 LOSS: 41.02255188694399\n",
      "EPOCH: 9286 LOSS: 41.02254513728225\n",
      "EPOCH: 9287 LOSS: 41.02253838862604\n",
      "EPOCH: 9288 LOSS: 41.022531640975195\n",
      "EPOCH: 9289 LOSS: 41.022524894329464\n",
      "EPOCH: 9290 LOSS: 41.022518148688704\n",
      "EPOCH: 9291 LOSS: 41.02251140405265\n",
      "EPOCH: 9292 LOSS: 41.02250466042114\n",
      "EPOCH: 9293 LOSS: 41.022497917793956\n",
      "EPOCH: 9294 LOSS: 41.02249117617089\n",
      "EPOCH: 9295 LOSS: 41.02248443555174\n",
      "EPOCH: 9296 LOSS: 41.02247769593632\n",
      "EPOCH: 9297 LOSS: 41.022470957324416\n",
      "EPOCH: 9298 LOSS: 41.0224642197158\n",
      "EPOCH: 9299 LOSS: 41.02245748311031\n",
      "EPOCH: 9300 LOSS: 41.022450747507705\n",
      "EPOCH: 9301 LOSS: 41.022444012907826\n",
      "EPOCH: 9302 LOSS: 41.022437279310424\n",
      "EPOCH: 9303 LOSS: 41.02243054671531\n",
      "EPOCH: 9304 LOSS: 41.02242381512231\n",
      "EPOCH: 9305 LOSS: 41.022417084531185\n",
      "EPOCH: 9306 LOSS: 41.02241035494175\n",
      "EPOCH: 9307 LOSS: 41.02240362635381\n",
      "EPOCH: 9308 LOSS: 41.02239689876713\n",
      "EPOCH: 9309 LOSS: 41.02239017218153\n",
      "EPOCH: 9310 LOSS: 41.02238344659683\n",
      "EPOCH: 9311 LOSS: 41.022376722012766\n",
      "EPOCH: 9312 LOSS: 41.022369998429184\n",
      "EPOCH: 9313 LOSS: 41.02236327584589\n",
      "EPOCH: 9314 LOSS: 41.02235655426264\n",
      "EPOCH: 9315 LOSS: 41.02234983367924\n",
      "EPOCH: 9316 LOSS: 41.022343114095534\n",
      "EPOCH: 9317 LOSS: 41.022336395511275\n",
      "EPOCH: 9318 LOSS: 41.022329677926265\n",
      "EPOCH: 9319 LOSS: 41.02232296134031\n",
      "EPOCH: 9320 LOSS: 41.02231624575322\n",
      "EPOCH: 9321 LOSS: 41.02230953116477\n",
      "EPOCH: 9322 LOSS: 41.022302817574776\n",
      "EPOCH: 9323 LOSS: 41.02229610498303\n",
      "EPOCH: 9324 LOSS: 41.0222893933893\n",
      "EPOCH: 9325 LOSS: 41.022282682793445\n",
      "EPOCH: 9326 LOSS: 41.022275973195214\n",
      "EPOCH: 9327 LOSS: 41.02226926459443\n",
      "EPOCH: 9328 LOSS: 41.02226255699088\n",
      "EPOCH: 9329 LOSS: 41.02225585038437\n",
      "EPOCH: 9330 LOSS: 41.02224914477469\n",
      "EPOCH: 9331 LOSS: 41.02224244016165\n",
      "EPOCH: 9332 LOSS: 41.022235736545035\n",
      "EPOCH: 9333 LOSS: 41.02222903392467\n",
      "EPOCH: 9334 LOSS: 41.0222223323003\n",
      "EPOCH: 9335 LOSS: 41.02221563167178\n",
      "EPOCH: 9336 LOSS: 41.022208932038886\n",
      "EPOCH: 9337 LOSS: 41.0222022334014\n",
      "EPOCH: 9338 LOSS: 41.02219553575917\n",
      "EPOCH: 9339 LOSS: 41.022188839111934\n",
      "EPOCH: 9340 LOSS: 41.02218214345954\n",
      "EPOCH: 9341 LOSS: 41.02217544880176\n",
      "EPOCH: 9342 LOSS: 41.02216875513841\n",
      "EPOCH: 9343 LOSS: 41.022162062469256\n",
      "EPOCH: 9344 LOSS: 41.02215537079413\n",
      "EPOCH: 9345 LOSS: 41.022148680112835\n",
      "EPOCH: 9346 LOSS: 41.02214199042516\n",
      "EPOCH: 9347 LOSS: 41.0221353017309\n",
      "EPOCH: 9348 LOSS: 41.02212861402985\n",
      "EPOCH: 9349 LOSS: 41.02212192732182\n",
      "EPOCH: 9350 LOSS: 41.0221152416066\n",
      "EPOCH: 9351 LOSS: 41.022108556884\n",
      "EPOCH: 9352 LOSS: 41.022101873153815\n",
      "EPOCH: 9353 LOSS: 41.02209519041585\n",
      "EPOCH: 9354 LOSS: 41.02208850866988\n",
      "EPOCH: 9355 LOSS: 41.02208182791574\n",
      "EPOCH: 9356 LOSS: 41.022075148153206\n",
      "EPOCH: 9357 LOSS: 41.0220684693821\n",
      "EPOCH: 9358 LOSS: 41.02206179160219\n",
      "EPOCH: 9359 LOSS: 41.02205511481331\n",
      "EPOCH: 9360 LOSS: 41.02204843901525\n",
      "EPOCH: 9361 LOSS: 41.022041764207785\n",
      "EPOCH: 9362 LOSS: 41.02203509039075\n",
      "EPOCH: 9363 LOSS: 41.02202841756393\n",
      "EPOCH: 9364 LOSS: 41.02202174572712\n",
      "EPOCH: 9365 LOSS: 41.02201507488011\n",
      "EPOCH: 9366 LOSS: 41.022008405022746\n",
      "EPOCH: 9367 LOSS: 41.02200173615478\n",
      "EPOCH: 9368 LOSS: 41.02199506827604\n",
      "EPOCH: 9369 LOSS: 41.02198840138632\n",
      "EPOCH: 9370 LOSS: 41.02198173548542\n",
      "EPOCH: 9371 LOSS: 41.02197507057312\n",
      "EPOCH: 9372 LOSS: 41.02196840664925\n",
      "EPOCH: 9373 LOSS: 41.02196174371359\n",
      "EPOCH: 9374 LOSS: 41.02195508176597\n",
      "EPOCH: 9375 LOSS: 41.021948420806176\n",
      "EPOCH: 9376 LOSS: 41.02194176083398\n",
      "EPOCH: 9377 LOSS: 41.02193510184924\n",
      "EPOCH: 9378 LOSS: 41.0219284438517\n",
      "EPOCH: 9379 LOSS: 41.021921786841204\n",
      "EPOCH: 9380 LOSS: 41.02191513081752\n",
      "EPOCH: 9381 LOSS: 41.02190847578048\n",
      "EPOCH: 9382 LOSS: 41.021901821729855\n",
      "EPOCH: 9383 LOSS: 41.021895168665466\n",
      "EPOCH: 9384 LOSS: 41.02188851658711\n",
      "EPOCH: 9385 LOSS: 41.0218818654946\n",
      "EPOCH: 9386 LOSS: 41.02187521538771\n",
      "EPOCH: 9387 LOSS: 41.021868566266264\n",
      "EPOCH: 9388 LOSS: 41.02186191813006\n",
      "EPOCH: 9389 LOSS: 41.02185527097889\n",
      "EPOCH: 9390 LOSS: 41.02184862481256\n",
      "EPOCH: 9391 LOSS: 41.02184197963088\n",
      "EPOCH: 9392 LOSS: 41.021835335433636\n",
      "EPOCH: 9393 LOSS: 41.021828692220666\n",
      "EPOCH: 9394 LOSS: 41.02182204999173\n",
      "EPOCH: 9395 LOSS: 41.02181540874665\n",
      "EPOCH: 9396 LOSS: 41.021808768485215\n",
      "EPOCH: 9397 LOSS: 41.02180212920723\n",
      "EPOCH: 9398 LOSS: 41.02179549091252\n",
      "EPOCH: 9399 LOSS: 41.02178885360085\n",
      "EPOCH: 9400 LOSS: 41.02178221727205\n",
      "EPOCH: 9401 LOSS: 41.02177558192593\n",
      "EPOCH: 9402 LOSS: 41.02176894756225\n",
      "EPOCH: 9403 LOSS: 41.02176231418086\n",
      "EPOCH: 9404 LOSS: 41.02175568178153\n",
      "EPOCH: 9405 LOSS: 41.021749050364086\n",
      "EPOCH: 9406 LOSS: 41.02174241992831\n",
      "EPOCH: 9407 LOSS: 41.021735790474004\n",
      "EPOCH: 9408 LOSS: 41.021729162000995\n",
      "EPOCH: 9409 LOSS: 41.021722534509074\n",
      "EPOCH: 9410 LOSS: 41.02171590799802\n",
      "EPOCH: 9411 LOSS: 41.02170928246767\n",
      "EPOCH: 9412 LOSS: 41.02170265791781\n",
      "EPOCH: 9413 LOSS: 41.021696034348246\n",
      "EPOCH: 9414 LOSS: 41.021689411758786\n",
      "EPOCH: 9415 LOSS: 41.0216827901492\n",
      "EPOCH: 9416 LOSS: 41.02167616951935\n",
      "EPOCH: 9417 LOSS: 41.021669549869\n",
      "EPOCH: 9418 LOSS: 41.02166293119798\n",
      "EPOCH: 9419 LOSS: 41.02165631350603\n",
      "EPOCH: 9420 LOSS: 41.021649696793034\n",
      "EPOCH: 9421 LOSS: 41.02164308105874\n",
      "EPOCH: 9422 LOSS: 41.021636466302965\n",
      "EPOCH: 9423 LOSS: 41.021629852525535\n",
      "EPOCH: 9424 LOSS: 41.02162323972624\n",
      "EPOCH: 9425 LOSS: 41.02161662790486\n",
      "EPOCH: 9426 LOSS: 41.02161001706123\n",
      "EPOCH: 9427 LOSS: 41.02160340719513\n",
      "EPOCH: 9428 LOSS: 41.02159679830639\n",
      "EPOCH: 9429 LOSS: 41.02159019039479\n",
      "EPOCH: 9430 LOSS: 41.02158358346015\n",
      "EPOCH: 9431 LOSS: 41.02157697750228\n",
      "EPOCH: 9432 LOSS: 41.02157037252095\n",
      "EPOCH: 9433 LOSS: 41.02156376851598\n",
      "EPOCH: 9434 LOSS: 41.02155716548718\n",
      "EPOCH: 9435 LOSS: 41.021550563434374\n",
      "EPOCH: 9436 LOSS: 41.02154396235733\n",
      "EPOCH: 9437 LOSS: 41.02153736225586\n",
      "EPOCH: 9438 LOSS: 41.02153076312979\n",
      "EPOCH: 9439 LOSS: 41.021524164978906\n",
      "EPOCH: 9440 LOSS: 41.021517567803016\n",
      "EPOCH: 9441 LOSS: 41.02151097160191\n",
      "EPOCH: 9442 LOSS: 41.02150437637543\n",
      "EPOCH: 9443 LOSS: 41.02149778212333\n",
      "EPOCH: 9444 LOSS: 41.02149118884546\n",
      "EPOCH: 9445 LOSS: 41.021484596541605\n",
      "EPOCH: 9446 LOSS: 41.02147800521157\n",
      "EPOCH: 9447 LOSS: 41.02147141485517\n",
      "EPOCH: 9448 LOSS: 41.02146482547218\n",
      "EPOCH: 9449 LOSS: 41.02145823706243\n",
      "EPOCH: 9450 LOSS: 41.021451649625725\n",
      "EPOCH: 9451 LOSS: 41.02144506316187\n",
      "EPOCH: 9452 LOSS: 41.02143847767064\n",
      "EPOCH: 9453 LOSS: 41.0214318931519\n",
      "EPOCH: 9454 LOSS: 41.02142530960539\n",
      "EPOCH: 9455 LOSS: 41.021418727030955\n",
      "EPOCH: 9456 LOSS: 41.021412145428386\n",
      "EPOCH: 9457 LOSS: 41.02140556479749\n",
      "EPOCH: 9458 LOSS: 41.02139898513809\n",
      "EPOCH: 9459 LOSS: 41.02139240644996\n",
      "EPOCH: 9460 LOSS: 41.02138582873293\n",
      "EPOCH: 9461 LOSS: 41.021379251986794\n",
      "EPOCH: 9462 LOSS: 41.02137267621136\n",
      "EPOCH: 9463 LOSS: 41.021366101406414\n",
      "EPOCH: 9464 LOSS: 41.021359527571796\n",
      "EPOCH: 9465 LOSS: 41.021352954707304\n",
      "EPOCH: 9466 LOSS: 41.02134638281274\n",
      "EPOCH: 9467 LOSS: 41.02133981188788\n",
      "EPOCH: 9468 LOSS: 41.02133324193257\n",
      "EPOCH: 9469 LOSS: 41.0213266729466\n",
      "EPOCH: 9470 LOSS: 41.021320104929785\n",
      "EPOCH: 9471 LOSS: 41.02131353788191\n",
      "EPOCH: 9472 LOSS: 41.0213069718028\n",
      "EPOCH: 9473 LOSS: 41.02130040669225\n",
      "EPOCH: 9474 LOSS: 41.02129384255007\n",
      "EPOCH: 9475 LOSS: 41.02128727937608\n",
      "EPOCH: 9476 LOSS: 41.02128071717007\n",
      "EPOCH: 9477 LOSS: 41.021274155931835\n",
      "EPOCH: 9478 LOSS: 41.021267595661215\n",
      "EPOCH: 9479 LOSS: 41.02126103635797\n",
      "EPOCH: 9480 LOSS: 41.02125447802196\n",
      "EPOCH: 9481 LOSS: 41.02124792065295\n",
      "EPOCH: 9482 LOSS: 41.021241364250756\n",
      "EPOCH: 9483 LOSS: 41.02123480881521\n",
      "EPOCH: 9484 LOSS: 41.0212282543461\n",
      "EPOCH: 9485 LOSS: 41.0212217008432\n",
      "EPOCH: 9486 LOSS: 41.021215148306375\n",
      "EPOCH: 9487 LOSS: 41.021208596735384\n",
      "EPOCH: 9488 LOSS: 41.02120204613007\n",
      "EPOCH: 9489 LOSS: 41.02119549649021\n",
      "EPOCH: 9490 LOSS: 41.02118894781564\n",
      "EPOCH: 9491 LOSS: 41.02118240010614\n",
      "EPOCH: 9492 LOSS: 41.02117585336154\n",
      "EPOCH: 9493 LOSS: 41.021169307581616\n",
      "EPOCH: 9494 LOSS: 41.02116276276622\n",
      "EPOCH: 9495 LOSS: 41.02115621891512\n",
      "EPOCH: 9496 LOSS: 41.02114967602813\n",
      "EPOCH: 9497 LOSS: 41.02114313410508\n",
      "EPOCH: 9498 LOSS: 41.02113659314574\n",
      "EPOCH: 9499 LOSS: 41.02113005314997\n",
      "EPOCH: 9500 LOSS: 41.02112351411753\n",
      "EPOCH: 9501 LOSS: 41.02111697604822\n",
      "EPOCH: 9502 LOSS: 41.0211104389419\n",
      "EPOCH: 9503 LOSS: 41.021103902798345\n",
      "EPOCH: 9504 LOSS: 41.02109736761737\n",
      "EPOCH: 9505 LOSS: 41.021090833398766\n",
      "EPOCH: 9506 LOSS: 41.02108430014236\n",
      "EPOCH: 9507 LOSS: 41.021077767847956\n",
      "EPOCH: 9508 LOSS: 41.02107123651535\n",
      "EPOCH: 9509 LOSS: 41.021064706144365\n",
      "EPOCH: 9510 LOSS: 41.02105817673478\n",
      "EPOCH: 9511 LOSS: 41.021051648286466\n",
      "EPOCH: 9512 LOSS: 41.02104512079917\n",
      "EPOCH: 9513 LOSS: 41.02103859427273\n",
      "EPOCH: 9514 LOSS: 41.02103206870692\n",
      "EPOCH: 9515 LOSS: 41.021025544101605\n",
      "EPOCH: 9516 LOSS: 41.02101902045655\n",
      "EPOCH: 9517 LOSS: 41.02101249777156\n",
      "EPOCH: 9518 LOSS: 41.02100597604647\n",
      "EPOCH: 9519 LOSS: 41.02099945528108\n",
      "EPOCH: 9520 LOSS: 41.02099293547518\n",
      "EPOCH: 9521 LOSS: 41.0209864166286\n",
      "EPOCH: 9522 LOSS: 41.02097989874114\n",
      "EPOCH: 9523 LOSS: 41.020973381812624\n",
      "EPOCH: 9524 LOSS: 41.02096686584282\n",
      "EPOCH: 9525 LOSS: 41.02096035083159\n",
      "EPOCH: 9526 LOSS: 41.0209538367787\n",
      "EPOCH: 9527 LOSS: 41.02094732368399\n",
      "EPOCH: 9528 LOSS: 41.020940811547234\n",
      "EPOCH: 9529 LOSS: 41.02093430036827\n",
      "EPOCH: 9530 LOSS: 41.020927790146885\n",
      "EPOCH: 9531 LOSS: 41.02092128088291\n",
      "EPOCH: 9532 LOSS: 41.02091477257614\n",
      "EPOCH: 9533 LOSS: 41.02090826522638\n",
      "EPOCH: 9534 LOSS: 41.02090175883347\n",
      "EPOCH: 9535 LOSS: 41.02089525339718\n",
      "EPOCH: 9536 LOSS: 41.02088874891734\n",
      "EPOCH: 9537 LOSS: 41.02088224539375\n",
      "EPOCH: 9538 LOSS: 41.020875742826235\n",
      "EPOCH: 9539 LOSS: 41.02086924121458\n",
      "EPOCH: 9540 LOSS: 41.020862740558606\n",
      "EPOCH: 9541 LOSS: 41.020856240858144\n",
      "EPOCH: 9542 LOSS: 41.02084974211296\n",
      "EPOCH: 9543 LOSS: 41.0208432443229\n",
      "EPOCH: 9544 LOSS: 41.02083674748776\n",
      "EPOCH: 9545 LOSS: 41.020830251607364\n",
      "EPOCH: 9546 LOSS: 41.020823756681494\n",
      "EPOCH: 9547 LOSS: 41.020817262709954\n",
      "EPOCH: 9548 LOSS: 41.02081076969259\n",
      "EPOCH: 9549 LOSS: 41.02080427762921\n",
      "EPOCH: 9550 LOSS: 41.020797786519594\n",
      "EPOCH: 9551 LOSS: 41.020791296363555\n",
      "EPOCH: 9552 LOSS: 41.02078480716094\n",
      "EPOCH: 9553 LOSS: 41.02077831891151\n",
      "EPOCH: 9554 LOSS: 41.020771831615136\n",
      "EPOCH: 9555 LOSS: 41.020765345271535\n",
      "EPOCH: 9556 LOSS: 41.020758859880615\n",
      "EPOCH: 9557 LOSS: 41.02075237544214\n",
      "EPOCH: 9558 LOSS: 41.02074589195593\n",
      "EPOCH: 9559 LOSS: 41.02073940942178\n",
      "EPOCH: 9560 LOSS: 41.020732927839504\n",
      "EPOCH: 9561 LOSS: 41.02072644720893\n",
      "EPOCH: 9562 LOSS: 41.02071996752986\n",
      "EPOCH: 9563 LOSS: 41.02071348880209\n",
      "EPOCH: 9564 LOSS: 41.02070701102545\n",
      "EPOCH: 9565 LOSS: 41.02070053419975\n",
      "EPOCH: 9566 LOSS: 41.02069405832478\n",
      "EPOCH: 9567 LOSS: 41.02068758340039\n",
      "EPOCH: 9568 LOSS: 41.020681109426334\n",
      "EPOCH: 9569 LOSS: 41.020674636402475\n",
      "EPOCH: 9570 LOSS: 41.02066816432859\n",
      "EPOCH: 9571 LOSS: 41.02066169320451\n",
      "EPOCH: 9572 LOSS: 41.020655223030055\n",
      "EPOCH: 9573 LOSS: 41.020648753805\n",
      "EPOCH: 9574 LOSS: 41.02064228552918\n",
      "EPOCH: 9575 LOSS: 41.02063581820241\n",
      "EPOCH: 9576 LOSS: 41.02062935182448\n",
      "EPOCH: 9577 LOSS: 41.020622886395216\n",
      "EPOCH: 9578 LOSS: 41.02061642191443\n",
      "EPOCH: 9579 LOSS: 41.020609958381925\n",
      "EPOCH: 9580 LOSS: 41.02060349579754\n",
      "EPOCH: 9581 LOSS: 41.02059703416106\n",
      "EPOCH: 9582 LOSS: 41.0205905734723\n",
      "EPOCH: 9583 LOSS: 41.020584113731076\n",
      "EPOCH: 9584 LOSS: 41.020577654937185\n",
      "EPOCH: 9585 LOSS: 41.02057119709045\n",
      "EPOCH: 9586 LOSS: 41.02056474019069\n",
      "EPOCH: 9587 LOSS: 41.02055828423771\n",
      "EPOCH: 9588 LOSS: 41.02055182923132\n",
      "EPOCH: 9589 LOSS: 41.02054537517134\n",
      "EPOCH: 9590 LOSS: 41.020538922057554\n",
      "EPOCH: 9591 LOSS: 41.020532469889815\n",
      "EPOCH: 9592 LOSS: 41.02052601866791\n",
      "EPOCH: 9593 LOSS: 41.02051956839166\n",
      "EPOCH: 9594 LOSS: 41.020513119060865\n",
      "EPOCH: 9595 LOSS: 41.02050667067535\n",
      "EPOCH: 9596 LOSS: 41.020500223234926\n",
      "EPOCH: 9597 LOSS: 41.020493776739386\n",
      "EPOCH: 9598 LOSS: 41.020487331188576\n",
      "EPOCH: 9599 LOSS: 41.020480886582284\n",
      "EPOCH: 9600 LOSS: 41.020474442920325\n",
      "EPOCH: 9601 LOSS: 41.02046800020253\n",
      "EPOCH: 9602 LOSS: 41.020461558428686\n",
      "EPOCH: 9603 LOSS: 41.0204551175986\n",
      "EPOCH: 9604 LOSS: 41.02044867771212\n",
      "EPOCH: 9605 LOSS: 41.02044223876903\n",
      "EPOCH: 9606 LOSS: 41.02043580076915\n",
      "EPOCH: 9607 LOSS: 41.02042936371231\n",
      "EPOCH: 9608 LOSS: 41.02042292759828\n",
      "EPOCH: 9609 LOSS: 41.020416492426925\n",
      "EPOCH: 9610 LOSS: 41.020410058198024\n",
      "EPOCH: 9611 LOSS: 41.020403624911395\n",
      "EPOCH: 9612 LOSS: 41.02039719256686\n",
      "EPOCH: 9613 LOSS: 41.020390761164215\n",
      "EPOCH: 9614 LOSS: 41.020384330703294\n",
      "EPOCH: 9615 LOSS: 41.0203779011839\n",
      "EPOCH: 9616 LOSS: 41.020371472605845\n",
      "EPOCH: 9617 LOSS: 41.020365044968955\n",
      "EPOCH: 9618 LOSS: 41.020358618273015\n",
      "EPOCH: 9619 LOSS: 41.02035219251787\n",
      "EPOCH: 9620 LOSS: 41.0203457677033\n",
      "EPOCH: 9621 LOSS: 41.020339343829164\n",
      "EPOCH: 9622 LOSS: 41.02033292089523\n",
      "EPOCH: 9623 LOSS: 41.020326498901326\n",
      "EPOCH: 9624 LOSS: 41.02032007784728\n",
      "EPOCH: 9625 LOSS: 41.020313657732885\n",
      "EPOCH: 9626 LOSS: 41.02030723855799\n",
      "EPOCH: 9627 LOSS: 41.02030082032235\n",
      "EPOCH: 9628 LOSS: 41.02029440302583\n",
      "EPOCH: 9629 LOSS: 41.02028798666822\n",
      "EPOCH: 9630 LOSS: 41.02028157124933\n",
      "EPOCH: 9631 LOSS: 41.02027515676901\n",
      "EPOCH: 9632 LOSS: 41.02026874322702\n",
      "EPOCH: 9633 LOSS: 41.020262330623225\n",
      "EPOCH: 9634 LOSS: 41.0202559189574\n",
      "EPOCH: 9635 LOSS: 41.020249508229384\n",
      "EPOCH: 9636 LOSS: 41.020243098438954\n",
      "EPOCH: 9637 LOSS: 41.020236689586\n",
      "EPOCH: 9638 LOSS: 41.02023028167025\n",
      "EPOCH: 9639 LOSS: 41.020223874691574\n",
      "EPOCH: 9640 LOSS: 41.02021746864976\n",
      "EPOCH: 9641 LOSS: 41.02021106354463\n",
      "EPOCH: 9642 LOSS: 41.02020465937599\n",
      "EPOCH: 9643 LOSS: 41.020198256143686\n",
      "EPOCH: 9644 LOSS: 41.02019185384749\n",
      "EPOCH: 9645 LOSS: 41.020185452487254\n",
      "EPOCH: 9646 LOSS: 41.02017905206276\n",
      "EPOCH: 9647 LOSS: 41.02017265257385\n",
      "EPOCH: 9648 LOSS: 41.0201662540203\n",
      "EPOCH: 9649 LOSS: 41.02015985640198\n",
      "EPOCH: 9650 LOSS: 41.02015345971866\n",
      "EPOCH: 9651 LOSS: 41.020147063970185\n",
      "EPOCH: 9652 LOSS: 41.02014066915635\n",
      "EPOCH: 9653 LOSS: 41.02013427527698\n",
      "EPOCH: 9654 LOSS: 41.02012788233188\n",
      "EPOCH: 9655 LOSS: 41.02012149032085\n",
      "EPOCH: 9656 LOSS: 41.02011509924375\n",
      "EPOCH: 9657 LOSS: 41.02010870910036\n",
      "EPOCH: 9658 LOSS: 41.0201023198905\n",
      "EPOCH: 9659 LOSS: 41.020095931614016\n",
      "EPOCH: 9660 LOSS: 41.020089544270675\n",
      "EPOCH: 9661 LOSS: 41.020083157860334\n",
      "EPOCH: 9662 LOSS: 41.02007677238278\n",
      "EPOCH: 9663 LOSS: 41.02007038783783\n",
      "EPOCH: 9664 LOSS: 41.02006400422532\n",
      "EPOCH: 9665 LOSS: 41.020057621545035\n",
      "EPOCH: 9666 LOSS: 41.02005123979683\n",
      "EPOCH: 9667 LOSS: 41.020044858980484\n",
      "EPOCH: 9668 LOSS: 41.02003847909583\n",
      "EPOCH: 9669 LOSS: 41.02003210014267\n",
      "EPOCH: 9670 LOSS: 41.020025722120856\n",
      "EPOCH: 9671 LOSS: 41.02001934503018\n",
      "EPOCH: 9672 LOSS: 41.02001296887043\n",
      "EPOCH: 9673 LOSS: 41.02000659364147\n",
      "EPOCH: 9674 LOSS: 41.020000219343096\n",
      "EPOCH: 9675 LOSS: 41.019993845975115\n",
      "EPOCH: 9676 LOSS: 41.01998747353734\n",
      "EPOCH: 9677 LOSS: 41.01998110202962\n",
      "EPOCH: 9678 LOSS: 41.01997473145173\n",
      "EPOCH: 9679 LOSS: 41.01996836180352\n",
      "EPOCH: 9680 LOSS: 41.01996199308478\n",
      "EPOCH: 9681 LOSS: 41.01995562529533\n",
      "EPOCH: 9682 LOSS: 41.01994925843501\n",
      "EPOCH: 9683 LOSS: 41.01994289250361\n",
      "EPOCH: 9684 LOSS: 41.01993652750097\n",
      "EPOCH: 9685 LOSS: 41.01993016342688\n",
      "EPOCH: 9686 LOSS: 41.01992380028116\n",
      "EPOCH: 9687 LOSS: 41.01991743806365\n",
      "EPOCH: 9688 LOSS: 41.019911076774164\n",
      "EPOCH: 9689 LOSS: 41.01990471641247\n",
      "EPOCH: 9690 LOSS: 41.01989835697845\n",
      "EPOCH: 9691 LOSS: 41.01989199847189\n",
      "EPOCH: 9692 LOSS: 41.01988564089261\n",
      "EPOCH: 9693 LOSS: 41.0198792842404\n",
      "EPOCH: 9694 LOSS: 41.01987292851514\n",
      "EPOCH: 9695 LOSS: 41.019866573716584\n",
      "EPOCH: 9696 LOSS: 41.01986021984459\n",
      "EPOCH: 9697 LOSS: 41.019853866898956\n",
      "EPOCH: 9698 LOSS: 41.0198475148795\n",
      "EPOCH: 9699 LOSS: 41.01984116378604\n",
      "EPOCH: 9700 LOSS: 41.01983481361839\n",
      "EPOCH: 9701 LOSS: 41.01982846437639\n",
      "EPOCH: 9702 LOSS: 41.019822116059814\n",
      "EPOCH: 9703 LOSS: 41.01981576866851\n",
      "EPOCH: 9704 LOSS: 41.019809422202314\n",
      "EPOCH: 9705 LOSS: 41.01980307666099\n",
      "EPOCH: 9706 LOSS: 41.0197967320444\n",
      "EPOCH: 9707 LOSS: 41.019790388352334\n",
      "EPOCH: 9708 LOSS: 41.01978404558464\n",
      "EPOCH: 9709 LOSS: 41.019777703741106\n",
      "EPOCH: 9710 LOSS: 41.01977136282157\n",
      "EPOCH: 9711 LOSS: 41.01976502282583\n",
      "EPOCH: 9712 LOSS: 41.01975868375372\n",
      "EPOCH: 9713 LOSS: 41.01975234560505\n",
      "EPOCH: 9714 LOSS: 41.01974600837965\n",
      "EPOCH: 9715 LOSS: 41.0197396720773\n",
      "EPOCH: 9716 LOSS: 41.01973333669787\n",
      "EPOCH: 9717 LOSS: 41.01972700224115\n",
      "EPOCH: 9718 LOSS: 41.01972066870695\n",
      "EPOCH: 9719 LOSS: 41.01971433609511\n",
      "EPOCH: 9720 LOSS: 41.01970800440543\n",
      "EPOCH: 9721 LOSS: 41.01970167363774\n",
      "EPOCH: 9722 LOSS: 41.01969534379186\n",
      "EPOCH: 9723 LOSS: 41.0196890148676\n",
      "EPOCH: 9724 LOSS: 41.019682686864776\n",
      "EPOCH: 9725 LOSS: 41.01967635978322\n",
      "EPOCH: 9726 LOSS: 41.01967003362271\n",
      "EPOCH: 9727 LOSS: 41.01966370838313\n",
      "EPOCH: 9728 LOSS: 41.01965738406424\n",
      "EPOCH: 9729 LOSS: 41.01965106066589\n",
      "EPOCH: 9730 LOSS: 41.01964473818789\n",
      "EPOCH: 9731 LOSS: 41.01963841663007\n",
      "EPOCH: 9732 LOSS: 41.019632095992236\n",
      "EPOCH: 9733 LOSS: 41.019625776274204\n",
      "EPOCH: 9734 LOSS: 41.0196194574758\n",
      "EPOCH: 9735 LOSS: 41.01961313959684\n",
      "EPOCH: 9736 LOSS: 41.01960682263713\n",
      "EPOCH: 9737 LOSS: 41.01960050659652\n",
      "EPOCH: 9738 LOSS: 41.0195941914748\n",
      "EPOCH: 9739 LOSS: 41.01958787727182\n",
      "EPOCH: 9740 LOSS: 41.01958156398736\n",
      "EPOCH: 9741 LOSS: 41.01957525162125\n",
      "EPOCH: 9742 LOSS: 41.019568940173336\n",
      "EPOCH: 9743 LOSS: 41.0195626296434\n",
      "EPOCH: 9744 LOSS: 41.0195563200313\n",
      "EPOCH: 9745 LOSS: 41.019550011336825\n",
      "EPOCH: 9746 LOSS: 41.0195437035598\n",
      "EPOCH: 9747 LOSS: 41.019537396700045\n",
      "EPOCH: 9748 LOSS: 41.0195310907574\n",
      "EPOCH: 9749 LOSS: 41.01952478573165\n",
      "EPOCH: 9750 LOSS: 41.01951848162263\n",
      "EPOCH: 9751 LOSS: 41.01951217843016\n",
      "EPOCH: 9752 LOSS: 41.019505876154085\n",
      "EPOCH: 9753 LOSS: 41.019499574794175\n",
      "EPOCH: 9754 LOSS: 41.01949327435028\n",
      "EPOCH: 9755 LOSS: 41.01948697482223\n",
      "EPOCH: 9756 LOSS: 41.019480676209824\n",
      "EPOCH: 9757 LOSS: 41.01947437851287\n",
      "EPOCH: 9758 LOSS: 41.01946808173122\n",
      "EPOCH: 9759 LOSS: 41.019461785864685\n",
      "EPOCH: 9760 LOSS: 41.01945549091305\n",
      "EPOCH: 9761 LOSS: 41.01944919687619\n",
      "EPOCH: 9762 LOSS: 41.0194429037539\n",
      "EPOCH: 9763 LOSS: 41.01943661154599\n",
      "EPOCH: 9764 LOSS: 41.01943032025229\n",
      "EPOCH: 9765 LOSS: 41.01942402987262\n",
      "EPOCH: 9766 LOSS: 41.019417740406794\n",
      "EPOCH: 9767 LOSS: 41.019411451854644\n",
      "EPOCH: 9768 LOSS: 41.01940516421598\n",
      "EPOCH: 9769 LOSS: 41.01939887749063\n",
      "EPOCH: 9770 LOSS: 41.0193925916784\n",
      "EPOCH: 9771 LOSS: 41.01938630677914\n",
      "EPOCH: 9772 LOSS: 41.01938002279264\n",
      "EPOCH: 9773 LOSS: 41.01937373971873\n",
      "EPOCH: 9774 LOSS: 41.01936745755724\n",
      "EPOCH: 9775 LOSS: 41.019361176307974\n",
      "EPOCH: 9776 LOSS: 41.019354895970764\n",
      "EPOCH: 9777 LOSS: 41.01934861654543\n",
      "EPOCH: 9778 LOSS: 41.01934233803179\n",
      "EPOCH: 9779 LOSS: 41.01933606042968\n",
      "EPOCH: 9780 LOSS: 41.0193297837389\n",
      "EPOCH: 9781 LOSS: 41.01932350795927\n",
      "EPOCH: 9782 LOSS: 41.019317233090625\n",
      "EPOCH: 9783 LOSS: 41.01931095913278\n",
      "EPOCH: 9784 LOSS: 41.01930468608557\n",
      "EPOCH: 9785 LOSS: 41.01929841394876\n",
      "EPOCH: 9786 LOSS: 41.01929214272225\n",
      "EPOCH: 9787 LOSS: 41.01928587240581\n",
      "EPOCH: 9788 LOSS: 41.019279602999276\n",
      "EPOCH: 9789 LOSS: 41.01927333450247\n",
      "EPOCH: 9790 LOSS: 41.01926706691522\n",
      "EPOCH: 9791 LOSS: 41.01926080023733\n",
      "EPOCH: 9792 LOSS: 41.019254534468644\n",
      "EPOCH: 9793 LOSS: 41.01924826960896\n",
      "EPOCH: 9794 LOSS: 41.019242005658114\n",
      "EPOCH: 9795 LOSS: 41.01923574261591\n",
      "EPOCH: 9796 LOSS: 41.019229480482196\n",
      "EPOCH: 9797 LOSS: 41.01922321925678\n",
      "EPOCH: 9798 LOSS: 41.01921695893948\n",
      "EPOCH: 9799 LOSS: 41.019210699530134\n",
      "EPOCH: 9800 LOSS: 41.01920444102854\n",
      "EPOCH: 9801 LOSS: 41.01919818343453\n",
      "EPOCH: 9802 LOSS: 41.019191926747936\n",
      "EPOCH: 9803 LOSS: 41.01918567096857\n",
      "EPOCH: 9804 LOSS: 41.01917941609624\n",
      "EPOCH: 9805 LOSS: 41.01917316213081\n",
      "EPOCH: 9806 LOSS: 41.019166909072055\n",
      "EPOCH: 9807 LOSS: 41.01916065691981\n",
      "EPOCH: 9808 LOSS: 41.01915440567392\n",
      "EPOCH: 9809 LOSS: 41.0191481553342\n",
      "EPOCH: 9810 LOSS: 41.01914190590044\n",
      "EPOCH: 9811 LOSS: 41.01913565737252\n",
      "EPOCH: 9812 LOSS: 41.0191294097502\n",
      "EPOCH: 9813 LOSS: 41.019123163033335\n",
      "EPOCH: 9814 LOSS: 41.019116917221766\n",
      "EPOCH: 9815 LOSS: 41.01911067231525\n",
      "EPOCH: 9816 LOSS: 41.019104428313675\n",
      "EPOCH: 9817 LOSS: 41.01909818521685\n",
      "EPOCH: 9818 LOSS: 41.01909194302458\n",
      "EPOCH: 9819 LOSS: 41.01908570173669\n",
      "EPOCH: 9820 LOSS: 41.019079461353016\n",
      "EPOCH: 9821 LOSS: 41.01907322187338\n",
      "EPOCH: 9822 LOSS: 41.019066983297584\n",
      "EPOCH: 9823 LOSS: 41.01906074562547\n",
      "EPOCH: 9824 LOSS: 41.019054508856854\n",
      "EPOCH: 9825 LOSS: 41.01904827299156\n",
      "EPOCH: 9826 LOSS: 41.01904203802941\n",
      "EPOCH: 9827 LOSS: 41.01903580397023\n",
      "EPOCH: 9828 LOSS: 41.01902957081385\n",
      "EPOCH: 9829 LOSS: 41.019023338560075\n",
      "EPOCH: 9830 LOSS: 41.01901710720874\n",
      "EPOCH: 9831 LOSS: 41.019010876759666\n",
      "EPOCH: 9832 LOSS: 41.01900464721268\n",
      "EPOCH: 9833 LOSS: 41.0189984185676\n",
      "EPOCH: 9834 LOSS: 41.01899219082425\n",
      "EPOCH: 9835 LOSS: 41.018985963982445\n",
      "EPOCH: 9836 LOSS: 41.01897973804203\n",
      "EPOCH: 9837 LOSS: 41.018973513002805\n",
      "EPOCH: 9838 LOSS: 41.018967288864616\n",
      "EPOCH: 9839 LOSS: 41.018961065627266\n",
      "EPOCH: 9840 LOSS: 41.01895484329059\n",
      "EPOCH: 9841 LOSS: 41.018948621854406\n",
      "EPOCH: 9842 LOSS: 41.01894240131855\n",
      "EPOCH: 9843 LOSS: 41.01893618168283\n",
      "EPOCH: 9844 LOSS: 41.01892996294708\n",
      "EPOCH: 9845 LOSS: 41.01892374511111\n",
      "EPOCH: 9846 LOSS: 41.01891752817477\n",
      "EPOCH: 9847 LOSS: 41.018911312137845\n",
      "EPOCH: 9848 LOSS: 41.0189050970002\n",
      "EPOCH: 9849 LOSS: 41.018898882761626\n",
      "EPOCH: 9850 LOSS: 41.01889266942197\n",
      "EPOCH: 9851 LOSS: 41.01888645698105\n",
      "EPOCH: 9852 LOSS: 41.01888024543868\n",
      "EPOCH: 9853 LOSS: 41.018874034794706\n",
      "EPOCH: 9854 LOSS: 41.01886782504892\n",
      "EPOCH: 9855 LOSS: 41.01886161620118\n",
      "EPOCH: 9856 LOSS: 41.01885540825129\n",
      "EPOCH: 9857 LOSS: 41.018849201199075\n",
      "EPOCH: 9858 LOSS: 41.01884299504437\n",
      "EPOCH: 9859 LOSS: 41.018836789786974\n",
      "EPOCH: 9860 LOSS: 41.018830585426755\n",
      "EPOCH: 9861 LOSS: 41.0188243819635\n",
      "EPOCH: 9862 LOSS: 41.01881817939704\n",
      "EPOCH: 9863 LOSS: 41.01881197772721\n",
      "EPOCH: 9864 LOSS: 41.01880577695384\n",
      "EPOCH: 9865 LOSS: 41.018799577076734\n",
      "EPOCH: 9866 LOSS: 41.01879337809572\n",
      "EPOCH: 9867 LOSS: 41.018787180010655\n",
      "EPOCH: 9868 LOSS: 41.018780982821326\n",
      "EPOCH: 9869 LOSS: 41.018774786527565\n",
      "EPOCH: 9870 LOSS: 41.018768591129216\n",
      "EPOCH: 9871 LOSS: 41.01876239662608\n",
      "EPOCH: 9872 LOSS: 41.018756203018\n",
      "EPOCH: 9873 LOSS: 41.018750010304785\n",
      "EPOCH: 9874 LOSS: 41.018743818486286\n",
      "EPOCH: 9875 LOSS: 41.018737627562295\n",
      "EPOCH: 9876 LOSS: 41.018731437532665\n",
      "EPOCH: 9877 LOSS: 41.0187252483972\n",
      "EPOCH: 9878 LOSS: 41.01871906015574\n",
      "EPOCH: 9879 LOSS: 41.01871287280811\n",
      "EPOCH: 9880 LOSS: 41.01870668635412\n",
      "EPOCH: 9881 LOSS: 41.018700500793614\n",
      "EPOCH: 9882 LOSS: 41.0186943161264\n",
      "EPOCH: 9883 LOSS: 41.018688132352324\n",
      "EPOCH: 9884 LOSS: 41.0186819494712\n",
      "EPOCH: 9885 LOSS: 41.018675767482854\n",
      "EPOCH: 9886 LOSS: 41.01866958638709\n",
      "EPOCH: 9887 LOSS: 41.01866340618378\n",
      "EPOCH: 9888 LOSS: 41.018657226872705\n",
      "EPOCH: 9889 LOSS: 41.01865104845371\n",
      "EPOCH: 9890 LOSS: 41.01864487092665\n",
      "EPOCH: 9891 LOSS: 41.018638694291305\n",
      "EPOCH: 9892 LOSS: 41.01863251854752\n",
      "EPOCH: 9893 LOSS: 41.01862634369512\n",
      "EPOCH: 9894 LOSS: 41.01862016973393\n",
      "EPOCH: 9895 LOSS: 41.018613996663774\n",
      "EPOCH: 9896 LOSS: 41.01860782448448\n",
      "EPOCH: 9897 LOSS: 41.01860165319587\n",
      "EPOCH: 9898 LOSS: 41.01859548279778\n",
      "EPOCH: 9899 LOSS: 41.01858931329002\n",
      "EPOCH: 9900 LOSS: 41.01858314467244\n",
      "EPOCH: 9901 LOSS: 41.01857697694484\n",
      "EPOCH: 9902 LOSS: 41.018570810107086\n",
      "EPOCH: 9903 LOSS: 41.01856464415896\n",
      "EPOCH: 9904 LOSS: 41.01855847910029\n",
      "EPOCH: 9905 LOSS: 41.01855231493094\n",
      "EPOCH: 9906 LOSS: 41.01854615165072\n",
      "EPOCH: 9907 LOSS: 41.01853998925943\n",
      "EPOCH: 9908 LOSS: 41.01853382775693\n",
      "EPOCH: 9909 LOSS: 41.01852766714303\n",
      "EPOCH: 9910 LOSS: 41.01852150741756\n",
      "EPOCH: 9911 LOSS: 41.018515348580365\n",
      "EPOCH: 9912 LOSS: 41.018509190631235\n",
      "EPOCH: 9913 LOSS: 41.018503033570035\n",
      "EPOCH: 9914 LOSS: 41.01849687739656\n",
      "EPOCH: 9915 LOSS: 41.01849072211064\n",
      "EPOCH: 9916 LOSS: 41.01848456771212\n",
      "EPOCH: 9917 LOSS: 41.01847841420084\n",
      "EPOCH: 9918 LOSS: 41.01847226157658\n",
      "EPOCH: 9919 LOSS: 41.01846610983921\n",
      "EPOCH: 9920 LOSS: 41.01845995898854\n",
      "EPOCH: 9921 LOSS: 41.01845380902438\n",
      "EPOCH: 9922 LOSS: 41.01844765994658\n",
      "EPOCH: 9923 LOSS: 41.018441511754986\n",
      "EPOCH: 9924 LOSS: 41.01843536444936\n",
      "EPOCH: 9925 LOSS: 41.01842921802961\n",
      "EPOCH: 9926 LOSS: 41.01842307249551\n",
      "EPOCH: 9927 LOSS: 41.018416927846886\n",
      "EPOCH: 9928 LOSS: 41.01841078408359\n",
      "EPOCH: 9929 LOSS: 41.01840464120545\n",
      "EPOCH: 9930 LOSS: 41.01839849921228\n",
      "EPOCH: 9931 LOSS: 41.0183923581039\n",
      "EPOCH: 9932 LOSS: 41.018386217880156\n",
      "EPOCH: 9933 LOSS: 41.018380078540886\n",
      "EPOCH: 9934 LOSS: 41.01837394008588\n",
      "EPOCH: 9935 LOSS: 41.01836780251498\n",
      "EPOCH: 9936 LOSS: 41.018361665828024\n",
      "EPOCH: 9937 LOSS: 41.01835553002484\n",
      "EPOCH: 9938 LOSS: 41.018349395105254\n",
      "EPOCH: 9939 LOSS: 41.01834326106909\n",
      "EPOCH: 9940 LOSS: 41.01833712791618\n",
      "EPOCH: 9941 LOSS: 41.01833099564635\n",
      "EPOCH: 9942 LOSS: 41.01832486425944\n",
      "EPOCH: 9943 LOSS: 41.01831873375523\n",
      "EPOCH: 9944 LOSS: 41.01831260413361\n",
      "EPOCH: 9945 LOSS: 41.018306475394375\n",
      "EPOCH: 9946 LOSS: 41.01830034753736\n",
      "EPOCH: 9947 LOSS: 41.018294220562396\n",
      "EPOCH: 9948 LOSS: 41.0182880944693\n",
      "EPOCH: 9949 LOSS: 41.01828196925792\n",
      "EPOCH: 9950 LOSS: 41.018275844928084\n",
      "EPOCH: 9951 LOSS: 41.01826972147958\n",
      "EPOCH: 9952 LOSS: 41.018263598912284\n",
      "EPOCH: 9953 LOSS: 41.018257477226\n",
      "EPOCH: 9954 LOSS: 41.01825135642056\n",
      "EPOCH: 9955 LOSS: 41.018245236495815\n",
      "EPOCH: 9956 LOSS: 41.01823911745156\n",
      "EPOCH: 9957 LOSS: 41.01823299928764\n",
      "EPOCH: 9958 LOSS: 41.01822688200389\n",
      "EPOCH: 9959 LOSS: 41.01822076560012\n",
      "EPOCH: 9960 LOSS: 41.018214650076175\n",
      "EPOCH: 9961 LOSS: 41.01820853543188\n",
      "EPOCH: 9962 LOSS: 41.01820242166706\n",
      "EPOCH: 9963 LOSS: 41.01819630878154\n",
      "EPOCH: 9964 LOSS: 41.01819019677517\n",
      "EPOCH: 9965 LOSS: 41.018184085647746\n",
      "EPOCH: 9966 LOSS: 41.01817797539913\n",
      "EPOCH: 9967 LOSS: 41.018171866029135\n",
      "EPOCH: 9968 LOSS: 41.01816575753759\n",
      "EPOCH: 9969 LOSS: 41.01815964992433\n",
      "EPOCH: 9970 LOSS: 41.01815354318917\n",
      "EPOCH: 9971 LOSS: 41.01814743733195\n",
      "EPOCH: 9972 LOSS: 41.01814133235252\n",
      "EPOCH: 9973 LOSS: 41.01813522825067\n",
      "EPOCH: 9974 LOSS: 41.01812912502625\n",
      "EPOCH: 9975 LOSS: 41.01812302267909\n",
      "EPOCH: 9976 LOSS: 41.018116921209014\n",
      "EPOCH: 9977 LOSS: 41.018110820615874\n",
      "EPOCH: 9978 LOSS: 41.018104720899444\n",
      "EPOCH: 9979 LOSS: 41.01809862205962\n",
      "EPOCH: 9980 LOSS: 41.018092524096176\n",
      "EPOCH: 9981 LOSS: 41.01808642700898\n",
      "EPOCH: 9982 LOSS: 41.01808033079786\n",
      "EPOCH: 9983 LOSS: 41.018074235462606\n",
      "EPOCH: 9984 LOSS: 41.01806814100309\n",
      "EPOCH: 9985 LOSS: 41.01806204741913\n",
      "EPOCH: 9986 LOSS: 41.01805595471056\n",
      "EPOCH: 9987 LOSS: 41.0180498628772\n",
      "EPOCH: 9988 LOSS: 41.01804377191888\n",
      "EPOCH: 9989 LOSS: 41.01803768183545\n",
      "EPOCH: 9990 LOSS: 41.01803159262669\n",
      "EPOCH: 9991 LOSS: 41.01802550429251\n",
      "EPOCH: 9992 LOSS: 41.01801941683266\n",
      "EPOCH: 9993 LOSS: 41.018013330247015\n",
      "EPOCH: 9994 LOSS: 41.018007244535404\n",
      "EPOCH: 9995 LOSS: 41.01800115969764\n",
      "EPOCH: 9996 LOSS: 41.01799507573357\n",
      "EPOCH: 9997 LOSS: 41.017988992643\n",
      "EPOCH: 9998 LOSS: 41.01798291042579\n",
      "EPOCH: 9999 LOSS: 41.01797682908174\n",
      "EPOCH: 10000 LOSS: 41.017970748610736\n",
      "EPOCH: 10001 LOSS: 41.01796466901254\n",
      "EPOCH: 10002 LOSS: 41.01795859028701\n",
      "EPOCH: 10003 LOSS: 41.01795251243399\n",
      "EPOCH: 10004 LOSS: 41.01794643545331\n",
      "EPOCH: 10005 LOSS: 41.01794035934478\n",
      "EPOCH: 10006 LOSS: 41.017934284108236\n",
      "EPOCH: 10007 LOSS: 41.017928209743516\n",
      "EPOCH: 10008 LOSS: 41.017922136250455\n",
      "EPOCH: 10009 LOSS: 41.017916063628874\n",
      "EPOCH: 10010 LOSS: 41.017909991878625\n",
      "EPOCH: 10011 LOSS: 41.01790392099949\n",
      "EPOCH: 10012 LOSS: 41.01789785099137\n",
      "EPOCH: 10013 LOSS: 41.01789178185403\n",
      "EPOCH: 10014 LOSS: 41.01788571358735\n",
      "EPOCH: 10015 LOSS: 41.01787964619113\n",
      "EPOCH: 10016 LOSS: 41.0178735796652\n",
      "EPOCH: 10017 LOSS: 41.01786751400941\n",
      "EPOCH: 10018 LOSS: 41.017861449223595\n",
      "EPOCH: 10019 LOSS: 41.01785538530757\n",
      "EPOCH: 10020 LOSS: 41.017849322261185\n",
      "EPOCH: 10021 LOSS: 41.01784326008425\n",
      "EPOCH: 10022 LOSS: 41.01783719877659\n",
      "EPOCH: 10023 LOSS: 41.01783113833807\n",
      "EPOCH: 10024 LOSS: 41.017825078768496\n",
      "EPOCH: 10025 LOSS: 41.017819020067705\n",
      "EPOCH: 10026 LOSS: 41.017812962235546\n",
      "EPOCH: 10027 LOSS: 41.0178069052718\n",
      "EPOCH: 10028 LOSS: 41.01780084917635\n",
      "EPOCH: 10029 LOSS: 41.01779479394903\n",
      "EPOCH: 10030 LOSS: 41.01778873958964\n",
      "EPOCH: 10031 LOSS: 41.01778268609801\n",
      "EPOCH: 10032 LOSS: 41.017776633474014\n",
      "EPOCH: 10033 LOSS: 41.01777058171745\n",
      "EPOCH: 10034 LOSS: 41.017764530828146\n",
      "EPOCH: 10035 LOSS: 41.01775848080596\n",
      "EPOCH: 10036 LOSS: 41.017752431650685\n",
      "EPOCH: 10037 LOSS: 41.0177463833622\n",
      "EPOCH: 10038 LOSS: 41.0177403359403\n",
      "EPOCH: 10039 LOSS: 41.01773428938485\n",
      "EPOCH: 10040 LOSS: 41.01772824369564\n",
      "EPOCH: 10041 LOSS: 41.01772219887255\n",
      "EPOCH: 10042 LOSS: 41.01771615491536\n",
      "EPOCH: 10043 LOSS: 41.017710111823945\n",
      "EPOCH: 10044 LOSS: 41.01770406959813\n",
      "EPOCH: 10045 LOSS: 41.017698028237724\n",
      "EPOCH: 10046 LOSS: 41.017691987742595\n",
      "EPOCH: 10047 LOSS: 41.01768594811254\n",
      "EPOCH: 10048 LOSS: 41.01767990934741\n",
      "EPOCH: 10049 LOSS: 41.017673871447045\n",
      "EPOCH: 10050 LOSS: 41.017667834411256\n",
      "EPOCH: 10051 LOSS: 41.0176617982399\n",
      "EPOCH: 10052 LOSS: 41.01765576293279\n",
      "EPOCH: 10053 LOSS: 41.01764972848976\n",
      "EPOCH: 10054 LOSS: 41.01764369491066\n",
      "EPOCH: 10055 LOSS: 41.0176376621953\n",
      "EPOCH: 10056 LOSS: 41.01763163034354\n",
      "EPOCH: 10057 LOSS: 41.017625599355185\n",
      "EPOCH: 10058 LOSS: 41.01761956923008\n",
      "EPOCH: 10059 LOSS: 41.01761353996806\n",
      "EPOCH: 10060 LOSS: 41.01760751156897\n",
      "EPOCH: 10061 LOSS: 41.017601484032625\n",
      "EPOCH: 10062 LOSS: 41.01759545735885\n",
      "EPOCH: 10063 LOSS: 41.01758943154748\n",
      "EPOCH: 10064 LOSS: 41.017583406598376\n",
      "EPOCH: 10065 LOSS: 41.01757738251137\n",
      "EPOCH: 10066 LOSS: 41.01757135928626\n",
      "EPOCH: 10067 LOSS: 41.01756533692291\n",
      "EPOCH: 10068 LOSS: 41.01755931542113\n",
      "EPOCH: 10069 LOSS: 41.017553294780775\n",
      "EPOCH: 10070 LOSS: 41.01754727500166\n",
      "EPOCH: 10071 LOSS: 41.01754125608363\n",
      "EPOCH: 10072 LOSS: 41.01753523802652\n",
      "EPOCH: 10073 LOSS: 41.017529220830156\n",
      "EPOCH: 10074 LOSS: 41.01752320449438\n",
      "EPOCH: 10075 LOSS: 41.01751718901902\n",
      "EPOCH: 10076 LOSS: 41.01751117440391\n",
      "EPOCH: 10077 LOSS: 41.01750516064888\n",
      "EPOCH: 10078 LOSS: 41.01749914775377\n",
      "EPOCH: 10079 LOSS: 41.017493135718425\n",
      "EPOCH: 10080 LOSS: 41.017487124542654\n",
      "EPOCH: 10081 LOSS: 41.0174811142263\n",
      "EPOCH: 10082 LOSS: 41.017475104769204\n",
      "EPOCH: 10083 LOSS: 41.01746909617119\n",
      "EPOCH: 10084 LOSS: 41.0174630884321\n",
      "EPOCH: 10085 LOSS: 41.01745708155178\n",
      "EPOCH: 10086 LOSS: 41.01745107553003\n",
      "EPOCH: 10087 LOSS: 41.01744507036673\n",
      "EPOCH: 10088 LOSS: 41.01743906606167\n",
      "EPOCH: 10089 LOSS: 41.017433062614714\n",
      "EPOCH: 10090 LOSS: 41.01742706002566\n",
      "EPOCH: 10091 LOSS: 41.017421058294396\n",
      "EPOCH: 10092 LOSS: 41.017415057420706\n",
      "EPOCH: 10093 LOSS: 41.017409057404464\n",
      "EPOCH: 10094 LOSS: 41.01740305824547\n",
      "EPOCH: 10095 LOSS: 41.01739705994359\n",
      "EPOCH: 10096 LOSS: 41.01739106249863\n",
      "EPOCH: 10097 LOSS: 41.017385065910446\n",
      "EPOCH: 10098 LOSS: 41.017379070178855\n",
      "EPOCH: 10099 LOSS: 41.01737307530371\n",
      "EPOCH: 10100 LOSS: 41.01736708128483\n",
      "EPOCH: 10101 LOSS: 41.01736108812207\n",
      "EPOCH: 10102 LOSS: 41.01735509581524\n",
      "EPOCH: 10103 LOSS: 41.01734910436419\n",
      "EPOCH: 10104 LOSS: 41.01734311376875\n",
      "EPOCH: 10105 LOSS: 41.01733712402876\n",
      "EPOCH: 10106 LOSS: 41.017331135144055\n",
      "EPOCH: 10107 LOSS: 41.01732514711445\n",
      "EPOCH: 10108 LOSS: 41.0173191599398\n",
      "EPOCH: 10109 LOSS: 41.017313173619954\n",
      "EPOCH: 10110 LOSS: 41.0173071881547\n",
      "EPOCH: 10111 LOSS: 41.01730120354394\n",
      "EPOCH: 10112 LOSS: 41.01729521978744\n",
      "EPOCH: 10113 LOSS: 41.01728923688506\n",
      "EPOCH: 10114 LOSS: 41.01728325483667\n",
      "EPOCH: 10115 LOSS: 41.01727727364207\n",
      "EPOCH: 10116 LOSS: 41.01727129330111\n",
      "EPOCH: 10117 LOSS: 41.01726531381358\n",
      "EPOCH: 10118 LOSS: 41.01725933517939\n",
      "EPOCH: 10119 LOSS: 41.01725335739833\n",
      "EPOCH: 10120 LOSS: 41.01724738047024\n",
      "EPOCH: 10121 LOSS: 41.017241404394966\n",
      "EPOCH: 10122 LOSS: 41.01723542917233\n",
      "EPOCH: 10123 LOSS: 41.01722945480218\n",
      "EPOCH: 10124 LOSS: 41.01722348128433\n",
      "EPOCH: 10125 LOSS: 41.017217508618664\n",
      "EPOCH: 10126 LOSS: 41.017211536804965\n",
      "EPOCH: 10127 LOSS: 41.0172055658431\n",
      "EPOCH: 10128 LOSS: 41.01719959573288\n",
      "EPOCH: 10129 LOSS: 41.01719362647417\n",
      "EPOCH: 10130 LOSS: 41.01718765806679\n",
      "EPOCH: 10131 LOSS: 41.01718169051057\n",
      "EPOCH: 10132 LOSS: 41.017175723805366\n",
      "EPOCH: 10133 LOSS: 41.01716975795098\n",
      "EPOCH: 10134 LOSS: 41.01716379294728\n",
      "EPOCH: 10135 LOSS: 41.01715782879411\n",
      "EPOCH: 10136 LOSS: 41.017151865491265\n",
      "EPOCH: 10137 LOSS: 41.01714590303861\n",
      "EPOCH: 10138 LOSS: 41.01713994143597\n",
      "EPOCH: 10139 LOSS: 41.0171339806832\n",
      "EPOCH: 10140 LOSS: 41.01712802078013\n",
      "EPOCH: 10141 LOSS: 41.01712206172656\n",
      "EPOCH: 10142 LOSS: 41.01711610352237\n",
      "EPOCH: 10143 LOSS: 41.01711014616738\n",
      "EPOCH: 10144 LOSS: 41.01710418966143\n",
      "EPOCH: 10145 LOSS: 41.017098234004365\n",
      "EPOCH: 10146 LOSS: 41.01709227919599\n",
      "EPOCH: 10147 LOSS: 41.01708632523618\n",
      "EPOCH: 10148 LOSS: 41.01708037212475\n",
      "EPOCH: 10149 LOSS: 41.017074419861544\n",
      "EPOCH: 10150 LOSS: 41.017068468446396\n",
      "EPOCH: 10151 LOSS: 41.017062517879154\n",
      "EPOCH: 10152 LOSS: 41.01705656815963\n",
      "EPOCH: 10153 LOSS: 41.01705061928767\n",
      "EPOCH: 10154 LOSS: 41.01704467126312\n",
      "EPOCH: 10155 LOSS: 41.01703872408582\n",
      "EPOCH: 10156 LOSS: 41.01703277775559\n",
      "EPOCH: 10157 LOSS: 41.017026832272265\n",
      "EPOCH: 10158 LOSS: 41.01702088763572\n",
      "EPOCH: 10159 LOSS: 41.01701494384574\n",
      "EPOCH: 10160 LOSS: 41.017009000902206\n",
      "EPOCH: 10161 LOSS: 41.01700305880493\n",
      "EPOCH: 10162 LOSS: 41.01699711755376\n",
      "EPOCH: 10163 LOSS: 41.016991177148526\n",
      "EPOCH: 10164 LOSS: 41.016985237589076\n",
      "EPOCH: 10165 LOSS: 41.01697929887522\n",
      "EPOCH: 10166 LOSS: 41.016973361006826\n",
      "EPOCH: 10167 LOSS: 41.01696742398373\n",
      "EPOCH: 10168 LOSS: 41.01696148780574\n",
      "EPOCH: 10169 LOSS: 41.01695555247273\n",
      "EPOCH: 10170 LOSS: 41.016949617984515\n",
      "EPOCH: 10171 LOSS: 41.01694368434094\n",
      "EPOCH: 10172 LOSS: 41.016937751541846\n",
      "EPOCH: 10173 LOSS: 41.01693181958706\n",
      "EPOCH: 10174 LOSS: 41.016925888476436\n",
      "EPOCH: 10175 LOSS: 41.01691995820978\n",
      "EPOCH: 10176 LOSS: 41.01691402878696\n",
      "EPOCH: 10177 LOSS: 41.01690810020781\n",
      "EPOCH: 10178 LOSS: 41.01690217247216\n",
      "EPOCH: 10179 LOSS: 41.01689624557983\n",
      "EPOCH: 10180 LOSS: 41.0168903195307\n",
      "EPOCH: 10181 LOSS: 41.01688439432459\n",
      "EPOCH: 10182 LOSS: 41.01687846996132\n",
      "EPOCH: 10183 LOSS: 41.01687254644075\n",
      "EPOCH: 10184 LOSS: 41.01686662376271\n",
      "EPOCH: 10185 LOSS: 41.016860701927044\n",
      "EPOCH: 10186 LOSS: 41.01685478093358\n",
      "EPOCH: 10187 LOSS: 41.01684886078216\n",
      "EPOCH: 10188 LOSS: 41.01684294147261\n",
      "EPOCH: 10189 LOSS: 41.0168370230048\n",
      "EPOCH: 10190 LOSS: 41.01683110537856\n",
      "EPOCH: 10191 LOSS: 41.01682518859367\n",
      "EPOCH: 10192 LOSS: 41.01681927265006\n",
      "EPOCH: 10193 LOSS: 41.01681335754751\n",
      "EPOCH: 10194 LOSS: 41.01680744328587\n",
      "EPOCH: 10195 LOSS: 41.01680152986499\n",
      "EPOCH: 10196 LOSS: 41.01679561728471\n",
      "EPOCH: 10197 LOSS: 41.01678970554484\n",
      "EPOCH: 10198 LOSS: 41.016783794645235\n",
      "EPOCH: 10199 LOSS: 41.01677788458575\n",
      "EPOCH: 10200 LOSS: 41.0167719753662\n",
      "EPOCH: 10201 LOSS: 41.016766066986435\n",
      "EPOCH: 10202 LOSS: 41.01676015944631\n",
      "EPOCH: 10203 LOSS: 41.01675425274563\n",
      "EPOCH: 10204 LOSS: 41.01674834688425\n",
      "EPOCH: 10205 LOSS: 41.01674244186201\n",
      "EPOCH: 10206 LOSS: 41.01673653767875\n",
      "EPOCH: 10207 LOSS: 41.0167306343343\n",
      "EPOCH: 10208 LOSS: 41.0167247318285\n",
      "EPOCH: 10209 LOSS: 41.01671883016121\n",
      "EPOCH: 10210 LOSS: 41.01671292933225\n",
      "EPOCH: 10211 LOSS: 41.01670702934146\n",
      "EPOCH: 10212 LOSS: 41.01670113018869\n",
      "EPOCH: 10213 LOSS: 41.016695231873776\n",
      "EPOCH: 10214 LOSS: 41.01668933439653\n",
      "EPOCH: 10215 LOSS: 41.01668343775684\n",
      "EPOCH: 10216 LOSS: 41.0166775419545\n",
      "EPOCH: 10217 LOSS: 41.01667164698938\n",
      "EPOCH: 10218 LOSS: 41.0166657528613\n",
      "EPOCH: 10219 LOSS: 41.01665985957012\n",
      "EPOCH: 10220 LOSS: 41.01665396711566\n",
      "EPOCH: 10221 LOSS: 41.01664807549777\n",
      "EPOCH: 10222 LOSS: 41.016642184716275\n",
      "EPOCH: 10223 LOSS: 41.01663629477105\n",
      "EPOCH: 10224 LOSS: 41.016630405661886\n",
      "EPOCH: 10225 LOSS: 41.01662451738864\n",
      "EPOCH: 10226 LOSS: 41.01661862995118\n",
      "EPOCH: 10227 LOSS: 41.01661274334932\n",
      "EPOCH: 10228 LOSS: 41.0166068575829\n",
      "EPOCH: 10229 LOSS: 41.016600972651766\n",
      "EPOCH: 10230 LOSS: 41.01659508855577\n",
      "EPOCH: 10231 LOSS: 41.01658920529472\n",
      "EPOCH: 10232 LOSS: 41.01658332286849\n",
      "EPOCH: 10233 LOSS: 41.0165774412769\n",
      "EPOCH: 10234 LOSS: 41.01657156051978\n",
      "EPOCH: 10235 LOSS: 41.016565680597\n",
      "EPOCH: 10236 LOSS: 41.01655980150837\n",
      "EPOCH: 10237 LOSS: 41.01655392325376\n",
      "EPOCH: 10238 LOSS: 41.01654804583299\n",
      "EPOCH: 10239 LOSS: 41.01654216924591\n",
      "EPOCH: 10240 LOSS: 41.01653629349234\n",
      "EPOCH: 10241 LOSS: 41.016530418572145\n",
      "EPOCH: 10242 LOSS: 41.01652454448515\n",
      "EPOCH: 10243 LOSS: 41.0165186712312\n",
      "EPOCH: 10244 LOSS: 41.016512798810155\n",
      "EPOCH: 10245 LOSS: 41.01650692722182\n",
      "EPOCH: 10246 LOSS: 41.01650105646607\n",
      "EPOCH: 10247 LOSS: 41.01649518654271\n",
      "EPOCH: 10248 LOSS: 41.0164893174516\n",
      "EPOCH: 10249 LOSS: 41.016483449192584\n",
      "EPOCH: 10250 LOSS: 41.0164775817655\n",
      "EPOCH: 10251 LOSS: 41.016471715170184\n",
      "EPOCH: 10252 LOSS: 41.01646584940647\n",
      "EPOCH: 10253 LOSS: 41.01645998447424\n",
      "EPOCH: 10254 LOSS: 41.01645412037328\n",
      "EPOCH: 10255 LOSS: 41.01644825710345\n",
      "EPOCH: 10256 LOSS: 41.01644239466461\n",
      "EPOCH: 10257 LOSS: 41.01643653305658\n",
      "EPOCH: 10258 LOSS: 41.0164306722792\n",
      "EPOCH: 10259 LOSS: 41.01642481233233\n",
      "EPOCH: 10260 LOSS: 41.01641895321579\n",
      "EPOCH: 10261 LOSS: 41.016413094929426\n",
      "EPOCH: 10262 LOSS: 41.01640723747309\n",
      "EPOCH: 10263 LOSS: 41.01640138084663\n",
      "EPOCH: 10264 LOSS: 41.016395525049845\n",
      "EPOCH: 10265 LOSS: 41.01638967008262\n",
      "EPOCH: 10266 LOSS: 41.016383815944785\n",
      "EPOCH: 10267 LOSS: 41.016377962636156\n",
      "EPOCH: 10268 LOSS: 41.016372110156624\n",
      "EPOCH: 10269 LOSS: 41.01636625850599\n",
      "EPOCH: 10270 LOSS: 41.01636040768412\n",
      "EPOCH: 10271 LOSS: 41.01635455769082\n",
      "EPOCH: 10272 LOSS: 41.01634870852597\n",
      "EPOCH: 10273 LOSS: 41.01634286018938\n",
      "EPOCH: 10274 LOSS: 41.01633701268093\n",
      "EPOCH: 10275 LOSS: 41.016331166000434\n",
      "EPOCH: 10276 LOSS: 41.01632532014772\n",
      "EPOCH: 10277 LOSS: 41.01631947512266\n",
      "EPOCH: 10278 LOSS: 41.0163136309251\n",
      "EPOCH: 10279 LOSS: 41.016307787554844\n",
      "EPOCH: 10280 LOSS: 41.01630194501177\n",
      "EPOCH: 10281 LOSS: 41.016296103295716\n",
      "EPOCH: 10282 LOSS: 41.0162902624065\n",
      "EPOCH: 10283 LOSS: 41.01628442234396\n",
      "EPOCH: 10284 LOSS: 41.016278583107976\n",
      "EPOCH: 10285 LOSS: 41.01627274469838\n",
      "EPOCH: 10286 LOSS: 41.01626690711499\n",
      "EPOCH: 10287 LOSS: 41.016261070357665\n",
      "EPOCH: 10288 LOSS: 41.01625523442624\n",
      "EPOCH: 10289 LOSS: 41.01624939932056\n",
      "EPOCH: 10290 LOSS: 41.016243565040476\n",
      "EPOCH: 10291 LOSS: 41.01623773158582\n",
      "EPOCH: 10292 LOSS: 41.01623189895642\n",
      "EPOCH: 10293 LOSS: 41.01622606715216\n",
      "EPOCH: 10294 LOSS: 41.01622023617285\n",
      "EPOCH: 10295 LOSS: 41.01621440601834\n",
      "EPOCH: 10296 LOSS: 41.01620857668847\n",
      "EPOCH: 10297 LOSS: 41.01620274818308\n",
      "EPOCH: 10298 LOSS: 41.016196920502026\n",
      "EPOCH: 10299 LOSS: 41.01619109364515\n",
      "EPOCH: 10300 LOSS: 41.01618526761227\n",
      "EPOCH: 10301 LOSS: 41.016179442403256\n",
      "EPOCH: 10302 LOSS: 41.01617361801792\n",
      "EPOCH: 10303 LOSS: 41.01616779445615\n",
      "EPOCH: 10304 LOSS: 41.01616197171774\n",
      "EPOCH: 10305 LOSS: 41.01615614980258\n",
      "EPOCH: 10306 LOSS: 41.016150328710495\n",
      "EPOCH: 10307 LOSS: 41.0161445084413\n",
      "EPOCH: 10308 LOSS: 41.01613868899486\n",
      "EPOCH: 10309 LOSS: 41.01613287037101\n",
      "EPOCH: 10310 LOSS: 41.01612705256962\n",
      "EPOCH: 10311 LOSS: 41.016121235590504\n",
      "EPOCH: 10312 LOSS: 41.016115419433525\n",
      "EPOCH: 10313 LOSS: 41.01610960409851\n",
      "EPOCH: 10314 LOSS: 41.01610378958531\n",
      "EPOCH: 10315 LOSS: 41.01609797589375\n",
      "EPOCH: 10316 LOSS: 41.016092163023714\n",
      "EPOCH: 10317 LOSS: 41.01608635097501\n",
      "EPOCH: 10318 LOSS: 41.01608053974749\n",
      "EPOCH: 10319 LOSS: 41.01607472934099\n",
      "EPOCH: 10320 LOSS: 41.016068919755384\n",
      "EPOCH: 10321 LOSS: 41.01606311099047\n",
      "EPOCH: 10322 LOSS: 41.01605730304613\n",
      "EPOCH: 10323 LOSS: 41.016051495922184\n",
      "EPOCH: 10324 LOSS: 41.016045689618494\n",
      "EPOCH: 10325 LOSS: 41.0160398841349\n",
      "EPOCH: 10326 LOSS: 41.01603407947121\n",
      "EPOCH: 10327 LOSS: 41.016028275627335\n",
      "EPOCH: 10328 LOSS: 41.016022472603055\n",
      "EPOCH: 10329 LOSS: 41.016016670398244\n",
      "EPOCH: 10330 LOSS: 41.01601086901274\n",
      "EPOCH: 10331 LOSS: 41.0160050684464\n",
      "EPOCH: 10332 LOSS: 41.015999268699034\n",
      "EPOCH: 10333 LOSS: 41.015993469770514\n",
      "EPOCH: 10334 LOSS: 41.01598767166069\n",
      "EPOCH: 10335 LOSS: 41.0159818743694\n",
      "EPOCH: 10336 LOSS: 41.015976077896454\n",
      "EPOCH: 10337 LOSS: 41.01597028224174\n",
      "EPOCH: 10338 LOSS: 41.01596448740507\n",
      "EPOCH: 10339 LOSS: 41.015958693386324\n",
      "EPOCH: 10340 LOSS: 41.01595290018531\n",
      "EPOCH: 10341 LOSS: 41.01594710780191\n",
      "EPOCH: 10342 LOSS: 41.01594131623593\n",
      "EPOCH: 10343 LOSS: 41.01593552548722\n",
      "EPOCH: 10344 LOSS: 41.015929735555645\n",
      "EPOCH: 10345 LOSS: 41.01592394644103\n",
      "EPOCH: 10346 LOSS: 41.01591815814324\n",
      "EPOCH: 10347 LOSS: 41.0159123706621\n",
      "EPOCH: 10348 LOSS: 41.01590658399746\n",
      "EPOCH: 10349 LOSS: 41.015900798149175\n",
      "EPOCH: 10350 LOSS: 41.015895013117074\n",
      "EPOCH: 10351 LOSS: 41.01588922890101\n",
      "EPOCH: 10352 LOSS: 41.01588344550082\n",
      "EPOCH: 10353 LOSS: 41.01587766291635\n",
      "EPOCH: 10354 LOSS: 41.015871881147476\n",
      "EPOCH: 10355 LOSS: 41.015866100193996\n",
      "EPOCH: 10356 LOSS: 41.01586032005577\n",
      "EPOCH: 10357 LOSS: 41.01585454073265\n",
      "EPOCH: 10358 LOSS: 41.01584876222449\n",
      "EPOCH: 10359 LOSS: 41.015842984531105\n",
      "EPOCH: 10360 LOSS: 41.015837207652375\n",
      "EPOCH: 10361 LOSS: 41.01583143158811\n",
      "EPOCH: 10362 LOSS: 41.01582565633818\n",
      "EPOCH: 10363 LOSS: 41.015819881902424\n",
      "EPOCH: 10364 LOSS: 41.01581410828068\n",
      "EPOCH: 10365 LOSS: 41.0158083354728\n",
      "EPOCH: 10366 LOSS: 41.01580256347864\n",
      "EPOCH: 10367 LOSS: 41.01579679229802\n",
      "EPOCH: 10368 LOSS: 41.0157910219308\n",
      "EPOCH: 10369 LOSS: 41.015785252376816\n",
      "EPOCH: 10370 LOSS: 41.01577948363592\n",
      "EPOCH: 10371 LOSS: 41.015773715707965\n",
      "EPOCH: 10372 LOSS: 41.01576794859279\n",
      "EPOCH: 10373 LOSS: 41.01576218229023\n",
      "EPOCH: 10374 LOSS: 41.01575641680015\n",
      "EPOCH: 10375 LOSS: 41.01575065212238\n",
      "EPOCH: 10376 LOSS: 41.01574488825676\n",
      "EPOCH: 10377 LOSS: 41.01573912520317\n",
      "EPOCH: 10378 LOSS: 41.01573336296142\n",
      "EPOCH: 10379 LOSS: 41.01572760153135\n",
      "EPOCH: 10380 LOSS: 41.015721840912846\n",
      "EPOCH: 10381 LOSS: 41.01571608110572\n",
      "EPOCH: 10382 LOSS: 41.01571032210981\n",
      "EPOCH: 10383 LOSS: 41.01570456392501\n",
      "EPOCH: 10384 LOSS: 41.01569880655112\n",
      "EPOCH: 10385 LOSS: 41.015693049988\n",
      "EPOCH: 10386 LOSS: 41.01568729423549\n",
      "EPOCH: 10387 LOSS: 41.01568153929347\n",
      "EPOCH: 10388 LOSS: 41.01567578516173\n",
      "EPOCH: 10389 LOSS: 41.01567003184016\n",
      "EPOCH: 10390 LOSS: 41.01566427932859\n",
      "EPOCH: 10391 LOSS: 41.015658527626854\n",
      "EPOCH: 10392 LOSS: 41.01565277673484\n",
      "EPOCH: 10393 LOSS: 41.01564702665233\n",
      "EPOCH: 10394 LOSS: 41.0156412773792\n",
      "EPOCH: 10395 LOSS: 41.01563552891534\n",
      "EPOCH: 10396 LOSS: 41.01562978126054\n",
      "EPOCH: 10397 LOSS: 41.01562403441467\n",
      "EPOCH: 10398 LOSS: 41.015618288377546\n",
      "EPOCH: 10399 LOSS: 41.01561254314906\n",
      "EPOCH: 10400 LOSS: 41.015606798729024\n",
      "EPOCH: 10401 LOSS: 41.0156010551173\n",
      "EPOCH: 10402 LOSS: 41.01559531231373\n",
      "EPOCH: 10403 LOSS: 41.01558957031815\n",
      "EPOCH: 10404 LOSS: 41.015583829130435\n",
      "EPOCH: 10405 LOSS: 41.01557808875042\n",
      "EPOCH: 10406 LOSS: 41.015572349177944\n",
      "EPOCH: 10407 LOSS: 41.01556661041285\n",
      "EPOCH: 10408 LOSS: 41.01556087245498\n",
      "EPOCH: 10409 LOSS: 41.0155551353042\n",
      "EPOCH: 10410 LOSS: 41.015549398960346\n",
      "EPOCH: 10411 LOSS: 41.015543663423266\n",
      "EPOCH: 10412 LOSS: 41.015537928692815\n",
      "EPOCH: 10413 LOSS: 41.01553219476884\n",
      "EPOCH: 10414 LOSS: 41.01552646165115\n",
      "EPOCH: 10415 LOSS: 41.015520729339634\n",
      "EPOCH: 10416 LOSS: 41.015514997834124\n",
      "EPOCH: 10417 LOSS: 41.01550926713449\n",
      "EPOCH: 10418 LOSS: 41.015503537240534\n",
      "EPOCH: 10419 LOSS: 41.01549780815213\n",
      "EPOCH: 10420 LOSS: 41.01549207986915\n",
      "EPOCH: 10421 LOSS: 41.01548635239139\n",
      "EPOCH: 10422 LOSS: 41.01548062571873\n",
      "EPOCH: 10423 LOSS: 41.015474899851\n",
      "EPOCH: 10424 LOSS: 41.015469174788066\n",
      "EPOCH: 10425 LOSS: 41.01546345052975\n",
      "EPOCH: 10426 LOSS: 41.01545772707593\n",
      "EPOCH: 10427 LOSS: 41.015452004426436\n",
      "EPOCH: 10428 LOSS: 41.01544628258111\n",
      "EPOCH: 10429 LOSS: 41.01544056153981\n",
      "EPOCH: 10430 LOSS: 41.01543484130238\n",
      "EPOCH: 10431 LOSS: 41.015429121868664\n",
      "EPOCH: 10432 LOSS: 41.015423403238515\n",
      "EPOCH: 10433 LOSS: 41.01541768541179\n",
      "EPOCH: 10434 LOSS: 41.01541196838831\n",
      "EPOCH: 10435 LOSS: 41.01540625216792\n",
      "EPOCH: 10436 LOSS: 41.01540053675052\n",
      "EPOCH: 10437 LOSS: 41.0153948221359\n",
      "EPOCH: 10438 LOSS: 41.01538910832393\n",
      "EPOCH: 10439 LOSS: 41.01538339531447\n",
      "EPOCH: 10440 LOSS: 41.015377683107346\n",
      "EPOCH: 10441 LOSS: 41.015371971702436\n",
      "EPOCH: 10442 LOSS: 41.01536626109955\n",
      "EPOCH: 10443 LOSS: 41.01536055129857\n",
      "EPOCH: 10444 LOSS: 41.0153548422993\n",
      "EPOCH: 10445 LOSS: 41.01534913410164\n",
      "EPOCH: 10446 LOSS: 41.01534342670541\n",
      "EPOCH: 10447 LOSS: 41.01533772011046\n",
      "EPOCH: 10448 LOSS: 41.01533201431663\n",
      "EPOCH: 10449 LOSS: 41.01532630932378\n",
      "EPOCH: 10450 LOSS: 41.01532060513178\n",
      "EPOCH: 10451 LOSS: 41.01531490174043\n",
      "EPOCH: 10452 LOSS: 41.0153091991496\n",
      "EPOCH: 10453 LOSS: 41.01530349735915\n",
      "EPOCH: 10454 LOSS: 41.01529779636894\n",
      "EPOCH: 10455 LOSS: 41.015292096178754\n",
      "EPOCH: 10456 LOSS: 41.01528639678852\n",
      "EPOCH: 10457 LOSS: 41.01528069819804\n",
      "EPOCH: 10458 LOSS: 41.01527500040717\n",
      "EPOCH: 10459 LOSS: 41.015269303415764\n",
      "EPOCH: 10460 LOSS: 41.01526360722366\n",
      "EPOCH: 10461 LOSS: 41.015257911830716\n",
      "EPOCH: 10462 LOSS: 41.01525221723679\n",
      "EPOCH: 10463 LOSS: 41.01524652344171\n",
      "EPOCH: 10464 LOSS: 41.015240830445336\n",
      "EPOCH: 10465 LOSS: 41.01523513824752\n",
      "EPOCH: 10466 LOSS: 41.015229446848096\n",
      "EPOCH: 10467 LOSS: 41.015223756246954\n",
      "EPOCH: 10468 LOSS: 41.01521806644388\n",
      "EPOCH: 10469 LOSS: 41.015212377438765\n",
      "EPOCH: 10470 LOSS: 41.01520668923144\n",
      "EPOCH: 10471 LOSS: 41.01520100182179\n",
      "EPOCH: 10472 LOSS: 41.015195315209596\n",
      "EPOCH: 10473 LOSS: 41.015189629394754\n",
      "EPOCH: 10474 LOSS: 41.01518394437712\n",
      "EPOCH: 10475 LOSS: 41.01517826015653\n",
      "EPOCH: 10476 LOSS: 41.01517257673283\n",
      "EPOCH: 10477 LOSS: 41.01516689410585\n",
      "EPOCH: 10478 LOSS: 41.01516121227547\n",
      "EPOCH: 10479 LOSS: 41.01515553124153\n",
      "EPOCH: 10480 LOSS: 41.0151498510039\n",
      "EPOCH: 10481 LOSS: 41.01514417156239\n",
      "EPOCH: 10482 LOSS: 41.015138492916876\n",
      "EPOCH: 10483 LOSS: 41.01513281506719\n",
      "EPOCH: 10484 LOSS: 41.01512713801317\n",
      "EPOCH: 10485 LOSS: 41.015121461754724\n",
      "EPOCH: 10486 LOSS: 41.01511578629163\n",
      "EPOCH: 10487 LOSS: 41.015110111623784\n",
      "EPOCH: 10488 LOSS: 41.01510443775102\n",
      "EPOCH: 10489 LOSS: 41.01509876467319\n",
      "EPOCH: 10490 LOSS: 41.015093092390146\n",
      "EPOCH: 10491 LOSS: 41.015087420901736\n",
      "EPOCH: 10492 LOSS: 41.015081750207806\n",
      "EPOCH: 10493 LOSS: 41.015076080308205\n",
      "EPOCH: 10494 LOSS: 41.01507041120278\n",
      "EPOCH: 10495 LOSS: 41.01506474289139\n",
      "EPOCH: 10496 LOSS: 41.015059075373884\n",
      "EPOCH: 10497 LOSS: 41.01505340865011\n",
      "EPOCH: 10498 LOSS: 41.015047742719915\n",
      "EPOCH: 10499 LOSS: 41.01504207758316\n",
      "EPOCH: 10500 LOSS: 41.015036413239685\n",
      "EPOCH: 10501 LOSS: 41.01503074968933\n",
      "EPOCH: 10502 LOSS: 41.015025086931956\n",
      "EPOCH: 10503 LOSS: 41.015019424967434\n",
      "EPOCH: 10504 LOSS: 41.01501376379558\n",
      "EPOCH: 10505 LOSS: 41.01500810341625\n",
      "EPOCH: 10506 LOSS: 41.01500244382932\n",
      "EPOCH: 10507 LOSS: 41.0149967850346\n",
      "EPOCH: 10508 LOSS: 41.014991127031976\n",
      "EPOCH: 10509 LOSS: 41.01498546982128\n",
      "EPOCH: 10510 LOSS: 41.01497981340236\n",
      "EPOCH: 10511 LOSS: 41.01497415777508\n",
      "EPOCH: 10512 LOSS: 41.01496850293929\n",
      "EPOCH: 10513 LOSS: 41.014962848894825\n",
      "EPOCH: 10514 LOSS: 41.01495719564154\n",
      "EPOCH: 10515 LOSS: 41.01495154317931\n",
      "EPOCH: 10516 LOSS: 41.01494589150795\n",
      "EPOCH: 10517 LOSS: 41.01494024062733\n",
      "EPOCH: 10518 LOSS: 41.01493459053731\n",
      "EPOCH: 10519 LOSS: 41.0149289412377\n",
      "EPOCH: 10520 LOSS: 41.01492329272841\n",
      "EPOCH: 10521 LOSS: 41.01491764500923\n",
      "EPOCH: 10522 LOSS: 41.01491199808004\n",
      "EPOCH: 10523 LOSS: 41.014906351940695\n",
      "EPOCH: 10524 LOSS: 41.014900706591064\n",
      "EPOCH: 10525 LOSS: 41.014895062030945\n",
      "EPOCH: 10526 LOSS: 41.01488941826024\n",
      "EPOCH: 10527 LOSS: 41.014883775278776\n",
      "EPOCH: 10528 LOSS: 41.014878133086405\n",
      "EPOCH: 10529 LOSS: 41.014872491682965\n",
      "EPOCH: 10530 LOSS: 41.01486685106835\n",
      "EPOCH: 10531 LOSS: 41.01486121124236\n",
      "EPOCH: 10532 LOSS: 41.01485557220487\n",
      "EPOCH: 10533 LOSS: 41.01484993395573\n",
      "EPOCH: 10534 LOSS: 41.014844296494815\n",
      "EPOCH: 10535 LOSS: 41.014838659821926\n",
      "EPOCH: 10536 LOSS: 41.01483302393696\n",
      "EPOCH: 10537 LOSS: 41.014827388839734\n",
      "EPOCH: 10538 LOSS: 41.014821754530125\n",
      "EPOCH: 10539 LOSS: 41.01481612100797\n",
      "EPOCH: 10540 LOSS: 41.01481048827311\n",
      "EPOCH: 10541 LOSS: 41.01480485632544\n",
      "EPOCH: 10542 LOSS: 41.014799225164765\n",
      "EPOCH: 10543 LOSS: 41.01479359479096\n",
      "EPOCH: 10544 LOSS: 41.01478796520386\n",
      "EPOCH: 10545 LOSS: 41.01478233640334\n",
      "EPOCH: 10546 LOSS: 41.014776708389235\n",
      "EPOCH: 10547 LOSS: 41.01477108116139\n",
      "EPOCH: 10548 LOSS: 41.01476545471967\n",
      "EPOCH: 10549 LOSS: 41.014759829063934\n",
      "EPOCH: 10550 LOSS: 41.01475420419401\n",
      "EPOCH: 10551 LOSS: 41.01474858010978\n",
      "EPOCH: 10552 LOSS: 41.01474295681106\n",
      "EPOCH: 10553 LOSS: 41.014737334297735\n",
      "EPOCH: 10554 LOSS: 41.01473171256962\n",
      "EPOCH: 10555 LOSS: 41.01472609162662\n",
      "EPOCH: 10556 LOSS: 41.01472047146852\n",
      "EPOCH: 10557 LOSS: 41.01471485209525\n",
      "EPOCH: 10558 LOSS: 41.01470923350659\n",
      "EPOCH: 10559 LOSS: 41.01470361570245\n",
      "EPOCH: 10560 LOSS: 41.014697998682635\n",
      "EPOCH: 10561 LOSS: 41.01469238244702\n",
      "EPOCH: 10562 LOSS: 41.01468676699545\n",
      "EPOCH: 10563 LOSS: 41.01468115232778\n",
      "EPOCH: 10564 LOSS: 41.01467553844388\n",
      "EPOCH: 10565 LOSS: 41.01466992534357\n",
      "EPOCH: 10566 LOSS: 41.01466431302673\n",
      "EPOCH: 10567 LOSS: 41.014658701493204\n",
      "EPOCH: 10568 LOSS: 41.014653090742826\n",
      "EPOCH: 10569 LOSS: 41.01464748077545\n",
      "EPOCH: 10570 LOSS: 41.01464187159097\n",
      "EPOCH: 10571 LOSS: 41.01463626318919\n",
      "EPOCH: 10572 LOSS: 41.01463065556999\n",
      "EPOCH: 10573 LOSS: 41.014625048733215\n",
      "EPOCH: 10574 LOSS: 41.01461944267872\n",
      "EPOCH: 10575 LOSS: 41.01461383740637\n",
      "EPOCH: 10576 LOSS: 41.014608232915975\n",
      "EPOCH: 10577 LOSS: 41.01460262920743\n",
      "EPOCH: 10578 LOSS: 41.01459702628057\n",
      "EPOCH: 10579 LOSS: 41.01459142413525\n",
      "EPOCH: 10580 LOSS: 41.01458582277132\n",
      "EPOCH: 10581 LOSS: 41.01458022218866\n",
      "EPOCH: 10582 LOSS: 41.01457462238707\n",
      "EPOCH: 10583 LOSS: 41.01456902336646\n",
      "EPOCH: 10584 LOSS: 41.01456342512663\n",
      "EPOCH: 10585 LOSS: 41.014557827667474\n",
      "EPOCH: 10586 LOSS: 41.01455223098882\n",
      "EPOCH: 10587 LOSS: 41.01454663509054\n",
      "EPOCH: 10588 LOSS: 41.01454103997247\n",
      "EPOCH: 10589 LOSS: 41.014535445634486\n",
      "EPOCH: 10590 LOSS: 41.01452985207641\n",
      "EPOCH: 10591 LOSS: 41.014524259298106\n",
      "EPOCH: 10592 LOSS: 41.01451866729945\n",
      "EPOCH: 10593 LOSS: 41.01451307608026\n",
      "EPOCH: 10594 LOSS: 41.01450748564042\n",
      "EPOCH: 10595 LOSS: 41.01450189597977\n",
      "EPOCH: 10596 LOSS: 41.01449630709815\n",
      "EPOCH: 10597 LOSS: 41.01449071899543\n",
      "EPOCH: 10598 LOSS: 41.01448513167147\n",
      "EPOCH: 10599 LOSS: 41.01447954512612\n",
      "EPOCH: 10600 LOSS: 41.01447395935921\n",
      "EPOCH: 10601 LOSS: 41.014468374370615\n",
      "EPOCH: 10602 LOSS: 41.014462790160195\n",
      "EPOCH: 10603 LOSS: 41.01445720672778\n",
      "EPOCH: 10604 LOSS: 41.014451624073246\n",
      "EPOCH: 10605 LOSS: 41.01444604219643\n",
      "EPOCH: 10606 LOSS: 41.014440461097195\n",
      "EPOCH: 10607 LOSS: 41.0144348807754\n",
      "EPOCH: 10608 LOSS: 41.01442930123088\n",
      "EPOCH: 10609 LOSS: 41.01442372246351\n",
      "EPOCH: 10610 LOSS: 41.014418144473126\n",
      "EPOCH: 10611 LOSS: 41.014412567259605\n",
      "EPOCH: 10612 LOSS: 41.01440699082276\n",
      "EPOCH: 10613 LOSS: 41.014401415162496\n",
      "EPOCH: 10614 LOSS: 41.014395840278624\n",
      "EPOCH: 10615 LOSS: 41.01439026617101\n",
      "EPOCH: 10616 LOSS: 41.01438469283954\n",
      "EPOCH: 10617 LOSS: 41.01437912028402\n",
      "EPOCH: 10618 LOSS: 41.01437354850434\n",
      "EPOCH: 10619 LOSS: 41.014367977500335\n",
      "EPOCH: 10620 LOSS: 41.01436240727185\n",
      "EPOCH: 10621 LOSS: 41.014356837818774\n",
      "EPOCH: 10622 LOSS: 41.014351269140946\n",
      "EPOCH: 10623 LOSS: 41.0143457012382\n",
      "EPOCH: 10624 LOSS: 41.0143401341104\n",
      "EPOCH: 10625 LOSS: 41.014334567757416\n",
      "EPOCH: 10626 LOSS: 41.01432900217909\n",
      "EPOCH: 10627 LOSS: 41.01432343737528\n",
      "EPOCH: 10628 LOSS: 41.01431787334583\n",
      "EPOCH: 10629 LOSS: 41.01431231009062\n",
      "EPOCH: 10630 LOSS: 41.014306747609474\n",
      "EPOCH: 10631 LOSS: 41.01430118590226\n",
      "EPOCH: 10632 LOSS: 41.01429562496885\n",
      "EPOCH: 10633 LOSS: 41.014290064809074\n",
      "EPOCH: 10634 LOSS: 41.01428450542278\n",
      "EPOCH: 10635 LOSS: 41.01427894680984\n",
      "EPOCH: 10636 LOSS: 41.01427338897014\n",
      "EPOCH: 10637 LOSS: 41.01426783190345\n",
      "EPOCH: 10638 LOSS: 41.014262275609696\n",
      "EPOCH: 10639 LOSS: 41.014256720088724\n",
      "EPOCH: 10640 LOSS: 41.01425116534036\n",
      "EPOCH: 10641 LOSS: 41.01424561136449\n",
      "EPOCH: 10642 LOSS: 41.01424005816095\n",
      "EPOCH: 10643 LOSS: 41.014234505729604\n",
      "EPOCH: 10644 LOSS: 41.014228954070305\n",
      "EPOCH: 10645 LOSS: 41.0142234031829\n",
      "EPOCH: 10646 LOSS: 41.014217853067244\n",
      "EPOCH: 10647 LOSS: 41.0142123037232\n",
      "EPOCH: 10648 LOSS: 41.01420675515064\n",
      "EPOCH: 10649 LOSS: 41.01420120734939\n",
      "EPOCH: 10650 LOSS: 41.01419566031931\n",
      "EPOCH: 10651 LOSS: 41.01419011406024\n",
      "EPOCH: 10652 LOSS: 41.01418456857208\n",
      "EPOCH: 10653 LOSS: 41.014179023854666\n",
      "EPOCH: 10654 LOSS: 41.01417347990784\n",
      "EPOCH: 10655 LOSS: 41.01416793673146\n",
      "EPOCH: 10656 LOSS: 41.01416239432541\n",
      "EPOCH: 10657 LOSS: 41.01415685268952\n",
      "EPOCH: 10658 LOSS: 41.01415131182364\n",
      "EPOCH: 10659 LOSS: 41.01414577172763\n",
      "EPOCH: 10660 LOSS: 41.01414023240134\n",
      "EPOCH: 10661 LOSS: 41.01413469384467\n",
      "EPOCH: 10662 LOSS: 41.01412915605739\n",
      "EPOCH: 10663 LOSS: 41.014123619039445\n",
      "EPOCH: 10664 LOSS: 41.01411808279063\n",
      "EPOCH: 10665 LOSS: 41.01411254731084\n",
      "EPOCH: 10666 LOSS: 41.014107012599915\n",
      "EPOCH: 10667 LOSS: 41.01410147865769\n",
      "EPOCH: 10668 LOSS: 41.014095945484065\n",
      "EPOCH: 10669 LOSS: 41.014090413078854\n",
      "EPOCH: 10670 LOSS: 41.01408488144193\n",
      "EPOCH: 10671 LOSS: 41.014079350573155\n",
      "EPOCH: 10672 LOSS: 41.014073820472376\n",
      "EPOCH: 10673 LOSS: 41.01406829113945\n",
      "EPOCH: 10674 LOSS: 41.01406276257424\n",
      "EPOCH: 10675 LOSS: 41.0140572347766\n",
      "EPOCH: 10676 LOSS: 41.01405170774636\n",
      "EPOCH: 10677 LOSS: 41.01404618148342\n",
      "EPOCH: 10678 LOSS: 41.01404065598761\n",
      "EPOCH: 10679 LOSS: 41.01403513125881\n",
      "EPOCH: 10680 LOSS: 41.014029607296834\n",
      "EPOCH: 10681 LOSS: 41.014024084101564\n",
      "EPOCH: 10682 LOSS: 41.014018561672856\n",
      "EPOCH: 10683 LOSS: 41.01401304001057\n",
      "EPOCH: 10684 LOSS: 41.01400751911455\n",
      "EPOCH: 10685 LOSS: 41.01400199898467\n",
      "EPOCH: 10686 LOSS: 41.01399647962077\n",
      "EPOCH: 10687 LOSS: 41.013990961022714\n",
      "EPOCH: 10688 LOSS: 41.01398544319035\n",
      "EPOCH: 10689 LOSS: 41.01397992612354\n",
      "EPOCH: 10690 LOSS: 41.01397440982214\n",
      "EPOCH: 10691 LOSS: 41.01396889428602\n",
      "EPOCH: 10692 LOSS: 41.01396337951501\n",
      "EPOCH: 10693 LOSS: 41.013957865509\n",
      "EPOCH: 10694 LOSS: 41.01395235226781\n",
      "EPOCH: 10695 LOSS: 41.01394683979133\n",
      "EPOCH: 10696 LOSS: 41.013941328079405\n",
      "EPOCH: 10697 LOSS: 41.013935817131866\n",
      "EPOCH: 10698 LOSS: 41.013930306948595\n",
      "EPOCH: 10699 LOSS: 41.01392479752947\n",
      "EPOCH: 10700 LOSS: 41.01391928887432\n",
      "EPOCH: 10701 LOSS: 41.01391378098299\n",
      "EPOCH: 10702 LOSS: 41.013908273855364\n",
      "EPOCH: 10703 LOSS: 41.013902767491274\n",
      "EPOCH: 10704 LOSS: 41.01389726189059\n",
      "EPOCH: 10705 LOSS: 41.0138917570532\n",
      "EPOCH: 10706 LOSS: 41.01388625297891\n",
      "EPOCH: 10707 LOSS: 41.01388074966759\n",
      "EPOCH: 10708 LOSS: 41.01387524711913\n",
      "EPOCH: 10709 LOSS: 41.01386974533334\n",
      "EPOCH: 10710 LOSS: 41.01386424431011\n",
      "EPOCH: 10711 LOSS: 41.01385874404928\n",
      "EPOCH: 10712 LOSS: 41.01385324455073\n",
      "EPOCH: 10713 LOSS: 41.01384774581428\n",
      "EPOCH: 10714 LOSS: 41.01384224783983\n",
      "EPOCH: 10715 LOSS: 41.013836750627206\n",
      "EPOCH: 10716 LOSS: 41.01383125417628\n",
      "EPOCH: 10717 LOSS: 41.0138257584869\n",
      "EPOCH: 10718 LOSS: 41.013820263558934\n",
      "EPOCH: 10719 LOSS: 41.013814769392226\n",
      "EPOCH: 10720 LOSS: 41.013809275986645\n",
      "EPOCH: 10721 LOSS: 41.013803783342055\n",
      "EPOCH: 10722 LOSS: 41.0137982914583\n",
      "EPOCH: 10723 LOSS: 41.01379280033524\n",
      "EPOCH: 10724 LOSS: 41.01378730997274\n",
      "EPOCH: 10725 LOSS: 41.013781820370646\n",
      "EPOCH: 10726 LOSS: 41.01377633152881\n",
      "EPOCH: 10727 LOSS: 41.01377084344712\n",
      "EPOCH: 10728 LOSS: 41.01376535612542\n",
      "EPOCH: 10729 LOSS: 41.01375986956355\n",
      "EPOCH: 10730 LOSS: 41.01375438376138\n",
      "EPOCH: 10731 LOSS: 41.01374889871876\n",
      "EPOCH: 10732 LOSS: 41.01374341443559\n",
      "EPOCH: 10733 LOSS: 41.013737930911674\n",
      "EPOCH: 10734 LOSS: 41.0137324481469\n",
      "EPOCH: 10735 LOSS: 41.01372696614109\n",
      "EPOCH: 10736 LOSS: 41.01372148489418\n",
      "EPOCH: 10737 LOSS: 41.013716004405936\n",
      "EPOCH: 10738 LOSS: 41.01371052467627\n",
      "EPOCH: 10739 LOSS: 41.013705045705024\n",
      "EPOCH: 10740 LOSS: 41.013699567492054\n",
      "EPOCH: 10741 LOSS: 41.01369409003726\n",
      "EPOCH: 10742 LOSS: 41.01368861334043\n",
      "EPOCH: 10743 LOSS: 41.013683137401465\n",
      "EPOCH: 10744 LOSS: 41.013677662220225\n",
      "EPOCH: 10745 LOSS: 41.01367218779656\n",
      "EPOCH: 10746 LOSS: 41.01366671413031\n",
      "EPOCH: 10747 LOSS: 41.01366124122136\n",
      "EPOCH: 10748 LOSS: 41.01365576906956\n",
      "EPOCH: 10749 LOSS: 41.01365029767477\n",
      "EPOCH: 10750 LOSS: 41.01364482703684\n",
      "EPOCH: 10751 LOSS: 41.01363935715564\n",
      "EPOCH: 10752 LOSS: 41.013633888031016\n",
      "EPOCH: 10753 LOSS: 41.01362841966284\n",
      "EPOCH: 10754 LOSS: 41.01362295205095\n",
      "EPOCH: 10755 LOSS: 41.013617485195255\n",
      "EPOCH: 10756 LOSS: 41.01361201909555\n",
      "EPOCH: 10757 LOSS: 41.013606553751735\n",
      "EPOCH: 10758 LOSS: 41.01360108916364\n",
      "EPOCH: 10759 LOSS: 41.01359562533115\n",
      "EPOCH: 10760 LOSS: 41.01359016225412\n",
      "EPOCH: 10761 LOSS: 41.013584699932395\n",
      "EPOCH: 10762 LOSS: 41.01357923836585\n",
      "EPOCH: 10763 LOSS: 41.01357377755433\n",
      "EPOCH: 10764 LOSS: 41.01356831749769\n",
      "EPOCH: 10765 LOSS: 41.0135628581958\n",
      "EPOCH: 10766 LOSS: 41.01355739964851\n",
      "EPOCH: 10767 LOSS: 41.01355194185572\n",
      "EPOCH: 10768 LOSS: 41.01354648481723\n",
      "EPOCH: 10769 LOSS: 41.013541028532934\n",
      "EPOCH: 10770 LOSS: 41.01353557300268\n",
      "EPOCH: 10771 LOSS: 41.01353011822631\n",
      "EPOCH: 10772 LOSS: 41.01352466420373\n",
      "EPOCH: 10773 LOSS: 41.01351921093477\n",
      "EPOCH: 10774 LOSS: 41.01351375841928\n",
      "EPOCH: 10775 LOSS: 41.01350830665714\n",
      "EPOCH: 10776 LOSS: 41.0135028556482\n",
      "EPOCH: 10777 LOSS: 41.01349740539231\n",
      "EPOCH: 10778 LOSS: 41.01349195588934\n",
      "EPOCH: 10779 LOSS: 41.01348650713915\n",
      "EPOCH: 10780 LOSS: 41.01348105914161\n",
      "EPOCH: 10781 LOSS: 41.01347561189656\n",
      "EPOCH: 10782 LOSS: 41.01347016540386\n",
      "EPOCH: 10783 LOSS: 41.013464719663396\n",
      "EPOCH: 10784 LOSS: 41.01345927467499\n",
      "EPOCH: 10785 LOSS: 41.01345383043852\n",
      "EPOCH: 10786 LOSS: 41.013448386953854\n",
      "EPOCH: 10787 LOSS: 41.013442944220856\n",
      "EPOCH: 10788 LOSS: 41.01343750223934\n",
      "EPOCH: 10789 LOSS: 41.013432061009226\n",
      "EPOCH: 10790 LOSS: 41.013426620530325\n",
      "EPOCH: 10791 LOSS: 41.01342118080257\n",
      "EPOCH: 10792 LOSS: 41.01341574182571\n",
      "EPOCH: 10793 LOSS: 41.0134103035997\n",
      "EPOCH: 10794 LOSS: 41.013404866124354\n",
      "EPOCH: 10795 LOSS: 41.013399429399556\n",
      "EPOCH: 10796 LOSS: 41.01339399342514\n",
      "EPOCH: 10797 LOSS: 41.01338855820099\n",
      "EPOCH: 10798 LOSS: 41.01338312372694\n",
      "EPOCH: 10799 LOSS: 41.01337769000286\n",
      "EPOCH: 10800 LOSS: 41.01337225702863\n",
      "EPOCH: 10801 LOSS: 41.013366824804095\n",
      "EPOCH: 10802 LOSS: 41.01336139332913\n",
      "EPOCH: 10803 LOSS: 41.01335596260355\n",
      "EPOCH: 10804 LOSS: 41.013350532627264\n",
      "EPOCH: 10805 LOSS: 41.01334510340013\n",
      "EPOCH: 10806 LOSS: 41.013339674921966\n",
      "EPOCH: 10807 LOSS: 41.013334247192674\n",
      "EPOCH: 10808 LOSS: 41.013328820212095\n",
      "EPOCH: 10809 LOSS: 41.0133233939801\n",
      "EPOCH: 10810 LOSS: 41.01331796849655\n",
      "EPOCH: 10811 LOSS: 41.01331254376129\n",
      "EPOCH: 10812 LOSS: 41.01330711977418\n",
      "EPOCH: 10813 LOSS: 41.013301696535116\n",
      "EPOCH: 10814 LOSS: 41.013296274043924\n",
      "EPOCH: 10815 LOSS: 41.01329085230047\n",
      "EPOCH: 10816 LOSS: 41.013285431304624\n",
      "EPOCH: 10817 LOSS: 41.01328001105624\n",
      "EPOCH: 10818 LOSS: 41.01327459155519\n",
      "EPOCH: 10819 LOSS: 41.01326917280131\n",
      "EPOCH: 10820 LOSS: 41.01326375479449\n",
      "EPOCH: 10821 LOSS: 41.01325833753456\n",
      "EPOCH: 10822 LOSS: 41.013252921021405\n",
      "EPOCH: 10823 LOSS: 41.013247505254874\n",
      "EPOCH: 10824 LOSS: 41.013242090234854\n",
      "EPOCH: 10825 LOSS: 41.01323667596115\n",
      "EPOCH: 10826 LOSS: 41.013231262433706\n",
      "EPOCH: 10827 LOSS: 41.01322584965231\n",
      "EPOCH: 10828 LOSS: 41.01322043761684\n",
      "EPOCH: 10829 LOSS: 41.01321502632718\n",
      "EPOCH: 10830 LOSS: 41.01320961578317\n",
      "EPOCH: 10831 LOSS: 41.01320420598468\n",
      "EPOCH: 10832 LOSS: 41.01319879693156\n",
      "EPOCH: 10833 LOSS: 41.01319338862369\n",
      "EPOCH: 10834 LOSS: 41.01318798106091\n",
      "EPOCH: 10835 LOSS: 41.0131825742431\n",
      "EPOCH: 10836 LOSS: 41.013177168170124\n",
      "EPOCH: 10837 LOSS: 41.013171762841814\n",
      "EPOCH: 10838 LOSS: 41.01316635825807\n",
      "EPOCH: 10839 LOSS: 41.01316095441871\n",
      "EPOCH: 10840 LOSS: 41.01315555132365\n",
      "EPOCH: 10841 LOSS: 41.013150148972706\n",
      "EPOCH: 10842 LOSS: 41.01314474736576\n",
      "EPOCH: 10843 LOSS: 41.01313934650264\n",
      "EPOCH: 10844 LOSS: 41.01313394638327\n",
      "EPOCH: 10845 LOSS: 41.013128547007476\n",
      "EPOCH: 10846 LOSS: 41.0131231483751\n",
      "EPOCH: 10847 LOSS: 41.01311775048604\n",
      "EPOCH: 10848 LOSS: 41.01311235334015\n",
      "EPOCH: 10849 LOSS: 41.013106956937264\n",
      "EPOCH: 10850 LOSS: 41.013101561277274\n",
      "EPOCH: 10851 LOSS: 41.01309616636004\n",
      "EPOCH: 10852 LOSS: 41.01309077218541\n",
      "EPOCH: 10853 LOSS: 41.013085378753246\n",
      "EPOCH: 10854 LOSS: 41.01307998606342\n",
      "EPOCH: 10855 LOSS: 41.013074594115785\n",
      "EPOCH: 10856 LOSS: 41.013069202910216\n",
      "EPOCH: 10857 LOSS: 41.013063812446575\n",
      "EPOCH: 10858 LOSS: 41.013058422724704\n",
      "EPOCH: 10859 LOSS: 41.013053033744484\n",
      "EPOCH: 10860 LOSS: 41.013047645505765\n",
      "EPOCH: 10861 LOSS: 41.0130422580084\n",
      "EPOCH: 10862 LOSS: 41.01303687125229\n",
      "EPOCH: 10863 LOSS: 41.01303148523725\n",
      "EPOCH: 10864 LOSS: 41.013026099963184\n",
      "EPOCH: 10865 LOSS: 41.013020715429924\n",
      "EPOCH: 10866 LOSS: 41.01301533163735\n",
      "EPOCH: 10867 LOSS: 41.01300994858532\n",
      "EPOCH: 10868 LOSS: 41.01300456627368\n",
      "EPOCH: 10869 LOSS: 41.01299918470232\n",
      "EPOCH: 10870 LOSS: 41.01299380387108\n",
      "EPOCH: 10871 LOSS: 41.01298842377983\n",
      "EPOCH: 10872 LOSS: 41.01298304442845\n",
      "EPOCH: 10873 LOSS: 41.01297766581677\n",
      "EPOCH: 10874 LOSS: 41.01297228794468\n",
      "EPOCH: 10875 LOSS: 41.012966910812025\n",
      "EPOCH: 10876 LOSS: 41.01296153441868\n",
      "EPOCH: 10877 LOSS: 41.0129561587645\n",
      "EPOCH: 10878 LOSS: 41.012950783849334\n",
      "EPOCH: 10879 LOSS: 41.01294540967308\n",
      "EPOCH: 10880 LOSS: 41.01294003623558\n",
      "EPOCH: 10881 LOSS: 41.0129346635367\n",
      "EPOCH: 10882 LOSS: 41.012929291576285\n",
      "EPOCH: 10883 LOSS: 41.01292392035421\n",
      "EPOCH: 10884 LOSS: 41.01291854987036\n",
      "EPOCH: 10885 LOSS: 41.012913180124585\n",
      "EPOCH: 10886 LOSS: 41.01290781111672\n",
      "EPOCH: 10887 LOSS: 41.012902442846666\n",
      "EPOCH: 10888 LOSS: 41.01289707531426\n",
      "EPOCH: 10889 LOSS: 41.012891708519376\n",
      "EPOCH: 10890 LOSS: 41.01288634246188\n",
      "EPOCH: 10891 LOSS: 41.012880977141634\n",
      "EPOCH: 10892 LOSS: 41.0128756125585\n",
      "EPOCH: 10893 LOSS: 41.01287024871233\n",
      "EPOCH: 10894 LOSS: 41.01286488560301\n",
      "EPOCH: 10895 LOSS: 41.012859523230375\n",
      "EPOCH: 10896 LOSS: 41.012854161594305\n",
      "EPOCH: 10897 LOSS: 41.01284880069467\n",
      "EPOCH: 10898 LOSS: 41.012843440531334\n",
      "EPOCH: 10899 LOSS: 41.012838081104114\n",
      "EPOCH: 10900 LOSS: 41.01283272241295\n",
      "EPOCH: 10901 LOSS: 41.01282736445767\n",
      "EPOCH: 10902 LOSS: 41.0128220072381\n",
      "EPOCH: 10903 LOSS: 41.01281665075415\n",
      "EPOCH: 10904 LOSS: 41.012811295005676\n",
      "EPOCH: 10905 LOSS: 41.01280593999253\n",
      "EPOCH: 10906 LOSS: 41.01280058571459\n",
      "EPOCH: 10907 LOSS: 41.01279523217172\n",
      "EPOCH: 10908 LOSS: 41.01278987936375\n",
      "EPOCH: 10909 LOSS: 41.01278452729058\n",
      "EPOCH: 10910 LOSS: 41.01277917595207\n",
      "EPOCH: 10911 LOSS: 41.01277382534807\n",
      "EPOCH: 10912 LOSS: 41.012768475478445\n",
      "EPOCH: 10913 LOSS: 41.01276312634306\n",
      "EPOCH: 10914 LOSS: 41.012757777941786\n",
      "EPOCH: 10915 LOSS: 41.01275243027449\n",
      "EPOCH: 10916 LOSS: 41.01274708334101\n",
      "EPOCH: 10917 LOSS: 41.01274173714125\n",
      "EPOCH: 10918 LOSS: 41.01273639167506\n",
      "EPOCH: 10919 LOSS: 41.012731046942264\n",
      "EPOCH: 10920 LOSS: 41.01272570294279\n",
      "EPOCH: 10921 LOSS: 41.01272035967647\n",
      "EPOCH: 10922 LOSS: 41.01271501714315\n",
      "EPOCH: 10923 LOSS: 41.01270967534271\n",
      "EPOCH: 10924 LOSS: 41.012704334275035\n",
      "EPOCH: 10925 LOSS: 41.01269899393996\n",
      "EPOCH: 10926 LOSS: 41.01269365433736\n",
      "EPOCH: 10927 LOSS: 41.01268831546712\n",
      "EPOCH: 10928 LOSS: 41.01268297732908\n",
      "EPOCH: 10929 LOSS: 41.012677639923076\n",
      "EPOCH: 10930 LOSS: 41.01267230324903\n",
      "EPOCH: 10931 LOSS: 41.012666967306785\n",
      "EPOCH: 10932 LOSS: 41.01266163209618\n",
      "EPOCH: 10933 LOSS: 41.01265629761713\n",
      "EPOCH: 10934 LOSS: 41.01265096386946\n",
      "EPOCH: 10935 LOSS: 41.01264563085303\n",
      "EPOCH: 10936 LOSS: 41.012640298567725\n",
      "EPOCH: 10937 LOSS: 41.01263496701342\n",
      "EPOCH: 10938 LOSS: 41.012629636189956\n",
      "EPOCH: 10939 LOSS: 41.012624306097194\n",
      "EPOCH: 10940 LOSS: 41.01261897673502\n",
      "EPOCH: 10941 LOSS: 41.01261364810327\n",
      "EPOCH: 10942 LOSS: 41.01260832020185\n",
      "EPOCH: 10943 LOSS: 41.01260299303058\n",
      "EPOCH: 10944 LOSS: 41.01259766658937\n",
      "EPOCH: 10945 LOSS: 41.01259234087805\n",
      "EPOCH: 10946 LOSS: 41.0125870158965\n",
      "EPOCH: 10947 LOSS: 41.012581691644584\n",
      "EPOCH: 10948 LOSS: 41.01257636812215\n",
      "EPOCH: 10949 LOSS: 41.01257104532909\n",
      "EPOCH: 10950 LOSS: 41.01256572326524\n",
      "EPOCH: 10951 LOSS: 41.01256040193049\n",
      "EPOCH: 10952 LOSS: 41.01255508132469\n",
      "EPOCH: 10953 LOSS: 41.012549761447715\n",
      "EPOCH: 10954 LOSS: 41.012544442299436\n",
      "EPOCH: 10955 LOSS: 41.012539123879705\n",
      "EPOCH: 10956 LOSS: 41.01253380618837\n",
      "EPOCH: 10957 LOSS: 41.01252848922533\n",
      "EPOCH: 10958 LOSS: 41.01252317299044\n",
      "EPOCH: 10959 LOSS: 41.01251785748356\n",
      "EPOCH: 10960 LOSS: 41.01251254270454\n",
      "EPOCH: 10961 LOSS: 41.012507228653284\n",
      "EPOCH: 10962 LOSS: 41.01250191532963\n",
      "EPOCH: 10963 LOSS: 41.01249660273345\n",
      "EPOCH: 10964 LOSS: 41.0124912908646\n",
      "EPOCH: 10965 LOSS: 41.01248597972296\n",
      "EPOCH: 10966 LOSS: 41.01248066930838\n",
      "EPOCH: 10967 LOSS: 41.012475359620744\n",
      "EPOCH: 10968 LOSS: 41.0124700506599\n",
      "EPOCH: 10969 LOSS: 41.01246474242572\n",
      "EPOCH: 10970 LOSS: 41.012459434918085\n",
      "EPOCH: 10971 LOSS: 41.01245412813684\n",
      "EPOCH: 10972 LOSS: 41.01244882208185\n",
      "EPOCH: 10973 LOSS: 41.01244351675298\n",
      "EPOCH: 10974 LOSS: 41.01243821215013\n",
      "EPOCH: 10975 LOSS: 41.01243290827313\n",
      "EPOCH: 10976 LOSS: 41.01242760512184\n",
      "EPOCH: 10977 LOSS: 41.012422302696145\n",
      "EPOCH: 10978 LOSS: 41.01241700099591\n",
      "EPOCH: 10979 LOSS: 41.012411700021005\n",
      "EPOCH: 10980 LOSS: 41.01240639977129\n",
      "EPOCH: 10981 LOSS: 41.012401100246606\n",
      "EPOCH: 10982 LOSS: 41.012395801446864\n",
      "EPOCH: 10983 LOSS: 41.012390503371904\n",
      "EPOCH: 10984 LOSS: 41.01238520602159\n",
      "EPOCH: 10985 LOSS: 41.01237990939579\n",
      "EPOCH: 10986 LOSS: 41.01237461349439\n",
      "EPOCH: 10987 LOSS: 41.01236931831723\n",
      "EPOCH: 10988 LOSS: 41.01236402386419\n",
      "EPOCH: 10989 LOSS: 41.01235873013512\n",
      "EPOCH: 10990 LOSS: 41.0123534371299\n",
      "EPOCH: 10991 LOSS: 41.01234814484842\n",
      "EPOCH: 10992 LOSS: 41.01234285329049\n",
      "EPOCH: 10993 LOSS: 41.012337562456025\n",
      "EPOCH: 10994 LOSS: 41.01233227234487\n",
      "EPOCH: 10995 LOSS: 41.01232698295689\n",
      "EPOCH: 10996 LOSS: 41.012321694291956\n",
      "EPOCH: 10997 LOSS: 41.01231640634994\n",
      "EPOCH: 10998 LOSS: 41.0123111191307\n",
      "EPOCH: 10999 LOSS: 41.01230583263411\n",
      "EPOCH: 11000 LOSS: 41.01230054686002\n",
      "EPOCH: 11001 LOSS: 41.01229526180833\n",
      "EPOCH: 11002 LOSS: 41.01228997747885\n",
      "EPOCH: 11003 LOSS: 41.012284693871514\n",
      "EPOCH: 11004 LOSS: 41.01227941098615\n",
      "EPOCH: 11005 LOSS: 41.012274128822625\n",
      "EPOCH: 11006 LOSS: 41.0122688473808\n",
      "EPOCH: 11007 LOSS: 41.012263566660565\n",
      "EPOCH: 11008 LOSS: 41.01225828666179\n",
      "EPOCH: 11009 LOSS: 41.01225300738429\n",
      "EPOCH: 11010 LOSS: 41.012247728828\n",
      "EPOCH: 11011 LOSS: 41.012242450992744\n",
      "EPOCH: 11012 LOSS: 41.012237173878404\n",
      "EPOCH: 11013 LOSS: 41.01223189748483\n",
      "EPOCH: 11014 LOSS: 41.01222662181192\n",
      "EPOCH: 11015 LOSS: 41.01222134685949\n",
      "EPOCH: 11016 LOSS: 41.01221607262748\n",
      "EPOCH: 11017 LOSS: 41.01221079911571\n",
      "EPOCH: 11018 LOSS: 41.012205526324024\n",
      "EPOCH: 11019 LOSS: 41.01220025425234\n",
      "EPOCH: 11020 LOSS: 41.0121949829005\n",
      "EPOCH: 11021 LOSS: 41.012189712268366\n",
      "EPOCH: 11022 LOSS: 41.01218444235583\n",
      "EPOCH: 11023 LOSS: 41.012179173162735\n",
      "EPOCH: 11024 LOSS: 41.01217390468896\n",
      "EPOCH: 11025 LOSS: 41.01216863693436\n",
      "EPOCH: 11026 LOSS: 41.012163369898815\n",
      "EPOCH: 11027 LOSS: 41.012158103582195\n",
      "EPOCH: 11028 LOSS: 41.01215283798435\n",
      "EPOCH: 11029 LOSS: 41.012147573105175\n",
      "EPOCH: 11030 LOSS: 41.012142308944505\n",
      "EPOCH: 11031 LOSS: 41.01213704550223\n",
      "EPOCH: 11032 LOSS: 41.01213178277819\n",
      "EPOCH: 11033 LOSS: 41.0121265207723\n",
      "EPOCH: 11034 LOSS: 41.01212125948439\n",
      "EPOCH: 11035 LOSS: 41.012115998914325\n",
      "EPOCH: 11036 LOSS: 41.01211073906198\n",
      "EPOCH: 11037 LOSS: 41.01210547992726\n",
      "EPOCH: 11038 LOSS: 41.01210022150999\n",
      "EPOCH: 11039 LOSS: 41.01209496381004\n",
      "EPOCH: 11040 LOSS: 41.01208970682728\n",
      "EPOCH: 11041 LOSS: 41.01208445056159\n",
      "EPOCH: 11042 LOSS: 41.01207919501284\n",
      "EPOCH: 11043 LOSS: 41.01207394018087\n",
      "EPOCH: 11044 LOSS: 41.012068686065575\n",
      "EPOCH: 11045 LOSS: 41.01206343266683\n",
      "EPOCH: 11046 LOSS: 41.012058179984464\n",
      "EPOCH: 11047 LOSS: 41.01205292801839\n",
      "EPOCH: 11048 LOSS: 41.01204767676845\n",
      "EPOCH: 11049 LOSS: 41.0120424262345\n",
      "EPOCH: 11050 LOSS: 41.01203717641644\n",
      "EPOCH: 11051 LOSS: 41.01203192731411\n",
      "EPOCH: 11052 LOSS: 41.0120266789274\n",
      "EPOCH: 11053 LOSS: 41.01202143125617\n",
      "EPOCH: 11054 LOSS: 41.01201618430027\n",
      "EPOCH: 11055 LOSS: 41.01201093805959\n",
      "EPOCH: 11056 LOSS: 41.012005692534\n",
      "EPOCH: 11057 LOSS: 41.01200044772335\n",
      "EPOCH: 11058 LOSS: 41.011995203627535\n",
      "EPOCH: 11059 LOSS: 41.01198996024641\n",
      "EPOCH: 11060 LOSS: 41.011984717579814\n",
      "EPOCH: 11061 LOSS: 41.01197947562767\n",
      "EPOCH: 11062 LOSS: 41.011974234389804\n",
      "EPOCH: 11063 LOSS: 41.011968993866105\n",
      "EPOCH: 11064 LOSS: 41.011963754056424\n",
      "EPOCH: 11065 LOSS: 41.01195851496065\n",
      "EPOCH: 11066 LOSS: 41.01195327657862\n",
      "EPOCH: 11067 LOSS: 41.01194803891026\n",
      "EPOCH: 11068 LOSS: 41.0119428019554\n",
      "EPOCH: 11069 LOSS: 41.01193756571389\n",
      "EPOCH: 11070 LOSS: 41.011932330185616\n",
      "EPOCH: 11071 LOSS: 41.01192709537048\n",
      "EPOCH: 11072 LOSS: 41.011921861268306\n",
      "EPOCH: 11073 LOSS: 41.011916627878975\n",
      "EPOCH: 11074 LOSS: 41.01191139520236\n",
      "EPOCH: 11075 LOSS: 41.011906163238336\n",
      "EPOCH: 11076 LOSS: 41.01190093198675\n",
      "EPOCH: 11077 LOSS: 41.0118957014475\n",
      "EPOCH: 11078 LOSS: 41.01189047162043\n",
      "EPOCH: 11079 LOSS: 41.01188524250542\n",
      "EPOCH: 11080 LOSS: 41.01188001410234\n",
      "EPOCH: 11081 LOSS: 41.01187478641105\n",
      "EPOCH: 11082 LOSS: 41.01186955943143\n",
      "EPOCH: 11083 LOSS: 41.011864333163345\n",
      "EPOCH: 11084 LOSS: 41.01185910760667\n",
      "EPOCH: 11085 LOSS: 41.01185388276127\n",
      "EPOCH: 11086 LOSS: 41.011848658627\n",
      "EPOCH: 11087 LOSS: 41.011843435203744\n",
      "EPOCH: 11088 LOSS: 41.01183821249137\n",
      "EPOCH: 11089 LOSS: 41.01183299048974\n",
      "EPOCH: 11090 LOSS: 41.01182776919873\n",
      "EPOCH: 11091 LOSS: 41.011822548618206\n",
      "EPOCH: 11092 LOSS: 41.01181732874804\n",
      "EPOCH: 11093 LOSS: 41.01181210958811\n",
      "EPOCH: 11094 LOSS: 41.01180689113825\n",
      "EPOCH: 11095 LOSS: 41.01180167339838\n",
      "EPOCH: 11096 LOSS: 41.01179645636833\n",
      "EPOCH: 11097 LOSS: 41.011791240047984\n",
      "EPOCH: 11098 LOSS: 41.011786024437214\n",
      "EPOCH: 11099 LOSS: 41.01178080953588\n",
      "EPOCH: 11100 LOSS: 41.01177559534386\n",
      "EPOCH: 11101 LOSS: 41.011770381861034\n",
      "EPOCH: 11102 LOSS: 41.01176516908724\n",
      "EPOCH: 11103 LOSS: 41.01175995702237\n",
      "EPOCH: 11104 LOSS: 41.011754745666295\n",
      "EPOCH: 11105 LOSS: 41.01174953501888\n",
      "EPOCH: 11106 LOSS: 41.01174432507999\n",
      "EPOCH: 11107 LOSS: 41.01173911584951\n",
      "EPOCH: 11108 LOSS: 41.01173390732729\n",
      "EPOCH: 11109 LOSS: 41.011728699513185\n",
      "EPOCH: 11110 LOSS: 41.01172349240712\n",
      "EPOCH: 11111 LOSS: 41.01171828600893\n",
      "EPOCH: 11112 LOSS: 41.01171308031847\n",
      "EPOCH: 11113 LOSS: 41.011707875335645\n",
      "EPOCH: 11114 LOSS: 41.011702671060284\n",
      "EPOCH: 11115 LOSS: 41.0116974674923\n",
      "EPOCH: 11116 LOSS: 41.011692264631534\n",
      "EPOCH: 11117 LOSS: 41.01168706247788\n",
      "EPOCH: 11118 LOSS: 41.01168186103119\n",
      "EPOCH: 11119 LOSS: 41.01167666029133\n",
      "EPOCH: 11120 LOSS: 41.01167146025816\n",
      "EPOCH: 11121 LOSS: 41.01166626093159\n",
      "EPOCH: 11122 LOSS: 41.01166106231146\n",
      "EPOCH: 11123 LOSS: 41.01165586439765\n",
      "EPOCH: 11124 LOSS: 41.01165066719004\n",
      "EPOCH: 11125 LOSS: 41.01164547068846\n",
      "EPOCH: 11126 LOSS: 41.01164027489283\n",
      "EPOCH: 11127 LOSS: 41.01163507980299\n",
      "EPOCH: 11128 LOSS: 41.01162988541881\n",
      "EPOCH: 11129 LOSS: 41.011624691740174\n",
      "EPOCH: 11130 LOSS: 41.01161949876696\n",
      "EPOCH: 11131 LOSS: 41.01161430649903\n",
      "EPOCH: 11132 LOSS: 41.01160911493622\n",
      "EPOCH: 11133 LOSS: 41.01160392407844\n",
      "EPOCH: 11134 LOSS: 41.01159873392558\n",
      "EPOCH: 11135 LOSS: 41.01159354447745\n",
      "EPOCH: 11136 LOSS: 41.01158835573396\n",
      "EPOCH: 11137 LOSS: 41.01158316769499\n",
      "EPOCH: 11138 LOSS: 41.01157798036036\n",
      "EPOCH: 11139 LOSS: 41.011572793730004\n",
      "EPOCH: 11140 LOSS: 41.01156760780374\n",
      "EPOCH: 11141 LOSS: 41.01156242258147\n",
      "EPOCH: 11142 LOSS: 41.01155723806306\n",
      "EPOCH: 11143 LOSS: 41.01155205424838\n",
      "EPOCH: 11144 LOSS: 41.011546871137284\n",
      "EPOCH: 11145 LOSS: 41.01154168872968\n",
      "EPOCH: 11146 LOSS: 41.01153650702539\n",
      "EPOCH: 11147 LOSS: 41.01153132602431\n",
      "EPOCH: 11148 LOSS: 41.01152614572632\n",
      "EPOCH: 11149 LOSS: 41.011520966131286\n",
      "EPOCH: 11150 LOSS: 41.01151578723907\n",
      "EPOCH: 11151 LOSS: 41.01151060904954\n",
      "EPOCH: 11152 LOSS: 41.0115054315626\n",
      "EPOCH: 11153 LOSS: 41.01150025477806\n",
      "EPOCH: 11154 LOSS: 41.01149507869586\n",
      "EPOCH: 11155 LOSS: 41.01148990331582\n",
      "EPOCH: 11156 LOSS: 41.011484728637825\n",
      "EPOCH: 11157 LOSS: 41.01147955466175\n",
      "EPOCH: 11158 LOSS: 41.01147438138747\n",
      "EPOCH: 11159 LOSS: 41.011469208814844\n",
      "EPOCH: 11160 LOSS: 41.011464036943785\n",
      "EPOCH: 11161 LOSS: 41.01145886577411\n",
      "EPOCH: 11162 LOSS: 41.01145369530571\n",
      "EPOCH: 11163 LOSS: 41.01144852553844\n",
      "EPOCH: 11164 LOSS: 41.011443356472206\n",
      "EPOCH: 11165 LOSS: 41.01143818810686\n",
      "EPOCH: 11166 LOSS: 41.01143302044228\n",
      "EPOCH: 11167 LOSS: 41.01142785347834\n",
      "EPOCH: 11168 LOSS: 41.011422687214875\n",
      "EPOCH: 11169 LOSS: 41.01141752165182\n",
      "EPOCH: 11170 LOSS: 41.011412356788995\n",
      "EPOCH: 11171 LOSS: 41.01140719262629\n",
      "EPOCH: 11172 LOSS: 41.01140202916358\n",
      "EPOCH: 11173 LOSS: 41.011396866400716\n",
      "EPOCH: 11174 LOSS: 41.01139170433761\n",
      "EPOCH: 11175 LOSS: 41.0113865429741\n",
      "EPOCH: 11176 LOSS: 41.01138138231006\n",
      "EPOCH: 11177 LOSS: 41.011376222345376\n",
      "EPOCH: 11178 LOSS: 41.01137106307992\n",
      "EPOCH: 11179 LOSS: 41.01136590451354\n",
      "EPOCH: 11180 LOSS: 41.011360746646126\n",
      "EPOCH: 11181 LOSS: 41.01135558947756\n",
      "EPOCH: 11182 LOSS: 41.01135043300768\n",
      "EPOCH: 11183 LOSS: 41.011345277236416\n",
      "EPOCH: 11184 LOSS: 41.01134012216357\n",
      "EPOCH: 11185 LOSS: 41.01133496778906\n",
      "EPOCH: 11186 LOSS: 41.011329814112756\n",
      "EPOCH: 11187 LOSS: 41.01132466113451\n",
      "EPOCH: 11188 LOSS: 41.0113195088542\n",
      "EPOCH: 11189 LOSS: 41.01131435727171\n",
      "EPOCH: 11190 LOSS: 41.011309206386905\n",
      "EPOCH: 11191 LOSS: 41.011304056199634\n",
      "EPOCH: 11192 LOSS: 41.01129890670981\n",
      "EPOCH: 11193 LOSS: 41.01129375791729\n",
      "EPOCH: 11194 LOSS: 41.011288609821946\n",
      "EPOCH: 11195 LOSS: 41.011283462423634\n",
      "EPOCH: 11196 LOSS: 41.01127831572224\n",
      "EPOCH: 11197 LOSS: 41.011273169717626\n",
      "EPOCH: 11198 LOSS: 41.01126802440969\n",
      "EPOCH: 11199 LOSS: 41.011262879798295\n",
      "EPOCH: 11200 LOSS: 41.01125773588329\n",
      "EPOCH: 11201 LOSS: 41.01125259266456\n",
      "EPOCH: 11202 LOSS: 41.011247450142\n",
      "EPOCH: 11203 LOSS: 41.01124230831545\n",
      "EPOCH: 11204 LOSS: 41.0112371671848\n",
      "EPOCH: 11205 LOSS: 41.01123202674992\n",
      "EPOCH: 11206 LOSS: 41.01122688701067\n",
      "EPOCH: 11207 LOSS: 41.01122174796694\n",
      "EPOCH: 11208 LOSS: 41.011216609618614\n",
      "EPOCH: 11209 LOSS: 41.01121147196553\n",
      "EPOCH: 11210 LOSS: 41.01120633500759\n",
      "EPOCH: 11211 LOSS: 41.01120119874463\n",
      "EPOCH: 11212 LOSS: 41.01119606317657\n",
      "EPOCH: 11213 LOSS: 41.01119092830325\n",
      "EPOCH: 11214 LOSS: 41.01118579412456\n",
      "EPOCH: 11215 LOSS: 41.01118066064036\n",
      "EPOCH: 11216 LOSS: 41.01117552785052\n",
      "EPOCH: 11217 LOSS: 41.01117039575494\n",
      "EPOCH: 11218 LOSS: 41.01116526435348\n",
      "EPOCH: 11219 LOSS: 41.01116013364597\n",
      "EPOCH: 11220 LOSS: 41.011155003632354\n",
      "EPOCH: 11221 LOSS: 41.01114987431246\n",
      "EPOCH: 11222 LOSS: 41.01114474568617\n",
      "EPOCH: 11223 LOSS: 41.01113961775335\n",
      "EPOCH: 11224 LOSS: 41.01113449051389\n",
      "EPOCH: 11225 LOSS: 41.01112936396767\n",
      "EPOCH: 11226 LOSS: 41.01112423811453\n",
      "EPOCH: 11227 LOSS: 41.01111911295437\n",
      "EPOCH: 11228 LOSS: 41.01111398848705\n",
      "EPOCH: 11229 LOSS: 41.011108864712455\n",
      "EPOCH: 11230 LOSS: 41.01110374163045\n",
      "EPOCH: 11231 LOSS: 41.01109861924089\n",
      "EPOCH: 11232 LOSS: 41.011093497543705\n",
      "EPOCH: 11233 LOSS: 41.011088376538694\n",
      "EPOCH: 11234 LOSS: 41.01108325622579\n",
      "EPOCH: 11235 LOSS: 41.01107813660483\n",
      "EPOCH: 11236 LOSS: 41.011073017675706\n",
      "EPOCH: 11237 LOSS: 41.01106789943829\n",
      "EPOCH: 11238 LOSS: 41.01106278189245\n",
      "EPOCH: 11239 LOSS: 41.01105766503807\n",
      "EPOCH: 11240 LOSS: 41.011052548875\n",
      "EPOCH: 11241 LOSS: 41.011047433403135\n",
      "EPOCH: 11242 LOSS: 41.011042318622344\n",
      "EPOCH: 11243 LOSS: 41.0110372045325\n",
      "EPOCH: 11244 LOSS: 41.01103209113347\n",
      "EPOCH: 11245 LOSS: 41.011026978425136\n",
      "EPOCH: 11246 LOSS: 41.01102186640737\n",
      "EPOCH: 11247 LOSS: 41.01101675508005\n",
      "EPOCH: 11248 LOSS: 41.01101164444303\n",
      "EPOCH: 11249 LOSS: 41.011006534496204\n",
      "EPOCH: 11250 LOSS: 41.01100142523944\n",
      "EPOCH: 11251 LOSS: 41.01099631667262\n",
      "EPOCH: 11252 LOSS: 41.0109912087956\n",
      "EPOCH: 11253 LOSS: 41.010986101608275\n",
      "EPOCH: 11254 LOSS: 41.01098099511049\n",
      "EPOCH: 11255 LOSS: 41.010975889302145\n",
      "EPOCH: 11256 LOSS: 41.01097078418309\n",
      "EPOCH: 11257 LOSS: 41.01096567975324\n",
      "EPOCH: 11258 LOSS: 41.01096057601244\n",
      "EPOCH: 11259 LOSS: 41.01095547296055\n",
      "EPOCH: 11260 LOSS: 41.010950370597484\n",
      "EPOCH: 11261 LOSS: 41.01094526892307\n",
      "EPOCH: 11262 LOSS: 41.01094016793722\n",
      "EPOCH: 11263 LOSS: 41.01093506763979\n",
      "EPOCH: 11264 LOSS: 41.010929968030645\n",
      "EPOCH: 11265 LOSS: 41.010924869109694\n",
      "EPOCH: 11266 LOSS: 41.01091977087678\n",
      "EPOCH: 11267 LOSS: 41.0109146733318\n",
      "EPOCH: 11268 LOSS: 41.010909576474596\n",
      "EPOCH: 11269 LOSS: 41.01090448030505\n",
      "EPOCH: 11270 LOSS: 41.010899384823084\n",
      "EPOCH: 11271 LOSS: 41.01089429002852\n",
      "EPOCH: 11272 LOSS: 41.01088919592124\n",
      "EPOCH: 11273 LOSS: 41.01088410250114\n",
      "EPOCH: 11274 LOSS: 41.01087900976806\n",
      "EPOCH: 11275 LOSS: 41.010873917721916\n",
      "EPOCH: 11276 LOSS: 41.010868826362554\n",
      "EPOCH: 11277 LOSS: 41.01086373568987\n",
      "EPOCH: 11278 LOSS: 41.01085864570372\n",
      "EPOCH: 11279 LOSS: 41.01085355640398\n",
      "EPOCH: 11280 LOSS: 41.010848467790524\n",
      "EPOCH: 11281 LOSS: 41.01084337986323\n",
      "EPOCH: 11282 LOSS: 41.01083829262198\n",
      "EPOCH: 11283 LOSS: 41.01083320606666\n",
      "EPOCH: 11284 LOSS: 41.01082812019711\n",
      "EPOCH: 11285 LOSS: 41.01082303501322\n",
      "EPOCH: 11286 LOSS: 41.01081795051489\n",
      "EPOCH: 11287 LOSS: 41.010812866701954\n",
      "EPOCH: 11288 LOSS: 41.0108077835743\n",
      "EPOCH: 11289 LOSS: 41.01080270113181\n",
      "EPOCH: 11290 LOSS: 41.01079761937436\n",
      "EPOCH: 11291 LOSS: 41.01079253830184\n",
      "EPOCH: 11292 LOSS: 41.01078745791408\n",
      "EPOCH: 11293 LOSS: 41.01078237821099\n",
      "EPOCH: 11294 LOSS: 41.01077729919244\n",
      "EPOCH: 11295 LOSS: 41.0107722208583\n",
      "EPOCH: 11296 LOSS: 41.010767143208454\n",
      "EPOCH: 11297 LOSS: 41.01076206624276\n",
      "EPOCH: 11298 LOSS: 41.01075698996111\n",
      "EPOCH: 11299 LOSS: 41.01075191436337\n",
      "EPOCH: 11300 LOSS: 41.01074683944942\n",
      "EPOCH: 11301 LOSS: 41.01074176521913\n",
      "EPOCH: 11302 LOSS: 41.01073669167238\n",
      "EPOCH: 11303 LOSS: 41.01073161880905\n",
      "EPOCH: 11304 LOSS: 41.010726546629\n",
      "EPOCH: 11305 LOSS: 41.0107214751321\n",
      "EPOCH: 11306 LOSS: 41.01071640431827\n",
      "EPOCH: 11307 LOSS: 41.010711334187334\n",
      "EPOCH: 11308 LOSS: 41.0107062647392\n",
      "EPOCH: 11309 LOSS: 41.01070119597374\n",
      "EPOCH: 11310 LOSS: 41.010696127890796\n",
      "EPOCH: 11311 LOSS: 41.01069106049029\n",
      "EPOCH: 11312 LOSS: 41.01068599377207\n",
      "EPOCH: 11313 LOSS: 41.010680927736004\n",
      "EPOCH: 11314 LOSS: 41.010675862382\n",
      "EPOCH: 11315 LOSS: 41.010670797709906\n",
      "EPOCH: 11316 LOSS: 41.01066573371961\n",
      "EPOCH: 11317 LOSS: 41.010660670410985\n",
      "EPOCH: 11318 LOSS: 41.01065560778389\n",
      "EPOCH: 11319 LOSS: 41.010650545838246\n",
      "EPOCH: 11320 LOSS: 41.01064548457388\n",
      "EPOCH: 11321 LOSS: 41.010640423990694\n",
      "EPOCH: 11322 LOSS: 41.010635364088564\n",
      "EPOCH: 11323 LOSS: 41.010630304867334\n",
      "EPOCH: 11324 LOSS: 41.01062524632694\n",
      "EPOCH: 11325 LOSS: 41.0106201884672\n",
      "EPOCH: 11326 LOSS: 41.01061513128802\n",
      "EPOCH: 11327 LOSS: 41.010610074789255\n",
      "EPOCH: 11328 LOSS: 41.01060501897082\n",
      "EPOCH: 11329 LOSS: 41.01059996383255\n",
      "EPOCH: 11330 LOSS: 41.01059490937434\n",
      "EPOCH: 11331 LOSS: 41.010589855596066\n",
      "EPOCH: 11332 LOSS: 41.01058480249759\n",
      "EPOCH: 11333 LOSS: 41.010579750078804\n",
      "EPOCH: 11334 LOSS: 41.01057469833957\n",
      "EPOCH: 11335 LOSS: 41.010569647279794\n",
      "EPOCH: 11336 LOSS: 41.01056459689933\n",
      "EPOCH: 11337 LOSS: 41.01055954719804\n",
      "EPOCH: 11338 LOSS: 41.01055449817582\n",
      "EPOCH: 11339 LOSS: 41.01054944983254\n",
      "EPOCH: 11340 LOSS: 41.0105444021681\n",
      "EPOCH: 11341 LOSS: 41.01053935518233\n",
      "EPOCH: 11342 LOSS: 41.01053430887514\n",
      "EPOCH: 11343 LOSS: 41.01052926324641\n",
      "EPOCH: 11344 LOSS: 41.01052421829599\n",
      "EPOCH: 11345 LOSS: 41.010519174023756\n",
      "EPOCH: 11346 LOSS: 41.01051413042963\n",
      "EPOCH: 11347 LOSS: 41.01050908751344\n",
      "EPOCH: 11348 LOSS: 41.01050404527508\n",
      "EPOCH: 11349 LOSS: 41.01049900371443\n",
      "EPOCH: 11350 LOSS: 41.01049396283136\n",
      "EPOCH: 11351 LOSS: 41.010488922625754\n",
      "EPOCH: 11352 LOSS: 41.0104838830975\n",
      "EPOCH: 11353 LOSS: 41.01047884424643\n",
      "EPOCH: 11354 LOSS: 41.010473806072454\n",
      "EPOCH: 11355 LOSS: 41.010468768575464\n",
      "EPOCH: 11356 LOSS: 41.010463731755294\n",
      "EPOCH: 11357 LOSS: 41.01045869561186\n",
      "EPOCH: 11358 LOSS: 41.010453660145025\n",
      "EPOCH: 11359 LOSS: 41.010448625354655\n",
      "EPOCH: 11360 LOSS: 41.01044359124064\n",
      "EPOCH: 11361 LOSS: 41.01043855780285\n",
      "EPOCH: 11362 LOSS: 41.010433525041165\n",
      "EPOCH: 11363 LOSS: 41.010428492955455\n",
      "EPOCH: 11364 LOSS: 41.01042346154561\n",
      "EPOCH: 11365 LOSS: 41.0104184308115\n",
      "EPOCH: 11366 LOSS: 41.010413400753\n",
      "EPOCH: 11367 LOSS: 41.01040837137\n",
      "EPOCH: 11368 LOSS: 41.01040334266236\n",
      "EPOCH: 11369 LOSS: 41.01039831462995\n",
      "EPOCH: 11370 LOSS: 41.01039328727268\n",
      "EPOCH: 11371 LOSS: 41.01038826059039\n",
      "EPOCH: 11372 LOSS: 41.01038323458299\n",
      "EPOCH: 11373 LOSS: 41.01037820925034\n",
      "EPOCH: 11374 LOSS: 41.01037318459231\n",
      "EPOCH: 11375 LOSS: 41.01036816060879\n",
      "EPOCH: 11376 LOSS: 41.01036313729967\n",
      "EPOCH: 11377 LOSS: 41.0103581146648\n",
      "EPOCH: 11378 LOSS: 41.01035309270405\n",
      "EPOCH: 11379 LOSS: 41.01034807141735\n",
      "EPOCH: 11380 LOSS: 41.010343050804515\n",
      "EPOCH: 11381 LOSS: 41.010338030865455\n",
      "EPOCH: 11382 LOSS: 41.010333011600046\n",
      "EPOCH: 11383 LOSS: 41.01032799300816\n",
      "EPOCH: 11384 LOSS: 41.01032297508971\n",
      "EPOCH: 11385 LOSS: 41.01031795784451\n",
      "EPOCH: 11386 LOSS: 41.01031294127247\n",
      "EPOCH: 11387 LOSS: 41.01030792537346\n",
      "EPOCH: 11388 LOSS: 41.01030291014738\n",
      "EPOCH: 11389 LOSS: 41.01029789559408\n",
      "EPOCH: 11390 LOSS: 41.010292881713454\n",
      "EPOCH: 11391 LOSS: 41.010287868505365\n",
      "EPOCH: 11392 LOSS: 41.010282855969706\n",
      "EPOCH: 11393 LOSS: 41.01027784410635\n",
      "EPOCH: 11394 LOSS: 41.01027283291518\n",
      "EPOCH: 11395 LOSS: 41.01026782239606\n",
      "EPOCH: 11396 LOSS: 41.01026281254889\n",
      "EPOCH: 11397 LOSS: 41.01025780337352\n",
      "EPOCH: 11398 LOSS: 41.010252794869835\n",
      "EPOCH: 11399 LOSS: 41.01024778703773\n",
      "EPOCH: 11400 LOSS: 41.010242779877075\n",
      "EPOCH: 11401 LOSS: 41.01023777338773\n",
      "EPOCH: 11402 LOSS: 41.01023276756959\n",
      "EPOCH: 11403 LOSS: 41.01022776242254\n",
      "EPOCH: 11404 LOSS: 41.01022275794644\n",
      "EPOCH: 11405 LOSS: 41.010217754141195\n",
      "EPOCH: 11406 LOSS: 41.01021275100665\n",
      "EPOCH: 11407 LOSS: 41.01020774854268\n",
      "EPOCH: 11408 LOSS: 41.01020274674923\n",
      "EPOCH: 11409 LOSS: 41.0101977456261\n",
      "EPOCH: 11410 LOSS: 41.0101927451732\n",
      "EPOCH: 11411 LOSS: 41.010187745390404\n",
      "EPOCH: 11412 LOSS: 41.010182746277586\n",
      "EPOCH: 11413 LOSS: 41.01017774783465\n",
      "EPOCH: 11414 LOSS: 41.01017275006146\n",
      "EPOCH: 11415 LOSS: 41.010167752957855\n",
      "EPOCH: 11416 LOSS: 41.01016275652378\n",
      "EPOCH: 11417 LOSS: 41.01015776075907\n",
      "EPOCH: 11418 LOSS: 41.0101527656636\n",
      "EPOCH: 11419 LOSS: 41.010147771237285\n",
      "EPOCH: 11420 LOSS: 41.010142777479984\n",
      "EPOCH: 11421 LOSS: 41.01013778439156\n",
      "EPOCH: 11422 LOSS: 41.0101327919719\n",
      "EPOCH: 11423 LOSS: 41.0101278002209\n",
      "EPOCH: 11424 LOSS: 41.01012280913842\n",
      "EPOCH: 11425 LOSS: 41.01011781872434\n",
      "EPOCH: 11426 LOSS: 41.01011282897854\n",
      "EPOCH: 11427 LOSS: 41.01010783990091\n",
      "EPOCH: 11428 LOSS: 41.010102851491325\n",
      "EPOCH: 11429 LOSS: 41.01009786374966\n",
      "EPOCH: 11430 LOSS: 41.01009287667577\n",
      "EPOCH: 11431 LOSS: 41.01008789026959\n",
      "EPOCH: 11432 LOSS: 41.01008290453094\n",
      "EPOCH: 11433 LOSS: 41.01007791945973\n",
      "EPOCH: 11434 LOSS: 41.01007293505584\n",
      "EPOCH: 11435 LOSS: 41.010067951319144\n",
      "EPOCH: 11436 LOSS: 41.010062968249514\n",
      "EPOCH: 11437 LOSS: 41.01005798584683\n",
      "EPOCH: 11438 LOSS: 41.01005300411097\n",
      "EPOCH: 11439 LOSS: 41.01004802304182\n",
      "EPOCH: 11440 LOSS: 41.01004304263927\n",
      "EPOCH: 11441 LOSS: 41.01003806290317\n",
      "EPOCH: 11442 LOSS: 41.01003308383343\n",
      "EPOCH: 11443 LOSS: 41.0100281054299\n",
      "EPOCH: 11444 LOSS: 41.01002312769248\n",
      "EPOCH: 11445 LOSS: 41.01001815062104\n",
      "EPOCH: 11446 LOSS: 41.01001317421547\n",
      "EPOCH: 11447 LOSS: 41.01000819847563\n",
      "EPOCH: 11448 LOSS: 41.0100032234014\n",
      "EPOCH: 11449 LOSS: 41.00999824899269\n",
      "EPOCH: 11450 LOSS: 41.00999327524936\n",
      "EPOCH: 11451 LOSS: 41.009988302171266\n",
      "EPOCH: 11452 LOSS: 41.009983329758334\n",
      "EPOCH: 11453 LOSS: 41.0099783580104\n",
      "EPOCH: 11454 LOSS: 41.00997338692737\n",
      "EPOCH: 11455 LOSS: 41.0099684165091\n",
      "EPOCH: 11456 LOSS: 41.009963446755506\n",
      "EPOCH: 11457 LOSS: 41.00995847766644\n",
      "EPOCH: 11458 LOSS: 41.009953509241775\n",
      "EPOCH: 11459 LOSS: 41.00994854148142\n",
      "EPOCH: 11460 LOSS: 41.00994357438523\n",
      "EPOCH: 11461 LOSS: 41.0099386079531\n",
      "EPOCH: 11462 LOSS: 41.00993364218488\n",
      "EPOCH: 11463 LOSS: 41.00992867708049\n",
      "EPOCH: 11464 LOSS: 41.00992371263979\n",
      "EPOCH: 11465 LOSS: 41.00991874886266\n",
      "EPOCH: 11466 LOSS: 41.00991378574897\n",
      "EPOCH: 11467 LOSS: 41.009908823298616\n",
      "EPOCH: 11468 LOSS: 41.00990386151147\n",
      "EPOCH: 11469 LOSS: 41.00989890038744\n",
      "EPOCH: 11470 LOSS: 41.00989393992634\n",
      "EPOCH: 11471 LOSS: 41.00988898012811\n",
      "EPOCH: 11472 LOSS: 41.00988402099261\n",
      "EPOCH: 11473 LOSS: 41.00987906251971\n",
      "EPOCH: 11474 LOSS: 41.009874104709304\n",
      "EPOCH: 11475 LOSS: 41.009869147561275\n",
      "EPOCH: 11476 LOSS: 41.00986419107547\n",
      "EPOCH: 11477 LOSS: 41.009859235251824\n",
      "EPOCH: 11478 LOSS: 41.00985428009017\n",
      "EPOCH: 11479 LOSS: 41.00984932559042\n",
      "EPOCH: 11480 LOSS: 41.009844371752415\n",
      "EPOCH: 11481 LOSS: 41.00983941857608\n",
      "EPOCH: 11482 LOSS: 41.009834466061264\n",
      "EPOCH: 11483 LOSS: 41.00982951420785\n",
      "EPOCH: 11484 LOSS: 41.00982456301574\n",
      "EPOCH: 11485 LOSS: 41.009819612484804\n",
      "EPOCH: 11486 LOSS: 41.00981466261491\n",
      "EPOCH: 11487 LOSS: 41.009809713405936\n",
      "EPOCH: 11488 LOSS: 41.009804764857776\n",
      "EPOCH: 11489 LOSS: 41.00979981697032\n",
      "EPOCH: 11490 LOSS: 41.00979486974344\n",
      "EPOCH: 11491 LOSS: 41.00978992317699\n",
      "EPOCH: 11492 LOSS: 41.00978497727089\n",
      "EPOCH: 11493 LOSS: 41.00978003202499\n",
      "EPOCH: 11494 LOSS: 41.00977508743918\n",
      "EPOCH: 11495 LOSS: 41.00977014351336\n",
      "EPOCH: 11496 LOSS: 41.00976520024739\n",
      "EPOCH: 11497 LOSS: 41.00976025764115\n",
      "EPOCH: 11498 LOSS: 41.00975531569452\n",
      "EPOCH: 11499 LOSS: 41.00975037440739\n",
      "EPOCH: 11500 LOSS: 41.00974543377963\n",
      "EPOCH: 11501 LOSS: 41.00974049381115\n",
      "EPOCH: 11502 LOSS: 41.00973555450177\n",
      "EPOCH: 11503 LOSS: 41.009730615851424\n",
      "EPOCH: 11504 LOSS: 41.00972567785999\n",
      "EPOCH: 11505 LOSS: 41.00972074052732\n",
      "EPOCH: 11506 LOSS: 41.009715803853325\n",
      "EPOCH: 11507 LOSS: 41.00971086783787\n",
      "EPOCH: 11508 LOSS: 41.00970593248081\n",
      "EPOCH: 11509 LOSS: 41.009700997782076\n",
      "EPOCH: 11510 LOSS: 41.00969606374153\n",
      "EPOCH: 11511 LOSS: 41.00969113035904\n",
      "EPOCH: 11512 LOSS: 41.009686197634494\n",
      "EPOCH: 11513 LOSS: 41.009681265567764\n",
      "EPOCH: 11514 LOSS: 41.00967633415876\n",
      "EPOCH: 11515 LOSS: 41.00967140340732\n",
      "EPOCH: 11516 LOSS: 41.00966647331339\n",
      "EPOCH: 11517 LOSS: 41.00966154387679\n",
      "EPOCH: 11518 LOSS: 41.0096566150974\n",
      "EPOCH: 11519 LOSS: 41.009651686975154\n",
      "EPOCH: 11520 LOSS: 41.00964675950988\n",
      "EPOCH: 11521 LOSS: 41.00964183270149\n",
      "EPOCH: 11522 LOSS: 41.00963690654985\n",
      "EPOCH: 11523 LOSS: 41.009631981054866\n",
      "EPOCH: 11524 LOSS: 41.009627056216374\n",
      "EPOCH: 11525 LOSS: 41.0096221320343\n",
      "EPOCH: 11526 LOSS: 41.00961720850851\n",
      "EPOCH: 11527 LOSS: 41.00961228563885\n",
      "EPOCH: 11528 LOSS: 41.00960736342526\n",
      "EPOCH: 11529 LOSS: 41.00960244186759\n",
      "EPOCH: 11530 LOSS: 41.00959752096574\n",
      "EPOCH: 11531 LOSS: 41.00959260071956\n",
      "EPOCH: 11532 LOSS: 41.00958768112895\n",
      "EPOCH: 11533 LOSS: 41.009582762193794\n",
      "EPOCH: 11534 LOSS: 41.00957784391397\n",
      "EPOCH: 11535 LOSS: 41.00957292628936\n",
      "EPOCH: 11536 LOSS: 41.00956800931985\n",
      "EPOCH: 11537 LOSS: 41.00956309300531\n",
      "EPOCH: 11538 LOSS: 41.00955817734563\n",
      "EPOCH: 11539 LOSS: 41.00955326234069\n",
      "EPOCH: 11540 LOSS: 41.00954834799037\n",
      "EPOCH: 11541 LOSS: 41.00954343429454\n",
      "EPOCH: 11542 LOSS: 41.009538521253134\n",
      "EPOCH: 11543 LOSS: 41.009533608865965\n",
      "EPOCH: 11544 LOSS: 41.00952869713296\n",
      "EPOCH: 11545 LOSS: 41.00952378605396\n",
      "EPOCH: 11546 LOSS: 41.009518875628885\n",
      "EPOCH: 11547 LOSS: 41.0095139658576\n",
      "EPOCH: 11548 LOSS: 41.00950905674\n",
      "EPOCH: 11549 LOSS: 41.00950414827594\n",
      "EPOCH: 11550 LOSS: 41.00949924046535\n",
      "EPOCH: 11551 LOSS: 41.00949433330806\n",
      "EPOCH: 11552 LOSS: 41.009489426803974\n",
      "EPOCH: 11553 LOSS: 41.00948452095297\n",
      "EPOCH: 11554 LOSS: 41.00947961575495\n",
      "EPOCH: 11555 LOSS: 41.009474711209755\n",
      "EPOCH: 11556 LOSS: 41.009469807317316\n",
      "EPOCH: 11557 LOSS: 41.009464904077475\n",
      "EPOCH: 11558 LOSS: 41.00946000149012\n",
      "EPOCH: 11559 LOSS: 41.009455099555154\n",
      "EPOCH: 11560 LOSS: 41.00945019827245\n",
      "EPOCH: 11561 LOSS: 41.00944529764188\n",
      "EPOCH: 11562 LOSS: 41.009440397663354\n",
      "EPOCH: 11563 LOSS: 41.00943549833673\n",
      "EPOCH: 11564 LOSS: 41.00943059966188\n",
      "EPOCH: 11565 LOSS: 41.009425701638705\n",
      "EPOCH: 11566 LOSS: 41.009420804267094\n",
      "EPOCH: 11567 LOSS: 41.00941590754691\n",
      "EPOCH: 11568 LOSS: 41.00941101147805\n",
      "EPOCH: 11569 LOSS: 41.00940611606038\n",
      "EPOCH: 11570 LOSS: 41.009401221293786\n",
      "EPOCH: 11571 LOSS: 41.009396327178166\n",
      "EPOCH: 11572 LOSS: 41.009391433713404\n",
      "EPOCH: 11573 LOSS: 41.00938654089937\n",
      "EPOCH: 11574 LOSS: 41.00938164873594\n",
      "EPOCH: 11575 LOSS: 41.00937675722301\n",
      "EPOCH: 11576 LOSS: 41.00937186636045\n",
      "EPOCH: 11577 LOSS: 41.009366976148144\n",
      "EPOCH: 11578 LOSS: 41.009362086586016\n",
      "EPOCH: 11579 LOSS: 41.009357197673864\n",
      "EPOCH: 11580 LOSS: 41.00935230941167\n",
      "EPOCH: 11581 LOSS: 41.009347421799234\n",
      "EPOCH: 11582 LOSS: 41.009342534836485\n",
      "EPOCH: 11583 LOSS: 41.00933764852328\n",
      "EPOCH: 11584 LOSS: 41.00933276285953\n",
      "EPOCH: 11585 LOSS: 41.009327877845095\n",
      "EPOCH: 11586 LOSS: 41.00932299347986\n",
      "EPOCH: 11587 LOSS: 41.009318109763726\n",
      "EPOCH: 11588 LOSS: 41.009313226696534\n",
      "EPOCH: 11589 LOSS: 41.00930834427824\n",
      "EPOCH: 11590 LOSS: 41.00930346250864\n",
      "EPOCH: 11591 LOSS: 41.00929858138767\n",
      "EPOCH: 11592 LOSS: 41.00929370091524\n",
      "EPOCH: 11593 LOSS: 41.00928882109115\n",
      "EPOCH: 11594 LOSS: 41.009283941915335\n",
      "EPOCH: 11595 LOSS: 41.00927906338768\n",
      "EPOCH: 11596 LOSS: 41.009274185508055\n",
      "EPOCH: 11597 LOSS: 41.00926930827636\n",
      "EPOCH: 11598 LOSS: 41.00926443169246\n",
      "EPOCH: 11599 LOSS: 41.00925955575624\n",
      "EPOCH: 11600 LOSS: 41.009254680467585\n",
      "EPOCH: 11601 LOSS: 41.009249805826386\n",
      "EPOCH: 11602 LOSS: 41.00924493183251\n",
      "EPOCH: 11603 LOSS: 41.00924005848586\n",
      "EPOCH: 11604 LOSS: 41.009235185786316\n",
      "EPOCH: 11605 LOSS: 41.009230313733745\n",
      "EPOCH: 11606 LOSS: 41.009225442328045\n",
      "EPOCH: 11607 LOSS: 41.009220571569095\n",
      "EPOCH: 11608 LOSS: 41.009215701456775\n",
      "EPOCH: 11609 LOSS: 41.00921083199097\n",
      "EPOCH: 11610 LOSS: 41.00920596317158\n",
      "EPOCH: 11611 LOSS: 41.00920109499846\n",
      "EPOCH: 11612 LOSS: 41.009196227471506\n",
      "EPOCH: 11613 LOSS: 41.00919136059061\n",
      "EPOCH: 11614 LOSS: 41.00918649435565\n",
      "EPOCH: 11615 LOSS: 41.0091816287665\n",
      "EPOCH: 11616 LOSS: 41.00917676382305\n",
      "EPOCH: 11617 LOSS: 41.0091718995252\n",
      "EPOCH: 11618 LOSS: 41.00916703587281\n",
      "EPOCH: 11619 LOSS: 41.009162172865764\n",
      "EPOCH: 11620 LOSS: 41.009157310503966\n",
      "EPOCH: 11621 LOSS: 41.00915244878727\n",
      "EPOCH: 11622 LOSS: 41.0091475877156\n",
      "EPOCH: 11623 LOSS: 41.00914272728879\n",
      "EPOCH: 11624 LOSS: 41.00913786750679\n",
      "EPOCH: 11625 LOSS: 41.00913300836941\n",
      "EPOCH: 11626 LOSS: 41.00912814987659\n",
      "EPOCH: 11627 LOSS: 41.00912329202818\n",
      "EPOCH: 11628 LOSS: 41.009118434824074\n",
      "EPOCH: 11629 LOSS: 41.00911357826416\n",
      "EPOCH: 11630 LOSS: 41.009108722348344\n",
      "EPOCH: 11631 LOSS: 41.009103867076455\n",
      "EPOCH: 11632 LOSS: 41.00909901244842\n",
      "EPOCH: 11633 LOSS: 41.009094158464116\n",
      "EPOCH: 11634 LOSS: 41.00908930512341\n",
      "EPOCH: 11635 LOSS: 41.00908445242622\n",
      "EPOCH: 11636 LOSS: 41.00907960037239\n",
      "EPOCH: 11637 LOSS: 41.00907474896184\n",
      "EPOCH: 11638 LOSS: 41.00906989819442\n",
      "EPOCH: 11639 LOSS: 41.00906504807003\n",
      "EPOCH: 11640 LOSS: 41.00906019858856\n",
      "EPOCH: 11641 LOSS: 41.00905534974989\n",
      "EPOCH: 11642 LOSS: 41.0090505015539\n",
      "EPOCH: 11643 LOSS: 41.00904565400049\n",
      "EPOCH: 11644 LOSS: 41.00904080708952\n",
      "EPOCH: 11645 LOSS: 41.009035960820896\n",
      "EPOCH: 11646 LOSS: 41.00903111519447\n",
      "EPOCH: 11647 LOSS: 41.009026270210185\n",
      "EPOCH: 11648 LOSS: 41.00902142586785\n",
      "EPOCH: 11649 LOSS: 41.00901658216742\n",
      "EPOCH: 11650 LOSS: 41.00901173910873\n",
      "EPOCH: 11651 LOSS: 41.0090068966917\n",
      "EPOCH: 11652 LOSS: 41.00900205491618\n",
      "EPOCH: 11653 LOSS: 41.008997213782095\n",
      "EPOCH: 11654 LOSS: 41.008992373289274\n",
      "EPOCH: 11655 LOSS: 41.00898753343766\n",
      "EPOCH: 11656 LOSS: 41.0089826942271\n",
      "EPOCH: 11657 LOSS: 41.00897785565749\n",
      "EPOCH: 11658 LOSS: 41.00897301772872\n",
      "EPOCH: 11659 LOSS: 41.008968180440654\n",
      "EPOCH: 11660 LOSS: 41.00896334379322\n",
      "EPOCH: 11661 LOSS: 41.00895850778626\n",
      "EPOCH: 11662 LOSS: 41.008953672419665\n",
      "EPOCH: 11663 LOSS: 41.00894883769334\n",
      "EPOCH: 11664 LOSS: 41.00894400360716\n",
      "EPOCH: 11665 LOSS: 41.008939170161\n",
      "EPOCH: 11666 LOSS: 41.00893433735476\n",
      "EPOCH: 11667 LOSS: 41.00892950518831\n",
      "EPOCH: 11668 LOSS: 41.008924673661554\n",
      "EPOCH: 11669 LOSS: 41.00891984277436\n",
      "EPOCH: 11670 LOSS: 41.00891501252661\n",
      "EPOCH: 11671 LOSS: 41.00891018291821\n",
      "EPOCH: 11672 LOSS: 41.00890535394902\n",
      "EPOCH: 11673 LOSS: 41.00890052561895\n",
      "EPOCH: 11674 LOSS: 41.00889569792787\n",
      "EPOCH: 11675 LOSS: 41.00889087087566\n",
      "EPOCH: 11676 LOSS: 41.00888604446223\n",
      "EPOCH: 11677 LOSS: 41.00888121868742\n",
      "EPOCH: 11678 LOSS: 41.00887639355116\n",
      "EPOCH: 11679 LOSS: 41.008871569053326\n",
      "EPOCH: 11680 LOSS: 41.008866745193785\n",
      "EPOCH: 11681 LOSS: 41.00886192197243\n",
      "EPOCH: 11682 LOSS: 41.008857099389154\n",
      "EPOCH: 11683 LOSS: 41.008852277443836\n",
      "EPOCH: 11684 LOSS: 41.008847456136365\n",
      "EPOCH: 11685 LOSS: 41.00884263546662\n",
      "EPOCH: 11686 LOSS: 41.008837815434504\n",
      "EPOCH: 11687 LOSS: 41.00883299603987\n",
      "EPOCH: 11688 LOSS: 41.008828177282616\n",
      "EPOCH: 11689 LOSS: 41.00882335916265\n",
      "EPOCH: 11690 LOSS: 41.00881854167983\n",
      "EPOCH: 11691 LOSS: 41.008813724834056\n",
      "EPOCH: 11692 LOSS: 41.00880890862521\n",
      "EPOCH: 11693 LOSS: 41.00880409305317\n",
      "EPOCH: 11694 LOSS: 41.008799278117834\n",
      "EPOCH: 11695 LOSS: 41.00879446381909\n",
      "EPOCH: 11696 LOSS: 41.00878965015681\n",
      "EPOCH: 11697 LOSS: 41.0087848371309\n",
      "EPOCH: 11698 LOSS: 41.00878002474121\n",
      "EPOCH: 11699 LOSS: 41.00877521298765\n",
      "EPOCH: 11700 LOSS: 41.00877040187011\n",
      "EPOCH: 11701 LOSS: 41.00876559138845\n",
      "EPOCH: 11702 LOSS: 41.008760781542605\n",
      "EPOCH: 11703 LOSS: 41.0087559723324\n",
      "EPOCH: 11704 LOSS: 41.008751163757765\n",
      "EPOCH: 11705 LOSS: 41.008746355818566\n",
      "EPOCH: 11706 LOSS: 41.0087415485147\n",
      "EPOCH: 11707 LOSS: 41.00873674184604\n",
      "EPOCH: 11708 LOSS: 41.0087319358125\n",
      "EPOCH: 11709 LOSS: 41.00872713041392\n",
      "EPOCH: 11710 LOSS: 41.00872232565021\n",
      "EPOCH: 11711 LOSS: 41.00871752152127\n",
      "EPOCH: 11712 LOSS: 41.00871271802697\n",
      "EPOCH: 11713 LOSS: 41.00870791516718\n",
      "EPOCH: 11714 LOSS: 41.00870311294183\n",
      "EPOCH: 11715 LOSS: 41.00869831135077\n",
      "EPOCH: 11716 LOSS: 41.0086935103939\n",
      "EPOCH: 11717 LOSS: 41.008688710071105\n",
      "EPOCH: 11718 LOSS: 41.00868391038226\n",
      "EPOCH: 11719 LOSS: 41.00867911132727\n",
      "EPOCH: 11720 LOSS: 41.008674312905995\n",
      "EPOCH: 11721 LOSS: 41.00866951511836\n",
      "EPOCH: 11722 LOSS: 41.008664717964216\n",
      "EPOCH: 11723 LOSS: 41.00865992144347\n",
      "EPOCH: 11724 LOSS: 41.008655125556\n",
      "EPOCH: 11725 LOSS: 41.00865033030168\n",
      "EPOCH: 11726 LOSS: 41.008645535680415\n",
      "EPOCH: 11727 LOSS: 41.00864074169209\n",
      "EPOCH: 11728 LOSS: 41.008635948336575\n",
      "EPOCH: 11729 LOSS: 41.00863115561378\n",
      "EPOCH: 11730 LOSS: 41.00862636352359\n",
      "EPOCH: 11731 LOSS: 41.008621572065856\n",
      "EPOCH: 11732 LOSS: 41.008616781240505\n",
      "EPOCH: 11733 LOSS: 41.00861199104739\n",
      "EPOCH: 11734 LOSS: 41.00860720148644\n",
      "EPOCH: 11735 LOSS: 41.00860241255751\n",
      "EPOCH: 11736 LOSS: 41.00859762426049\n",
      "EPOCH: 11737 LOSS: 41.00859283659527\n",
      "EPOCH: 11738 LOSS: 41.00858804956174\n",
      "EPOCH: 11739 LOSS: 41.008583263159764\n",
      "EPOCH: 11740 LOSS: 41.00857847738928\n",
      "EPOCH: 11741 LOSS: 41.008573692250124\n",
      "EPOCH: 11742 LOSS: 41.0085689077422\n",
      "EPOCH: 11743 LOSS: 41.0085641238654\n",
      "EPOCH: 11744 LOSS: 41.00855934061961\n",
      "EPOCH: 11745 LOSS: 41.00855455800471\n",
      "EPOCH: 11746 LOSS: 41.008549776020594\n",
      "EPOCH: 11747 LOSS: 41.008544994667155\n",
      "EPOCH: 11748 LOSS: 41.00854021394426\n",
      "EPOCH: 11749 LOSS: 41.0085354338518\n",
      "EPOCH: 11750 LOSS: 41.00853065438968\n",
      "EPOCH: 11751 LOSS: 41.008525875557766\n",
      "EPOCH: 11752 LOSS: 41.00852109735596\n",
      "EPOCH: 11753 LOSS: 41.008516319784135\n",
      "EPOCH: 11754 LOSS: 41.008511542842186\n",
      "EPOCH: 11755 LOSS: 41.00850676653002\n",
      "EPOCH: 11756 LOSS: 41.00850199084748\n",
      "EPOCH: 11757 LOSS: 41.0084972157945\n",
      "EPOCH: 11758 LOSS: 41.008492441370926\n",
      "EPOCH: 11759 LOSS: 41.008487667576674\n",
      "EPOCH: 11760 LOSS: 41.008482894411614\n",
      "EPOCH: 11761 LOSS: 41.00847812187565\n",
      "EPOCH: 11762 LOSS: 41.00847334996864\n",
      "EPOCH: 11763 LOSS: 41.00846857869051\n",
      "EPOCH: 11764 LOSS: 41.008463808041114\n",
      "EPOCH: 11765 LOSS: 41.00845903802036\n",
      "EPOCH: 11766 LOSS: 41.00845426862812\n",
      "EPOCH: 11767 LOSS: 41.0084494998643\n",
      "EPOCH: 11768 LOSS: 41.00844473172877\n",
      "EPOCH: 11769 LOSS: 41.008439964221424\n",
      "EPOCH: 11770 LOSS: 41.00843519734215\n",
      "EPOCH: 11771 LOSS: 41.00843043109086\n",
      "EPOCH: 11772 LOSS: 41.008425665467385\n",
      "EPOCH: 11773 LOSS: 41.00842090047165\n",
      "EPOCH: 11774 LOSS: 41.00841613610355\n",
      "EPOCH: 11775 LOSS: 41.008411372362964\n",
      "EPOCH: 11776 LOSS: 41.00840660924975\n",
      "EPOCH: 11777 LOSS: 41.00840184676382\n",
      "EPOCH: 11778 LOSS: 41.00839708490508\n",
      "EPOCH: 11779 LOSS: 41.00839232367339\n",
      "EPOCH: 11780 LOSS: 41.00838756306864\n",
      "EPOCH: 11781 LOSS: 41.008382803090726\n",
      "EPOCH: 11782 LOSS: 41.00837804373955\n",
      "EPOCH: 11783 LOSS: 41.00837328501497\n",
      "EPOCH: 11784 LOSS: 41.00836852691689\n",
      "EPOCH: 11785 LOSS: 41.00836376944521\n",
      "EPOCH: 11786 LOSS: 41.00835901259978\n",
      "EPOCH: 11787 LOSS: 41.008354256380535\n",
      "EPOCH: 11788 LOSS: 41.00834950078733\n",
      "EPOCH: 11789 LOSS: 41.00834474582006\n",
      "EPOCH: 11790 LOSS: 41.00833999147861\n",
      "EPOCH: 11791 LOSS: 41.00833523776287\n",
      "EPOCH: 11792 LOSS: 41.00833048467274\n",
      "EPOCH: 11793 LOSS: 41.00832573220811\n",
      "EPOCH: 11794 LOSS: 41.008320980368836\n",
      "EPOCH: 11795 LOSS: 41.008316229154836\n",
      "EPOCH: 11796 LOSS: 41.00831147856598\n",
      "EPOCH: 11797 LOSS: 41.008306728602165\n",
      "EPOCH: 11798 LOSS: 41.008301979263294\n",
      "EPOCH: 11799 LOSS: 41.00829723054924\n",
      "EPOCH: 11800 LOSS: 41.008292482459865\n",
      "EPOCH: 11801 LOSS: 41.0082877349951\n",
      "EPOCH: 11802 LOSS: 41.00828298815481\n",
      "EPOCH: 11803 LOSS: 41.008278241938896\n",
      "EPOCH: 11804 LOSS: 41.00827349634725\n",
      "EPOCH: 11805 LOSS: 41.00826875137973\n",
      "EPOCH: 11806 LOSS: 41.00826400703626\n",
      "EPOCH: 11807 LOSS: 41.0082592633167\n",
      "EPOCH: 11808 LOSS: 41.00825452022096\n",
      "EPOCH: 11809 LOSS: 41.00824977774893\n",
      "EPOCH: 11810 LOSS: 41.00824503590046\n",
      "EPOCH: 11811 LOSS: 41.008240294675474\n",
      "EPOCH: 11812 LOSS: 41.008235554073856\n",
      "EPOCH: 11813 LOSS: 41.008230814095484\n",
      "EPOCH: 11814 LOSS: 41.00822607474027\n",
      "EPOCH: 11815 LOSS: 41.008221336008084\n",
      "EPOCH: 11816 LOSS: 41.00821659789881\n",
      "EPOCH: 11817 LOSS: 41.00821186041233\n",
      "EPOCH: 11818 LOSS: 41.00820712354857\n",
      "EPOCH: 11819 LOSS: 41.008202387307364\n",
      "EPOCH: 11820 LOSS: 41.008197651688654\n",
      "EPOCH: 11821 LOSS: 41.008192916692316\n",
      "EPOCH: 11822 LOSS: 41.00818818231819\n",
      "EPOCH: 11823 LOSS: 41.00818344856623\n",
      "EPOCH: 11824 LOSS: 41.008178715436294\n",
      "EPOCH: 11825 LOSS: 41.00817398292827\n",
      "EPOCH: 11826 LOSS: 41.00816925104205\n",
      "EPOCH: 11827 LOSS: 41.00816451977751\n",
      "EPOCH: 11828 LOSS: 41.00815978913459\n",
      "EPOCH: 11829 LOSS: 41.00815505911311\n",
      "EPOCH: 11830 LOSS: 41.008150329713\n",
      "EPOCH: 11831 LOSS: 41.00814560093413\n",
      "EPOCH: 11832 LOSS: 41.008140872776394\n",
      "EPOCH: 11833 LOSS: 41.008136145239696\n",
      "EPOCH: 11834 LOSS: 41.00813141832391\n",
      "EPOCH: 11835 LOSS: 41.00812669202893\n",
      "EPOCH: 11836 LOSS: 41.00812196635465\n",
      "EPOCH: 11837 LOSS: 41.00811724130095\n",
      "EPOCH: 11838 LOSS: 41.00811251686772\n",
      "EPOCH: 11839 LOSS: 41.00810779305485\n",
      "EPOCH: 11840 LOSS: 41.00810306986222\n",
      "EPOCH: 11841 LOSS: 41.008098347289746\n",
      "EPOCH: 11842 LOSS: 41.00809362533729\n",
      "EPOCH: 11843 LOSS: 41.00808890400473\n",
      "EPOCH: 11844 LOSS: 41.00808418329201\n",
      "EPOCH: 11845 LOSS: 41.008079463198975\n",
      "EPOCH: 11846 LOSS: 41.00807474372552\n",
      "EPOCH: 11847 LOSS: 41.00807002487154\n",
      "EPOCH: 11848 LOSS: 41.00806530663693\n",
      "EPOCH: 11849 LOSS: 41.00806058902157\n",
      "EPOCH: 11850 LOSS: 41.00805587202534\n",
      "EPOCH: 11851 LOSS: 41.00805115564815\n",
      "EPOCH: 11852 LOSS: 41.00804643988988\n",
      "EPOCH: 11853 LOSS: 41.00804172475044\n",
      "EPOCH: 11854 LOSS: 41.00803701022966\n",
      "EPOCH: 11855 LOSS: 41.00803229632749\n",
      "EPOCH: 11856 LOSS: 41.0080275830438\n",
      "EPOCH: 11857 LOSS: 41.00802287037847\n",
      "EPOCH: 11858 LOSS: 41.008018158331396\n",
      "EPOCH: 11859 LOSS: 41.00801344690248\n",
      "EPOCH: 11860 LOSS: 41.00800873609159\n",
      "EPOCH: 11861 LOSS: 41.008004025898636\n",
      "EPOCH: 11862 LOSS: 41.00799931632349\n",
      "EPOCH: 11863 LOSS: 41.00799460736606\n",
      "EPOCH: 11864 LOSS: 41.007989899026185\n",
      "EPOCH: 11865 LOSS: 41.007985191303845\n",
      "EPOCH: 11866 LOSS: 41.00798048419885\n",
      "EPOCH: 11867 LOSS: 41.00797577771114\n",
      "EPOCH: 11868 LOSS: 41.00797107184056\n",
      "EPOCH: 11869 LOSS: 41.00796636658704\n",
      "EPOCH: 11870 LOSS: 41.007961661950446\n",
      "EPOCH: 11871 LOSS: 41.00795695793066\n",
      "EPOCH: 11872 LOSS: 41.00795225452761\n",
      "EPOCH: 11873 LOSS: 41.00794755174117\n",
      "EPOCH: 11874 LOSS: 41.007942849571194\n",
      "EPOCH: 11875 LOSS: 41.00793814801762\n",
      "EPOCH: 11876 LOSS: 41.00793344708031\n",
      "EPOCH: 11877 LOSS: 41.00792874675917\n",
      "EPOCH: 11878 LOSS: 41.007924047054075\n",
      "EPOCH: 11879 LOSS: 41.00791934796493\n",
      "EPOCH: 11880 LOSS: 41.007914649491596\n",
      "EPOCH: 11881 LOSS: 41.007909951634005\n",
      "EPOCH: 11882 LOSS: 41.00790525439203\n",
      "EPOCH: 11883 LOSS: 41.00790055776555\n",
      "EPOCH: 11884 LOSS: 41.00789586175446\n",
      "EPOCH: 11885 LOSS: 41.00789116635865\n",
      "EPOCH: 11886 LOSS: 41.00788647157802\n",
      "EPOCH: 11887 LOSS: 41.00788177741244\n",
      "EPOCH: 11888 LOSS: 41.00787708386183\n",
      "EPOCH: 11889 LOSS: 41.00787239092606\n",
      "EPOCH: 11890 LOSS: 41.00786769860502\n",
      "EPOCH: 11891 LOSS: 41.00786300689859\n",
      "EPOCH: 11892 LOSS: 41.0078583158067\n",
      "EPOCH: 11893 LOSS: 41.007853625329204\n",
      "EPOCH: 11894 LOSS: 41.00784893546601\n",
      "EPOCH: 11895 LOSS: 41.00784424621698\n",
      "EPOCH: 11896 LOSS: 41.00783955758205\n",
      "EPOCH: 11897 LOSS: 41.007834869561066\n",
      "EPOCH: 11898 LOSS: 41.00783018215396\n",
      "EPOCH: 11899 LOSS: 41.0078254953606\n",
      "EPOCH: 11900 LOSS: 41.00782080918087\n",
      "EPOCH: 11901 LOSS: 41.00781612361466\n",
      "EPOCH: 11902 LOSS: 41.00781143866189\n",
      "EPOCH: 11903 LOSS: 41.007806754322395\n",
      "EPOCH: 11904 LOSS: 41.00780207059613\n",
      "EPOCH: 11905 LOSS: 41.00779738748294\n",
      "EPOCH: 11906 LOSS: 41.007792704982734\n",
      "EPOCH: 11907 LOSS: 41.0077880230954\n",
      "EPOCH: 11908 LOSS: 41.00778334182084\n",
      "EPOCH: 11909 LOSS: 41.00777866115892\n",
      "EPOCH: 11910 LOSS: 41.00777398110955\n",
      "EPOCH: 11911 LOSS: 41.00776930167261\n",
      "EPOCH: 11912 LOSS: 41.007764622848015\n",
      "EPOCH: 11913 LOSS: 41.00775994463561\n",
      "EPOCH: 11914 LOSS: 41.00775526703532\n",
      "EPOCH: 11915 LOSS: 41.007750590047024\n",
      "EPOCH: 11916 LOSS: 41.007745913670625\n",
      "EPOCH: 11917 LOSS: 41.007741237906004\n",
      "EPOCH: 11918 LOSS: 41.00773656275305\n",
      "EPOCH: 11919 LOSS: 41.007731888211666\n",
      "EPOCH: 11920 LOSS: 41.00772721428173\n",
      "EPOCH: 11921 LOSS: 41.00772254096314\n",
      "EPOCH: 11922 LOSS: 41.00771786825579\n",
      "EPOCH: 11923 LOSS: 41.00771319615955\n",
      "EPOCH: 11924 LOSS: 41.00770852467433\n",
      "EPOCH: 11925 LOSS: 41.007703853800024\n",
      "EPOCH: 11926 LOSS: 41.0076991835365\n",
      "EPOCH: 11927 LOSS: 41.00769451388368\n",
      "EPOCH: 11928 LOSS: 41.00768984484145\n",
      "EPOCH: 11929 LOSS: 41.007685176409666\n",
      "EPOCH: 11930 LOSS: 41.00768050858829\n",
      "EPOCH: 11931 LOSS: 41.007675841377136\n",
      "EPOCH: 11932 LOSS: 41.00767117477612\n",
      "EPOCH: 11933 LOSS: 41.00766650878516\n",
      "EPOCH: 11934 LOSS: 41.007661843404115\n",
      "EPOCH: 11935 LOSS: 41.00765717863291\n",
      "EPOCH: 11936 LOSS: 41.0076525144714\n",
      "EPOCH: 11937 LOSS: 41.00764785091949\n",
      "EPOCH: 11938 LOSS: 41.00764318797707\n",
      "EPOCH: 11939 LOSS: 41.00763852564406\n",
      "EPOCH: 11940 LOSS: 41.00763386392031\n",
      "EPOCH: 11941 LOSS: 41.007629202805724\n",
      "EPOCH: 11942 LOSS: 41.007624542300206\n",
      "EPOCH: 11943 LOSS: 41.00761988240364\n",
      "EPOCH: 11944 LOSS: 41.007615223115906\n",
      "EPOCH: 11945 LOSS: 41.007610564436916\n",
      "EPOCH: 11946 LOSS: 41.007605906366535\n",
      "EPOCH: 11947 LOSS: 41.00760124890469\n",
      "EPOCH: 11948 LOSS: 41.00759659205126\n",
      "EPOCH: 11949 LOSS: 41.007591935806104\n",
      "EPOCH: 11950 LOSS: 41.00758728016916\n",
      "EPOCH: 11951 LOSS: 41.007582625140294\n",
      "EPOCH: 11952 LOSS: 41.00757797071941\n",
      "EPOCH: 11953 LOSS: 41.00757331690639\n",
      "EPOCH: 11954 LOSS: 41.007568663701115\n",
      "EPOCH: 11955 LOSS: 41.00756401110351\n",
      "EPOCH: 11956 LOSS: 41.00755935911343\n",
      "EPOCH: 11957 LOSS: 41.00755470773079\n",
      "EPOCH: 11958 LOSS: 41.00755005695549\n",
      "EPOCH: 11959 LOSS: 41.0075454067874\n",
      "EPOCH: 11960 LOSS: 41.00754075722642\n",
      "EPOCH: 11961 LOSS: 41.00753610827244\n",
      "EPOCH: 11962 LOSS: 41.00753145992535\n",
      "EPOCH: 11963 LOSS: 41.00752681218505\n",
      "EPOCH: 11964 LOSS: 41.00752216505144\n",
      "EPOCH: 11965 LOSS: 41.00751751852437\n",
      "EPOCH: 11966 LOSS: 41.00751287260378\n",
      "EPOCH: 11967 LOSS: 41.00750822728954\n",
      "EPOCH: 11968 LOSS: 41.007503582581556\n",
      "EPOCH: 11969 LOSS: 41.0074989384797\n",
      "EPOCH: 11970 LOSS: 41.00749429498387\n",
      "EPOCH: 11971 LOSS: 41.00748965209397\n",
      "EPOCH: 11972 LOSS: 41.007485009809876\n",
      "EPOCH: 11973 LOSS: 41.0074803681315\n",
      "EPOCH: 11974 LOSS: 41.00747572705872\n",
      "EPOCH: 11975 LOSS: 41.00747108659143\n",
      "EPOCH: 11976 LOSS: 41.007466446729524\n",
      "EPOCH: 11977 LOSS: 41.00746180747288\n",
      "EPOCH: 11978 LOSS: 41.00745716882142\n",
      "EPOCH: 11979 LOSS: 41.00745253077501\n",
      "EPOCH: 11980 LOSS: 41.00744789333356\n",
      "EPOCH: 11981 LOSS: 41.007443256496956\n",
      "EPOCH: 11982 LOSS: 41.007438620265084\n",
      "EPOCH: 11983 LOSS: 41.00743398463785\n",
      "EPOCH: 11984 LOSS: 41.00742934961512\n",
      "EPOCH: 11985 LOSS: 41.00742471519683\n",
      "EPOCH: 11986 LOSS: 41.00742008138282\n",
      "EPOCH: 11987 LOSS: 41.00741544817302\n",
      "EPOCH: 11988 LOSS: 41.00741081556734\n",
      "EPOCH: 11989 LOSS: 41.0074061835656\n",
      "EPOCH: 11990 LOSS: 41.00740155216776\n",
      "EPOCH: 11991 LOSS: 41.00739692137368\n",
      "EPOCH: 11992 LOSS: 41.00739229118326\n",
      "EPOCH: 11993 LOSS: 41.00738766159641\n",
      "EPOCH: 11994 LOSS: 41.00738303261299\n",
      "EPOCH: 11995 LOSS: 41.007378404232945\n",
      "EPOCH: 11996 LOSS: 41.00737377645609\n",
      "EPOCH: 11997 LOSS: 41.00736914928238\n",
      "EPOCH: 11998 LOSS: 41.00736452271169\n",
      "EPOCH: 11999 LOSS: 41.00735989674392\n",
      "EPOCH: 12000 LOSS: 41.007355271378934\n",
      "EPOCH: 12001 LOSS: 41.00735064661664\n",
      "EPOCH: 12002 LOSS: 41.007346022456964\n",
      "EPOCH: 12003 LOSS: 41.00734139889975\n",
      "EPOCH: 12004 LOSS: 41.00733677594492\n",
      "EPOCH: 12005 LOSS: 41.00733215359237\n",
      "EPOCH: 12006 LOSS: 41.007327531841966\n",
      "EPOCH: 12007 LOSS: 41.0073229106936\n",
      "EPOCH: 12008 LOSS: 41.007318290147204\n",
      "EPOCH: 12009 LOSS: 41.00731367020265\n",
      "EPOCH: 12010 LOSS: 41.00730905085983\n",
      "EPOCH: 12011 LOSS: 41.007304432118616\n",
      "EPOCH: 12012 LOSS: 41.00729981397894\n",
      "EPOCH: 12013 LOSS: 41.007295196440666\n",
      "EPOCH: 12014 LOSS: 41.0072905795037\n",
      "EPOCH: 12015 LOSS: 41.00728596316795\n",
      "EPOCH: 12016 LOSS: 41.00728134743327\n",
      "EPOCH: 12017 LOSS: 41.00727673229958\n",
      "EPOCH: 12018 LOSS: 41.00727211776676\n",
      "EPOCH: 12019 LOSS: 41.00726750383473\n",
      "EPOCH: 12020 LOSS: 41.00726289050336\n",
      "EPOCH: 12021 LOSS: 41.00725827777254\n",
      "EPOCH: 12022 LOSS: 41.00725366564219\n",
      "EPOCH: 12023 LOSS: 41.00724905411215\n",
      "EPOCH: 12024 LOSS: 41.00724444318239\n",
      "EPOCH: 12025 LOSS: 41.00723983285273\n",
      "EPOCH: 12026 LOSS: 41.007235223123104\n",
      "EPOCH: 12027 LOSS: 41.00723061399341\n",
      "EPOCH: 12028 LOSS: 41.00722600546351\n",
      "EPOCH: 12029 LOSS: 41.0072213975333\n",
      "EPOCH: 12030 LOSS: 41.00721679020272\n",
      "EPOCH: 12031 LOSS: 41.007212183471616\n",
      "EPOCH: 12032 LOSS: 41.007207577339905\n",
      "EPOCH: 12033 LOSS: 41.00720297180747\n",
      "EPOCH: 12034 LOSS: 41.00719836687422\n",
      "EPOCH: 12035 LOSS: 41.00719376254003\n",
      "EPOCH: 12036 LOSS: 41.007189158804785\n",
      "EPOCH: 12037 LOSS: 41.0071845556684\n",
      "EPOCH: 12038 LOSS: 41.00717995313076\n",
      "EPOCH: 12039 LOSS: 41.00717535119178\n",
      "EPOCH: 12040 LOSS: 41.00717074985131\n",
      "EPOCH: 12041 LOSS: 41.00716614910928\n",
      "EPOCH: 12042 LOSS: 41.00716154896558\n",
      "EPOCH: 12043 LOSS: 41.00715694942008\n",
      "EPOCH: 12044 LOSS: 41.007152350472694\n",
      "EPOCH: 12045 LOSS: 41.007147752123316\n",
      "EPOCH: 12046 LOSS: 41.00714315437183\n",
      "EPOCH: 12047 LOSS: 41.00713855721813\n",
      "EPOCH: 12048 LOSS: 41.00713396066213\n",
      "EPOCH: 12049 LOSS: 41.0071293647037\n",
      "EPOCH: 12050 LOSS: 41.00712476934274\n",
      "EPOCH: 12051 LOSS: 41.00712017457916\n",
      "EPOCH: 12052 LOSS: 41.00711558041283\n",
      "EPOCH: 12053 LOSS: 41.00711098684366\n",
      "EPOCH: 12054 LOSS: 41.00710639387154\n",
      "EPOCH: 12055 LOSS: 41.00710180149635\n",
      "EPOCH: 12056 LOSS: 41.007097209718005\n",
      "EPOCH: 12057 LOSS: 41.00709261853639\n",
      "EPOCH: 12058 LOSS: 41.0070880279514\n",
      "EPOCH: 12059 LOSS: 41.00708343796293\n",
      "EPOCH: 12060 LOSS: 41.00707884857088\n",
      "EPOCH: 12061 LOSS: 41.00707425977513\n",
      "EPOCH: 12062 LOSS: 41.00706967157558\n",
      "EPOCH: 12063 LOSS: 41.00706508397213\n",
      "EPOCH: 12064 LOSS: 41.007060496964655\n",
      "EPOCH: 12065 LOSS: 41.007055910553085\n",
      "EPOCH: 12066 LOSS: 41.00705132473729\n",
      "EPOCH: 12067 LOSS: 41.007046739517165\n",
      "EPOCH: 12068 LOSS: 41.00704215489261\n",
      "EPOCH: 12069 LOSS: 41.00703757086351\n",
      "EPOCH: 12070 LOSS: 41.00703298742976\n",
      "EPOCH: 12071 LOSS: 41.00702840459128\n",
      "EPOCH: 12072 LOSS: 41.00702382234793\n",
      "EPOCH: 12073 LOSS: 41.007019240699634\n",
      "EPOCH: 12074 LOSS: 41.00701465964626\n",
      "EPOCH: 12075 LOSS: 41.00701007918771\n",
      "EPOCH: 12076 LOSS: 41.00700549932389\n",
      "EPOCH: 12077 LOSS: 41.00700092005469\n",
      "EPOCH: 12078 LOSS: 41.006996341379995\n",
      "EPOCH: 12079 LOSS: 41.00699176329971\n",
      "EPOCH: 12080 LOSS: 41.00698718581373\n",
      "EPOCH: 12081 LOSS: 41.00698260892193\n",
      "EPOCH: 12082 LOSS: 41.00697803262425\n",
      "EPOCH: 12083 LOSS: 41.00697345692052\n",
      "EPOCH: 12084 LOSS: 41.00696888181069\n",
      "EPOCH: 12085 LOSS: 41.00696430729462\n",
      "EPOCH: 12086 LOSS: 41.00695973337223\n",
      "EPOCH: 12087 LOSS: 41.006955160043404\n",
      "EPOCH: 12088 LOSS: 41.006950587308026\n",
      "EPOCH: 12089 LOSS: 41.00694601516604\n",
      "EPOCH: 12090 LOSS: 41.00694144361725\n",
      "EPOCH: 12091 LOSS: 41.006936872661626\n",
      "EPOCH: 12092 LOSS: 41.006932302299035\n",
      "EPOCH: 12093 LOSS: 41.00692773252939\n",
      "EPOCH: 12094 LOSS: 41.006923163352546\n",
      "EPOCH: 12095 LOSS: 41.00691859476846\n",
      "EPOCH: 12096 LOSS: 41.00691402677698\n",
      "EPOCH: 12097 LOSS: 41.006909459378\n",
      "EPOCH: 12098 LOSS: 41.006904892571434\n",
      "EPOCH: 12099 LOSS: 41.00690032635717\n",
      "EPOCH: 12100 LOSS: 41.00689576073511\n",
      "EPOCH: 12101 LOSS: 41.00689119570514\n",
      "EPOCH: 12102 LOSS: 41.00688663126716\n",
      "EPOCH: 12103 LOSS: 41.00688206742103\n",
      "EPOCH: 12104 LOSS: 41.006877504166724\n",
      "EPOCH: 12105 LOSS: 41.00687294150407\n",
      "EPOCH: 12106 LOSS: 41.00686837943299\n",
      "EPOCH: 12107 LOSS: 41.006863817953345\n",
      "EPOCH: 12108 LOSS: 41.006859257065095\n",
      "EPOCH: 12109 LOSS: 41.00685469676809\n",
      "EPOCH: 12110 LOSS: 41.00685013706223\n",
      "EPOCH: 12111 LOSS: 41.006845577947416\n",
      "EPOCH: 12112 LOSS: 41.006841019423554\n",
      "EPOCH: 12113 LOSS: 41.0068364614905\n",
      "EPOCH: 12114 LOSS: 41.00683190414819\n",
      "EPOCH: 12115 LOSS: 41.00682734739651\n",
      "EPOCH: 12116 LOSS: 41.00682279123535\n",
      "EPOCH: 12117 LOSS: 41.006818235664596\n",
      "EPOCH: 12118 LOSS: 41.00681368068417\n",
      "EPOCH: 12119 LOSS: 41.00680912629393\n",
      "EPOCH: 12120 LOSS: 41.00680457249381\n",
      "EPOCH: 12121 LOSS: 41.00680001928369\n",
      "EPOCH: 12122 LOSS: 41.006795466663455\n",
      "EPOCH: 12123 LOSS: 41.00679091463303\n",
      "EPOCH: 12124 LOSS: 41.00678636319226\n",
      "EPOCH: 12125 LOSS: 41.00678181234109\n",
      "EPOCH: 12126 LOSS: 41.006777262079396\n",
      "EPOCH: 12127 LOSS: 41.00677271240707\n",
      "EPOCH: 12128 LOSS: 41.006768163324004\n",
      "EPOCH: 12129 LOSS: 41.00676361483012\n",
      "EPOCH: 12130 LOSS: 41.00675906692528\n",
      "EPOCH: 12131 LOSS: 41.00675451960939\n",
      "EPOCH: 12132 LOSS: 41.00674997288236\n",
      "EPOCH: 12133 LOSS: 41.006745426744075\n",
      "EPOCH: 12134 LOSS: 41.00674088119443\n",
      "EPOCH: 12135 LOSS: 41.00673633623332\n",
      "EPOCH: 12136 LOSS: 41.00673179186065\n",
      "EPOCH: 12137 LOSS: 41.0067272480763\n",
      "EPOCH: 12138 LOSS: 41.0067227048802\n",
      "EPOCH: 12139 LOSS: 41.006718162272186\n",
      "EPOCH: 12140 LOSS: 41.00671362025223\n",
      "EPOCH: 12141 LOSS: 41.00670907882015\n",
      "EPOCH: 12142 LOSS: 41.00670453797588\n",
      "EPOCH: 12143 LOSS: 41.00669999771934\n",
      "EPOCH: 12144 LOSS: 41.006695458050395\n",
      "EPOCH: 12145 LOSS: 41.00669091896893\n",
      "EPOCH: 12146 LOSS: 41.006686380474875\n",
      "EPOCH: 12147 LOSS: 41.00668184256809\n",
      "EPOCH: 12148 LOSS: 41.00667730524851\n",
      "EPOCH: 12149 LOSS: 41.006672768516\n",
      "EPOCH: 12150 LOSS: 41.00666823237047\n",
      "EPOCH: 12151 LOSS: 41.00666369681182\n",
      "EPOCH: 12152 LOSS: 41.006659161839934\n",
      "EPOCH: 12153 LOSS: 41.00665462745472\n",
      "EPOCH: 12154 LOSS: 41.00665009365606\n",
      "EPOCH: 12155 LOSS: 41.00664556044386\n",
      "EPOCH: 12156 LOSS: 41.00664102781802\n",
      "EPOCH: 12157 LOSS: 41.00663649577842\n",
      "EPOCH: 12158 LOSS: 41.00663196432499\n",
      "EPOCH: 12159 LOSS: 41.00662743345758\n",
      "EPOCH: 12160 LOSS: 41.00662290317612\n",
      "EPOCH: 12161 LOSS: 41.0066183734805\n",
      "EPOCH: 12162 LOSS: 41.00661384437061\n",
      "EPOCH: 12163 LOSS: 41.00660931584635\n",
      "EPOCH: 12164 LOSS: 41.00660478790762\n",
      "EPOCH: 12165 LOSS: 41.00660026055429\n",
      "EPOCH: 12166 LOSS: 41.006595733786305\n",
      "EPOCH: 12167 LOSS: 41.00659120760353\n",
      "EPOCH: 12168 LOSS: 41.00658668200586\n",
      "EPOCH: 12169 LOSS: 41.00658215699319\n",
      "EPOCH: 12170 LOSS: 41.00657763256543\n",
      "EPOCH: 12171 LOSS: 41.00657310872248\n",
      "EPOCH: 12172 LOSS: 41.00656858546424\n",
      "EPOCH: 12173 LOSS: 41.00656406279057\n",
      "EPOCH: 12174 LOSS: 41.0065595407014\n",
      "EPOCH: 12175 LOSS: 41.00655501919662\n",
      "EPOCH: 12176 LOSS: 41.00655049827611\n",
      "EPOCH: 12177 LOSS: 41.00654597793981\n",
      "EPOCH: 12178 LOSS: 41.00654145818756\n",
      "EPOCH: 12179 LOSS: 41.0065369390193\n",
      "EPOCH: 12180 LOSS: 41.00653242043491\n",
      "EPOCH: 12181 LOSS: 41.006527902434286\n",
      "EPOCH: 12182 LOSS: 41.00652338501733\n",
      "EPOCH: 12183 LOSS: 41.00651886818393\n",
      "EPOCH: 12184 LOSS: 41.006514351934\n",
      "EPOCH: 12185 LOSS: 41.00650983626741\n",
      "EPOCH: 12186 LOSS: 41.00650532118409\n",
      "EPOCH: 12187 LOSS: 41.00650080668392\n",
      "EPOCH: 12188 LOSS: 41.00649629276679\n",
      "EPOCH: 12189 LOSS: 41.006491779432594\n",
      "EPOCH: 12190 LOSS: 41.00648726668125\n",
      "EPOCH: 12191 LOSS: 41.00648275451264\n",
      "EPOCH: 12192 LOSS: 41.006478242926676\n",
      "EPOCH: 12193 LOSS: 41.006473731923236\n",
      "EPOCH: 12194 LOSS: 41.00646922150222\n",
      "EPOCH: 12195 LOSS: 41.006464711663526\n",
      "EPOCH: 12196 LOSS: 41.00646020240707\n",
      "EPOCH: 12197 LOSS: 41.00645569373272\n",
      "EPOCH: 12198 LOSS: 41.0064511856404\n",
      "EPOCH: 12199 LOSS: 41.00644667812999\n",
      "EPOCH: 12200 LOSS: 41.00644217120139\n",
      "EPOCH: 12201 LOSS: 41.00643766485451\n",
      "EPOCH: 12202 LOSS: 41.00643315908922\n",
      "EPOCH: 12203 LOSS: 41.00642865390544\n",
      "EPOCH: 12204 LOSS: 41.00642414930307\n",
      "EPOCH: 12205 LOSS: 41.006419645281994\n",
      "EPOCH: 12206 LOSS: 41.00641514184211\n",
      "EPOCH: 12207 LOSS: 41.00641063898332\n",
      "EPOCH: 12208 LOSS: 41.006406136705515\n",
      "EPOCH: 12209 LOSS: 41.0064016350086\n",
      "EPOCH: 12210 LOSS: 41.00639713389248\n",
      "EPOCH: 12211 LOSS: 41.00639263335704\n",
      "EPOCH: 12212 LOSS: 41.00638813340217\n",
      "EPOCH: 12213 LOSS: 41.006383634027785\n",
      "EPOCH: 12214 LOSS: 41.00637913523378\n",
      "EPOCH: 12215 LOSS: 41.00637463702003\n",
      "EPOCH: 12216 LOSS: 41.00637013938647\n",
      "EPOCH: 12217 LOSS: 41.006365642332966\n",
      "EPOCH: 12218 LOSS: 41.00636114585944\n",
      "EPOCH: 12219 LOSS: 41.00635664996577\n",
      "EPOCH: 12220 LOSS: 41.00635215465187\n",
      "EPOCH: 12221 LOSS: 41.00634765991761\n",
      "EPOCH: 12222 LOSS: 41.00634316576291\n",
      "EPOCH: 12223 LOSS: 41.00633867218767\n",
      "EPOCH: 12224 LOSS: 41.00633417919179\n",
      "EPOCH: 12225 LOSS: 41.00632968677514\n",
      "EPOCH: 12226 LOSS: 41.00632519493766\n",
      "EPOCH: 12227 LOSS: 41.00632070367921\n",
      "EPOCH: 12228 LOSS: 41.006316212999714\n",
      "EPOCH: 12229 LOSS: 41.006311722899035\n",
      "EPOCH: 12230 LOSS: 41.00630723337711\n",
      "EPOCH: 12231 LOSS: 41.006302744433825\n",
      "EPOCH: 12232 LOSS: 41.006298256069066\n",
      "EPOCH: 12233 LOSS: 41.006293768282745\n",
      "EPOCH: 12234 LOSS: 41.00628928107476\n",
      "EPOCH: 12235 LOSS: 41.00628479444499\n",
      "EPOCH: 12236 LOSS: 41.00628030839335\n",
      "EPOCH: 12237 LOSS: 41.00627582291974\n",
      "EPOCH: 12238 LOSS: 41.00627133802404\n",
      "EPOCH: 12239 LOSS: 41.00626685370618\n",
      "EPOCH: 12240 LOSS: 41.006262369966024\n",
      "EPOCH: 12241 LOSS: 41.00625788680349\n",
      "EPOCH: 12242 LOSS: 41.006253404218455\n",
      "EPOCH: 12243 LOSS: 41.00624892221086\n",
      "EPOCH: 12244 LOSS: 41.00624444078055\n",
      "EPOCH: 12245 LOSS: 41.006239959927456\n",
      "EPOCH: 12246 LOSS: 41.00623547965148\n",
      "EPOCH: 12247 LOSS: 41.00623099995249\n",
      "EPOCH: 12248 LOSS: 41.00622652083044\n",
      "EPOCH: 12249 LOSS: 41.00622204228516\n",
      "EPOCH: 12250 LOSS: 41.00621756431659\n",
      "EPOCH: 12251 LOSS: 41.00621308692462\n",
      "EPOCH: 12252 LOSS: 41.00620861010914\n",
      "EPOCH: 12253 LOSS: 41.006204133870064\n",
      "EPOCH: 12254 LOSS: 41.00619965820727\n",
      "EPOCH: 12255 LOSS: 41.00619518312068\n",
      "EPOCH: 12256 LOSS: 41.00619070861018\n",
      "EPOCH: 12257 LOSS: 41.006186234675646\n",
      "EPOCH: 12258 LOSS: 41.00618176131702\n",
      "EPOCH: 12259 LOSS: 41.00617728853419\n",
      "EPOCH: 12260 LOSS: 41.00617281632704\n",
      "EPOCH: 12261 LOSS: 41.00616834469545\n",
      "EPOCH: 12262 LOSS: 41.00616387363935\n",
      "EPOCH: 12263 LOSS: 41.006159403158634\n",
      "EPOCH: 12264 LOSS: 41.00615493325321\n",
      "EPOCH: 12265 LOSS: 41.00615046392295\n",
      "EPOCH: 12266 LOSS: 41.00614599516778\n",
      "EPOCH: 12267 LOSS: 41.00614152698755\n",
      "EPOCH: 12268 LOSS: 41.006137059382226\n",
      "EPOCH: 12269 LOSS: 41.00613259235166\n",
      "EPOCH: 12270 LOSS: 41.00612812589576\n",
      "EPOCH: 12271 LOSS: 41.00612366001444\n",
      "EPOCH: 12272 LOSS: 41.00611919470757\n",
      "EPOCH: 12273 LOSS: 41.006114729975096\n",
      "EPOCH: 12274 LOSS: 41.00611026581686\n",
      "EPOCH: 12275 LOSS: 41.00610580223281\n",
      "EPOCH: 12276 LOSS: 41.0061013392228\n",
      "EPOCH: 12277 LOSS: 41.00609687678677\n",
      "EPOCH: 12278 LOSS: 41.006092414924595\n",
      "EPOCH: 12279 LOSS: 41.00608795363617\n",
      "EPOCH: 12280 LOSS: 41.006083492921434\n",
      "EPOCH: 12281 LOSS: 41.00607903278023\n",
      "EPOCH: 12282 LOSS: 41.00607457321247\n",
      "EPOCH: 12283 LOSS: 41.0060701142181\n",
      "EPOCH: 12284 LOSS: 41.00606565579696\n",
      "EPOCH: 12285 LOSS: 41.00606119794899\n",
      "EPOCH: 12286 LOSS: 41.00605674067407\n",
      "EPOCH: 12287 LOSS: 41.00605228397208\n",
      "EPOCH: 12288 LOSS: 41.006047827842956\n",
      "EPOCH: 12289 LOSS: 41.006043372286584\n",
      "EPOCH: 12290 LOSS: 41.00603891730286\n",
      "EPOCH: 12291 LOSS: 41.00603446289168\n",
      "EPOCH: 12292 LOSS: 41.00603000905295\n",
      "EPOCH: 12293 LOSS: 41.006025555786564\n",
      "EPOCH: 12294 LOSS: 41.006021103092436\n",
      "EPOCH: 12295 LOSS: 41.00601665097045\n",
      "EPOCH: 12296 LOSS: 41.006012199420496\n",
      "EPOCH: 12297 LOSS: 41.00600774844249\n",
      "EPOCH: 12298 LOSS: 41.00600329803634\n",
      "EPOCH: 12299 LOSS: 41.00599884820191\n",
      "EPOCH: 12300 LOSS: 41.00599439893914\n",
      "EPOCH: 12301 LOSS: 41.005989950247894\n",
      "EPOCH: 12302 LOSS: 41.0059855021281\n",
      "EPOCH: 12303 LOSS: 41.005981054579635\n",
      "EPOCH: 12304 LOSS: 41.00597660760243\n",
      "EPOCH: 12305 LOSS: 41.00597216119635\n",
      "EPOCH: 12306 LOSS: 41.0059677153613\n",
      "EPOCH: 12307 LOSS: 41.0059632700972\n",
      "EPOCH: 12308 LOSS: 41.00595882540394\n",
      "EPOCH: 12309 LOSS: 41.0059543812814\n",
      "EPOCH: 12310 LOSS: 41.0059499377295\n",
      "EPOCH: 12311 LOSS: 41.00594549474815\n",
      "EPOCH: 12312 LOSS: 41.00594105233722\n",
      "EPOCH: 12313 LOSS: 41.00593661049663\n",
      "EPOCH: 12314 LOSS: 41.00593216922628\n",
      "EPOCH: 12315 LOSS: 41.00592772852606\n",
      "EPOCH: 12316 LOSS: 41.00592328839586\n",
      "EPOCH: 12317 LOSS: 41.00591884883563\n",
      "EPOCH: 12318 LOSS: 41.005914409845204\n",
      "EPOCH: 12319 LOSS: 41.00590997142451\n",
      "EPOCH: 12320 LOSS: 41.005905533573454\n",
      "EPOCH: 12321 LOSS: 41.005901096291936\n",
      "EPOCH: 12322 LOSS: 41.00589665957985\n",
      "EPOCH: 12323 LOSS: 41.00589222343709\n",
      "EPOCH: 12324 LOSS: 41.00588778786356\n",
      "EPOCH: 12325 LOSS: 41.00588335285917\n",
      "EPOCH: 12326 LOSS: 41.005878918423804\n",
      "EPOCH: 12327 LOSS: 41.00587448455737\n",
      "EPOCH: 12328 LOSS: 41.005870051259784\n",
      "EPOCH: 12329 LOSS: 41.005865618530905\n",
      "EPOCH: 12330 LOSS: 41.005861186370666\n",
      "EPOCH: 12331 LOSS: 41.00585675477896\n",
      "EPOCH: 12332 LOSS: 41.00585232375569\n",
      "EPOCH: 12333 LOSS: 41.00584789330074\n",
      "EPOCH: 12334 LOSS: 41.00584346341404\n",
      "EPOCH: 12335 LOSS: 41.00583903409545\n",
      "EPOCH: 12336 LOSS: 41.00583460534491\n",
      "EPOCH: 12337 LOSS: 41.0058301771623\n",
      "EPOCH: 12338 LOSS: 41.0058257495475\n",
      "EPOCH: 12339 LOSS: 41.00582132250045\n",
      "EPOCH: 12340 LOSS: 41.005816896021024\n",
      "EPOCH: 12341 LOSS: 41.00581247010915\n",
      "EPOCH: 12342 LOSS: 41.00580804476468\n",
      "EPOCH: 12343 LOSS: 41.00580361998758\n",
      "EPOCH: 12344 LOSS: 41.00579919577767\n",
      "EPOCH: 12345 LOSS: 41.005794772134905\n",
      "EPOCH: 12346 LOSS: 41.005790349059204\n",
      "EPOCH: 12347 LOSS: 41.00578592655041\n",
      "EPOCH: 12348 LOSS: 41.005781504608464\n",
      "EPOCH: 12349 LOSS: 41.005777083233234\n",
      "EPOCH: 12350 LOSS: 41.005772662424654\n",
      "EPOCH: 12351 LOSS: 41.0057682421826\n",
      "EPOCH: 12352 LOSS: 41.005763822506985\n",
      "EPOCH: 12353 LOSS: 41.00575940339772\n",
      "EPOCH: 12354 LOSS: 41.005754984854676\n",
      "EPOCH: 12355 LOSS: 41.005750566877765\n",
      "EPOCH: 12356 LOSS: 41.00574614946691\n",
      "EPOCH: 12357 LOSS: 41.005741732621985\n",
      "EPOCH: 12358 LOSS: 41.005737316342895\n",
      "EPOCH: 12359 LOSS: 41.00573290062954\n",
      "EPOCH: 12360 LOSS: 41.00572848548183\n",
      "EPOCH: 12361 LOSS: 41.00572407089967\n",
      "EPOCH: 12362 LOSS: 41.005719656882945\n",
      "EPOCH: 12363 LOSS: 41.00571524343155\n",
      "EPOCH: 12364 LOSS: 41.00571083054541\n",
      "EPOCH: 12365 LOSS: 41.00570641822442\n",
      "EPOCH: 12366 LOSS: 41.00570200646847\n",
      "EPOCH: 12367 LOSS: 41.005697595277454\n",
      "EPOCH: 12368 LOSS: 41.00569318465128\n",
      "EPOCH: 12369 LOSS: 41.00568877458987\n",
      "EPOCH: 12370 LOSS: 41.005684365093096\n",
      "EPOCH: 12371 LOSS: 41.005679956160876\n",
      "EPOCH: 12372 LOSS: 41.00567554779312\n",
      "EPOCH: 12373 LOSS: 41.00567113998967\n",
      "EPOCH: 12374 LOSS: 41.0056667327505\n",
      "EPOCH: 12375 LOSS: 41.00566232607547\n",
      "EPOCH: 12376 LOSS: 41.005657919964506\n",
      "EPOCH: 12377 LOSS: 41.005653514417475\n",
      "EPOCH: 12378 LOSS: 41.005649109434316\n",
      "EPOCH: 12379 LOSS: 41.0056447050149\n",
      "EPOCH: 12380 LOSS: 41.00564030115915\n",
      "EPOCH: 12381 LOSS: 41.00563589786695\n",
      "EPOCH: 12382 LOSS: 41.00563149513822\n",
      "EPOCH: 12383 LOSS: 41.005627092972844\n",
      "EPOCH: 12384 LOSS: 41.00562269137071\n",
      "EPOCH: 12385 LOSS: 41.00561829033175\n",
      "EPOCH: 12386 LOSS: 41.00561388985587\n",
      "EPOCH: 12387 LOSS: 41.005609489942934\n",
      "EPOCH: 12388 LOSS: 41.005605090592866\n",
      "EPOCH: 12389 LOSS: 41.005600691805554\n",
      "EPOCH: 12390 LOSS: 41.00559629358092\n",
      "EPOCH: 12391 LOSS: 41.005591895918855\n",
      "EPOCH: 12392 LOSS: 41.00558749881925\n",
      "EPOCH: 12393 LOSS: 41.00558310228203\n",
      "EPOCH: 12394 LOSS: 41.00557870630708\n",
      "EPOCH: 12395 LOSS: 41.0055743108943\n",
      "EPOCH: 12396 LOSS: 41.0055699160436\n",
      "EPOCH: 12397 LOSS: 41.005565521754875\n",
      "EPOCH: 12398 LOSS: 41.00556112802802\n",
      "EPOCH: 12399 LOSS: 41.00555673486295\n",
      "EPOCH: 12400 LOSS: 41.005552342259556\n",
      "EPOCH: 12401 LOSS: 41.00554795021774\n",
      "EPOCH: 12402 LOSS: 41.005543558737415\n",
      "EPOCH: 12403 LOSS: 41.005539167818476\n",
      "EPOCH: 12404 LOSS: 41.00553477746081\n",
      "EPOCH: 12405 LOSS: 41.005530387664336\n",
      "EPOCH: 12406 LOSS: 41.005525998428965\n",
      "EPOCH: 12407 LOSS: 41.00552160975458\n",
      "EPOCH: 12408 LOSS: 41.005517221641085\n",
      "EPOCH: 12409 LOSS: 41.00551283408837\n",
      "EPOCH: 12410 LOSS: 41.005508447096375\n",
      "EPOCH: 12411 LOSS: 41.00550406066496\n",
      "EPOCH: 12412 LOSS: 41.005499674794045\n",
      "EPOCH: 12413 LOSS: 41.005495289483534\n",
      "EPOCH: 12414 LOSS: 41.00549090473332\n",
      "EPOCH: 12415 LOSS: 41.00548652054333\n",
      "EPOCH: 12416 LOSS: 41.005482136913415\n",
      "EPOCH: 12417 LOSS: 41.00547775384352\n",
      "EPOCH: 12418 LOSS: 41.005473371333544\n",
      "EPOCH: 12419 LOSS: 41.00546898938336\n",
      "EPOCH: 12420 LOSS: 41.00546460799291\n",
      "EPOCH: 12421 LOSS: 41.00546022716206\n",
      "EPOCH: 12422 LOSS: 41.00545584689074\n",
      "EPOCH: 12423 LOSS: 41.005451467178816\n",
      "EPOCH: 12424 LOSS: 41.00544708802623\n",
      "EPOCH: 12425 LOSS: 41.005442709432856\n",
      "EPOCH: 12426 LOSS: 41.00543833139861\n",
      "EPOCH: 12427 LOSS: 41.0054339539234\n",
      "EPOCH: 12428 LOSS: 41.00542957700709\n",
      "EPOCH: 12429 LOSS: 41.00542520064964\n",
      "EPOCH: 12430 LOSS: 41.005420824850916\n",
      "EPOCH: 12431 LOSS: 41.00541644961082\n",
      "EPOCH: 12432 LOSS: 41.005412074929254\n",
      "EPOCH: 12433 LOSS: 41.00540770080613\n",
      "EPOCH: 12434 LOSS: 41.00540332724136\n",
      "EPOCH: 12435 LOSS: 41.00539895423481\n",
      "EPOCH: 12436 LOSS: 41.00539458178642\n",
      "EPOCH: 12437 LOSS: 41.00539020989608\n",
      "EPOCH: 12438 LOSS: 41.005385838563676\n",
      "EPOCH: 12439 LOSS: 41.00538146778913\n",
      "EPOCH: 12440 LOSS: 41.00537709757232\n",
      "EPOCH: 12441 LOSS: 41.005372727913176\n",
      "EPOCH: 12442 LOSS: 41.0053683588116\n",
      "EPOCH: 12443 LOSS: 41.00536399026748\n",
      "EPOCH: 12444 LOSS: 41.00535962228072\n",
      "EPOCH: 12445 LOSS: 41.00535525485121\n",
      "EPOCH: 12446 LOSS: 41.00535088797889\n",
      "EPOCH: 12447 LOSS: 41.00534652166363\n",
      "EPOCH: 12448 LOSS: 41.00534215590533\n",
      "EPOCH: 12449 LOSS: 41.00533779070393\n",
      "EPOCH: 12450 LOSS: 41.005333426059295\n",
      "EPOCH: 12451 LOSS: 41.00532906197131\n",
      "EPOCH: 12452 LOSS: 41.00532469843996\n",
      "EPOCH: 12453 LOSS: 41.00532033546506\n",
      "EPOCH: 12454 LOSS: 41.00531597304654\n",
      "EPOCH: 12455 LOSS: 41.00531161118433\n",
      "EPOCH: 12456 LOSS: 41.0053072498783\n",
      "EPOCH: 12457 LOSS: 41.00530288912837\n",
      "EPOCH: 12458 LOSS: 41.00529852893443\n",
      "EPOCH: 12459 LOSS: 41.0052941692964\n",
      "EPOCH: 12460 LOSS: 41.005289810214165\n",
      "EPOCH: 12461 LOSS: 41.00528545168763\n",
      "EPOCH: 12462 LOSS: 41.005281093716704\n",
      "EPOCH: 12463 LOSS: 41.0052767363013\n",
      "EPOCH: 12464 LOSS: 41.00527237944129\n",
      "EPOCH: 12465 LOSS: 41.005268023136594\n",
      "EPOCH: 12466 LOSS: 41.005263667387126\n",
      "EPOCH: 12467 LOSS: 41.00525931219277\n",
      "EPOCH: 12468 LOSS: 41.00525495755344\n",
      "EPOCH: 12469 LOSS: 41.00525060346906\n",
      "EPOCH: 12470 LOSS: 41.00524624993948\n",
      "EPOCH: 12471 LOSS: 41.005241896964634\n",
      "EPOCH: 12472 LOSS: 41.00523754454444\n",
      "EPOCH: 12473 LOSS: 41.00523319267877\n",
      "EPOCH: 12474 LOSS: 41.00522884136755\n",
      "EPOCH: 12475 LOSS: 41.00522449061066\n",
      "EPOCH: 12476 LOSS: 41.00522014040803\n",
      "EPOCH: 12477 LOSS: 41.00521579075955\n",
      "EPOCH: 12478 LOSS: 41.00521144166511\n",
      "EPOCH: 12479 LOSS: 41.00520709312462\n",
      "EPOCH: 12480 LOSS: 41.00520274513801\n",
      "EPOCH: 12481 LOSS: 41.00519839770514\n",
      "EPOCH: 12482 LOSS: 41.00519405082595\n",
      "EPOCH: 12483 LOSS: 41.00518970450031\n",
      "EPOCH: 12484 LOSS: 41.00518535872817\n",
      "EPOCH: 12485 LOSS: 41.005181013509386\n",
      "EPOCH: 12486 LOSS: 41.00517666884387\n",
      "EPOCH: 12487 LOSS: 41.005172324731554\n",
      "EPOCH: 12488 LOSS: 41.005167981172306\n",
      "EPOCH: 12489 LOSS: 41.00516363816604\n",
      "EPOCH: 12490 LOSS: 41.00515929571266\n",
      "EPOCH: 12491 LOSS: 41.005154953812095\n",
      "EPOCH: 12492 LOSS: 41.005150612464234\n",
      "EPOCH: 12493 LOSS: 41.005146271668934\n",
      "EPOCH: 12494 LOSS: 41.00514193142616\n",
      "EPOCH: 12495 LOSS: 41.005137591735796\n",
      "EPOCH: 12496 LOSS: 41.00513325259773\n",
      "EPOCH: 12497 LOSS: 41.00512891401189\n",
      "EPOCH: 12498 LOSS: 41.005124575978144\n",
      "EPOCH: 12499 LOSS: 41.00512023849643\n",
      "EPOCH: 12500 LOSS: 41.005115901566654\n",
      "EPOCH: 12501 LOSS: 41.00511156518869\n",
      "EPOCH: 12502 LOSS: 41.00510722936245\n",
      "EPOCH: 12503 LOSS: 41.00510289408784\n",
      "EPOCH: 12504 LOSS: 41.005098559364775\n",
      "EPOCH: 12505 LOSS: 41.00509422519317\n",
      "EPOCH: 12506 LOSS: 41.00508989157288\n",
      "EPOCH: 12507 LOSS: 41.00508555850385\n",
      "EPOCH: 12508 LOSS: 41.00508122598597\n",
      "EPOCH: 12509 LOSS: 41.00507689401915\n",
      "EPOCH: 12510 LOSS: 41.00507256260327\n",
      "EPOCH: 12511 LOSS: 41.00506823173825\n",
      "EPOCH: 12512 LOSS: 41.00506390142401\n",
      "EPOCH: 12513 LOSS: 41.005059571660446\n",
      "EPOCH: 12514 LOSS: 41.00505524244744\n",
      "EPOCH: 12515 LOSS: 41.00505091378493\n",
      "EPOCH: 12516 LOSS: 41.005046585672766\n",
      "EPOCH: 12517 LOSS: 41.00504225811092\n",
      "EPOCH: 12518 LOSS: 41.005037931099245\n",
      "EPOCH: 12519 LOSS: 41.00503360463766\n",
      "EPOCH: 12520 LOSS: 41.00502927872607\n",
      "EPOCH: 12521 LOSS: 41.0050249533644\n",
      "EPOCH: 12522 LOSS: 41.005020628552515\n",
      "EPOCH: 12523 LOSS: 41.005016304290336\n",
      "EPOCH: 12524 LOSS: 41.005011980577784\n",
      "EPOCH: 12525 LOSS: 41.005007657414716\n",
      "EPOCH: 12526 LOSS: 41.00500333480109\n",
      "EPOCH: 12527 LOSS: 41.00499901273678\n",
      "EPOCH: 12528 LOSS: 41.0049946912217\n",
      "EPOCH: 12529 LOSS: 41.00499037025574\n",
      "EPOCH: 12530 LOSS: 41.00498604983881\n",
      "EPOCH: 12531 LOSS: 41.00498172997084\n",
      "EPOCH: 12532 LOSS: 41.004977410651726\n",
      "EPOCH: 12533 LOSS: 41.00497309188133\n",
      "EPOCH: 12534 LOSS: 41.00496877365958\n",
      "EPOCH: 12535 LOSS: 41.0049644559864\n",
      "EPOCH: 12536 LOSS: 41.00496013886168\n",
      "EPOCH: 12537 LOSS: 41.004955822285325\n",
      "EPOCH: 12538 LOSS: 41.00495150625722\n",
      "EPOCH: 12539 LOSS: 41.004947190777294\n",
      "EPOCH: 12540 LOSS: 41.00494287584545\n",
      "EPOCH: 12541 LOSS: 41.004938561461586\n",
      "EPOCH: 12542 LOSS: 41.0049342476256\n",
      "EPOCH: 12543 LOSS: 41.00492993433741\n",
      "EPOCH: 12544 LOSS: 41.00492562159691\n",
      "EPOCH: 12545 LOSS: 41.00492130940401\n",
      "EPOCH: 12546 LOSS: 41.0049169977586\n",
      "EPOCH: 12547 LOSS: 41.0049126866606\n",
      "EPOCH: 12548 LOSS: 41.00490837610992\n",
      "EPOCH: 12549 LOSS: 41.00490406610645\n",
      "EPOCH: 12550 LOSS: 41.00489975665009\n",
      "EPOCH: 12551 LOSS: 41.004895447740765\n",
      "EPOCH: 12552 LOSS: 41.00489113937836\n",
      "EPOCH: 12553 LOSS: 41.0048868315628\n",
      "EPOCH: 12554 LOSS: 41.00488252429395\n",
      "EPOCH: 12555 LOSS: 41.004878217571765\n",
      "EPOCH: 12556 LOSS: 41.00487391139612\n",
      "EPOCH: 12557 LOSS: 41.00486960576693\n",
      "EPOCH: 12558 LOSS: 41.00486530068408\n",
      "EPOCH: 12559 LOSS: 41.0048609961475\n",
      "EPOCH: 12560 LOSS: 41.00485669215709\n",
      "EPOCH: 12561 LOSS: 41.004852388712735\n",
      "EPOCH: 12562 LOSS: 41.00484808581437\n",
      "EPOCH: 12563 LOSS: 41.00484378346187\n",
      "EPOCH: 12564 LOSS: 41.004839481655154\n",
      "EPOCH: 12565 LOSS: 41.004835180394124\n",
      "EPOCH: 12566 LOSS: 41.00483087967868\n",
      "EPOCH: 12567 LOSS: 41.00482657950875\n",
      "EPOCH: 12568 LOSS: 41.0048222798842\n",
      "EPOCH: 12569 LOSS: 41.004817980805\n",
      "EPOCH: 12570 LOSS: 41.00481368227096\n",
      "EPOCH: 12571 LOSS: 41.004809384282055\n",
      "EPOCH: 12572 LOSS: 41.004805086838175\n",
      "EPOCH: 12573 LOSS: 41.00480078993922\n",
      "EPOCH: 12574 LOSS: 41.00479649358508\n",
      "EPOCH: 12575 LOSS: 41.00479219777571\n",
      "EPOCH: 12576 LOSS: 41.00478790251094\n",
      "EPOCH: 12577 LOSS: 41.00478360779075\n",
      "EPOCH: 12578 LOSS: 41.00477931361499\n",
      "EPOCH: 12579 LOSS: 41.00477501998359\n",
      "EPOCH: 12580 LOSS: 41.004770726896446\n",
      "EPOCH: 12581 LOSS: 41.00476643435347\n",
      "EPOCH: 12582 LOSS: 41.004762142354565\n",
      "EPOCH: 12583 LOSS: 41.00475785089964\n",
      "EPOCH: 12584 LOSS: 41.004753559988586\n",
      "EPOCH: 12585 LOSS: 41.00474926962132\n",
      "EPOCH: 12586 LOSS: 41.00474497979774\n",
      "EPOCH: 12587 LOSS: 41.004740690517764\n",
      "EPOCH: 12588 LOSS: 41.00473640178129\n",
      "EPOCH: 12589 LOSS: 41.00473211358822\n",
      "EPOCH: 12590 LOSS: 41.00472782593846\n",
      "EPOCH: 12591 LOSS: 41.00472353883191\n",
      "EPOCH: 12592 LOSS: 41.00471925226849\n",
      "EPOCH: 12593 LOSS: 41.0047149662481\n",
      "EPOCH: 12594 LOSS: 41.00471068077064\n",
      "EPOCH: 12595 LOSS: 41.004706395835996\n",
      "EPOCH: 12596 LOSS: 41.00470211144412\n",
      "EPOCH: 12597 LOSS: 41.004697827594875\n",
      "EPOCH: 12598 LOSS: 41.0046935442882\n",
      "EPOCH: 12599 LOSS: 41.00468926152397\n",
      "EPOCH: 12600 LOSS: 41.0046849793021\n",
      "EPOCH: 12601 LOSS: 41.00468069762252\n",
      "EPOCH: 12602 LOSS: 41.00467641648511\n",
      "EPOCH: 12603 LOSS: 41.00467213588976\n",
      "EPOCH: 12604 LOSS: 41.004667855836416\n",
      "EPOCH: 12605 LOSS: 41.00466357632496\n",
      "EPOCH: 12606 LOSS: 41.004659297355296\n",
      "EPOCH: 12607 LOSS: 41.00465501892733\n",
      "EPOCH: 12608 LOSS: 41.00465074104099\n",
      "EPOCH: 12609 LOSS: 41.00464646369613\n",
      "EPOCH: 12610 LOSS: 41.00464218689273\n",
      "EPOCH: 12611 LOSS: 41.00463791063062\n",
      "EPOCH: 12612 LOSS: 41.00463363490975\n",
      "EPOCH: 12613 LOSS: 41.004629359730025\n",
      "EPOCH: 12614 LOSS: 41.00462508509134\n",
      "EPOCH: 12615 LOSS: 41.0046208109936\n",
      "EPOCH: 12616 LOSS: 41.0046165374367\n",
      "EPOCH: 12617 LOSS: 41.00461226442057\n",
      "EPOCH: 12618 LOSS: 41.00460799194509\n",
      "EPOCH: 12619 LOSS: 41.00460372001021\n",
      "EPOCH: 12620 LOSS: 41.00459944861578\n",
      "EPOCH: 12621 LOSS: 41.00459517776175\n",
      "EPOCH: 12622 LOSS: 41.00459090744798\n",
      "EPOCH: 12623 LOSS: 41.00458663767442\n",
      "EPOCH: 12624 LOSS: 41.004582368440964\n",
      "EPOCH: 12625 LOSS: 41.004578099747505\n",
      "EPOCH: 12626 LOSS: 41.00457383159396\n",
      "EPOCH: 12627 LOSS: 41.00456956398024\n",
      "EPOCH: 12628 LOSS: 41.00456529690622\n",
      "EPOCH: 12629 LOSS: 41.00456103037183\n",
      "EPOCH: 12630 LOSS: 41.00455676437699\n",
      "EPOCH: 12631 LOSS: 41.00455249892158\n",
      "EPOCH: 12632 LOSS: 41.00454823400553\n",
      "EPOCH: 12633 LOSS: 41.004543969628735\n",
      "EPOCH: 12634 LOSS: 41.004539705791075\n",
      "EPOCH: 12635 LOSS: 41.0045354424925\n",
      "EPOCH: 12636 LOSS: 41.00453117973287\n",
      "EPOCH: 12637 LOSS: 41.00452691751214\n",
      "EPOCH: 12638 LOSS: 41.004522655830186\n",
      "EPOCH: 12639 LOSS: 41.004518394686905\n",
      "EPOCH: 12640 LOSS: 41.00451413408226\n",
      "EPOCH: 12641 LOSS: 41.00450987401607\n",
      "EPOCH: 12642 LOSS: 41.00450561448831\n",
      "EPOCH: 12643 LOSS: 41.004501355498846\n",
      "EPOCH: 12644 LOSS: 41.00449709704764\n",
      "EPOCH: 12645 LOSS: 41.00449283913453\n",
      "EPOCH: 12646 LOSS: 41.00448858175945\n",
      "EPOCH: 12647 LOSS: 41.00448432492233\n",
      "EPOCH: 12648 LOSS: 41.004480068623025\n",
      "EPOCH: 12649 LOSS: 41.004475812861486\n",
      "EPOCH: 12650 LOSS: 41.00447155763761\n",
      "EPOCH: 12651 LOSS: 41.004467302951284\n",
      "EPOCH: 12652 LOSS: 41.00446304880244\n",
      "EPOCH: 12653 LOSS: 41.00445879519098\n",
      "EPOCH: 12654 LOSS: 41.00445454211679\n",
      "EPOCH: 12655 LOSS: 41.0044502895798\n",
      "EPOCH: 12656 LOSS: 41.00444603757988\n",
      "EPOCH: 12657 LOSS: 41.004441786116985\n",
      "EPOCH: 12658 LOSS: 41.004437535190995\n",
      "EPOCH: 12659 LOSS: 41.004433284801806\n",
      "EPOCH: 12660 LOSS: 41.004429034949354\n",
      "EPOCH: 12661 LOSS: 41.00442478563354\n",
      "EPOCH: 12662 LOSS: 41.004420536854255\n",
      "EPOCH: 12663 LOSS: 41.0044162886114\n",
      "EPOCH: 12664 LOSS: 41.004412040904896\n",
      "EPOCH: 12665 LOSS: 41.00440779373464\n",
      "EPOCH: 12666 LOSS: 41.00440354710055\n",
      "EPOCH: 12667 LOSS: 41.004399301002536\n",
      "EPOCH: 12668 LOSS: 41.0043950554405\n",
      "EPOCH: 12669 LOSS: 41.00439081041433\n",
      "EPOCH: 12670 LOSS: 41.004386565923966\n",
      "EPOCH: 12671 LOSS: 41.00438232196928\n",
      "EPOCH: 12672 LOSS: 41.00437807855021\n",
      "EPOCH: 12673 LOSS: 41.00437383566664\n",
      "EPOCH: 12674 LOSS: 41.00436959331848\n",
      "EPOCH: 12675 LOSS: 41.004365351505655\n",
      "EPOCH: 12676 LOSS: 41.004361110228054\n",
      "EPOCH: 12677 LOSS: 41.004356869485584\n",
      "EPOCH: 12678 LOSS: 41.004352629278145\n",
      "EPOCH: 12679 LOSS: 41.00434838960568\n",
      "EPOCH: 12680 LOSS: 41.00434415046807\n",
      "EPOCH: 12681 LOSS: 41.0043399118652\n",
      "EPOCH: 12682 LOSS: 41.00433567379702\n",
      "EPOCH: 12683 LOSS: 41.00433143626341\n",
      "EPOCH: 12684 LOSS: 41.00432719926428\n",
      "EPOCH: 12685 LOSS: 41.004322962799556\n",
      "EPOCH: 12686 LOSS: 41.00431872686912\n",
      "EPOCH: 12687 LOSS: 41.00431449147288\n",
      "EPOCH: 12688 LOSS: 41.00431025661077\n",
      "EPOCH: 12689 LOSS: 41.00430602228268\n",
      "EPOCH: 12690 LOSS: 41.004301788488505\n",
      "EPOCH: 12691 LOSS: 41.00429755522818\n",
      "EPOCH: 12692 LOSS: 41.00429332250157\n",
      "EPOCH: 12693 LOSS: 41.00428909030862\n",
      "EPOCH: 12694 LOSS: 41.004284858649235\n",
      "EPOCH: 12695 LOSS: 41.0042806275233\n",
      "EPOCH: 12696 LOSS: 41.004276396930734\n",
      "EPOCH: 12697 LOSS: 41.004272166871445\n",
      "EPOCH: 12698 LOSS: 41.00426793734535\n",
      "EPOCH: 12699 LOSS: 41.00426370835234\n",
      "EPOCH: 12700 LOSS: 41.004259479892326\n",
      "EPOCH: 12701 LOSS: 41.00425525196521\n",
      "EPOCH: 12702 LOSS: 41.00425102457093\n",
      "EPOCH: 12703 LOSS: 41.00424679770936\n",
      "EPOCH: 12704 LOSS: 41.0042425713804\n",
      "EPOCH: 12705 LOSS: 41.00423834558401\n",
      "EPOCH: 12706 LOSS: 41.00423412032002\n",
      "EPOCH: 12707 LOSS: 41.00422989558841\n",
      "EPOCH: 12708 LOSS: 41.00422567138905\n",
      "EPOCH: 12709 LOSS: 41.00422144772185\n",
      "EPOCH: 12710 LOSS: 41.00421722458673\n",
      "EPOCH: 12711 LOSS: 41.00421300198359\n",
      "EPOCH: 12712 LOSS: 41.00420877991233\n",
      "EPOCH: 12713 LOSS: 41.00420455837288\n",
      "EPOCH: 12714 LOSS: 41.00420033736511\n",
      "EPOCH: 12715 LOSS: 41.00419611688896\n",
      "EPOCH: 12716 LOSS: 41.004191896944334\n",
      "EPOCH: 12717 LOSS: 41.00418767753113\n",
      "EPOCH: 12718 LOSS: 41.004183458649244\n",
      "EPOCH: 12719 LOSS: 41.004179240298626\n",
      "EPOCH: 12720 LOSS: 41.00417502247913\n",
      "EPOCH: 12721 LOSS: 41.00417080519071\n",
      "EPOCH: 12722 LOSS: 41.00416658843324\n",
      "EPOCH: 12723 LOSS: 41.00416237220664\n",
      "EPOCH: 12724 LOSS: 41.00415815651084\n",
      "EPOCH: 12725 LOSS: 41.004153941345706\n",
      "EPOCH: 12726 LOSS: 41.00414972671116\n",
      "EPOCH: 12727 LOSS: 41.004145512607145\n",
      "EPOCH: 12728 LOSS: 41.004141299033535\n",
      "EPOCH: 12729 LOSS: 41.00413708599021\n",
      "EPOCH: 12730 LOSS: 41.00413287347714\n",
      "EPOCH: 12731 LOSS: 41.0041286614942\n",
      "EPOCH: 12732 LOSS: 41.0041244500413\n",
      "EPOCH: 12733 LOSS: 41.00412023911835\n",
      "EPOCH: 12734 LOSS: 41.00411602872525\n",
      "EPOCH: 12735 LOSS: 41.004111818861915\n",
      "EPOCH: 12736 LOSS: 41.00410760952826\n",
      "EPOCH: 12737 LOSS: 41.00410340072419\n",
      "EPOCH: 12738 LOSS: 41.0040991924496\n",
      "EPOCH: 12739 LOSS: 41.00409498470441\n",
      "EPOCH: 12740 LOSS: 41.00409077748853\n",
      "EPOCH: 12741 LOSS: 41.00408657080185\n",
      "EPOCH: 12742 LOSS: 41.004082364644326\n",
      "EPOCH: 12743 LOSS: 41.00407815901579\n",
      "EPOCH: 12744 LOSS: 41.00407395391622\n",
      "EPOCH: 12745 LOSS: 41.00406974934548\n",
      "EPOCH: 12746 LOSS: 41.004065545303504\n",
      "EPOCH: 12747 LOSS: 41.004061341790184\n",
      "EPOCH: 12748 LOSS: 41.00405713880542\n",
      "EPOCH: 12749 LOSS: 41.00405293634914\n",
      "EPOCH: 12750 LOSS: 41.00404873442127\n",
      "EPOCH: 12751 LOSS: 41.00404453302168\n",
      "EPOCH: 12752 LOSS: 41.004040332150296\n",
      "EPOCH: 12753 LOSS: 41.00403613180701\n",
      "EPOCH: 12754 LOSS: 41.00403193199176\n",
      "EPOCH: 12755 LOSS: 41.004027732704444\n",
      "EPOCH: 12756 LOSS: 41.004023533944945\n",
      "EPOCH: 12757 LOSS: 41.004019335713195\n",
      "EPOCH: 12758 LOSS: 41.00401513800911\n",
      "EPOCH: 12759 LOSS: 41.00401094083258\n",
      "EPOCH: 12760 LOSS: 41.00400674418352\n",
      "EPOCH: 12761 LOSS: 41.004002548061834\n",
      "EPOCH: 12762 LOSS: 41.00399835246744\n",
      "EPOCH: 12763 LOSS: 41.003994157400236\n",
      "EPOCH: 12764 LOSS: 41.00398996286014\n",
      "EPOCH: 12765 LOSS: 41.003985768847045\n",
      "EPOCH: 12766 LOSS: 41.003981575360896\n",
      "EPOCH: 12767 LOSS: 41.00397738240156\n",
      "EPOCH: 12768 LOSS: 41.003973189968946\n",
      "EPOCH: 12769 LOSS: 41.003968998063016\n",
      "EPOCH: 12770 LOSS: 41.00396480668362\n",
      "EPOCH: 12771 LOSS: 41.00396061583069\n",
      "EPOCH: 12772 LOSS: 41.00395642550413\n",
      "EPOCH: 12773 LOSS: 41.00395223570385\n",
      "EPOCH: 12774 LOSS: 41.003948046429755\n",
      "EPOCH: 12775 LOSS: 41.00394385768176\n",
      "EPOCH: 12776 LOSS: 41.00393966945978\n",
      "EPOCH: 12777 LOSS: 41.003935481763705\n",
      "EPOCH: 12778 LOSS: 41.00393129459347\n",
      "EPOCH: 12779 LOSS: 41.003927107948954\n",
      "EPOCH: 12780 LOSS: 41.003922921830096\n",
      "EPOCH: 12781 LOSS: 41.00391873623677\n",
      "EPOCH: 12782 LOSS: 41.003914551168904\n",
      "EPOCH: 12783 LOSS: 41.003910366626435\n",
      "EPOCH: 12784 LOSS: 41.003906182609214\n",
      "EPOCH: 12785 LOSS: 41.003901999117176\n",
      "EPOCH: 12786 LOSS: 41.00389781615025\n",
      "EPOCH: 12787 LOSS: 41.00389363370833\n",
      "EPOCH: 12788 LOSS: 41.0038894517913\n",
      "EPOCH: 12789 LOSS: 41.00388527039911\n",
      "EPOCH: 12790 LOSS: 41.00388108953166\n",
      "EPOCH: 12791 LOSS: 41.00387690918883\n",
      "EPOCH: 12792 LOSS: 41.003872729370556\n",
      "EPOCH: 12793 LOSS: 41.00386855007675\n",
      "EPOCH: 12794 LOSS: 41.0038643713073\n",
      "EPOCH: 12795 LOSS: 41.00386019306213\n",
      "EPOCH: 12796 LOSS: 41.00385601534114\n",
      "EPOCH: 12797 LOSS: 41.00385183814424\n",
      "EPOCH: 12798 LOSS: 41.003847661471355\n",
      "EPOCH: 12799 LOSS: 41.003843485322385\n",
      "EPOCH: 12800 LOSS: 41.00383930969722\n",
      "EPOCH: 12801 LOSS: 41.003835134595796\n",
      "EPOCH: 12802 LOSS: 41.00383096001802\n",
      "EPOCH: 12803 LOSS: 41.003826785963774\n",
      "EPOCH: 12804 LOSS: 41.003822612432984\n",
      "EPOCH: 12805 LOSS: 41.00381843942557\n",
      "EPOCH: 12806 LOSS: 41.00381426694145\n",
      "EPOCH: 12807 LOSS: 41.0038100949805\n",
      "EPOCH: 12808 LOSS: 41.003805923542636\n",
      "EPOCH: 12809 LOSS: 41.0038017526278\n",
      "EPOCH: 12810 LOSS: 41.00379758223587\n",
      "EPOCH: 12811 LOSS: 41.00379341236675\n",
      "EPOCH: 12812 LOSS: 41.00378924302037\n",
      "EPOCH: 12813 LOSS: 41.003785074196635\n",
      "EPOCH: 12814 LOSS: 41.00378090589545\n",
      "EPOCH: 12815 LOSS: 41.00377673811671\n",
      "EPOCH: 12816 LOSS: 41.00377257086036\n",
      "EPOCH: 12817 LOSS: 41.00376840412628\n",
      "EPOCH: 12818 LOSS: 41.00376423791441\n",
      "EPOCH: 12819 LOSS: 41.00376007222462\n",
      "EPOCH: 12820 LOSS: 41.00375590705684\n",
      "EPOCH: 12821 LOSS: 41.003751742410984\n",
      "EPOCH: 12822 LOSS: 41.00374757828695\n",
      "EPOCH: 12823 LOSS: 41.00374341468464\n",
      "EPOCH: 12824 LOSS: 41.00373925160399\n",
      "EPOCH: 12825 LOSS: 41.0037350890449\n",
      "EPOCH: 12826 LOSS: 41.003730927007275\n",
      "EPOCH: 12827 LOSS: 41.003726765491024\n",
      "EPOCH: 12828 LOSS: 41.00372260449605\n",
      "EPOCH: 12829 LOSS: 41.003718444022276\n",
      "EPOCH: 12830 LOSS: 41.0037142840696\n",
      "EPOCH: 12831 LOSS: 41.00371012463795\n",
      "EPOCH: 12832 LOSS: 41.00370596572722\n",
      "EPOCH: 12833 LOSS: 41.00370180733733\n",
      "EPOCH: 12834 LOSS: 41.00369764946817\n",
      "EPOCH: 12835 LOSS: 41.003693492119666\n",
      "EPOCH: 12836 LOSS: 41.003689335291725\n",
      "EPOCH: 12837 LOSS: 41.00368517898425\n",
      "EPOCH: 12838 LOSS: 41.003681023197174\n",
      "EPOCH: 12839 LOSS: 41.003676867930395\n",
      "EPOCH: 12840 LOSS: 41.003672713183796\n",
      "EPOCH: 12841 LOSS: 41.003668558957315\n",
      "EPOCH: 12842 LOSS: 41.00366440525086\n",
      "EPOCH: 12843 LOSS: 41.00366025206435\n",
      "EPOCH: 12844 LOSS: 41.00365609939766\n",
      "EPOCH: 12845 LOSS: 41.00365194725074\n",
      "EPOCH: 12846 LOSS: 41.00364779562347\n",
      "EPOCH: 12847 LOSS: 41.00364364451576\n",
      "EPOCH: 12848 LOSS: 41.003639493927565\n",
      "EPOCH: 12849 LOSS: 41.00363534385875\n",
      "EPOCH: 12850 LOSS: 41.00363119430921\n",
      "EPOCH: 12851 LOSS: 41.003627045278904\n",
      "EPOCH: 12852 LOSS: 41.00362289676772\n",
      "EPOCH: 12853 LOSS: 41.00361874877558\n",
      "EPOCH: 12854 LOSS: 41.003614601302374\n",
      "EPOCH: 12855 LOSS: 41.00361045434802\n",
      "EPOCH: 12856 LOSS: 41.00360630791241\n",
      "EPOCH: 12857 LOSS: 41.0036021619955\n",
      "EPOCH: 12858 LOSS: 41.00359801659716\n",
      "EPOCH: 12859 LOSS: 41.003593871717314\n",
      "EPOCH: 12860 LOSS: 41.00358972735587\n",
      "EPOCH: 12861 LOSS: 41.00358558351275\n",
      "EPOCH: 12862 LOSS: 41.003581440187844\n",
      "EPOCH: 12863 LOSS: 41.00357729738108\n",
      "EPOCH: 12864 LOSS: 41.003573155092354\n",
      "EPOCH: 12865 LOSS: 41.00356901332158\n",
      "EPOCH: 12866 LOSS: 41.003564872068694\n",
      "EPOCH: 12867 LOSS: 41.00356073133357\n",
      "EPOCH: 12868 LOSS: 41.00355659111612\n",
      "EPOCH: 12869 LOSS: 41.00355245141628\n",
      "EPOCH: 12870 LOSS: 41.003548312233946\n",
      "EPOCH: 12871 LOSS: 41.003544173569026\n",
      "EPOCH: 12872 LOSS: 41.00354003542144\n",
      "EPOCH: 12873 LOSS: 41.00353589779108\n",
      "EPOCH: 12874 LOSS: 41.00353176067788\n",
      "EPOCH: 12875 LOSS: 41.003527624081734\n",
      "EPOCH: 12876 LOSS: 41.003523488002564\n",
      "EPOCH: 12877 LOSS: 41.00351935244025\n",
      "EPOCH: 12878 LOSS: 41.003515217394764\n",
      "EPOCH: 12879 LOSS: 41.00351108286597\n",
      "EPOCH: 12880 LOSS: 41.00350694885377\n",
      "EPOCH: 12881 LOSS: 41.00350281535811\n",
      "EPOCH: 12882 LOSS: 41.00349868237889\n",
      "EPOCH: 12883 LOSS: 41.003494549916\n",
      "EPOCH: 12884 LOSS: 41.00349041796936\n",
      "EPOCH: 12885 LOSS: 41.0034862865389\n",
      "EPOCH: 12886 LOSS: 41.0034821556245\n",
      "EPOCH: 12887 LOSS: 41.00347802522609\n",
      "EPOCH: 12888 LOSS: 41.003473895343596\n",
      "EPOCH: 12889 LOSS: 41.00346976597689\n",
      "EPOCH: 12890 LOSS: 41.00346563712592\n",
      "EPOCH: 12891 LOSS: 41.003461508790565\n",
      "EPOCH: 12892 LOSS: 41.00345738097076\n",
      "EPOCH: 12893 LOSS: 41.0034532536664\n",
      "EPOCH: 12894 LOSS: 41.00344912687742\n",
      "EPOCH: 12895 LOSS: 41.003445000603705\n",
      "EPOCH: 12896 LOSS: 41.00344087484516\n",
      "EPOCH: 12897 LOSS: 41.00343674960172\n",
      "EPOCH: 12898 LOSS: 41.003432624873284\n",
      "EPOCH: 12899 LOSS: 41.003428500659766\n",
      "EPOCH: 12900 LOSS: 41.00342437696109\n",
      "EPOCH: 12901 LOSS: 41.003420253777136\n",
      "EPOCH: 12902 LOSS: 41.00341613110783\n",
      "EPOCH: 12903 LOSS: 41.00341200895309\n",
      "EPOCH: 12904 LOSS: 41.00340788731283\n",
      "EPOCH: 12905 LOSS: 41.00340376618694\n",
      "EPOCH: 12906 LOSS: 41.00339964557536\n",
      "EPOCH: 12907 LOSS: 41.00339552547797\n",
      "EPOCH: 12908 LOSS: 41.00339140589472\n",
      "EPOCH: 12909 LOSS: 41.00338728682547\n",
      "EPOCH: 12910 LOSS: 41.00338316827015\n",
      "EPOCH: 12911 LOSS: 41.00337905022872\n",
      "EPOCH: 12912 LOSS: 41.00337493270102\n",
      "EPOCH: 12913 LOSS: 41.003370815687006\n",
      "EPOCH: 12914 LOSS: 41.00336669918657\n",
      "EPOCH: 12915 LOSS: 41.003362583199625\n",
      "EPOCH: 12916 LOSS: 41.0033584677261\n",
      "EPOCH: 12917 LOSS: 41.00335435276588\n",
      "EPOCH: 12918 LOSS: 41.0033502383189\n",
      "EPOCH: 12919 LOSS: 41.00334612438505\n",
      "EPOCH: 12920 LOSS: 41.00334201096426\n",
      "EPOCH: 12921 LOSS: 41.003337898056415\n",
      "EPOCH: 12922 LOSS: 41.00333378566145\n",
      "EPOCH: 12923 LOSS: 41.00332967377928\n",
      "EPOCH: 12924 LOSS: 41.0033255624098\n",
      "EPOCH: 12925 LOSS: 41.00332145155292\n",
      "EPOCH: 12926 LOSS: 41.003317341208586\n",
      "EPOCH: 12927 LOSS: 41.00331323137665\n",
      "EPOCH: 12928 LOSS: 41.003309122057075\n",
      "EPOCH: 12929 LOSS: 41.003305013249765\n",
      "EPOCH: 12930 LOSS: 41.003300904954585\n",
      "EPOCH: 12931 LOSS: 41.00329679717152\n",
      "EPOCH: 12932 LOSS: 41.00329268990042\n",
      "EPOCH: 12933 LOSS: 41.00328858314122\n",
      "EPOCH: 12934 LOSS: 41.003284476893846\n",
      "EPOCH: 12935 LOSS: 41.00328037115818\n",
      "EPOCH: 12936 LOSS: 41.00327626593415\n",
      "EPOCH: 12937 LOSS: 41.003272161221666\n",
      "EPOCH: 12938 LOSS: 41.00326805702065\n",
      "EPOCH: 12939 LOSS: 41.003263953331\n",
      "EPOCH: 12940 LOSS: 41.00325985015262\n",
      "EPOCH: 12941 LOSS: 41.003255747485454\n",
      "EPOCH: 12942 LOSS: 41.00325164532937\n",
      "EPOCH: 12943 LOSS: 41.00324754368432\n",
      "EPOCH: 12944 LOSS: 41.003243442550186\n",
      "EPOCH: 12945 LOSS: 41.0032393419269\n",
      "EPOCH: 12946 LOSS: 41.003235241814366\n",
      "EPOCH: 12947 LOSS: 41.003231142212485\n",
      "EPOCH: 12948 LOSS: 41.003227043121186\n",
      "EPOCH: 12949 LOSS: 41.00322294454037\n",
      "EPOCH: 12950 LOSS: 41.003218846469956\n",
      "EPOCH: 12951 LOSS: 41.003214748909855\n",
      "EPOCH: 12952 LOSS: 41.00321065185997\n",
      "EPOCH: 12953 LOSS: 41.00320655532023\n",
      "EPOCH: 12954 LOSS: 41.00320245929052\n",
      "EPOCH: 12955 LOSS: 41.0031983637708\n",
      "EPOCH: 12956 LOSS: 41.00319426876093\n",
      "EPOCH: 12957 LOSS: 41.00319017426082\n",
      "EPOCH: 12958 LOSS: 41.00318608027044\n",
      "EPOCH: 12959 LOSS: 41.003181986789656\n",
      "EPOCH: 12960 LOSS: 41.00317789381839\n",
      "EPOCH: 12961 LOSS: 41.00317380135655\n",
      "EPOCH: 12962 LOSS: 41.00316970940405\n",
      "EPOCH: 12963 LOSS: 41.0031656179608\n",
      "EPOCH: 12964 LOSS: 41.003161527026734\n",
      "EPOCH: 12965 LOSS: 41.00315743660174\n",
      "EPOCH: 12966 LOSS: 41.003153346685735\n",
      "EPOCH: 12967 LOSS: 41.003149257278636\n",
      "EPOCH: 12968 LOSS: 41.00314516838035\n",
      "EPOCH: 12969 LOSS: 41.00314107999079\n",
      "EPOCH: 12970 LOSS: 41.00313699210986\n",
      "EPOCH: 12971 LOSS: 41.0031329047375\n",
      "EPOCH: 12972 LOSS: 41.003128817873595\n",
      "EPOCH: 12973 LOSS: 41.00312473151807\n",
      "EPOCH: 12974 LOSS: 41.003120645670826\n",
      "EPOCH: 12975 LOSS: 41.0031165603318\n",
      "EPOCH: 12976 LOSS: 41.003112475500856\n",
      "EPOCH: 12977 LOSS: 41.00310839117797\n",
      "EPOCH: 12978 LOSS: 41.003104307363\n",
      "EPOCH: 12979 LOSS: 41.0031002240559\n",
      "EPOCH: 12980 LOSS: 41.003096141256535\n",
      "EPOCH: 12981 LOSS: 41.003092058964874\n",
      "EPOCH: 12982 LOSS: 41.00308797718078\n",
      "EPOCH: 12983 LOSS: 41.00308389590421\n",
      "EPOCH: 12984 LOSS: 41.003079815135024\n",
      "EPOCH: 12985 LOSS: 41.00307573487318\n",
      "EPOCH: 12986 LOSS: 41.00307165511857\n",
      "EPOCH: 12987 LOSS: 41.00306757587111\n",
      "EPOCH: 12988 LOSS: 41.00306349713071\n",
      "EPOCH: 12989 LOSS: 41.00305941889728\n",
      "EPOCH: 12990 LOSS: 41.00305534117074\n",
      "EPOCH: 12991 LOSS: 41.003051263951\n",
      "EPOCH: 12992 LOSS: 41.003047187237975\n",
      "EPOCH: 12993 LOSS: 41.00304311103158\n",
      "EPOCH: 12994 LOSS: 41.003039035331724\n",
      "EPOCH: 12995 LOSS: 41.00303496013831\n",
      "EPOCH: 12996 LOSS: 41.00303088545126\n",
      "EPOCH: 12997 LOSS: 41.00302681127049\n",
      "EPOCH: 12998 LOSS: 41.0030227375959\n",
      "EPOCH: 12999 LOSS: 41.00301866442743\n",
      "EPOCH: 13000 LOSS: 41.00301459176495\n",
      "EPOCH: 13001 LOSS: 41.0030105196084\n",
      "EPOCH: 13002 LOSS: 41.0030064479577\n",
      "EPOCH: 13003 LOSS: 41.00300237681275\n",
      "EPOCH: 13004 LOSS: 41.00299830617347\n",
      "EPOCH: 13005 LOSS: 41.00299423603977\n",
      "EPOCH: 13006 LOSS: 41.002990166411536\n",
      "EPOCH: 13007 LOSS: 41.00298609728874\n",
      "EPOCH: 13008 LOSS: 41.002982028671234\n",
      "EPOCH: 13009 LOSS: 41.002977960558965\n",
      "EPOCH: 13010 LOSS: 41.00297389295184\n",
      "EPOCH: 13011 LOSS: 41.00296982584977\n",
      "EPOCH: 13012 LOSS: 41.00296575925266\n",
      "EPOCH: 13013 LOSS: 41.002961693160444\n",
      "EPOCH: 13014 LOSS: 41.00295762757301\n",
      "EPOCH: 13015 LOSS: 41.00295356249028\n",
      "EPOCH: 13016 LOSS: 41.00294949791219\n",
      "EPOCH: 13017 LOSS: 41.00294543383863\n",
      "EPOCH: 13018 LOSS: 41.0029413702695\n",
      "EPOCH: 13019 LOSS: 41.00293730720474\n",
      "EPOCH: 13020 LOSS: 41.00293324464425\n",
      "EPOCH: 13021 LOSS: 41.00292918258795\n",
      "EPOCH: 13022 LOSS: 41.00292512103573\n",
      "EPOCH: 13023 LOSS: 41.00292105998754\n",
      "EPOCH: 13024 LOSS: 41.00291699944327\n",
      "EPOCH: 13025 LOSS: 41.00291293940283\n",
      "EPOCH: 13026 LOSS: 41.002908879866155\n",
      "EPOCH: 13027 LOSS: 41.00290482083314\n",
      "EPOCH: 13028 LOSS: 41.002900762303696\n",
      "EPOCH: 13029 LOSS: 41.00289670427776\n",
      "EPOCH: 13030 LOSS: 41.002892646755214\n",
      "EPOCH: 13031 LOSS: 41.002888589735974\n",
      "EPOCH: 13032 LOSS: 41.00288453321997\n",
      "EPOCH: 13033 LOSS: 41.00288047720711\n",
      "EPOCH: 13034 LOSS: 41.00287642169734\n",
      "EPOCH: 13035 LOSS: 41.0028723666905\n",
      "EPOCH: 13036 LOSS: 41.00286831218655\n",
      "EPOCH: 13037 LOSS: 41.0028642581854\n",
      "EPOCH: 13038 LOSS: 41.00286020468697\n",
      "EPOCH: 13039 LOSS: 41.002856151691155\n",
      "EPOCH: 13040 LOSS: 41.00285209919787\n",
      "EPOCH: 13041 LOSS: 41.00284804720706\n",
      "EPOCH: 13042 LOSS: 41.00284399571861\n",
      "EPOCH: 13043 LOSS: 41.00283994473242\n",
      "EPOCH: 13044 LOSS: 41.002835894248435\n",
      "EPOCH: 13045 LOSS: 41.002831844266545\n",
      "EPOCH: 13046 LOSS: 41.002827794786675\n",
      "EPOCH: 13047 LOSS: 41.00282374580873\n",
      "EPOCH: 13048 LOSS: 41.00281969733265\n",
      "EPOCH: 13049 LOSS: 41.00281564935831\n",
      "EPOCH: 13050 LOSS: 41.00281160188566\n",
      "EPOCH: 13051 LOSS: 41.00280755491458\n",
      "EPOCH: 13052 LOSS: 41.00280350844501\n",
      "EPOCH: 13053 LOSS: 41.00279946247686\n",
      "EPOCH: 13054 LOSS: 41.00279541701002\n",
      "EPOCH: 13055 LOSS: 41.00279137204444\n",
      "EPOCH: 13056 LOSS: 41.002787327579995\n",
      "EPOCH: 13057 LOSS: 41.00278328361663\n",
      "EPOCH: 13058 LOSS: 41.002779240154254\n",
      "EPOCH: 13059 LOSS: 41.002775197192754\n",
      "EPOCH: 13060 LOSS: 41.00277115473208\n",
      "EPOCH: 13061 LOSS: 41.00276711277212\n",
      "EPOCH: 13062 LOSS: 41.002763071312806\n",
      "EPOCH: 13063 LOSS: 41.00275903035403\n",
      "EPOCH: 13064 LOSS: 41.00275498989572\n",
      "EPOCH: 13065 LOSS: 41.00275094993779\n",
      "EPOCH: 13066 LOSS: 41.00274691048017\n",
      "EPOCH: 13067 LOSS: 41.00274287152274\n",
      "EPOCH: 13068 LOSS: 41.002738833065436\n",
      "EPOCH: 13069 LOSS: 41.00273479510816\n",
      "EPOCH: 13070 LOSS: 41.00273075765082\n",
      "EPOCH: 13071 LOSS: 41.00272672069337\n",
      "EPOCH: 13072 LOSS: 41.00272268423568\n",
      "EPOCH: 13073 LOSS: 41.00271864827768\n",
      "EPOCH: 13074 LOSS: 41.002714612819304\n",
      "EPOCH: 13075 LOSS: 41.00271057786043\n",
      "EPOCH: 13076 LOSS: 41.002706543400976\n",
      "EPOCH: 13077 LOSS: 41.00270250944089\n",
      "EPOCH: 13078 LOSS: 41.00269847598006\n",
      "EPOCH: 13079 LOSS: 41.002694443018385\n",
      "EPOCH: 13080 LOSS: 41.002690410555815\n",
      "EPOCH: 13081 LOSS: 41.002686378592244\n",
      "EPOCH: 13082 LOSS: 41.0026823471276\n",
      "EPOCH: 13083 LOSS: 41.00267831616178\n",
      "EPOCH: 13084 LOSS: 41.002674285694695\n",
      "EPOCH: 13085 LOSS: 41.00267025572629\n",
      "EPOCH: 13086 LOSS: 41.00266622625644\n",
      "EPOCH: 13087 LOSS: 41.00266219728509\n",
      "EPOCH: 13088 LOSS: 41.00265816881213\n",
      "EPOCH: 13089 LOSS: 41.00265414083749\n",
      "EPOCH: 13090 LOSS: 41.002650113361085\n",
      "EPOCH: 13091 LOSS: 41.002646086382825\n",
      "EPOCH: 13092 LOSS: 41.00264205990262\n",
      "EPOCH: 13093 LOSS: 41.00263803392039\n",
      "EPOCH: 13094 LOSS: 41.00263400843605\n",
      "EPOCH: 13095 LOSS: 41.002629983449516\n",
      "EPOCH: 13096 LOSS: 41.00262595896069\n",
      "EPOCH: 13097 LOSS: 41.002621934969504\n",
      "EPOCH: 13098 LOSS: 41.00261791147586\n",
      "EPOCH: 13099 LOSS: 41.00261388847967\n",
      "EPOCH: 13100 LOSS: 41.00260986598086\n",
      "EPOCH: 13101 LOSS: 41.002605843979346\n",
      "EPOCH: 13102 LOSS: 41.00260182247502\n",
      "EPOCH: 13103 LOSS: 41.00259780146783\n",
      "EPOCH: 13104 LOSS: 41.00259378095766\n",
      "EPOCH: 13105 LOSS: 41.00258976094443\n",
      "EPOCH: 13106 LOSS: 41.00258574142808\n",
      "EPOCH: 13107 LOSS: 41.002581722408486\n",
      "EPOCH: 13108 LOSS: 41.00257770388559\n",
      "EPOCH: 13109 LOSS: 41.00257368585931\n",
      "EPOCH: 13110 LOSS: 41.00256966832954\n",
      "EPOCH: 13111 LOSS: 41.00256565129621\n",
      "EPOCH: 13112 LOSS: 41.00256163475923\n",
      "EPOCH: 13113 LOSS: 41.0025576187185\n",
      "EPOCH: 13114 LOSS: 41.002553603173965\n",
      "EPOCH: 13115 LOSS: 41.002549588125504\n",
      "EPOCH: 13116 LOSS: 41.00254557357307\n",
      "EPOCH: 13117 LOSS: 41.00254155951655\n",
      "EPOCH: 13118 LOSS: 41.002537545955875\n",
      "EPOCH: 13119 LOSS: 41.00253353289095\n",
      "EPOCH: 13120 LOSS: 41.00252952032169\n",
      "EPOCH: 13121 LOSS: 41.002525508248\n",
      "EPOCH: 13122 LOSS: 41.00252149666982\n",
      "EPOCH: 13123 LOSS: 41.00251748558706\n",
      "EPOCH: 13124 LOSS: 41.0025134749996\n",
      "EPOCH: 13125 LOSS: 41.0025094649074\n",
      "EPOCH: 13126 LOSS: 41.002505455310356\n",
      "EPOCH: 13127 LOSS: 41.002501446208385\n",
      "EPOCH: 13128 LOSS: 41.0024974376014\n",
      "EPOCH: 13129 LOSS: 41.0024934294893\n",
      "EPOCH: 13130 LOSS: 41.00248942187204\n",
      "EPOCH: 13131 LOSS: 41.0024854147495\n",
      "EPOCH: 13132 LOSS: 41.0024814081216\n",
      "EPOCH: 13133 LOSS: 41.00247740198825\n",
      "EPOCH: 13134 LOSS: 41.0024733963494\n",
      "EPOCH: 13135 LOSS: 41.00246939120494\n",
      "EPOCH: 13136 LOSS: 41.00246538655477\n",
      "EPOCH: 13137 LOSS: 41.00246138239883\n",
      "EPOCH: 13138 LOSS: 41.002457378737034\n",
      "EPOCH: 13139 LOSS: 41.002453375569274\n",
      "EPOCH: 13140 LOSS: 41.0024493728955\n",
      "EPOCH: 13141 LOSS: 41.002445370715606\n",
      "EPOCH: 13142 LOSS: 41.00244136902948\n",
      "EPOCH: 13143 LOSS: 41.002437367837096\n",
      "EPOCH: 13144 LOSS: 41.00243336713833\n",
      "EPOCH: 13145 LOSS: 41.0024293669331\n",
      "EPOCH: 13146 LOSS: 41.002425367221335\n",
      "EPOCH: 13147 LOSS: 41.00242136800294\n",
      "EPOCH: 13148 LOSS: 41.002417369277836\n",
      "EPOCH: 13149 LOSS: 41.00241337104593\n",
      "EPOCH: 13150 LOSS: 41.00240937330714\n",
      "EPOCH: 13151 LOSS: 41.0024053760614\n",
      "EPOCH: 13152 LOSS: 41.00240137930859\n",
      "EPOCH: 13153 LOSS: 41.00239738304865\n",
      "EPOCH: 13154 LOSS: 41.00239338728151\n",
      "EPOCH: 13155 LOSS: 41.002389392007046\n",
      "EPOCH: 13156 LOSS: 41.0023853972252\n",
      "EPOCH: 13157 LOSS: 41.00238140293587\n",
      "EPOCH: 13158 LOSS: 41.00237740913899\n",
      "EPOCH: 13159 LOSS: 41.00237341583447\n",
      "EPOCH: 13160 LOSS: 41.002369423022216\n",
      "EPOCH: 13161 LOSS: 41.00236543070215\n",
      "EPOCH: 13162 LOSS: 41.002361438874196\n",
      "EPOCH: 13163 LOSS: 41.00235744753825\n",
      "EPOCH: 13164 LOSS: 41.00235345669425\n",
      "EPOCH: 13165 LOSS: 41.002349466342096\n",
      "EPOCH: 13166 LOSS: 41.00234547648172\n",
      "EPOCH: 13167 LOSS: 41.002341487113\n",
      "EPOCH: 13168 LOSS: 41.0023374982359\n",
      "EPOCH: 13169 LOSS: 41.0023335098503\n",
      "EPOCH: 13170 LOSS: 41.00232952195614\n",
      "EPOCH: 13171 LOSS: 41.00232553455331\n",
      "EPOCH: 13172 LOSS: 41.002321547641735\n",
      "EPOCH: 13173 LOSS: 41.002317561221346\n",
      "EPOCH: 13174 LOSS: 41.00231357529206\n",
      "EPOCH: 13175 LOSS: 41.00230958985375\n",
      "EPOCH: 13176 LOSS: 41.0023056049064\n",
      "EPOCH: 13177 LOSS: 41.002301620449856\n",
      "EPOCH: 13178 LOSS: 41.0022976364841\n",
      "EPOCH: 13179 LOSS: 41.002293653009\n",
      "EPOCH: 13180 LOSS: 41.00228967002448\n",
      "EPOCH: 13181 LOSS: 41.002285687530446\n",
      "EPOCH: 13182 LOSS: 41.00228170552686\n",
      "EPOCH: 13183 LOSS: 41.00227772401358\n",
      "EPOCH: 13184 LOSS: 41.00227374299056\n",
      "EPOCH: 13185 LOSS: 41.002269762457715\n",
      "EPOCH: 13186 LOSS: 41.00226578241493\n",
      "EPOCH: 13187 LOSS: 41.00226180286217\n",
      "EPOCH: 13188 LOSS: 41.0022578237993\n",
      "EPOCH: 13189 LOSS: 41.002253845226264\n",
      "EPOCH: 13190 LOSS: 41.00224986714298\n",
      "EPOCH: 13191 LOSS: 41.00224588954935\n",
      "EPOCH: 13192 LOSS: 41.002241912445285\n",
      "EPOCH: 13193 LOSS: 41.00223793583074\n",
      "EPOCH: 13194 LOSS: 41.00223395970558\n",
      "EPOCH: 13195 LOSS: 41.00222998406976\n",
      "EPOCH: 13196 LOSS: 41.002226008923174\n",
      "EPOCH: 13197 LOSS: 41.002222034265756\n",
      "EPOCH: 13198 LOSS: 41.00221806009739\n",
      "EPOCH: 13199 LOSS: 41.002214086418036\n",
      "EPOCH: 13200 LOSS: 41.00221011322756\n",
      "EPOCH: 13201 LOSS: 41.002206140525935\n",
      "EPOCH: 13202 LOSS: 41.00220216831302\n",
      "EPOCH: 13203 LOSS: 41.00219819658878\n",
      "EPOCH: 13204 LOSS: 41.00219422535311\n",
      "EPOCH: 13205 LOSS: 41.00219025460591\n",
      "EPOCH: 13206 LOSS: 41.00218628434711\n",
      "EPOCH: 13207 LOSS: 41.00218231457665\n",
      "EPOCH: 13208 LOSS: 41.002178345294425\n",
      "EPOCH: 13209 LOSS: 41.002174376500335\n",
      "EPOCH: 13210 LOSS: 41.00217040819433\n",
      "EPOCH: 13211 LOSS: 41.002166440376286\n",
      "EPOCH: 13212 LOSS: 41.00216247304617\n",
      "EPOCH: 13213 LOSS: 41.00215850620385\n",
      "EPOCH: 13214 LOSS: 41.00215453984926\n",
      "EPOCH: 13215 LOSS: 41.00215057398232\n",
      "EPOCH: 13216 LOSS: 41.002146608602956\n",
      "EPOCH: 13217 LOSS: 41.00214264371108\n",
      "EPOCH: 13218 LOSS: 41.00213867930659\n",
      "EPOCH: 13219 LOSS: 41.00213471538943\n",
      "EPOCH: 13220 LOSS: 41.002130751959484\n",
      "EPOCH: 13221 LOSS: 41.00212678901669\n",
      "EPOCH: 13222 LOSS: 41.00212282656098\n",
      "EPOCH: 13223 LOSS: 41.002118864592234\n",
      "EPOCH: 13224 LOSS: 41.00211490311038\n",
      "EPOCH: 13225 LOSS: 41.002110942115344\n",
      "EPOCH: 13226 LOSS: 41.00210698160706\n",
      "EPOCH: 13227 LOSS: 41.00210302158539\n",
      "EPOCH: 13228 LOSS: 41.00209906205029\n",
      "EPOCH: 13229 LOSS: 41.00209510300169\n",
      "EPOCH: 13230 LOSS: 41.002091144439476\n",
      "EPOCH: 13231 LOSS: 41.002087186363575\n",
      "EPOCH: 13232 LOSS: 41.0020832287739\n",
      "EPOCH: 13233 LOSS: 41.00207927167038\n",
      "EPOCH: 13234 LOSS: 41.00207531505293\n",
      "EPOCH: 13235 LOSS: 41.002071358921455\n",
      "EPOCH: 13236 LOSS: 41.00206740327587\n",
      "EPOCH: 13237 LOSS: 41.002063448116104\n",
      "EPOCH: 13238 LOSS: 41.002059493442076\n",
      "EPOCH: 13239 LOSS: 41.00205553925369\n",
      "EPOCH: 13240 LOSS: 41.00205158555087\n",
      "EPOCH: 13241 LOSS: 41.00204763233352\n",
      "EPOCH: 13242 LOSS: 41.002043679601584\n",
      "EPOCH: 13243 LOSS: 41.00203972735496\n",
      "EPOCH: 13244 LOSS: 41.002035775593555\n",
      "EPOCH: 13245 LOSS: 41.002031824317314\n",
      "EPOCH: 13246 LOSS: 41.00202787352614\n",
      "EPOCH: 13247 LOSS: 41.00202392321994\n",
      "EPOCH: 13248 LOSS: 41.002019973398646\n",
      "EPOCH: 13249 LOSS: 41.002016024062165\n",
      "EPOCH: 13250 LOSS: 41.002012075210416\n",
      "EPOCH: 13251 LOSS: 41.00200812684331\n",
      "EPOCH: 13252 LOSS: 41.002004178960775\n",
      "EPOCH: 13253 LOSS: 41.00200023156273\n",
      "EPOCH: 13254 LOSS: 41.00199628464908\n",
      "EPOCH: 13255 LOSS: 41.00199233821975\n",
      "EPOCH: 13256 LOSS: 41.00198839227468\n",
      "EPOCH: 13257 LOSS: 41.00198444681372\n",
      "EPOCH: 13258 LOSS: 41.00198050183686\n",
      "EPOCH: 13259 LOSS: 41.00197655734397\n",
      "EPOCH: 13260 LOSS: 41.00197261333499\n",
      "EPOCH: 13261 LOSS: 41.00196866980984\n",
      "EPOCH: 13262 LOSS: 41.001964726768406\n",
      "EPOCH: 13263 LOSS: 41.00196078421065\n",
      "EPOCH: 13264 LOSS: 41.00195684213648\n",
      "EPOCH: 13265 LOSS: 41.00195290054576\n",
      "EPOCH: 13266 LOSS: 41.00194895943848\n",
      "EPOCH: 13267 LOSS: 41.0019450188145\n",
      "EPOCH: 13268 LOSS: 41.00194107867378\n",
      "EPOCH: 13269 LOSS: 41.001937139016206\n",
      "EPOCH: 13270 LOSS: 41.001933199841716\n",
      "EPOCH: 13271 LOSS: 41.00192926115022\n",
      "EPOCH: 13272 LOSS: 41.001925322941645\n",
      "EPOCH: 13273 LOSS: 41.00192138521587\n",
      "EPOCH: 13274 LOSS: 41.00191744797286\n",
      "EPOCH: 13275 LOSS: 41.00191351121251\n",
      "EPOCH: 13276 LOSS: 41.00190957493474\n",
      "EPOCH: 13277 LOSS: 41.00190563913947\n",
      "EPOCH: 13278 LOSS: 41.001901703826604\n",
      "EPOCH: 13279 LOSS: 41.00189776899607\n",
      "EPOCH: 13280 LOSS: 41.0018938346478\n",
      "EPOCH: 13281 LOSS: 41.001889900781705\n",
      "EPOCH: 13282 LOSS: 41.00188596739767\n",
      "EPOCH: 13283 LOSS: 41.00188203449565\n",
      "EPOCH: 13284 LOSS: 41.00187810207555\n",
      "EPOCH: 13285 LOSS: 41.001874170137285\n",
      "EPOCH: 13286 LOSS: 41.00187023868078\n",
      "EPOCH: 13287 LOSS: 41.001866307705946\n",
      "EPOCH: 13288 LOSS: 41.00186237721269\n",
      "EPOCH: 13289 LOSS: 41.001858447200966\n",
      "EPOCH: 13290 LOSS: 41.00185451767065\n",
      "EPOCH: 13291 LOSS: 41.00185058862169\n",
      "EPOCH: 13292 LOSS: 41.00184666005398\n",
      "EPOCH: 13293 LOSS: 41.00184273196744\n",
      "EPOCH: 13294 LOSS: 41.00183880436201\n",
      "EPOCH: 13295 LOSS: 41.001834877237584\n",
      "EPOCH: 13296 LOSS: 41.00183095059411\n",
      "EPOCH: 13297 LOSS: 41.00182702443146\n",
      "EPOCH: 13298 LOSS: 41.001823098749604\n",
      "EPOCH: 13299 LOSS: 41.001819173548405\n",
      "EPOCH: 13300 LOSS: 41.00181524882782\n",
      "EPOCH: 13301 LOSS: 41.001811324587756\n",
      "EPOCH: 13302 LOSS: 41.00180740082814\n",
      "EPOCH: 13303 LOSS: 41.00180347754887\n",
      "EPOCH: 13304 LOSS: 41.00179955474987\n",
      "EPOCH: 13305 LOSS: 41.00179563243107\n",
      "EPOCH: 13306 LOSS: 41.00179171059237\n",
      "EPOCH: 13307 LOSS: 41.0017877892337\n",
      "EPOCH: 13308 LOSS: 41.00178386835498\n",
      "EPOCH: 13309 LOSS: 41.00177994795613\n",
      "EPOCH: 13310 LOSS: 41.00177602803706\n",
      "EPOCH: 13311 LOSS: 41.00177210859768\n",
      "EPOCH: 13312 LOSS: 41.00176818963792\n",
      "EPOCH: 13313 LOSS: 41.00176427115769\n",
      "EPOCH: 13314 LOSS: 41.00176035315692\n",
      "EPOCH: 13315 LOSS: 41.00175643563553\n",
      "EPOCH: 13316 LOSS: 41.001752518593406\n",
      "EPOCH: 13317 LOSS: 41.00174860203052\n",
      "EPOCH: 13318 LOSS: 41.00174468594673\n",
      "EPOCH: 13319 LOSS: 41.00174077034198\n",
      "EPOCH: 13320 LOSS: 41.00173685521624\n",
      "EPOCH: 13321 LOSS: 41.00173294056934\n",
      "EPOCH: 13322 LOSS: 41.001729026401236\n",
      "EPOCH: 13323 LOSS: 41.00172511271185\n",
      "EPOCH: 13324 LOSS: 41.001721199501105\n",
      "EPOCH: 13325 LOSS: 41.00171728676892\n",
      "EPOCH: 13326 LOSS: 41.00171337451519\n",
      "EPOCH: 13327 LOSS: 41.001709462739875\n",
      "EPOCH: 13328 LOSS: 41.00170555144284\n",
      "EPOCH: 13329 LOSS: 41.001701640624034\n",
      "EPOCH: 13330 LOSS: 41.001697730283375\n",
      "EPOCH: 13331 LOSS: 41.00169382042079\n",
      "EPOCH: 13332 LOSS: 41.001689911036166\n",
      "EPOCH: 13333 LOSS: 41.001686002129446\n",
      "EPOCH: 13334 LOSS: 41.00168209370056\n",
      "EPOCH: 13335 LOSS: 41.001678185749384\n",
      "EPOCH: 13336 LOSS: 41.001674278275885\n",
      "EPOCH: 13337 LOSS: 41.00167037127994\n",
      "EPOCH: 13338 LOSS: 41.0016664647615\n",
      "EPOCH: 13339 LOSS: 41.001662558720454\n",
      "EPOCH: 13340 LOSS: 41.00165865315674\n",
      "EPOCH: 13341 LOSS: 41.001654748070266\n",
      "EPOCH: 13342 LOSS: 41.00165084346097\n",
      "EPOCH: 13343 LOSS: 41.001646939328744\n",
      "EPOCH: 13344 LOSS: 41.001643035673524\n",
      "EPOCH: 13345 LOSS: 41.00163913249523\n",
      "EPOCH: 13346 LOSS: 41.00163522979376\n",
      "EPOCH: 13347 LOSS: 41.00163132756906\n",
      "EPOCH: 13348 LOSS: 41.00162742582103\n",
      "EPOCH: 13349 LOSS: 41.0016235245496\n",
      "EPOCH: 13350 LOSS: 41.00161962375467\n",
      "EPOCH: 13351 LOSS: 41.001615723436174\n",
      "EPOCH: 13352 LOSS: 41.00161182359403\n",
      "EPOCH: 13353 LOSS: 41.00160792422815\n",
      "EPOCH: 13354 LOSS: 41.001604025338466\n",
      "EPOCH: 13355 LOSS: 41.00160012692489\n",
      "EPOCH: 13356 LOSS: 41.001596228987324\n",
      "EPOCH: 13357 LOSS: 41.001592331525714\n",
      "EPOCH: 13358 LOSS: 41.001588434539954\n",
      "EPOCH: 13359 LOSS: 41.00158453802998\n",
      "EPOCH: 13360 LOSS: 41.0015806419957\n",
      "EPOCH: 13361 LOSS: 41.00157674643705\n",
      "EPOCH: 13362 LOSS: 41.00157285135392\n",
      "EPOCH: 13363 LOSS: 41.001568956746254\n",
      "EPOCH: 13364 LOSS: 41.00156506261396\n",
      "EPOCH: 13365 LOSS: 41.001561168956975\n",
      "EPOCH: 13366 LOSS: 41.001557275775184\n",
      "EPOCH: 13367 LOSS: 41.00155338306854\n",
      "EPOCH: 13368 LOSS: 41.00154949083692\n",
      "EPOCH: 13369 LOSS: 41.0015455990803\n",
      "EPOCH: 13370 LOSS: 41.00154170779855\n",
      "EPOCH: 13371 LOSS: 41.00153781699161\n",
      "EPOCH: 13372 LOSS: 41.00153392665938\n",
      "EPOCH: 13373 LOSS: 41.00153003680181\n",
      "EPOCH: 13374 LOSS: 41.001526147418794\n",
      "EPOCH: 13375 LOSS: 41.00152225851025\n",
      "EPOCH: 13376 LOSS: 41.001518370076134\n",
      "EPOCH: 13377 LOSS: 41.001514482116335\n",
      "EPOCH: 13378 LOSS: 41.00151059463077\n",
      "EPOCH: 13379 LOSS: 41.001506707619356\n",
      "EPOCH: 13380 LOSS: 41.00150282108203\n",
      "EPOCH: 13381 LOSS: 41.00149893501869\n",
      "EPOCH: 13382 LOSS: 41.00149504942928\n",
      "EPOCH: 13383 LOSS: 41.00149116431369\n",
      "EPOCH: 13384 LOSS: 41.00148727967186\n",
      "EPOCH: 13385 LOSS: 41.0014833955037\n",
      "EPOCH: 13386 LOSS: 41.00147951180914\n",
      "EPOCH: 13387 LOSS: 41.00147562858809\n",
      "EPOCH: 13388 LOSS: 41.00147174584047\n",
      "EPOCH: 13389 LOSS: 41.00146786356619\n",
      "EPOCH: 13390 LOSS: 41.001463981765184\n",
      "EPOCH: 13391 LOSS: 41.001460100437356\n",
      "EPOCH: 13392 LOSS: 41.00145621958265\n",
      "EPOCH: 13393 LOSS: 41.001452339200966\n",
      "EPOCH: 13394 LOSS: 41.001448459292234\n",
      "EPOCH: 13395 LOSS: 41.001444579856354\n",
      "EPOCH: 13396 LOSS: 41.00144070089328\n",
      "EPOCH: 13397 LOSS: 41.00143682240291\n",
      "EPOCH: 13398 LOSS: 41.00143294438515\n",
      "EPOCH: 13399 LOSS: 41.00142906683993\n",
      "EPOCH: 13400 LOSS: 41.001425189767176\n",
      "EPOCH: 13401 LOSS: 41.001421313166794\n",
      "EPOCH: 13402 LOSS: 41.001417437038725\n",
      "EPOCH: 13403 LOSS: 41.001413561382876\n",
      "EPOCH: 13404 LOSS: 41.00140968619918\n",
      "EPOCH: 13405 LOSS: 41.00140581148753\n",
      "EPOCH: 13406 LOSS: 41.00140193724784\n",
      "EPOCH: 13407 LOSS: 41.001398063480075\n",
      "EPOCH: 13408 LOSS: 41.001394190184115\n",
      "EPOCH: 13409 LOSS: 41.0013903173599\n",
      "EPOCH: 13410 LOSS: 41.00138644500734\n",
      "EPOCH: 13411 LOSS: 41.00138257312634\n",
      "EPOCH: 13412 LOSS: 41.001378701716845\n",
      "EPOCH: 13413 LOSS: 41.0013748307788\n",
      "EPOCH: 13414 LOSS: 41.001370960312045\n",
      "EPOCH: 13415 LOSS: 41.00136709031655\n",
      "EPOCH: 13416 LOSS: 41.00136322079226\n",
      "EPOCH: 13417 LOSS: 41.001359351739026\n",
      "EPOCH: 13418 LOSS: 41.001355483156836\n",
      "EPOCH: 13419 LOSS: 41.001351615045564\n",
      "EPOCH: 13420 LOSS: 41.00134774740515\n",
      "EPOCH: 13421 LOSS: 41.00134388023551\n",
      "EPOCH: 13422 LOSS: 41.00134001353656\n",
      "EPOCH: 13423 LOSS: 41.001336147308216\n",
      "EPOCH: 13424 LOSS: 41.001332281550404\n",
      "EPOCH: 13425 LOSS: 41.001328416263064\n",
      "EPOCH: 13426 LOSS: 41.0013245514461\n",
      "EPOCH: 13427 LOSS: 41.0013206870994\n",
      "EPOCH: 13428 LOSS: 41.001316823222915\n",
      "EPOCH: 13429 LOSS: 41.001312959816566\n",
      "EPOCH: 13430 LOSS: 41.00130909688028\n",
      "EPOCH: 13431 LOSS: 41.001305234413955\n",
      "EPOCH: 13432 LOSS: 41.001301372417515\n",
      "EPOCH: 13433 LOSS: 41.001297510890886\n",
      "EPOCH: 13434 LOSS: 41.001293649834\n",
      "EPOCH: 13435 LOSS: 41.001289789246755\n",
      "EPOCH: 13436 LOSS: 41.00128592912908\n",
      "EPOCH: 13437 LOSS: 41.0012820694809\n",
      "EPOCH: 13438 LOSS: 41.00127821030213\n",
      "EPOCH: 13439 LOSS: 41.0012743515927\n",
      "EPOCH: 13440 LOSS: 41.00127049335249\n",
      "EPOCH: 13441 LOSS: 41.00126663558148\n",
      "EPOCH: 13442 LOSS: 41.00126277827955\n",
      "EPOCH: 13443 LOSS: 41.001258921446635\n",
      "EPOCH: 13444 LOSS: 41.00125506508266\n",
      "EPOCH: 13445 LOSS: 41.00125120918752\n",
      "EPOCH: 13446 LOSS: 41.00124735376115\n",
      "EPOCH: 13447 LOSS: 41.001243498803476\n",
      "EPOCH: 13448 LOSS: 41.001239644314424\n",
      "EPOCH: 13449 LOSS: 41.00123579029388\n",
      "EPOCH: 13450 LOSS: 41.0012319367418\n",
      "EPOCH: 13451 LOSS: 41.001228083658106\n",
      "EPOCH: 13452 LOSS: 41.00122423104267\n",
      "EPOCH: 13453 LOSS: 41.00122037889548\n",
      "EPOCH: 13454 LOSS: 41.001216527216414\n",
      "EPOCH: 13455 LOSS: 41.00121267600539\n",
      "EPOCH: 13456 LOSS: 41.00120882526234\n",
      "EPOCH: 13457 LOSS: 41.0012049749872\n",
      "EPOCH: 13458 LOSS: 41.00120112517985\n",
      "EPOCH: 13459 LOSS: 41.00119727584026\n",
      "EPOCH: 13460 LOSS: 41.0011934269683\n",
      "EPOCH: 13461 LOSS: 41.00118957856393\n",
      "EPOCH: 13462 LOSS: 41.00118573062704\n",
      "EPOCH: 13463 LOSS: 41.00118188315758\n",
      "EPOCH: 13464 LOSS: 41.00117803615544\n",
      "EPOCH: 13465 LOSS: 41.00117418962057\n",
      "EPOCH: 13466 LOSS: 41.00117034355288\n",
      "EPOCH: 13467 LOSS: 41.00116649795227\n",
      "EPOCH: 13468 LOSS: 41.0011626528187\n",
      "EPOCH: 13469 LOSS: 41.00115880815204\n",
      "EPOCH: 13470 LOSS: 41.00115496395226\n",
      "EPOCH: 13471 LOSS: 41.00115112021926\n",
      "EPOCH: 13472 LOSS: 41.001147276952956\n",
      "EPOCH: 13473 LOSS: 41.00114343415326\n",
      "EPOCH: 13474 LOSS: 41.00113959182012\n",
      "EPOCH: 13475 LOSS: 41.001135749953406\n",
      "EPOCH: 13476 LOSS: 41.0011319085531\n",
      "EPOCH: 13477 LOSS: 41.00112806761911\n",
      "EPOCH: 13478 LOSS: 41.00112422715132\n",
      "EPOCH: 13479 LOSS: 41.0011203871497\n",
      "EPOCH: 13480 LOSS: 41.00111654761412\n",
      "EPOCH: 13481 LOSS: 41.00111270854453\n",
      "EPOCH: 13482 LOSS: 41.001108869940836\n",
      "EPOCH: 13483 LOSS: 41.001105031802986\n",
      "EPOCH: 13484 LOSS: 41.00110119413089\n",
      "EPOCH: 13485 LOSS: 41.00109735692443\n",
      "EPOCH: 13486 LOSS: 41.001093520183595\n",
      "EPOCH: 13487 LOSS: 41.00108968390824\n",
      "EPOCH: 13488 LOSS: 41.00108584809831\n",
      "EPOCH: 13489 LOSS: 41.001082012753756\n",
      "EPOCH: 13490 LOSS: 41.00107817787445\n",
      "EPOCH: 13491 LOSS: 41.00107434346035\n",
      "EPOCH: 13492 LOSS: 41.00107050951138\n",
      "EPOCH: 13493 LOSS: 41.00106667602742\n",
      "EPOCH: 13494 LOSS: 41.00106284300841\n",
      "EPOCH: 13495 LOSS: 41.0010590104543\n",
      "EPOCH: 13496 LOSS: 41.00105517836497\n",
      "EPOCH: 13497 LOSS: 41.001051346740354\n",
      "EPOCH: 13498 LOSS: 41.00104751558039\n",
      "EPOCH: 13499 LOSS: 41.00104368488498\n",
      "EPOCH: 13500 LOSS: 41.00103985465404\n",
      "EPOCH: 13501 LOSS: 41.00103602488751\n",
      "EPOCH: 13502 LOSS: 41.0010321955853\n",
      "EPOCH: 13503 LOSS: 41.00102836674732\n",
      "EPOCH: 13504 LOSS: 41.00102453837352\n",
      "EPOCH: 13505 LOSS: 41.001020710463806\n",
      "EPOCH: 13506 LOSS: 41.001016883018096\n",
      "EPOCH: 13507 LOSS: 41.00101305603631\n",
      "EPOCH: 13508 LOSS: 41.00100922951838\n",
      "EPOCH: 13509 LOSS: 41.001005403464205\n",
      "EPOCH: 13510 LOSS: 41.00100157787372\n",
      "EPOCH: 13511 LOSS: 41.00099775274687\n",
      "EPOCH: 13512 LOSS: 41.00099392808354\n",
      "EPOCH: 13513 LOSS: 41.000990103883666\n",
      "EPOCH: 13514 LOSS: 41.00098628014716\n",
      "EPOCH: 13515 LOSS: 41.000982456873956\n",
      "EPOCH: 13516 LOSS: 41.00097863406397\n",
      "EPOCH: 13517 LOSS: 41.00097481171712\n",
      "EPOCH: 13518 LOSS: 41.00097098983332\n",
      "EPOCH: 13519 LOSS: 41.00096716841252\n",
      "EPOCH: 13520 LOSS: 41.000963347454615\n",
      "EPOCH: 13521 LOSS: 41.000959526959534\n",
      "EPOCH: 13522 LOSS: 41.00095570692719\n",
      "EPOCH: 13523 LOSS: 41.00095188735753\n",
      "EPOCH: 13524 LOSS: 41.00094806825044\n",
      "EPOCH: 13525 LOSS: 41.000944249605865\n",
      "EPOCH: 13526 LOSS: 41.00094043142373\n",
      "EPOCH: 13527 LOSS: 41.00093661370393\n",
      "EPOCH: 13528 LOSS: 41.00093279644641\n",
      "EPOCH: 13529 LOSS: 41.0009289796511\n",
      "EPOCH: 13530 LOSS: 41.00092516331788\n",
      "EPOCH: 13531 LOSS: 41.00092134744672\n",
      "EPOCH: 13532 LOSS: 41.000917532037505\n",
      "EPOCH: 13533 LOSS: 41.00091371709018\n",
      "EPOCH: 13534 LOSS: 41.00090990260463\n",
      "EPOCH: 13535 LOSS: 41.000906088580834\n",
      "EPOCH: 13536 LOSS: 41.000902275018674\n",
      "EPOCH: 13537 LOSS: 41.00089846191807\n",
      "EPOCH: 13538 LOSS: 41.000894649278955\n",
      "EPOCH: 13539 LOSS: 41.00089083710126\n",
      "EPOCH: 13540 LOSS: 41.000887025384884\n",
      "EPOCH: 13541 LOSS: 41.000883214129786\n",
      "EPOCH: 13542 LOSS: 41.00087940333584\n",
      "EPOCH: 13543 LOSS: 41.000875593002995\n",
      "EPOCH: 13544 LOSS: 41.000871783131174\n",
      "EPOCH: 13545 LOSS: 41.000867973720275\n",
      "EPOCH: 13546 LOSS: 41.000864164770235\n",
      "EPOCH: 13547 LOSS: 41.000860356281\n",
      "EPOCH: 13548 LOSS: 41.00085654825245\n",
      "EPOCH: 13549 LOSS: 41.000852740684536\n",
      "EPOCH: 13550 LOSS: 41.00084893357717\n",
      "EPOCH: 13551 LOSS: 41.00084512693027\n",
      "EPOCH: 13552 LOSS: 41.00084132074376\n",
      "EPOCH: 13553 LOSS: 41.00083751501757\n",
      "EPOCH: 13554 LOSS: 41.00083370975161\n",
      "EPOCH: 13555 LOSS: 41.00082990494579\n",
      "EPOCH: 13556 LOSS: 41.00082610060007\n",
      "EPOCH: 13557 LOSS: 41.00082229671435\n",
      "EPOCH: 13558 LOSS: 41.00081849328854\n",
      "EPOCH: 13559 LOSS: 41.000814690322585\n",
      "EPOCH: 13560 LOSS: 41.00081088781638\n",
      "EPOCH: 13561 LOSS: 41.00080708576988\n",
      "EPOCH: 13562 LOSS: 41.00080328418297\n",
      "EPOCH: 13563 LOSS: 41.000799483055616\n",
      "EPOCH: 13564 LOSS: 41.00079568238769\n",
      "EPOCH: 13565 LOSS: 41.00079188217914\n",
      "EPOCH: 13566 LOSS: 41.00078808242991\n",
      "EPOCH: 13567 LOSS: 41.000784283139886\n",
      "EPOCH: 13568 LOSS: 41.000780484309\n",
      "EPOCH: 13569 LOSS: 41.000776685937176\n",
      "EPOCH: 13570 LOSS: 41.00077288802434\n",
      "EPOCH: 13571 LOSS: 41.000769090570415\n",
      "EPOCH: 13572 LOSS: 41.000765293575306\n",
      "EPOCH: 13573 LOSS: 41.00076149703898\n",
      "EPOCH: 13574 LOSS: 41.00075770096129\n",
      "EPOCH: 13575 LOSS: 41.000753905342215\n",
      "EPOCH: 13576 LOSS: 41.00075011018165\n",
      "EPOCH: 13577 LOSS: 41.00074631547953\n",
      "EPOCH: 13578 LOSS: 41.000742521235765\n",
      "EPOCH: 13579 LOSS: 41.00073872745028\n",
      "EPOCH: 13580 LOSS: 41.00073493412302\n",
      "EPOCH: 13581 LOSS: 41.00073114125388\n",
      "EPOCH: 13582 LOSS: 41.00072734884277\n",
      "EPOCH: 13583 LOSS: 41.00072355688968\n",
      "EPOCH: 13584 LOSS: 41.00071976539446\n",
      "EPOCH: 13585 LOSS: 41.00071597435705\n",
      "EPOCH: 13586 LOSS: 41.000712183777374\n",
      "EPOCH: 13587 LOSS: 41.00070839365537\n",
      "EPOCH: 13588 LOSS: 41.00070460399095\n",
      "EPOCH: 13589 LOSS: 41.000700814784054\n",
      "EPOCH: 13590 LOSS: 41.00069702603455\n",
      "EPOCH: 13591 LOSS: 41.000693237742425\n",
      "EPOCH: 13592 LOSS: 41.00068944990757\n",
      "EPOCH: 13593 LOSS: 41.000685662529904\n",
      "EPOCH: 13594 LOSS: 41.00068187560935\n",
      "EPOCH: 13595 LOSS: 41.00067808914584\n",
      "EPOCH: 13596 LOSS: 41.0006743031393\n",
      "EPOCH: 13597 LOSS: 41.000670517589654\n",
      "EPOCH: 13598 LOSS: 41.0006667324968\n",
      "EPOCH: 13599 LOSS: 41.000662947860675\n",
      "EPOCH: 13600 LOSS: 41.000659163681206\n",
      "EPOCH: 13601 LOSS: 41.00065537995832\n",
      "EPOCH: 13602 LOSS: 41.00065159669193\n",
      "EPOCH: 13603 LOSS: 41.00064781388197\n",
      "EPOCH: 13604 LOSS: 41.00064403152834\n",
      "EPOCH: 13605 LOSS: 41.00064024963097\n",
      "EPOCH: 13606 LOSS: 41.000636468189796\n",
      "EPOCH: 13607 LOSS: 41.00063268720474\n",
      "EPOCH: 13608 LOSS: 41.0006289066757\n",
      "EPOCH: 13609 LOSS: 41.00062512660263\n",
      "EPOCH: 13610 LOSS: 41.00062134698544\n",
      "EPOCH: 13611 LOSS: 41.00061756782405\n",
      "EPOCH: 13612 LOSS: 41.000613789118376\n",
      "EPOCH: 13613 LOSS: 41.00061001086834\n",
      "EPOCH: 13614 LOSS: 41.00060623307389\n",
      "EPOCH: 13615 LOSS: 41.00060245573492\n",
      "EPOCH: 13616 LOSS: 41.00059867885137\n",
      "EPOCH: 13617 LOSS: 41.00059490242315\n",
      "EPOCH: 13618 LOSS: 41.00059112645021\n",
      "EPOCH: 13619 LOSS: 41.00058735093244\n",
      "EPOCH: 13620 LOSS: 41.00058357586978\n",
      "EPOCH: 13621 LOSS: 41.00057980126215\n",
      "EPOCH: 13622 LOSS: 41.000576027109474\n",
      "EPOCH: 13623 LOSS: 41.00057225341166\n",
      "EPOCH: 13624 LOSS: 41.000568480168646\n",
      "EPOCH: 13625 LOSS: 41.00056470738035\n",
      "EPOCH: 13626 LOSS: 41.00056093504671\n",
      "EPOCH: 13627 LOSS: 41.00055716316763\n",
      "EPOCH: 13628 LOSS: 41.000553391743026\n",
      "EPOCH: 13629 LOSS: 41.00054962077285\n",
      "EPOCH: 13630 LOSS: 41.000545850257\n",
      "EPOCH: 13631 LOSS: 41.00054208019541\n",
      "EPOCH: 13632 LOSS: 41.000538310587984\n",
      "EPOCH: 13633 LOSS: 41.00053454143469\n",
      "EPOCH: 13634 LOSS: 41.00053077273541\n",
      "EPOCH: 13635 LOSS: 41.00052700449007\n",
      "EPOCH: 13636 LOSS: 41.00052323669861\n",
      "EPOCH: 13637 LOSS: 41.00051946936096\n",
      "EPOCH: 13638 LOSS: 41.000515702477\n",
      "EPOCH: 13639 LOSS: 41.00051193604669\n",
      "EPOCH: 13640 LOSS: 41.00050817006996\n",
      "EPOCH: 13641 LOSS: 41.00050440454672\n",
      "EPOCH: 13642 LOSS: 41.00050063947687\n",
      "EPOCH: 13643 LOSS: 41.00049687486036\n",
      "EPOCH: 13644 LOSS: 41.00049311069711\n",
      "EPOCH: 13645 LOSS: 41.00048934698705\n",
      "EPOCH: 13646 LOSS: 41.00048558373008\n",
      "EPOCH: 13647 LOSS: 41.00048182092615\n",
      "EPOCH: 13648 LOSS: 41.000478058575155\n",
      "EPOCH: 13649 LOSS: 41.00047429667703\n",
      "EPOCH: 13650 LOSS: 41.000470535231706\n",
      "EPOCH: 13651 LOSS: 41.0004667742391\n",
      "EPOCH: 13652 LOSS: 41.000463013699154\n",
      "EPOCH: 13653 LOSS: 41.000459253611766\n",
      "EPOCH: 13654 LOSS: 41.000455493976844\n",
      "EPOCH: 13655 LOSS: 41.00045173479436\n",
      "EPOCH: 13656 LOSS: 41.00044797606421\n",
      "EPOCH: 13657 LOSS: 41.00044421778631\n",
      "EPOCH: 13658 LOSS: 41.000440459960586\n",
      "EPOCH: 13659 LOSS: 41.000436702586995\n",
      "EPOCH: 13660 LOSS: 41.000432945665395\n",
      "EPOCH: 13661 LOSS: 41.000429189195785\n",
      "EPOCH: 13662 LOSS: 41.00042543317804\n",
      "EPOCH: 13663 LOSS: 41.00042167761208\n",
      "EPOCH: 13664 LOSS: 41.00041792249785\n",
      "EPOCH: 13665 LOSS: 41.00041416783529\n",
      "EPOCH: 13666 LOSS: 41.000410413624266\n",
      "EPOCH: 13667 LOSS: 41.00040665986476\n",
      "EPOCH: 13668 LOSS: 41.000402906556644\n",
      "EPOCH: 13669 LOSS: 41.0003991536999\n",
      "EPOCH: 13670 LOSS: 41.0003954012944\n",
      "EPOCH: 13671 LOSS: 41.000391649340095\n",
      "EPOCH: 13672 LOSS: 41.00038789783689\n",
      "EPOCH: 13673 LOSS: 41.00038414678473\n",
      "EPOCH: 13674 LOSS: 41.00038039618353\n",
      "EPOCH: 13675 LOSS: 41.00037664603322\n",
      "EPOCH: 13676 LOSS: 41.0003728963337\n",
      "EPOCH: 13677 LOSS: 41.000369147084896\n",
      "EPOCH: 13678 LOSS: 41.000365398286775\n",
      "EPOCH: 13679 LOSS: 41.00036164993921\n",
      "EPOCH: 13680 LOSS: 41.000357902042154\n",
      "EPOCH: 13681 LOSS: 41.00035415459553\n",
      "EPOCH: 13682 LOSS: 41.00035040759923\n",
      "EPOCH: 13683 LOSS: 41.00034666105322\n",
      "EPOCH: 13684 LOSS: 41.0003429149574\n",
      "EPOCH: 13685 LOSS: 41.000339169311694\n",
      "EPOCH: 13686 LOSS: 41.000335424116045\n",
      "EPOCH: 13687 LOSS: 41.00033167937035\n",
      "EPOCH: 13688 LOSS: 41.00032793507454\n",
      "EPOCH: 13689 LOSS: 41.00032419122856\n",
      "EPOCH: 13690 LOSS: 41.000320447832294\n",
      "EPOCH: 13691 LOSS: 41.00031670488571\n",
      "EPOCH: 13692 LOSS: 41.00031296238872\n",
      "EPOCH: 13693 LOSS: 41.00030922034121\n",
      "EPOCH: 13694 LOSS: 41.000305478743165\n",
      "EPOCH: 13695 LOSS: 41.000301737594455\n",
      "EPOCH: 13696 LOSS: 41.000297996895036\n",
      "EPOCH: 13697 LOSS: 41.000294256644814\n",
      "EPOCH: 13698 LOSS: 41.00029051684374\n",
      "EPOCH: 13699 LOSS: 41.00028677749168\n",
      "EPOCH: 13700 LOSS: 41.00028303858861\n",
      "EPOCH: 13701 LOSS: 41.00027930013447\n",
      "EPOCH: 13702 LOSS: 41.00027556212915\n",
      "EPOCH: 13703 LOSS: 41.00027182457256\n",
      "EPOCH: 13704 LOSS: 41.00026808746463\n",
      "EPOCH: 13705 LOSS: 41.00026435080533\n",
      "EPOCH: 13706 LOSS: 41.000260614594524\n",
      "EPOCH: 13707 LOSS: 41.00025687883219\n",
      "EPOCH: 13708 LOSS: 41.00025314351821\n",
      "EPOCH: 13709 LOSS: 41.00024940865251\n",
      "EPOCH: 13710 LOSS: 41.00024567423506\n",
      "EPOCH: 13711 LOSS: 41.000241940265724\n",
      "EPOCH: 13712 LOSS: 41.00023820674447\n",
      "EPOCH: 13713 LOSS: 41.00023447367119\n",
      "EPOCH: 13714 LOSS: 41.000230741045826\n",
      "EPOCH: 13715 LOSS: 41.00022700886831\n",
      "EPOCH: 13716 LOSS: 41.00022327713856\n",
      "EPOCH: 13717 LOSS: 41.00021954585647\n",
      "EPOCH: 13718 LOSS: 41.00021581502203\n",
      "EPOCH: 13719 LOSS: 41.000212084635095\n",
      "EPOCH: 13720 LOSS: 41.00020835469563\n",
      "EPOCH: 13721 LOSS: 41.00020462520355\n",
      "EPOCH: 13722 LOSS: 41.00020089615877\n",
      "EPOCH: 13723 LOSS: 41.00019716756124\n",
      "EPOCH: 13724 LOSS: 41.00019343941085\n",
      "EPOCH: 13725 LOSS: 41.000189711707556\n",
      "EPOCH: 13726 LOSS: 41.00018598445125\n",
      "EPOCH: 13727 LOSS: 41.00018225764188\n",
      "EPOCH: 13728 LOSS: 41.00017853127937\n",
      "EPOCH: 13729 LOSS: 41.00017480536363\n",
      "EPOCH: 13730 LOSS: 41.000171079894606\n",
      "EPOCH: 13731 LOSS: 41.00016735487219\n",
      "EPOCH: 13732 LOSS: 41.000163630296335\n",
      "EPOCH: 13733 LOSS: 41.00015990616697\n",
      "EPOCH: 13734 LOSS: 41.00015618248399\n",
      "EPOCH: 13735 LOSS: 41.00015245924734\n",
      "EPOCH: 13736 LOSS: 41.000148736456936\n",
      "EPOCH: 13737 LOSS: 41.00014501411271\n",
      "EPOCH: 13738 LOSS: 41.00014129221458\n",
      "EPOCH: 13739 LOSS: 41.00013757076246\n",
      "EPOCH: 13740 LOSS: 41.00013384975632\n",
      "EPOCH: 13741 LOSS: 41.00013012919603\n",
      "EPOCH: 13742 LOSS: 41.00012640908155\n",
      "EPOCH: 13743 LOSS: 41.000122689412784\n",
      "EPOCH: 13744 LOSS: 41.000118970189654\n",
      "EPOCH: 13745 LOSS: 41.000115251412105\n",
      "EPOCH: 13746 LOSS: 41.00011153308005\n",
      "EPOCH: 13747 LOSS: 41.00010781519343\n",
      "EPOCH: 13748 LOSS: 41.00010409775215\n",
      "EPOCH: 13749 LOSS: 41.00010038075612\n",
      "EPOCH: 13750 LOSS: 41.000096664205294\n",
      "EPOCH: 13751 LOSS: 41.000092948099606\n",
      "EPOCH: 13752 LOSS: 41.00008923243893\n",
      "EPOCH: 13753 LOSS: 41.00008551722324\n",
      "EPOCH: 13754 LOSS: 41.00008180245243\n",
      "EPOCH: 13755 LOSS: 41.00007808812646\n",
      "EPOCH: 13756 LOSS: 41.000074374245216\n",
      "EPOCH: 13757 LOSS: 41.00007066080865\n",
      "EPOCH: 13758 LOSS: 41.00006694781668\n",
      "EPOCH: 13759 LOSS: 41.00006323526921\n",
      "EPOCH: 13760 LOSS: 41.00005952316619\n",
      "EPOCH: 13761 LOSS: 41.00005581150755\n",
      "EPOCH: 13762 LOSS: 41.000052100293196\n",
      "EPOCH: 13763 LOSS: 41.00004838952305\n",
      "EPOCH: 13764 LOSS: 41.000044679197046\n",
      "EPOCH: 13765 LOSS: 41.00004096931512\n",
      "EPOCH: 13766 LOSS: 41.000037259877175\n",
      "EPOCH: 13767 LOSS: 41.00003355088316\n",
      "EPOCH: 13768 LOSS: 41.000029842332964\n",
      "EPOCH: 13769 LOSS: 41.00002613422655\n",
      "EPOCH: 13770 LOSS: 41.000022426563824\n",
      "EPOCH: 13771 LOSS: 41.000018719344716\n",
      "EPOCH: 13772 LOSS: 41.00001501256915\n",
      "EPOCH: 13773 LOSS: 41.00001130623704\n",
      "EPOCH: 13774 LOSS: 41.00000760034835\n",
      "EPOCH: 13775 LOSS: 41.00000389490295\n",
      "EPOCH: 13776 LOSS: 41.0000001899008\n",
      "EPOCH: 13777 LOSS: 40.99999648534181\n",
      "EPOCH: 13778 LOSS: 40.99999278122593\n",
      "EPOCH: 13779 LOSS: 40.99998907755305\n",
      "EPOCH: 13780 LOSS: 40.99998537432313\n",
      "EPOCH: 13781 LOSS: 40.99998167153605\n",
      "EPOCH: 13782 LOSS: 40.999977969191804\n",
      "EPOCH: 13783 LOSS: 40.999974267290256\n",
      "EPOCH: 13784 LOSS: 40.99997056583133\n",
      "EPOCH: 13785 LOSS: 40.99996686481499\n",
      "EPOCH: 13786 LOSS: 40.99996316424115\n",
      "EPOCH: 13787 LOSS: 40.99995946410971\n",
      "EPOCH: 13788 LOSS: 40.99995576442064\n",
      "EPOCH: 13789 LOSS: 40.99995206517382\n",
      "EPOCH: 13790 LOSS: 40.9999483663692\n",
      "EPOCH: 13791 LOSS: 40.999944668006705\n",
      "EPOCH: 13792 LOSS: 40.99994097008624\n",
      "EPOCH: 13793 LOSS: 40.99993727260775\n",
      "EPOCH: 13794 LOSS: 40.99993357557117\n",
      "EPOCH: 13795 LOSS: 40.999929878976396\n",
      "EPOCH: 13796 LOSS: 40.99992618282339\n",
      "EPOCH: 13797 LOSS: 40.99992248711203\n",
      "EPOCH: 13798 LOSS: 40.99991879184229\n",
      "EPOCH: 13799 LOSS: 40.99991509701406\n",
      "EPOCH: 13800 LOSS: 40.99991140262726\n",
      "EPOCH: 13801 LOSS: 40.999907708681874\n",
      "EPOCH: 13802 LOSS: 40.99990401517776\n",
      "EPOCH: 13803 LOSS: 40.99990032211487\n",
      "EPOCH: 13804 LOSS: 40.99989662949315\n",
      "EPOCH: 13805 LOSS: 40.999892937312495\n",
      "EPOCH: 13806 LOSS: 40.99988924557284\n",
      "EPOCH: 13807 LOSS: 40.999885554274115\n",
      "EPOCH: 13808 LOSS: 40.99988186341624\n",
      "EPOCH: 13809 LOSS: 40.99987817299914\n",
      "EPOCH: 13810 LOSS: 40.99987448302275\n",
      "EPOCH: 13811 LOSS: 40.99987079348699\n",
      "EPOCH: 13812 LOSS: 40.999867104391775\n",
      "EPOCH: 13813 LOSS: 40.99986341573705\n",
      "EPOCH: 13814 LOSS: 40.99985972752273\n",
      "EPOCH: 13815 LOSS: 40.99985603974872\n",
      "EPOCH: 13816 LOSS: 40.999852352415004\n",
      "EPOCH: 13817 LOSS: 40.99984866552144\n",
      "EPOCH: 13818 LOSS: 40.99984497906801\n",
      "EPOCH: 13819 LOSS: 40.9998412930546\n",
      "EPOCH: 13820 LOSS: 40.99983760748115\n",
      "EPOCH: 13821 LOSS: 40.999833922347584\n",
      "EPOCH: 13822 LOSS: 40.999830237653846\n",
      "EPOCH: 13823 LOSS: 40.99982655339983\n",
      "EPOCH: 13824 LOSS: 40.99982286958548\n",
      "EPOCH: 13825 LOSS: 40.9998191862107\n",
      "EPOCH: 13826 LOSS: 40.99981550327546\n",
      "EPOCH: 13827 LOSS: 40.99981182077967\n",
      "EPOCH: 13828 LOSS: 40.99980813872324\n",
      "EPOCH: 13829 LOSS: 40.99980445710608\n",
      "EPOCH: 13830 LOSS: 40.99980077592815\n",
      "EPOCH: 13831 LOSS: 40.999797095189365\n",
      "EPOCH: 13832 LOSS: 40.99979341488965\n",
      "EPOCH: 13833 LOSS: 40.999789735028926\n",
      "EPOCH: 13834 LOSS: 40.99978605560713\n",
      "EPOCH: 13835 LOSS: 40.99978237662418\n",
      "EPOCH: 13836 LOSS: 40.99977869808001\n",
      "EPOCH: 13837 LOSS: 40.99977501997453\n",
      "EPOCH: 13838 LOSS: 40.99977134230768\n",
      "EPOCH: 13839 LOSS: 40.999767665079375\n",
      "EPOCH: 13840 LOSS: 40.99976398828956\n",
      "EPOCH: 13841 LOSS: 40.99976031193813\n",
      "EPOCH: 13842 LOSS: 40.99975663602505\n",
      "EPOCH: 13843 LOSS: 40.99975296055021\n",
      "EPOCH: 13844 LOSS: 40.99974928551355\n",
      "EPOCH: 13845 LOSS: 40.999745610915014\n",
      "EPOCH: 13846 LOSS: 40.99974193675451\n",
      "EPOCH: 13847 LOSS: 40.99973826303196\n",
      "EPOCH: 13848 LOSS: 40.99973458974729\n",
      "EPOCH: 13849 LOSS: 40.99973091690044\n",
      "EPOCH: 13850 LOSS: 40.99972724449134\n",
      "EPOCH: 13851 LOSS: 40.999723572519876\n",
      "EPOCH: 13852 LOSS: 40.999719900986015\n",
      "EPOCH: 13853 LOSS: 40.99971622988968\n",
      "EPOCH: 13854 LOSS: 40.99971255923079\n",
      "EPOCH: 13855 LOSS: 40.99970888900927\n",
      "EPOCH: 13856 LOSS: 40.99970521922502\n",
      "EPOCH: 13857 LOSS: 40.99970154987801\n",
      "EPOCH: 13858 LOSS: 40.99969788096816\n",
      "EPOCH: 13859 LOSS: 40.99969421249536\n",
      "EPOCH: 13860 LOSS: 40.99969054445958\n",
      "EPOCH: 13861 LOSS: 40.999686876860714\n",
      "EPOCH: 13862 LOSS: 40.99968320969871\n",
      "EPOCH: 13863 LOSS: 40.99967954297349\n",
      "EPOCH: 13864 LOSS: 40.99967587668496\n",
      "EPOCH: 13865 LOSS: 40.99967221083307\n",
      "EPOCH: 13866 LOSS: 40.99966854541775\n",
      "EPOCH: 13867 LOSS: 40.999664880438914\n",
      "EPOCH: 13868 LOSS: 40.99966121589648\n",
      "EPOCH: 13869 LOSS: 40.99965755179038\n",
      "EPOCH: 13870 LOSS: 40.99965388812055\n",
      "EPOCH: 13871 LOSS: 40.999650224886906\n",
      "EPOCH: 13872 LOSS: 40.999646562089396\n",
      "EPOCH: 13873 LOSS: 40.99964289972792\n",
      "EPOCH: 13874 LOSS: 40.999639237802405\n",
      "EPOCH: 13875 LOSS: 40.9996355763128\n",
      "EPOCH: 13876 LOSS: 40.999631915259\n",
      "EPOCH: 13877 LOSS: 40.99962825464097\n",
      "EPOCH: 13878 LOSS: 40.99962459445861\n",
      "EPOCH: 13879 LOSS: 40.99962093471186\n",
      "EPOCH: 13880 LOSS: 40.99961727540063\n",
      "EPOCH: 13881 LOSS: 40.99961361652485\n",
      "EPOCH: 13882 LOSS: 40.99960995808448\n",
      "EPOCH: 13883 LOSS: 40.99960630007939\n",
      "EPOCH: 13884 LOSS: 40.999602642509544\n",
      "EPOCH: 13885 LOSS: 40.99959898537486\n",
      "EPOCH: 13886 LOSS: 40.99959532867527\n",
      "EPOCH: 13887 LOSS: 40.99959167241069\n",
      "EPOCH: 13888 LOSS: 40.99958801658107\n",
      "EPOCH: 13889 LOSS: 40.99958436118631\n",
      "EPOCH: 13890 LOSS: 40.99958070622634\n",
      "EPOCH: 13891 LOSS: 40.99957705170108\n",
      "EPOCH: 13892 LOSS: 40.999573397610504\n",
      "EPOCH: 13893 LOSS: 40.999569743954474\n",
      "EPOCH: 13894 LOSS: 40.99956609073297\n",
      "EPOCH: 13895 LOSS: 40.99956243794589\n",
      "EPOCH: 13896 LOSS: 40.99955878559316\n",
      "EPOCH: 13897 LOSS: 40.99955513367472\n",
      "EPOCH: 13898 LOSS: 40.99955148219048\n",
      "EPOCH: 13899 LOSS: 40.99954783114038\n",
      "EPOCH: 13900 LOSS: 40.99954418052434\n",
      "EPOCH: 13901 LOSS: 40.999540530342315\n",
      "EPOCH: 13902 LOSS: 40.99953688059419\n",
      "EPOCH: 13903 LOSS: 40.99953323127991\n",
      "EPOCH: 13904 LOSS: 40.99952958239942\n",
      "EPOCH: 13905 LOSS: 40.9995259339526\n",
      "EPOCH: 13906 LOSS: 40.99952228593942\n",
      "EPOCH: 13907 LOSS: 40.99951863835979\n",
      "EPOCH: 13908 LOSS: 40.999514991213644\n",
      "EPOCH: 13909 LOSS: 40.99951134450091\n",
      "EPOCH: 13910 LOSS: 40.999507698221485\n",
      "EPOCH: 13911 LOSS: 40.99950405237533\n",
      "EPOCH: 13912 LOSS: 40.99950040696238\n",
      "EPOCH: 13913 LOSS: 40.999496761982535\n",
      "EPOCH: 13914 LOSS: 40.999493117435726\n",
      "EPOCH: 13915 LOSS: 40.99948947332189\n",
      "EPOCH: 13916 LOSS: 40.99948582964095\n",
      "EPOCH: 13917 LOSS: 40.99948218639284\n",
      "EPOCH: 13918 LOSS: 40.999478543577474\n",
      "EPOCH: 13919 LOSS: 40.99947490119479\n",
      "EPOCH: 13920 LOSS: 40.99947125924469\n",
      "EPOCH: 13921 LOSS: 40.999467617727134\n",
      "EPOCH: 13922 LOSS: 40.999463976642055\n",
      "EPOCH: 13923 LOSS: 40.999460335989326\n",
      "EPOCH: 13924 LOSS: 40.99945669576894\n",
      "EPOCH: 13925 LOSS: 40.99945305598078\n",
      "EPOCH: 13926 LOSS: 40.99944941662479\n",
      "EPOCH: 13927 LOSS: 40.9994457777009\n",
      "EPOCH: 13928 LOSS: 40.99944213920903\n",
      "EPOCH: 13929 LOSS: 40.999438501149115\n",
      "EPOCH: 13930 LOSS: 40.99943486352105\n",
      "EPOCH: 13931 LOSS: 40.999431226324816\n",
      "EPOCH: 13932 LOSS: 40.999427589560305\n",
      "EPOCH: 13933 LOSS: 40.99942395322746\n",
      "EPOCH: 13934 LOSS: 40.9994203173262\n",
      "EPOCH: 13935 LOSS: 40.99941668185644\n",
      "EPOCH: 13936 LOSS: 40.99941304681813\n",
      "EPOCH: 13937 LOSS: 40.99940941221118\n",
      "EPOCH: 13938 LOSS: 40.99940577803554\n",
      "EPOCH: 13939 LOSS: 40.9994021442911\n",
      "EPOCH: 13940 LOSS: 40.99939851097783\n",
      "EPOCH: 13941 LOSS: 40.99939487809563\n",
      "EPOCH: 13942 LOSS: 40.99939124564443\n",
      "EPOCH: 13943 LOSS: 40.99938761362419\n",
      "EPOCH: 13944 LOSS: 40.99938398203478\n",
      "EPOCH: 13945 LOSS: 40.999380350876166\n",
      "EPOCH: 13946 LOSS: 40.99937672014826\n",
      "EPOCH: 13947 LOSS: 40.999373089851\n",
      "EPOCH: 13948 LOSS: 40.999369459984315\n",
      "EPOCH: 13949 LOSS: 40.99936583054813\n",
      "EPOCH: 13950 LOSS: 40.99936220154238\n",
      "EPOCH: 13951 LOSS: 40.999358572966955\n",
      "EPOCH: 13952 LOSS: 40.99935494482183\n",
      "EPOCH: 13953 LOSS: 40.999351317106914\n",
      "EPOCH: 13954 LOSS: 40.999347689822116\n",
      "EPOCH: 13955 LOSS: 40.999344062967396\n",
      "EPOCH: 13956 LOSS: 40.999340436542674\n",
      "EPOCH: 13957 LOSS: 40.999336810547845\n",
      "EPOCH: 13958 LOSS: 40.99933318498289\n",
      "EPOCH: 13959 LOSS: 40.99932955984768\n",
      "EPOCH: 13960 LOSS: 40.9993259351422\n",
      "EPOCH: 13961 LOSS: 40.99932231086634\n",
      "EPOCH: 13962 LOSS: 40.99931868702003\n",
      "EPOCH: 13963 LOSS: 40.999315063603206\n",
      "EPOCH: 13964 LOSS: 40.9993114406158\n",
      "EPOCH: 13965 LOSS: 40.99930781805773\n",
      "EPOCH: 13966 LOSS: 40.99930419592892\n",
      "EPOCH: 13967 LOSS: 40.999300574229316\n",
      "EPOCH: 13968 LOSS: 40.999296952958844\n",
      "EPOCH: 13969 LOSS: 40.99929333211741\n",
      "EPOCH: 13970 LOSS: 40.99928971170496\n",
      "EPOCH: 13971 LOSS: 40.99928609172142\n",
      "EPOCH: 13972 LOSS: 40.99928247216671\n",
      "EPOCH: 13973 LOSS: 40.99927885304076\n",
      "EPOCH: 13974 LOSS: 40.9992752343435\n",
      "EPOCH: 13975 LOSS: 40.99927161607488\n",
      "EPOCH: 13976 LOSS: 40.99926799823478\n",
      "EPOCH: 13977 LOSS: 40.99926438082316\n",
      "EPOCH: 13978 LOSS: 40.999260763839956\n",
      "EPOCH: 13979 LOSS: 40.99925714728507\n",
      "EPOCH: 13980 LOSS: 40.99925353115846\n",
      "EPOCH: 13981 LOSS: 40.99924991546001\n",
      "EPOCH: 13982 LOSS: 40.99924630018971\n",
      "EPOCH: 13983 LOSS: 40.99924268534741\n",
      "EPOCH: 13984 LOSS: 40.9992390709331\n",
      "EPOCH: 13985 LOSS: 40.99923545694669\n",
      "EPOCH: 13986 LOSS: 40.9992318433881\n",
      "EPOCH: 13987 LOSS: 40.99922823025729\n",
      "EPOCH: 13988 LOSS: 40.99922461755414\n",
      "EPOCH: 13989 LOSS: 40.9992210052786\n",
      "EPOCH: 13990 LOSS: 40.99921739343061\n",
      "EPOCH: 13991 LOSS: 40.99921378201009\n",
      "EPOCH: 13992 LOSS: 40.999210171016955\n",
      "EPOCH: 13993 LOSS: 40.99920656045113\n",
      "EPOCH: 13994 LOSS: 40.99920295031258\n",
      "EPOCH: 13995 LOSS: 40.9991993406012\n",
      "EPOCH: 13996 LOSS: 40.99919573131693\n",
      "EPOCH: 13997 LOSS: 40.99919212245969\n",
      "EPOCH: 13998 LOSS: 40.99918851402943\n",
      "EPOCH: 13999 LOSS: 40.99918490602606\n",
      "EPOCH: 14000 LOSS: 40.9991812984495\n",
      "EPOCH: 14001 LOSS: 40.999177691299685\n",
      "EPOCH: 14002 LOSS: 40.99917408457656\n",
      "EPOCH: 14003 LOSS: 40.999170478280035\n",
      "EPOCH: 14004 LOSS: 40.99916687241004\n",
      "EPOCH: 14005 LOSS: 40.99916326696651\n",
      "EPOCH: 14006 LOSS: 40.999159661949385\n",
      "EPOCH: 14007 LOSS: 40.99915605735857\n",
      "EPOCH: 14008 LOSS: 40.999152453193986\n",
      "EPOCH: 14009 LOSS: 40.99914884945562\n",
      "EPOCH: 14010 LOSS: 40.999145246143314\n",
      "EPOCH: 14011 LOSS: 40.999141643257055\n",
      "EPOCH: 14012 LOSS: 40.99913804079675\n",
      "EPOCH: 14013 LOSS: 40.999134438762354\n",
      "EPOCH: 14014 LOSS: 40.99913083715378\n",
      "EPOCH: 14015 LOSS: 40.99912723597093\n",
      "EPOCH: 14016 LOSS: 40.99912363521376\n",
      "EPOCH: 14017 LOSS: 40.9991200348822\n",
      "EPOCH: 14018 LOSS: 40.99911643497617\n",
      "EPOCH: 14019 LOSS: 40.999112835495595\n",
      "EPOCH: 14020 LOSS: 40.99910923644043\n",
      "EPOCH: 14021 LOSS: 40.99910563781056\n",
      "EPOCH: 14022 LOSS: 40.99910203960595\n",
      "EPOCH: 14023 LOSS: 40.99909844182649\n",
      "EPOCH: 14024 LOSS: 40.999094844472154\n",
      "EPOCH: 14025 LOSS: 40.99909124754285\n",
      "EPOCH: 14026 LOSS: 40.99908765103851\n",
      "EPOCH: 14027 LOSS: 40.99908405495904\n",
      "EPOCH: 14028 LOSS: 40.9990804593044\n",
      "EPOCH: 14029 LOSS: 40.99907686407451\n",
      "EPOCH: 14030 LOSS: 40.999073269269296\n",
      "EPOCH: 14031 LOSS: 40.99906967488867\n",
      "EPOCH: 14032 LOSS: 40.99906608093259\n",
      "EPOCH: 14033 LOSS: 40.99906248740096\n",
      "EPOCH: 14034 LOSS: 40.99905889429374\n",
      "EPOCH: 14035 LOSS: 40.99905530161083\n",
      "EPOCH: 14036 LOSS: 40.99905170935216\n",
      "EPOCH: 14037 LOSS: 40.999048117517674\n",
      "EPOCH: 14038 LOSS: 40.999044526107284\n",
      "EPOCH: 14039 LOSS: 40.99904093512093\n",
      "EPOCH: 14040 LOSS: 40.999037344558545\n",
      "EPOCH: 14041 LOSS: 40.99903375442004\n",
      "EPOCH: 14042 LOSS: 40.999030164705374\n",
      "EPOCH: 14043 LOSS: 40.99902657541444\n",
      "EPOCH: 14044 LOSS: 40.999022986547196\n",
      "EPOCH: 14045 LOSS: 40.99901939810354\n",
      "EPOCH: 14046 LOSS: 40.99901581008343\n",
      "EPOCH: 14047 LOSS: 40.9990122224868\n",
      "EPOCH: 14048 LOSS: 40.99900863531356\n",
      "EPOCH: 14049 LOSS: 40.99900504856362\n",
      "EPOCH: 14050 LOSS: 40.999001462236954\n",
      "EPOCH: 14051 LOSS: 40.99899787633345\n",
      "EPOCH: 14052 LOSS: 40.998994290853055\n",
      "EPOCH: 14053 LOSS: 40.9989907057957\n",
      "EPOCH: 14054 LOSS: 40.99898712116133\n",
      "EPOCH: 14055 LOSS: 40.99898353694984\n",
      "EPOCH: 14056 LOSS: 40.99897995316118\n",
      "EPOCH: 14057 LOSS: 40.99897636979527\n",
      "EPOCH: 14058 LOSS: 40.99897278685205\n",
      "EPOCH: 14059 LOSS: 40.99896920433145\n",
      "EPOCH: 14060 LOSS: 40.99896562223337\n",
      "EPOCH: 14061 LOSS: 40.99896204055777\n",
      "EPOCH: 14062 LOSS: 40.99895845930458\n",
      "EPOCH: 14063 LOSS: 40.998954878473704\n",
      "EPOCH: 14064 LOSS: 40.99895129806511\n",
      "EPOCH: 14065 LOSS: 40.99894771807867\n",
      "EPOCH: 14066 LOSS: 40.99894413851436\n",
      "EPOCH: 14067 LOSS: 40.99894055937209\n",
      "EPOCH: 14068 LOSS: 40.998936980651806\n",
      "EPOCH: 14069 LOSS: 40.998933402353416\n",
      "EPOCH: 14070 LOSS: 40.99892982447687\n",
      "EPOCH: 14071 LOSS: 40.99892624702207\n",
      "EPOCH: 14072 LOSS: 40.99892266998897\n",
      "EPOCH: 14073 LOSS: 40.998919093377495\n",
      "EPOCH: 14074 LOSS: 40.998915517187555\n",
      "EPOCH: 14075 LOSS: 40.998911941419124\n",
      "EPOCH: 14076 LOSS: 40.99890836607209\n",
      "EPOCH: 14077 LOSS: 40.99890479114639\n",
      "EPOCH: 14078 LOSS: 40.99890121664194\n",
      "EPOCH: 14079 LOSS: 40.998897642558696\n",
      "EPOCH: 14080 LOSS: 40.99889406889659\n",
      "EPOCH: 14081 LOSS: 40.99889049565554\n",
      "EPOCH: 14082 LOSS: 40.99888692283546\n",
      "EPOCH: 14083 LOSS: 40.9988833504363\n",
      "EPOCH: 14084 LOSS: 40.99887977845797\n",
      "EPOCH: 14085 LOSS: 40.998876206900434\n",
      "EPOCH: 14086 LOSS: 40.998872635763604\n",
      "EPOCH: 14087 LOSS: 40.99886906504739\n",
      "EPOCH: 14088 LOSS: 40.99886549475175\n",
      "EPOCH: 14089 LOSS: 40.99886192487658\n",
      "EPOCH: 14090 LOSS: 40.998858355421845\n",
      "EPOCH: 14091 LOSS: 40.99885478638746\n",
      "EPOCH: 14092 LOSS: 40.99885121777335\n",
      "EPOCH: 14093 LOSS: 40.998847649579446\n",
      "EPOCH: 14094 LOSS: 40.998844081805686\n",
      "EPOCH: 14095 LOSS: 40.99884051445199\n",
      "EPOCH: 14096 LOSS: 40.9988369475183\n",
      "EPOCH: 14097 LOSS: 40.998833381004516\n",
      "EPOCH: 14098 LOSS: 40.99882981491059\n",
      "EPOCH: 14099 LOSS: 40.99882624923649\n",
      "EPOCH: 14100 LOSS: 40.99882268398207\n",
      "EPOCH: 14101 LOSS: 40.998819119147285\n",
      "EPOCH: 14102 LOSS: 40.998815554732104\n",
      "EPOCH: 14103 LOSS: 40.998811990736414\n",
      "EPOCH: 14104 LOSS: 40.99880842716016\n",
      "EPOCH: 14105 LOSS: 40.998804864003276\n",
      "EPOCH: 14106 LOSS: 40.99880130126568\n",
      "EPOCH: 14107 LOSS: 40.998797738947296\n",
      "EPOCH: 14108 LOSS: 40.99879417704808\n",
      "EPOCH: 14109 LOSS: 40.99879061556794\n",
      "EPOCH: 14110 LOSS: 40.99878705450682\n",
      "EPOCH: 14111 LOSS: 40.99878349386463\n",
      "EPOCH: 14112 LOSS: 40.99877993364132\n",
      "EPOCH: 14113 LOSS: 40.99877637383682\n",
      "EPOCH: 14114 LOSS: 40.99877281445103\n",
      "EPOCH: 14115 LOSS: 40.99876925548392\n",
      "EPOCH: 14116 LOSS: 40.99876569693539\n",
      "EPOCH: 14117 LOSS: 40.998762138805404\n",
      "EPOCH: 14118 LOSS: 40.998758581093846\n",
      "EPOCH: 14119 LOSS: 40.998755023800676\n",
      "EPOCH: 14120 LOSS: 40.99875146692582\n",
      "EPOCH: 14121 LOSS: 40.9987479104692\n",
      "EPOCH: 14122 LOSS: 40.99874435443075\n",
      "EPOCH: 14123 LOSS: 40.9987407988104\n",
      "EPOCH: 14124 LOSS: 40.99873724360808\n",
      "EPOCH: 14125 LOSS: 40.998733688823734\n",
      "EPOCH: 14126 LOSS: 40.99873013445726\n",
      "EPOCH: 14127 LOSS: 40.99872658050862\n",
      "EPOCH: 14128 LOSS: 40.99872302697772\n",
      "EPOCH: 14129 LOSS: 40.99871947386451\n",
      "EPOCH: 14130 LOSS: 40.998715921168895\n",
      "EPOCH: 14131 LOSS: 40.998712368890835\n",
      "EPOCH: 14132 LOSS: 40.99870881703025\n",
      "EPOCH: 14133 LOSS: 40.99870526558705\n",
      "EPOCH: 14134 LOSS: 40.99870171456118\n",
      "EPOCH: 14135 LOSS: 40.99869816395258\n",
      "EPOCH: 14136 LOSS: 40.998694613761174\n",
      "EPOCH: 14137 LOSS: 40.9986910639869\n",
      "EPOCH: 14138 LOSS: 40.99868751462964\n",
      "EPOCH: 14139 LOSS: 40.998683965689395\n",
      "EPOCH: 14140 LOSS: 40.99868041716604\n",
      "EPOCH: 14141 LOSS: 40.99867686905954\n",
      "EPOCH: 14142 LOSS: 40.9986733213698\n",
      "EPOCH: 14143 LOSS: 40.99866977409677\n",
      "EPOCH: 14144 LOSS: 40.99866622724038\n",
      "EPOCH: 14145 LOSS: 40.998662680800535\n",
      "EPOCH: 14146 LOSS: 40.998659134777185\n",
      "EPOCH: 14147 LOSS: 40.998655589170276\n",
      "EPOCH: 14148 LOSS: 40.99865204397969\n",
      "EPOCH: 14149 LOSS: 40.998648499205416\n",
      "EPOCH: 14150 LOSS: 40.99864495484734\n",
      "EPOCH: 14151 LOSS: 40.99864141090543\n",
      "EPOCH: 14152 LOSS: 40.99863786737957\n",
      "EPOCH: 14153 LOSS: 40.99863432426972\n",
      "EPOCH: 14154 LOSS: 40.9986307815758\n",
      "EPOCH: 14155 LOSS: 40.99862723929776\n",
      "EPOCH: 14156 LOSS: 40.998623697435505\n",
      "EPOCH: 14157 LOSS: 40.99862015598898\n",
      "EPOCH: 14158 LOSS: 40.99861661495811\n",
      "EPOCH: 14159 LOSS: 40.99861307434283\n",
      "EPOCH: 14160 LOSS: 40.998609534143064\n",
      "EPOCH: 14161 LOSS: 40.99860599435875\n",
      "EPOCH: 14162 LOSS: 40.99860245498981\n",
      "EPOCH: 14163 LOSS: 40.99859891603617\n",
      "EPOCH: 14164 LOSS: 40.998595377497765\n",
      "EPOCH: 14165 LOSS: 40.998591839374555\n",
      "EPOCH: 14166 LOSS: 40.99858830166642\n",
      "EPOCH: 14167 LOSS: 40.99858476437335\n",
      "EPOCH: 14168 LOSS: 40.99858122749522\n",
      "EPOCH: 14169 LOSS: 40.99857769103198\n",
      "EPOCH: 14170 LOSS: 40.99857415498356\n",
      "EPOCH: 14171 LOSS: 40.99857061934989\n",
      "EPOCH: 14172 LOSS: 40.99856708413092\n",
      "EPOCH: 14173 LOSS: 40.99856354932655\n",
      "EPOCH: 14174 LOSS: 40.99856001493673\n",
      "EPOCH: 14175 LOSS: 40.99855648096138\n",
      "EPOCH: 14176 LOSS: 40.99855294740044\n",
      "EPOCH: 14177 LOSS: 40.99854941425383\n",
      "EPOCH: 14178 LOSS: 40.998545881521494\n",
      "EPOCH: 14179 LOSS: 40.998542349203355\n",
      "EPOCH: 14180 LOSS: 40.99853881729935\n",
      "EPOCH: 14181 LOSS: 40.99853528580941\n",
      "EPOCH: 14182 LOSS: 40.998531754733435\n",
      "EPOCH: 14183 LOSS: 40.9985282240714\n",
      "EPOCH: 14184 LOSS: 40.99852469382321\n",
      "EPOCH: 14185 LOSS: 40.9985211639888\n",
      "EPOCH: 14186 LOSS: 40.9985176345681\n",
      "EPOCH: 14187 LOSS: 40.99851410556105\n",
      "EPOCH: 14188 LOSS: 40.99851057696758\n",
      "EPOCH: 14189 LOSS: 40.9985070487876\n",
      "EPOCH: 14190 LOSS: 40.998503521021064\n",
      "EPOCH: 14191 LOSS: 40.99849999366791\n",
      "EPOCH: 14192 LOSS: 40.99849646672803\n",
      "EPOCH: 14193 LOSS: 40.99849294020139\n",
      "EPOCH: 14194 LOSS: 40.9984894140879\n",
      "EPOCH: 14195 LOSS: 40.99848588838752\n",
      "EPOCH: 14196 LOSS: 40.99848236310015\n",
      "EPOCH: 14197 LOSS: 40.99847883822572\n",
      "EPOCH: 14198 LOSS: 40.99847531376419\n",
      "EPOCH: 14199 LOSS: 40.99847178971547\n",
      "EPOCH: 14200 LOSS: 40.99846826607951\n",
      "EPOCH: 14201 LOSS: 40.998464742856186\n",
      "EPOCH: 14202 LOSS: 40.998461220045506\n",
      "EPOCH: 14203 LOSS: 40.99845769764734\n",
      "EPOCH: 14204 LOSS: 40.99845417566166\n",
      "EPOCH: 14205 LOSS: 40.99845065408837\n",
      "EPOCH: 14206 LOSS: 40.998447132927424\n",
      "EPOCH: 14207 LOSS: 40.998443612178725\n",
      "EPOCH: 14208 LOSS: 40.99844009184223\n",
      "EPOCH: 14209 LOSS: 40.99843657191785\n",
      "EPOCH: 14210 LOSS: 40.99843305240553\n",
      "EPOCH: 14211 LOSS: 40.9984295333052\n",
      "EPOCH: 14212 LOSS: 40.99842601461677\n",
      "EPOCH: 14213 LOSS: 40.99842249634021\n",
      "EPOCH: 14214 LOSS: 40.998418978475414\n",
      "EPOCH: 14215 LOSS: 40.99841546102235\n",
      "EPOCH: 14216 LOSS: 40.9984119439809\n",
      "EPOCH: 14217 LOSS: 40.99840842735104\n",
      "EPOCH: 14218 LOSS: 40.998404911132695\n",
      "EPOCH: 14219 LOSS: 40.99840139532577\n",
      "EPOCH: 14220 LOSS: 40.99839787993022\n",
      "EPOCH: 14221 LOSS: 40.99839436494595\n",
      "EPOCH: 14222 LOSS: 40.99839085037293\n",
      "EPOCH: 14223 LOSS: 40.99838733621105\n",
      "EPOCH: 14224 LOSS: 40.99838382246028\n",
      "EPOCH: 14225 LOSS: 40.99838030912052\n",
      "EPOCH: 14226 LOSS: 40.99837679619172\n",
      "EPOCH: 14227 LOSS: 40.99837328367382\n",
      "EPOCH: 14228 LOSS: 40.99836977156671\n",
      "EPOCH: 14229 LOSS: 40.99836625987037\n",
      "EPOCH: 14230 LOSS: 40.99836274858471\n",
      "EPOCH: 14231 LOSS: 40.99835923770965\n",
      "EPOCH: 14232 LOSS: 40.998355727245126\n",
      "EPOCH: 14233 LOSS: 40.99835221719109\n",
      "EPOCH: 14234 LOSS: 40.998348707547464\n",
      "EPOCH: 14235 LOSS: 40.99834519831417\n",
      "EPOCH: 14236 LOSS: 40.99834168949113\n",
      "EPOCH: 14237 LOSS: 40.998338181078296\n",
      "EPOCH: 14238 LOSS: 40.99833467307559\n",
      "EPOCH: 14239 LOSS: 40.99833116548295\n",
      "EPOCH: 14240 LOSS: 40.99832765830031\n",
      "EPOCH: 14241 LOSS: 40.99832415152759\n",
      "EPOCH: 14242 LOSS: 40.998320645164725\n",
      "EPOCH: 14243 LOSS: 40.99831713921166\n",
      "EPOCH: 14244 LOSS: 40.998313633668296\n",
      "EPOCH: 14245 LOSS: 40.9983101285346\n",
      "EPOCH: 14246 LOSS: 40.99830662381048\n",
      "EPOCH: 14247 LOSS: 40.99830311949587\n",
      "EPOCH: 14248 LOSS: 40.998299615590724\n",
      "EPOCH: 14249 LOSS: 40.998296112094934\n",
      "EPOCH: 14250 LOSS: 40.99829260900846\n",
      "EPOCH: 14251 LOSS: 40.99828910633123\n",
      "EPOCH: 14252 LOSS: 40.99828560406317\n",
      "EPOCH: 14253 LOSS: 40.99828210220423\n",
      "EPOCH: 14254 LOSS: 40.998278600754304\n",
      "EPOCH: 14255 LOSS: 40.99827509971335\n",
      "EPOCH: 14256 LOSS: 40.99827159908129\n",
      "EPOCH: 14257 LOSS: 40.99826809885808\n",
      "EPOCH: 14258 LOSS: 40.998264599043615\n",
      "EPOCH: 14259 LOSS: 40.99826109963787\n",
      "EPOCH: 14260 LOSS: 40.99825760064073\n",
      "EPOCH: 14261 LOSS: 40.99825410205215\n",
      "EPOCH: 14262 LOSS: 40.99825060387206\n",
      "EPOCH: 14263 LOSS: 40.99824710610038\n",
      "EPOCH: 14264 LOSS: 40.99824360873708\n",
      "EPOCH: 14265 LOSS: 40.998240111782046\n",
      "EPOCH: 14266 LOSS: 40.99823661523523\n",
      "EPOCH: 14267 LOSS: 40.99823311909656\n",
      "EPOCH: 14268 LOSS: 40.99822962336597\n",
      "EPOCH: 14269 LOSS: 40.998226128043406\n",
      "EPOCH: 14270 LOSS: 40.99822263312878\n",
      "EPOCH: 14271 LOSS: 40.99821913862202\n",
      "EPOCH: 14272 LOSS: 40.99821564452308\n",
      "EPOCH: 14273 LOSS: 40.998212150831876\n",
      "EPOCH: 14274 LOSS: 40.998208657548346\n",
      "EPOCH: 14275 LOSS: 40.99820516467241\n",
      "EPOCH: 14276 LOSS: 40.998201672204026\n",
      "EPOCH: 14277 LOSS: 40.998198180143106\n",
      "EPOCH: 14278 LOSS: 40.998194688489555\n",
      "EPOCH: 14279 LOSS: 40.99819119724338\n",
      "EPOCH: 14280 LOSS: 40.998187706404444\n",
      "EPOCH: 14281 LOSS: 40.9981842159727\n",
      "EPOCH: 14282 LOSS: 40.9981807259481\n",
      "EPOCH: 14283 LOSS: 40.99817723633056\n",
      "EPOCH: 14284 LOSS: 40.998173747120006\n",
      "EPOCH: 14285 LOSS: 40.998170258316364\n",
      "EPOCH: 14286 LOSS: 40.99816676991958\n",
      "EPOCH: 14287 LOSS: 40.9981632819296\n",
      "EPOCH: 14288 LOSS: 40.998159794346336\n",
      "EPOCH: 14289 LOSS: 40.9981563071697\n",
      "EPOCH: 14290 LOSS: 40.99815282039969\n",
      "EPOCH: 14291 LOSS: 40.99814933403616\n",
      "EPOCH: 14292 LOSS: 40.99814584807909\n",
      "EPOCH: 14293 LOSS: 40.99814236252842\n",
      "EPOCH: 14294 LOSS: 40.99813887738404\n",
      "EPOCH: 14295 LOSS: 40.99813539264592\n",
      "EPOCH: 14296 LOSS: 40.99813190831396\n",
      "EPOCH: 14297 LOSS: 40.99812842438811\n",
      "EPOCH: 14298 LOSS: 40.99812494086831\n",
      "EPOCH: 14299 LOSS: 40.99812145775448\n",
      "EPOCH: 14300 LOSS: 40.99811797504657\n",
      "EPOCH: 14301 LOSS: 40.99811449274448\n",
      "EPOCH: 14302 LOSS: 40.99811101084816\n",
      "EPOCH: 14303 LOSS: 40.99810752935756\n",
      "EPOCH: 14304 LOSS: 40.99810404827259\n",
      "EPOCH: 14305 LOSS: 40.998100567593184\n",
      "EPOCH: 14306 LOSS: 40.99809708731928\n",
      "EPOCH: 14307 LOSS: 40.998093607450805\n",
      "EPOCH: 14308 LOSS: 40.9980901279877\n",
      "EPOCH: 14309 LOSS: 40.99808664892989\n",
      "EPOCH: 14310 LOSS: 40.99808317027731\n",
      "EPOCH: 14311 LOSS: 40.99807969202989\n",
      "EPOCH: 14312 LOSS: 40.998076214187556\n",
      "EPOCH: 14313 LOSS: 40.99807273675027\n",
      "EPOCH: 14314 LOSS: 40.99806925971794\n",
      "EPOCH: 14315 LOSS: 40.99806578309047\n",
      "EPOCH: 14316 LOSS: 40.99806230686785\n",
      "EPOCH: 14317 LOSS: 40.998058831049974\n",
      "EPOCH: 14318 LOSS: 40.998055355636794\n",
      "EPOCH: 14319 LOSS: 40.99805188062824\n",
      "EPOCH: 14320 LOSS: 40.99804840602424\n",
      "EPOCH: 14321 LOSS: 40.99804493182472\n",
      "EPOCH: 14322 LOSS: 40.998041458029626\n",
      "EPOCH: 14323 LOSS: 40.99803798463887\n",
      "EPOCH: 14324 LOSS: 40.99803451165242\n",
      "EPOCH: 14325 LOSS: 40.99803103907016\n",
      "EPOCH: 14326 LOSS: 40.99802756689208\n",
      "EPOCH: 14327 LOSS: 40.99802409511806\n",
      "EPOCH: 14328 LOSS: 40.998020623748076\n",
      "EPOCH: 14329 LOSS: 40.99801715278201\n",
      "EPOCH: 14330 LOSS: 40.998013682219835\n",
      "EPOCH: 14331 LOSS: 40.99801021206148\n",
      "EPOCH: 14332 LOSS: 40.99800674230687\n",
      "EPOCH: 14333 LOSS: 40.99800327295591\n",
      "EPOCH: 14334 LOSS: 40.9979998040086\n",
      "EPOCH: 14335 LOSS: 40.99799633546481\n",
      "EPOCH: 14336 LOSS: 40.99799286732451\n",
      "EPOCH: 14337 LOSS: 40.99798939958761\n",
      "EPOCH: 14338 LOSS: 40.99798593225405\n",
      "EPOCH: 14339 LOSS: 40.99798246532376\n",
      "EPOCH: 14340 LOSS: 40.9979789987967\n",
      "EPOCH: 14341 LOSS: 40.997975532672754\n",
      "EPOCH: 14342 LOSS: 40.997972066951895\n",
      "EPOCH: 14343 LOSS: 40.997968601634035\n",
      "EPOCH: 14344 LOSS: 40.99796513671912\n",
      "EPOCH: 14345 LOSS: 40.99796167220706\n",
      "EPOCH: 14346 LOSS: 40.99795820809781\n",
      "EPOCH: 14347 LOSS: 40.99795474439131\n",
      "EPOCH: 14348 LOSS: 40.99795128108747\n",
      "EPOCH: 14349 LOSS: 40.997947818186226\n",
      "EPOCH: 14350 LOSS: 40.99794435568752\n",
      "EPOCH: 14351 LOSS: 40.99794089359129\n",
      "EPOCH: 14352 LOSS: 40.99793743189746\n",
      "EPOCH: 14353 LOSS: 40.99793397060596\n",
      "EPOCH: 14354 LOSS: 40.99793050971674\n",
      "EPOCH: 14355 LOSS: 40.99792704922969\n",
      "EPOCH: 14356 LOSS: 40.9979235891448\n",
      "EPOCH: 14357 LOSS: 40.99792012946197\n",
      "EPOCH: 14358 LOSS: 40.99791667018113\n",
      "EPOCH: 14359 LOSS: 40.99791321130225\n",
      "EPOCH: 14360 LOSS: 40.99790975282519\n",
      "EPOCH: 14361 LOSS: 40.99790629474995\n",
      "EPOCH: 14362 LOSS: 40.997902837076445\n",
      "EPOCH: 14363 LOSS: 40.9978993798046\n",
      "EPOCH: 14364 LOSS: 40.99789592293436\n",
      "EPOCH: 14365 LOSS: 40.997892466465636\n",
      "EPOCH: 14366 LOSS: 40.99788901039838\n",
      "EPOCH: 14367 LOSS: 40.997885554732534\n",
      "EPOCH: 14368 LOSS: 40.997882099468\n",
      "EPOCH: 14369 LOSS: 40.99787864460475\n",
      "EPOCH: 14370 LOSS: 40.99787519014267\n",
      "EPOCH: 14371 LOSS: 40.99787173608172\n",
      "EPOCH: 14372 LOSS: 40.99786828242186\n",
      "EPOCH: 14373 LOSS: 40.99786482916297\n",
      "EPOCH: 14374 LOSS: 40.99786137630501\n",
      "EPOCH: 14375 LOSS: 40.99785792384792\n",
      "EPOCH: 14376 LOSS: 40.99785447179163\n",
      "EPOCH: 14377 LOSS: 40.99785102013605\n",
      "EPOCH: 14378 LOSS: 40.997847568881156\n",
      "EPOCH: 14379 LOSS: 40.99784411802684\n",
      "EPOCH: 14380 LOSS: 40.99784066757306\n",
      "EPOCH: 14381 LOSS: 40.997837217519724\n",
      "EPOCH: 14382 LOSS: 40.99783376786681\n",
      "EPOCH: 14383 LOSS: 40.997830318614206\n",
      "EPOCH: 14384 LOSS: 40.997826869761866\n",
      "EPOCH: 14385 LOSS: 40.997823421309725\n",
      "EPOCH: 14386 LOSS: 40.997819973257705\n",
      "EPOCH: 14387 LOSS: 40.99781652560576\n",
      "EPOCH: 14388 LOSS: 40.9978130783538\n",
      "EPOCH: 14389 LOSS: 40.99780963150176\n",
      "EPOCH: 14390 LOSS: 40.997806185049576\n",
      "EPOCH: 14391 LOSS: 40.99780273899721\n",
      "EPOCH: 14392 LOSS: 40.997799293344556\n",
      "EPOCH: 14393 LOSS: 40.997795848091585\n",
      "EPOCH: 14394 LOSS: 40.99779240323819\n",
      "EPOCH: 14395 LOSS: 40.997788958784334\n",
      "EPOCH: 14396 LOSS: 40.99778551472993\n",
      "EPOCH: 14397 LOSS: 40.99778207107492\n",
      "EPOCH: 14398 LOSS: 40.99777862781926\n",
      "EPOCH: 14399 LOSS: 40.99777518496285\n",
      "EPOCH: 14400 LOSS: 40.997771742505634\n",
      "EPOCH: 14401 LOSS: 40.99776830044754\n",
      "EPOCH: 14402 LOSS: 40.997764858788535\n",
      "EPOCH: 14403 LOSS: 40.997761417528494\n",
      "EPOCH: 14404 LOSS: 40.9977579766674\n",
      "EPOCH: 14405 LOSS: 40.99775453620518\n",
      "EPOCH: 14406 LOSS: 40.99775109614174\n",
      "EPOCH: 14407 LOSS: 40.99774765647704\n",
      "EPOCH: 14408 LOSS: 40.997744217211\n",
      "EPOCH: 14409 LOSS: 40.99774077834357\n",
      "EPOCH: 14410 LOSS: 40.99773733987467\n",
      "EPOCH: 14411 LOSS: 40.99773390180422\n",
      "EPOCH: 14412 LOSS: 40.99773046413219\n",
      "EPOCH: 14413 LOSS: 40.99772702685848\n",
      "EPOCH: 14414 LOSS: 40.99772358998303\n",
      "EPOCH: 14415 LOSS: 40.997720153505796\n",
      "EPOCH: 14416 LOSS: 40.9977167174267\n",
      "EPOCH: 14417 LOSS: 40.99771328174566\n",
      "EPOCH: 14418 LOSS: 40.99770984646261\n",
      "EPOCH: 14419 LOSS: 40.997706411577525\n",
      "EPOCH: 14420 LOSS: 40.99770297709029\n",
      "EPOCH: 14421 LOSS: 40.99769954300086\n",
      "EPOCH: 14422 LOSS: 40.997696109309175\n",
      "EPOCH: 14423 LOSS: 40.99769267601517\n",
      "EPOCH: 14424 LOSS: 40.99768924311875\n",
      "EPOCH: 14425 LOSS: 40.99768581061988\n",
      "EPOCH: 14426 LOSS: 40.99768237851848\n",
      "EPOCH: 14427 LOSS: 40.997678946814474\n",
      "EPOCH: 14428 LOSS: 40.99767551550782\n",
      "EPOCH: 14429 LOSS: 40.997672084598435\n",
      "EPOCH: 14430 LOSS: 40.997668654086276\n",
      "EPOCH: 14431 LOSS: 40.99766522397124\n",
      "EPOCH: 14432 LOSS: 40.99766179425329\n",
      "EPOCH: 14433 LOSS: 40.997658364932335\n",
      "EPOCH: 14434 LOSS: 40.997654936008345\n",
      "EPOCH: 14435 LOSS: 40.99765150748121\n",
      "EPOCH: 14436 LOSS: 40.997648079350896\n",
      "EPOCH: 14437 LOSS: 40.99764465161732\n",
      "EPOCH: 14438 LOSS: 40.99764122428043\n",
      "EPOCH: 14439 LOSS: 40.99763779734017\n",
      "EPOCH: 14440 LOSS: 40.99763437079643\n",
      "EPOCH: 14441 LOSS: 40.9976309446492\n",
      "EPOCH: 14442 LOSS: 40.997627518898355\n",
      "EPOCH: 14443 LOSS: 40.99762409354389\n",
      "EPOCH: 14444 LOSS: 40.99762066858568\n",
      "EPOCH: 14445 LOSS: 40.997617244023715\n",
      "EPOCH: 14446 LOSS: 40.99761381985789\n",
      "EPOCH: 14447 LOSS: 40.99761039608816\n",
      "EPOCH: 14448 LOSS: 40.99760697271443\n",
      "EPOCH: 14449 LOSS: 40.997603549736674\n",
      "EPOCH: 14450 LOSS: 40.997600127154804\n",
      "EPOCH: 14451 LOSS: 40.99759670496874\n",
      "EPOCH: 14452 LOSS: 40.99759328317845\n",
      "EPOCH: 14453 LOSS: 40.997589861783844\n",
      "EPOCH: 14454 LOSS: 40.99758644078487\n",
      "EPOCH: 14455 LOSS: 40.99758302018145\n",
      "EPOCH: 14456 LOSS: 40.997579599973534\n",
      "EPOCH: 14457 LOSS: 40.99757618016105\n",
      "EPOCH: 14458 LOSS: 40.99757276074391\n",
      "EPOCH: 14459 LOSS: 40.997569341722055\n",
      "EPOCH: 14460 LOSS: 40.99756592309548\n",
      "EPOCH: 14461 LOSS: 40.99756250486403\n",
      "EPOCH: 14462 LOSS: 40.99755908702768\n",
      "EPOCH: 14463 LOSS: 40.99755566958639\n",
      "EPOCH: 14464 LOSS: 40.997552252540046\n",
      "EPOCH: 14465 LOSS: 40.99754883588861\n",
      "EPOCH: 14466 LOSS: 40.997545419632004\n",
      "EPOCH: 14467 LOSS: 40.99754200377018\n",
      "EPOCH: 14468 LOSS: 40.99753858830306\n",
      "EPOCH: 14469 LOSS: 40.99753517323058\n",
      "EPOCH: 14470 LOSS: 40.997531758552675\n",
      "EPOCH: 14471 LOSS: 40.997528344269256\n",
      "EPOCH: 14472 LOSS: 40.997524930380315\n",
      "EPOCH: 14473 LOSS: 40.99752151688573\n",
      "EPOCH: 14474 LOSS: 40.99751810378547\n",
      "EPOCH: 14475 LOSS: 40.99751469107946\n",
      "EPOCH: 14476 LOSS: 40.99751127876762\n",
      "EPOCH: 14477 LOSS: 40.9975078668499\n",
      "EPOCH: 14478 LOSS: 40.99750445532623\n",
      "EPOCH: 14479 LOSS: 40.99750104419654\n",
      "EPOCH: 14480 LOSS: 40.99749763346078\n",
      "EPOCH: 14481 LOSS: 40.99749422311886\n",
      "EPOCH: 14482 LOSS: 40.997490813170735\n",
      "EPOCH: 14483 LOSS: 40.99748740361633\n",
      "EPOCH: 14484 LOSS: 40.997483994455585\n",
      "EPOCH: 14485 LOSS: 40.997480585688436\n",
      "EPOCH: 14486 LOSS: 40.997477177314806\n",
      "EPOCH: 14487 LOSS: 40.997473769334654\n",
      "EPOCH: 14488 LOSS: 40.99747036174787\n",
      "EPOCH: 14489 LOSS: 40.99746695455443\n",
      "EPOCH: 14490 LOSS: 40.997463547754265\n",
      "EPOCH: 14491 LOSS: 40.997460141347304\n",
      "EPOCH: 14492 LOSS: 40.99745673533346\n",
      "EPOCH: 14493 LOSS: 40.997453329712684\n",
      "EPOCH: 14494 LOSS: 40.99744992448491\n",
      "EPOCH: 14495 LOSS: 40.99744651965008\n",
      "EPOCH: 14496 LOSS: 40.997443115208135\n",
      "EPOCH: 14497 LOSS: 40.99743971115899\n",
      "EPOCH: 14498 LOSS: 40.99743630750258\n",
      "EPOCH: 14499 LOSS: 40.99743290423886\n",
      "EPOCH: 14500 LOSS: 40.997429501367755\n",
      "EPOCH: 14501 LOSS: 40.9974260988892\n",
      "EPOCH: 14502 LOSS: 40.9974226968031\n",
      "EPOCH: 14503 LOSS: 40.997419295109424\n",
      "EPOCH: 14504 LOSS: 40.997415893808125\n",
      "EPOCH: 14505 LOSS: 40.9974124928991\n",
      "EPOCH: 14506 LOSS: 40.99740909238229\n",
      "EPOCH: 14507 LOSS: 40.99740569225764\n",
      "EPOCH: 14508 LOSS: 40.99740229252509\n",
      "EPOCH: 14509 LOSS: 40.99739889318454\n",
      "EPOCH: 14510 LOSS: 40.99739549423598\n",
      "EPOCH: 14511 LOSS: 40.9973920956793\n",
      "EPOCH: 14512 LOSS: 40.99738869751445\n",
      "EPOCH: 14513 LOSS: 40.99738529974136\n",
      "EPOCH: 14514 LOSS: 40.99738190235999\n",
      "EPOCH: 14515 LOSS: 40.997378505370236\n",
      "EPOCH: 14516 LOSS: 40.99737510877206\n",
      "EPOCH: 14517 LOSS: 40.9973717125654\n",
      "EPOCH: 14518 LOSS: 40.99736831675017\n",
      "EPOCH: 14519 LOSS: 40.99736492132632\n",
      "EPOCH: 14520 LOSS: 40.99736152629377\n",
      "EPOCH: 14521 LOSS: 40.99735813165248\n",
      "EPOCH: 14522 LOSS: 40.99735473740237\n",
      "EPOCH: 14523 LOSS: 40.997351343543365\n",
      "EPOCH: 14524 LOSS: 40.99734795007541\n",
      "EPOCH: 14525 LOSS: 40.99734455699845\n",
      "EPOCH: 14526 LOSS: 40.99734116431242\n",
      "EPOCH: 14527 LOSS: 40.997337772017225\n",
      "EPOCH: 14528 LOSS: 40.99733438011283\n",
      "EPOCH: 14529 LOSS: 40.99733098859917\n",
      "EPOCH: 14530 LOSS: 40.99732759747616\n",
      "EPOCH: 14531 LOSS: 40.99732420674375\n",
      "EPOCH: 14532 LOSS: 40.99732081640187\n",
      "EPOCH: 14533 LOSS: 40.997317426450444\n",
      "EPOCH: 14534 LOSS: 40.997314036889435\n",
      "EPOCH: 14535 LOSS: 40.99731064771878\n",
      "EPOCH: 14536 LOSS: 40.99730725893836\n",
      "EPOCH: 14537 LOSS: 40.997303870548166\n",
      "EPOCH: 14538 LOSS: 40.99730048254811\n",
      "EPOCH: 14539 LOSS: 40.99729709493815\n",
      "EPOCH: 14540 LOSS: 40.997293707718185\n",
      "EPOCH: 14541 LOSS: 40.99729032088818\n",
      "EPOCH: 14542 LOSS: 40.99728693444807\n",
      "EPOCH: 14543 LOSS: 40.99728354839776\n",
      "EPOCH: 14544 LOSS: 40.997280162737205\n",
      "EPOCH: 14545 LOSS: 40.99727677746635\n",
      "EPOCH: 14546 LOSS: 40.9972733925851\n",
      "EPOCH: 14547 LOSS: 40.99727000809344\n",
      "EPOCH: 14548 LOSS: 40.99726662399126\n",
      "EPOCH: 14549 LOSS: 40.99726324027852\n",
      "EPOCH: 14550 LOSS: 40.997259856955125\n",
      "EPOCH: 14551 LOSS: 40.99725647402107\n",
      "EPOCH: 14552 LOSS: 40.99725309147622\n",
      "EPOCH: 14553 LOSS: 40.99724970932054\n",
      "EPOCH: 14554 LOSS: 40.997246327553995\n",
      "EPOCH: 14555 LOSS: 40.99724294617647\n",
      "EPOCH: 14556 LOSS: 40.997239565187954\n",
      "EPOCH: 14557 LOSS: 40.997236184588324\n",
      "EPOCH: 14558 LOSS: 40.99723280437756\n",
      "EPOCH: 14559 LOSS: 40.99722942455556\n",
      "EPOCH: 14560 LOSS: 40.99722604512232\n",
      "EPOCH: 14561 LOSS: 40.9972226660777\n",
      "EPOCH: 14562 LOSS: 40.9972192874217\n",
      "EPOCH: 14563 LOSS: 40.99721590915421\n",
      "EPOCH: 14564 LOSS: 40.997212531275196\n",
      "EPOCH: 14565 LOSS: 40.997209153784574\n",
      "EPOCH: 14566 LOSS: 40.9972057766823\n",
      "EPOCH: 14567 LOSS: 40.99720239996827\n",
      "EPOCH: 14568 LOSS: 40.99719902364246\n",
      "EPOCH: 14569 LOSS: 40.9971956477048\n",
      "EPOCH: 14570 LOSS: 40.9971922721552\n",
      "EPOCH: 14571 LOSS: 40.99718889699363\n",
      "EPOCH: 14572 LOSS: 40.99718552222\n",
      "EPOCH: 14573 LOSS: 40.99718214783425\n",
      "EPOCH: 14574 LOSS: 40.997178773836325\n",
      "EPOCH: 14575 LOSS: 40.997175400226155\n",
      "EPOCH: 14576 LOSS: 40.9971720270037\n",
      "EPOCH: 14577 LOSS: 40.99716865416884\n",
      "EPOCH: 14578 LOSS: 40.99716528172155\n",
      "EPOCH: 14579 LOSS: 40.997161909661756\n",
      "EPOCH: 14580 LOSS: 40.9971585379894\n",
      "EPOCH: 14581 LOSS: 40.99715516670442\n",
      "EPOCH: 14582 LOSS: 40.99715179580673\n",
      "EPOCH: 14583 LOSS: 40.99714842529629\n",
      "EPOCH: 14584 LOSS: 40.99714505517303\n",
      "EPOCH: 14585 LOSS: 40.997141685436894\n",
      "EPOCH: 14586 LOSS: 40.9971383160878\n",
      "EPOCH: 14587 LOSS: 40.99713494712567\n",
      "EPOCH: 14588 LOSS: 40.99713157855048\n",
      "EPOCH: 14589 LOSS: 40.99712821036216\n",
      "EPOCH: 14590 LOSS: 40.99712484256062\n",
      "EPOCH: 14591 LOSS: 40.9971214751458\n",
      "EPOCH: 14592 LOSS: 40.99711810811765\n",
      "EPOCH: 14593 LOSS: 40.9971147414761\n",
      "EPOCH: 14594 LOSS: 40.997111375221074\n",
      "EPOCH: 14595 LOSS: 40.99710800935253\n",
      "EPOCH: 14596 LOSS: 40.9971046438704\n",
      "EPOCH: 14597 LOSS: 40.99710127877462\n",
      "EPOCH: 14598 LOSS: 40.997097914065115\n",
      "EPOCH: 14599 LOSS: 40.9970945497418\n",
      "EPOCH: 14600 LOSS: 40.99709118580466\n",
      "EPOCH: 14601 LOSS: 40.99708782225362\n",
      "EPOCH: 14602 LOSS: 40.99708445908858\n",
      "EPOCH: 14603 LOSS: 40.99708109630952\n",
      "EPOCH: 14604 LOSS: 40.997077733916335\n",
      "EPOCH: 14605 LOSS: 40.997074371909\n",
      "EPOCH: 14606 LOSS: 40.997071010287435\n",
      "EPOCH: 14607 LOSS: 40.997067649051544\n",
      "EPOCH: 14608 LOSS: 40.99706428820133\n",
      "EPOCH: 14609 LOSS: 40.997060927736676\n",
      "EPOCH: 14610 LOSS: 40.997057567657535\n",
      "EPOCH: 14611 LOSS: 40.99705420796384\n",
      "EPOCH: 14612 LOSS: 40.99705084865554\n",
      "EPOCH: 14613 LOSS: 40.997047489732545\n",
      "EPOCH: 14614 LOSS: 40.99704413119482\n",
      "EPOCH: 14615 LOSS: 40.997040773042286\n",
      "EPOCH: 14616 LOSS: 40.997037415274875\n",
      "EPOCH: 14617 LOSS: 40.997034057892535\n",
      "EPOCH: 14618 LOSS: 40.9970307008952\n",
      "EPOCH: 14619 LOSS: 40.9970273442828\n",
      "EPOCH: 14620 LOSS: 40.997023988055275\n",
      "EPOCH: 14621 LOSS: 40.99702063221257\n",
      "EPOCH: 14622 LOSS: 40.99701727675459\n",
      "EPOCH: 14623 LOSS: 40.997013921681315\n",
      "EPOCH: 14624 LOSS: 40.99701056699264\n",
      "EPOCH: 14625 LOSS: 40.99700721268854\n",
      "EPOCH: 14626 LOSS: 40.99700385876893\n",
      "EPOCH: 14627 LOSS: 40.99700050523374\n",
      "EPOCH: 14628 LOSS: 40.99699715208291\n",
      "EPOCH: 14629 LOSS: 40.996993799316385\n",
      "EPOCH: 14630 LOSS: 40.996990446934106\n",
      "EPOCH: 14631 LOSS: 40.996987094935996\n",
      "EPOCH: 14632 LOSS: 40.99698374332199\n",
      "EPOCH: 14633 LOSS: 40.99698039209204\n",
      "EPOCH: 14634 LOSS: 40.99697704124606\n",
      "EPOCH: 14635 LOSS: 40.996973690784\n",
      "EPOCH: 14636 LOSS: 40.996970340705815\n",
      "EPOCH: 14637 LOSS: 40.99696699101139\n",
      "EPOCH: 14638 LOSS: 40.99696364170073\n",
      "EPOCH: 14639 LOSS: 40.99696029277373\n",
      "EPOCH: 14640 LOSS: 40.996956944230305\n",
      "EPOCH: 14641 LOSS: 40.99695359607044\n",
      "EPOCH: 14642 LOSS: 40.99695024829404\n",
      "EPOCH: 14643 LOSS: 40.996946900901065\n",
      "EPOCH: 14644 LOSS: 40.99694355389143\n",
      "EPOCH: 14645 LOSS: 40.99694020726507\n",
      "EPOCH: 14646 LOSS: 40.99693686102195\n",
      "EPOCH: 14647 LOSS: 40.99693351516196\n",
      "EPOCH: 14648 LOSS: 40.996930169685086\n",
      "EPOCH: 14649 LOSS: 40.99692682459123\n",
      "EPOCH: 14650 LOSS: 40.996923479880344\n",
      "EPOCH: 14651 LOSS: 40.99692013555237\n",
      "EPOCH: 14652 LOSS: 40.99691679160725\n",
      "EPOCH: 14653 LOSS: 40.99691344804488\n",
      "EPOCH: 14654 LOSS: 40.99691010486523\n",
      "EPOCH: 14655 LOSS: 40.99690676206821\n",
      "EPOCH: 14656 LOSS: 40.99690341965382\n",
      "EPOCH: 14657 LOSS: 40.996900077621916\n",
      "EPOCH: 14658 LOSS: 40.996896735972484\n",
      "EPOCH: 14659 LOSS: 40.996893394705474\n",
      "EPOCH: 14660 LOSS: 40.99689005382077\n",
      "EPOCH: 14661 LOSS: 40.99688671331835\n",
      "EPOCH: 14662 LOSS: 40.99688337319813\n",
      "EPOCH: 14663 LOSS: 40.99688003346006\n",
      "EPOCH: 14664 LOSS: 40.99687669410406\n",
      "EPOCH: 14665 LOSS: 40.996873355130084\n",
      "EPOCH: 14666 LOSS: 40.99687001653807\n",
      "EPOCH: 14667 LOSS: 40.99686667832793\n",
      "EPOCH: 14668 LOSS: 40.996863340499644\n",
      "EPOCH: 14669 LOSS: 40.99686000305309\n",
      "EPOCH: 14670 LOSS: 40.99685666598826\n",
      "EPOCH: 14671 LOSS: 40.99685332930506\n",
      "EPOCH: 14672 LOSS: 40.996849993003444\n",
      "EPOCH: 14673 LOSS: 40.99684665708334\n",
      "EPOCH: 14674 LOSS: 40.996843321544674\n",
      "EPOCH: 14675 LOSS: 40.996839986387386\n",
      "EPOCH: 14676 LOSS: 40.99683665161143\n",
      "EPOCH: 14677 LOSS: 40.99683331721673\n",
      "EPOCH: 14678 LOSS: 40.99682998320324\n",
      "EPOCH: 14679 LOSS: 40.99682664957089\n",
      "EPOCH: 14680 LOSS: 40.996823316319606\n",
      "EPOCH: 14681 LOSS: 40.99681998344932\n",
      "EPOCH: 14682 LOSS: 40.99681665095997\n",
      "EPOCH: 14683 LOSS: 40.996813318851515\n",
      "EPOCH: 14684 LOSS: 40.99680998712387\n",
      "EPOCH: 14685 LOSS: 40.996806655776986\n",
      "EPOCH: 14686 LOSS: 40.9968033248108\n",
      "EPOCH: 14687 LOSS: 40.99679999422524\n",
      "EPOCH: 14688 LOSS: 40.99679666402024\n",
      "EPOCH: 14689 LOSS: 40.99679333419575\n",
      "EPOCH: 14690 LOSS: 40.9967900047517\n",
      "EPOCH: 14691 LOSS: 40.99678667568803\n",
      "EPOCH: 14692 LOSS: 40.996783347004666\n",
      "EPOCH: 14693 LOSS: 40.99678001870156\n",
      "EPOCH: 14694 LOSS: 40.99677669077863\n",
      "EPOCH: 14695 LOSS: 40.996773363235846\n",
      "EPOCH: 14696 LOSS: 40.996770036073116\n",
      "EPOCH: 14697 LOSS: 40.9967667092904\n",
      "EPOCH: 14698 LOSS: 40.99676338288761\n",
      "EPOCH: 14699 LOSS: 40.9967600568647\n",
      "EPOCH: 14700 LOSS: 40.99675673122159\n",
      "EPOCH: 14701 LOSS: 40.99675340595825\n",
      "EPOCH: 14702 LOSS: 40.99675008107459\n",
      "EPOCH: 14703 LOSS: 40.99674675657053\n",
      "EPOCH: 14704 LOSS: 40.99674343244606\n",
      "EPOCH: 14705 LOSS: 40.99674010870106\n",
      "EPOCH: 14706 LOSS: 40.99673678533553\n",
      "EPOCH: 14707 LOSS: 40.99673346234937\n",
      "EPOCH: 14708 LOSS: 40.996730139742496\n",
      "EPOCH: 14709 LOSS: 40.99672681751487\n",
      "EPOCH: 14710 LOSS: 40.99672349566645\n",
      "EPOCH: 14711 LOSS: 40.99672017419713\n",
      "EPOCH: 14712 LOSS: 40.9967168531069\n",
      "EPOCH: 14713 LOSS: 40.99671353239563\n",
      "EPOCH: 14714 LOSS: 40.99671021206332\n",
      "EPOCH: 14715 LOSS: 40.99670689210987\n",
      "EPOCH: 14716 LOSS: 40.996703572535225\n",
      "EPOCH: 14717 LOSS: 40.99670025333935\n",
      "EPOCH: 14718 LOSS: 40.996696934522134\n",
      "EPOCH: 14719 LOSS: 40.99669361608354\n",
      "EPOCH: 14720 LOSS: 40.99669029802351\n",
      "EPOCH: 14721 LOSS: 40.99668698034198\n",
      "EPOCH: 14722 LOSS: 40.99668366303889\n",
      "EPOCH: 14723 LOSS: 40.996680346114154\n",
      "EPOCH: 14724 LOSS: 40.996677029567735\n",
      "EPOCH: 14725 LOSS: 40.99667371339956\n",
      "EPOCH: 14726 LOSS: 40.99667039760956\n",
      "EPOCH: 14727 LOSS: 40.996667082197696\n",
      "EPOCH: 14728 LOSS: 40.99666376716388\n",
      "EPOCH: 14729 LOSS: 40.99666045250808\n",
      "EPOCH: 14730 LOSS: 40.99665713823018\n",
      "EPOCH: 14731 LOSS: 40.99665382433018\n",
      "EPOCH: 14732 LOSS: 40.99665051080797\n",
      "EPOCH: 14733 LOSS: 40.99664719766349\n",
      "EPOCH: 14734 LOSS: 40.99664388489674\n",
      "EPOCH: 14735 LOSS: 40.99664057250757\n",
      "EPOCH: 14736 LOSS: 40.99663726049598\n",
      "EPOCH: 14737 LOSS: 40.996633948861884\n",
      "EPOCH: 14738 LOSS: 40.99663063760522\n",
      "EPOCH: 14739 LOSS: 40.99662732672594\n",
      "EPOCH: 14740 LOSS: 40.99662401622396\n",
      "EPOCH: 14741 LOSS: 40.99662070609922\n",
      "EPOCH: 14742 LOSS: 40.99661739635169\n",
      "EPOCH: 14743 LOSS: 40.99661408698125\n",
      "EPOCH: 14744 LOSS: 40.99661077798788\n",
      "EPOCH: 14745 LOSS: 40.996607469371504\n",
      "EPOCH: 14746 LOSS: 40.99660416113207\n",
      "EPOCH: 14747 LOSS: 40.99660085326952\n",
      "EPOCH: 14748 LOSS: 40.99659754578377\n",
      "EPOCH: 14749 LOSS: 40.99659423867478\n",
      "EPOCH: 14750 LOSS: 40.996590931942464\n",
      "EPOCH: 14751 LOSS: 40.99658762558676\n",
      "EPOCH: 14752 LOSS: 40.99658431960765\n",
      "EPOCH: 14753 LOSS: 40.996581014005024\n",
      "EPOCH: 14754 LOSS: 40.996577708778844\n",
      "EPOCH: 14755 LOSS: 40.99657440392902\n",
      "EPOCH: 14756 LOSS: 40.996571099455515\n",
      "EPOCH: 14757 LOSS: 40.996567795358274\n",
      "EPOCH: 14758 LOSS: 40.99656449163722\n",
      "EPOCH: 14759 LOSS: 40.996561188292304\n",
      "EPOCH: 14760 LOSS: 40.996557885323426\n",
      "EPOCH: 14761 LOSS: 40.996554582730575\n",
      "EPOCH: 14762 LOSS: 40.99655128051365\n",
      "EPOCH: 14763 LOSS: 40.9965479786726\n",
      "EPOCH: 14764 LOSS: 40.99654467720739\n",
      "EPOCH: 14765 LOSS: 40.99654137611791\n",
      "EPOCH: 14766 LOSS: 40.99653807540413\n",
      "EPOCH: 14767 LOSS: 40.996534775065996\n",
      "EPOCH: 14768 LOSS: 40.99653147510341\n",
      "EPOCH: 14769 LOSS: 40.99652817551635\n",
      "EPOCH: 14770 LOSS: 40.99652487630472\n",
      "EPOCH: 14771 LOSS: 40.99652157746848\n",
      "EPOCH: 14772 LOSS: 40.99651827900756\n",
      "EPOCH: 14773 LOSS: 40.996514980921894\n",
      "EPOCH: 14774 LOSS: 40.99651168321143\n",
      "EPOCH: 14775 LOSS: 40.99650838587608\n",
      "EPOCH: 14776 LOSS: 40.99650508891584\n",
      "EPOCH: 14777 LOSS: 40.9965017923306\n",
      "EPOCH: 14778 LOSS: 40.99649849612029\n",
      "EPOCH: 14779 LOSS: 40.99649520028488\n",
      "EPOCH: 14780 LOSS: 40.9964919048243\n",
      "EPOCH: 14781 LOSS: 40.99648860973849\n",
      "EPOCH: 14782 LOSS: 40.99648531502736\n",
      "EPOCH: 14783 LOSS: 40.99648202069088\n",
      "EPOCH: 14784 LOSS: 40.99647872672898\n",
      "EPOCH: 14785 LOSS: 40.9964754331416\n",
      "EPOCH: 14786 LOSS: 40.996472139928684\n",
      "EPOCH: 14787 LOSS: 40.99646884709013\n",
      "EPOCH: 14788 LOSS: 40.99646555462592\n",
      "EPOCH: 14789 LOSS: 40.99646226253601\n",
      "EPOCH: 14790 LOSS: 40.99645897082027\n",
      "EPOCH: 14791 LOSS: 40.996455679478686\n",
      "EPOCH: 14792 LOSS: 40.99645238851119\n",
      "EPOCH: 14793 LOSS: 40.99644909791771\n",
      "EPOCH: 14794 LOSS: 40.996445807698194\n",
      "EPOCH: 14795 LOSS: 40.99644251785258\n",
      "EPOCH: 14796 LOSS: 40.9964392283808\n",
      "EPOCH: 14797 LOSS: 40.9964359392828\n",
      "EPOCH: 14798 LOSS: 40.99643265055852\n",
      "EPOCH: 14799 LOSS: 40.99642936220786\n",
      "EPOCH: 14800 LOSS: 40.996426074230826\n",
      "EPOCH: 14801 LOSS: 40.996422786627306\n",
      "EPOCH: 14802 LOSS: 40.99641949939725\n",
      "EPOCH: 14803 LOSS: 40.99641621254061\n",
      "EPOCH: 14804 LOSS: 40.9964129260573\n",
      "EPOCH: 14805 LOSS: 40.99640963994729\n",
      "EPOCH: 14806 LOSS: 40.996406354210485\n",
      "EPOCH: 14807 LOSS: 40.99640306884684\n",
      "EPOCH: 14808 LOSS: 40.996399783856305\n",
      "EPOCH: 14809 LOSS: 40.9963964992388\n",
      "EPOCH: 14810 LOSS: 40.996393214994285\n",
      "EPOCH: 14811 LOSS: 40.996389931122664\n",
      "EPOCH: 14812 LOSS: 40.9963866476239\n",
      "EPOCH: 14813 LOSS: 40.99638336449793\n",
      "EPOCH: 14814 LOSS: 40.996380081744675\n",
      "EPOCH: 14815 LOSS: 40.996376799364114\n",
      "EPOCH: 14816 LOSS: 40.996373517356126\n",
      "EPOCH: 14817 LOSS: 40.996370235720704\n",
      "EPOCH: 14818 LOSS: 40.99636695445775\n",
      "EPOCH: 14819 LOSS: 40.99636367356724\n",
      "EPOCH: 14820 LOSS: 40.99636039304907\n",
      "EPOCH: 14821 LOSS: 40.99635711290321\n",
      "EPOCH: 14822 LOSS: 40.99635383312959\n",
      "EPOCH: 14823 LOSS: 40.996350553728135\n",
      "EPOCH: 14824 LOSS: 40.996347274698806\n",
      "EPOCH: 14825 LOSS: 40.99634399604151\n",
      "EPOCH: 14826 LOSS: 40.996340717756226\n",
      "EPOCH: 14827 LOSS: 40.996337439842875\n",
      "EPOCH: 14828 LOSS: 40.99633416230137\n",
      "EPOCH: 14829 LOSS: 40.9963308851317\n",
      "EPOCH: 14830 LOSS: 40.996327608333765\n",
      "EPOCH: 14831 LOSS: 40.996324331907516\n",
      "EPOCH: 14832 LOSS: 40.99632105585289\n",
      "EPOCH: 14833 LOSS: 40.99631778016983\n",
      "EPOCH: 14834 LOSS: 40.99631450485827\n",
      "EPOCH: 14835 LOSS: 40.99631122991816\n",
      "EPOCH: 14836 LOSS: 40.99630795534941\n",
      "EPOCH: 14837 LOSS: 40.996304681151976\n",
      "EPOCH: 14838 LOSS: 40.99630140732582\n",
      "EPOCH: 14839 LOSS: 40.996298133870845\n",
      "EPOCH: 14840 LOSS: 40.99629486078702\n",
      "EPOCH: 14841 LOSS: 40.99629158807425\n",
      "EPOCH: 14842 LOSS: 40.99628831573251\n",
      "EPOCH: 14843 LOSS: 40.9962850437617\n",
      "EPOCH: 14844 LOSS: 40.9962817721618\n",
      "EPOCH: 14845 LOSS: 40.99627850093271\n",
      "EPOCH: 14846 LOSS: 40.9962752300744\n",
      "EPOCH: 14847 LOSS: 40.9962719595868\n",
      "EPOCH: 14848 LOSS: 40.996268689469844\n",
      "EPOCH: 14849 LOSS: 40.99626541972346\n",
      "EPOCH: 14850 LOSS: 40.996262150347604\n",
      "EPOCH: 14851 LOSS: 40.996258881342214\n",
      "EPOCH: 14852 LOSS: 40.996255612707216\n",
      "EPOCH: 14853 LOSS: 40.996252344442574\n",
      "EPOCH: 14854 LOSS: 40.99624907654821\n",
      "EPOCH: 14855 LOSS: 40.996245809024046\n",
      "EPOCH: 14856 LOSS: 40.99624254187006\n",
      "EPOCH: 14857 LOSS: 40.996239275086154\n",
      "EPOCH: 14858 LOSS: 40.9962360086723\n",
      "EPOCH: 14859 LOSS: 40.9962327426284\n",
      "EPOCH: 14860 LOSS: 40.99622947695444\n",
      "EPOCH: 14861 LOSS: 40.99622621165031\n",
      "EPOCH: 14862 LOSS: 40.996222946715974\n",
      "EPOCH: 14863 LOSS: 40.99621968215137\n",
      "EPOCH: 14864 LOSS: 40.996216417956454\n",
      "EPOCH: 14865 LOSS: 40.99621315413112\n",
      "EPOCH: 14866 LOSS: 40.99620989067535\n",
      "EPOCH: 14867 LOSS: 40.99620662758906\n",
      "EPOCH: 14868 LOSS: 40.99620336487219\n",
      "EPOCH: 14869 LOSS: 40.99620010252471\n",
      "EPOCH: 14870 LOSS: 40.9961968405465\n",
      "EPOCH: 14871 LOSS: 40.99619357893755\n",
      "EPOCH: 14872 LOSS: 40.996190317697796\n",
      "EPOCH: 14873 LOSS: 40.996187056827154\n",
      "EPOCH: 14874 LOSS: 40.99618379632556\n",
      "EPOCH: 14875 LOSS: 40.99618053619299\n",
      "EPOCH: 14876 LOSS: 40.99617727642935\n",
      "EPOCH: 14877 LOSS: 40.996174017034576\n",
      "EPOCH: 14878 LOSS: 40.99617075800863\n",
      "EPOCH: 14879 LOSS: 40.99616749935144\n",
      "EPOCH: 14880 LOSS: 40.996164241062964\n",
      "EPOCH: 14881 LOSS: 40.9961609831431\n",
      "EPOCH: 14882 LOSS: 40.996157725591814\n",
      "EPOCH: 14883 LOSS: 40.99615446840906\n",
      "EPOCH: 14884 LOSS: 40.996151211594736\n",
      "EPOCH: 14885 LOSS: 40.99614795514883\n",
      "EPOCH: 14886 LOSS: 40.99614469907123\n",
      "EPOCH: 14887 LOSS: 40.99614144336192\n",
      "EPOCH: 14888 LOSS: 40.99613818802081\n",
      "EPOCH: 14889 LOSS: 40.99613493304787\n",
      "EPOCH: 14890 LOSS: 40.99613167844301\n",
      "EPOCH: 14891 LOSS: 40.99612842420618\n",
      "EPOCH: 14892 LOSS: 40.9961251703373\n",
      "EPOCH: 14893 LOSS: 40.996121916836344\n",
      "EPOCH: 14894 LOSS: 40.99611866370325\n",
      "EPOCH: 14895 LOSS: 40.99611541093793\n",
      "EPOCH: 14896 LOSS: 40.996112158540335\n",
      "EPOCH: 14897 LOSS: 40.996108906510415\n",
      "EPOCH: 14898 LOSS: 40.996105654848094\n",
      "EPOCH: 14899 LOSS: 40.99610240355331\n",
      "EPOCH: 14900 LOSS: 40.99609915262602\n",
      "EPOCH: 14901 LOSS: 40.99609590206616\n",
      "EPOCH: 14902 LOSS: 40.99609265187365\n",
      "EPOCH: 14903 LOSS: 40.996089402048455\n",
      "EPOCH: 14904 LOSS: 40.99608615259049\n",
      "EPOCH: 14905 LOSS: 40.99608290349971\n",
      "EPOCH: 14906 LOSS: 40.996079654776075\n",
      "EPOCH: 14907 LOSS: 40.996076406419476\n",
      "EPOCH: 14908 LOSS: 40.99607315842988\n",
      "EPOCH: 14909 LOSS: 40.99606991080723\n",
      "EPOCH: 14910 LOSS: 40.99606666355146\n",
      "EPOCH: 14911 LOSS: 40.996063416662516\n",
      "EPOCH: 14912 LOSS: 40.99606017014033\n",
      "EPOCH: 14913 LOSS: 40.99605692398484\n",
      "EPOCH: 14914 LOSS: 40.99605367819599\n",
      "EPOCH: 14915 LOSS: 40.99605043277371\n",
      "EPOCH: 14916 LOSS: 40.996047187717956\n",
      "EPOCH: 14917 LOSS: 40.99604394302865\n",
      "EPOCH: 14918 LOSS: 40.99604069870577\n",
      "EPOCH: 14919 LOSS: 40.99603745474921\n",
      "EPOCH: 14920 LOSS: 40.996034211158914\n",
      "EPOCH: 14921 LOSS: 40.99603096793484\n",
      "EPOCH: 14922 LOSS: 40.996027725076935\n",
      "EPOCH: 14923 LOSS: 40.99602448258511\n",
      "EPOCH: 14924 LOSS: 40.99602124045935\n",
      "EPOCH: 14925 LOSS: 40.99601799869954\n",
      "EPOCH: 14926 LOSS: 40.99601475730566\n",
      "EPOCH: 14927 LOSS: 40.99601151627763\n",
      "EPOCH: 14928 LOSS: 40.996008275615395\n",
      "EPOCH: 14929 LOSS: 40.99600503531889\n",
      "EPOCH: 14930 LOSS: 40.99600179538807\n",
      "EPOCH: 14931 LOSS: 40.995998555822844\n",
      "EPOCH: 14932 LOSS: 40.995995316623194\n",
      "EPOCH: 14933 LOSS: 40.995992077789026\n",
      "EPOCH: 14934 LOSS: 40.99598883932031\n",
      "EPOCH: 14935 LOSS: 40.995985601216944\n",
      "EPOCH: 14936 LOSS: 40.9959823634789\n",
      "EPOCH: 14937 LOSS: 40.995979126106135\n",
      "EPOCH: 14938 LOSS: 40.99597588909856\n",
      "EPOCH: 14939 LOSS: 40.99597265245609\n",
      "EPOCH: 14940 LOSS: 40.9959694161787\n",
      "EPOCH: 14941 LOSS: 40.99596618026635\n",
      "EPOCH: 14942 LOSS: 40.995962944718926\n",
      "EPOCH: 14943 LOSS: 40.99595970953642\n",
      "EPOCH: 14944 LOSS: 40.995956474718724\n",
      "EPOCH: 14945 LOSS: 40.99595324026583\n",
      "EPOCH: 14946 LOSS: 40.995950006177615\n",
      "EPOCH: 14947 LOSS: 40.99594677245408\n",
      "EPOCH: 14948 LOSS: 40.99594353909513\n",
      "EPOCH: 14949 LOSS: 40.99594030610072\n",
      "EPOCH: 14950 LOSS: 40.99593707347078\n",
      "EPOCH: 14951 LOSS: 40.99593384120527\n",
      "EPOCH: 14952 LOSS: 40.9959306093041\n",
      "EPOCH: 14953 LOSS: 40.99592737776722\n",
      "EPOCH: 14954 LOSS: 40.99592414659457\n",
      "EPOCH: 14955 LOSS: 40.9959209157861\n",
      "EPOCH: 14956 LOSS: 40.99591768534175\n",
      "EPOCH: 14957 LOSS: 40.99591445526146\n",
      "EPOCH: 14958 LOSS: 40.99591122554516\n",
      "EPOCH: 14959 LOSS: 40.9959079961928\n",
      "EPOCH: 14960 LOSS: 40.995904767204294\n",
      "EPOCH: 14961 LOSS: 40.99590153857963\n",
      "EPOCH: 14962 LOSS: 40.99589831031871\n",
      "EPOCH: 14963 LOSS: 40.99589508242149\n",
      "EPOCH: 14964 LOSS: 40.9958918548879\n",
      "EPOCH: 14965 LOSS: 40.9958886277179\n",
      "EPOCH: 14966 LOSS: 40.9958854009114\n",
      "EPOCH: 14967 LOSS: 40.99588217446836\n",
      "EPOCH: 14968 LOSS: 40.995878948388736\n",
      "EPOCH: 14969 LOSS: 40.99587572267244\n",
      "EPOCH: 14970 LOSS: 40.9958724973194\n",
      "EPOCH: 14971 LOSS: 40.995869272329614\n",
      "EPOCH: 14972 LOSS: 40.99586604770296\n",
      "EPOCH: 14973 LOSS: 40.99586282343942\n",
      "EPOCH: 14974 LOSS: 40.99585959953891\n",
      "EPOCH: 14975 LOSS: 40.995856376001385\n",
      "EPOCH: 14976 LOSS: 40.99585315282678\n",
      "EPOCH: 14977 LOSS: 40.99584993001503\n",
      "EPOCH: 14978 LOSS: 40.99584670756609\n",
      "EPOCH: 14979 LOSS: 40.99584348547988\n",
      "EPOCH: 14980 LOSS: 40.99584026375634\n",
      "EPOCH: 14981 LOSS: 40.99583704239545\n",
      "EPOCH: 14982 LOSS: 40.99583382139711\n",
      "EPOCH: 14983 LOSS: 40.995830600761295\n",
      "EPOCH: 14984 LOSS: 40.995827380487896\n",
      "EPOCH: 14985 LOSS: 40.99582416057689\n",
      "EPOCH: 14986 LOSS: 40.99582094102821\n",
      "EPOCH: 14987 LOSS: 40.99581772184179\n",
      "EPOCH: 14988 LOSS: 40.99581450301758\n",
      "EPOCH: 14989 LOSS: 40.99581128455551\n",
      "EPOCH: 14990 LOSS: 40.99580806645552\n",
      "EPOCH: 14991 LOSS: 40.995804848717555\n",
      "EPOCH: 14992 LOSS: 40.995801631341585\n",
      "EPOCH: 14993 LOSS: 40.99579841432749\n",
      "EPOCH: 14994 LOSS: 40.995795197675264\n",
      "EPOCH: 14995 LOSS: 40.99579198138483\n",
      "EPOCH: 14996 LOSS: 40.995788765456105\n",
      "EPOCH: 14997 LOSS: 40.995785549889064\n",
      "EPOCH: 14998 LOSS: 40.995782334683625\n",
      "EPOCH: 14999 LOSS: 40.99577911983974\n",
      "EPOCH: 15000 LOSS: 40.99577590535736\n",
      "EPOCH: 15001 LOSS: 40.995772691236404\n",
      "EPOCH: 15002 LOSS: 40.99576947747683\n",
      "EPOCH: 15003 LOSS: 40.995766264078554\n",
      "EPOCH: 15004 LOSS: 40.99576305104154\n",
      "EPOCH: 15005 LOSS: 40.99575983836572\n",
      "EPOCH: 15006 LOSS: 40.99575662605103\n",
      "EPOCH: 15007 LOSS: 40.99575341409743\n",
      "EPOCH: 15008 LOSS: 40.995750202504844\n",
      "EPOCH: 15009 LOSS: 40.99574699127321\n",
      "EPOCH: 15010 LOSS: 40.995743780402485\n",
      "EPOCH: 15011 LOSS: 40.995740569892575\n",
      "EPOCH: 15012 LOSS: 40.99573735974347\n",
      "EPOCH: 15013 LOSS: 40.995734149955084\n",
      "EPOCH: 15014 LOSS: 40.99573094052735\n",
      "EPOCH: 15015 LOSS: 40.99572773146022\n",
      "EPOCH: 15016 LOSS: 40.99572452275363\n",
      "EPOCH: 15017 LOSS: 40.99572131440754\n",
      "EPOCH: 15018 LOSS: 40.99571810642186\n",
      "EPOCH: 15019 LOSS: 40.99571489879656\n",
      "EPOCH: 15020 LOSS: 40.99571169153156\n",
      "EPOCH: 15021 LOSS: 40.995708484626796\n",
      "EPOCH: 15022 LOSS: 40.99570527808224\n",
      "EPOCH: 15023 LOSS: 40.99570207189781\n",
      "EPOCH: 15024 LOSS: 40.99569886607344\n",
      "EPOCH: 15025 LOSS: 40.99569566060909\n",
      "EPOCH: 15026 LOSS: 40.99569245550468\n",
      "EPOCH: 15027 LOSS: 40.99568925076017\n",
      "EPOCH: 15028 LOSS: 40.9956860463755\n",
      "EPOCH: 15029 LOSS: 40.9956828423506\n",
      "EPOCH: 15030 LOSS: 40.99567963868542\n",
      "EPOCH: 15031 LOSS: 40.99567643537989\n",
      "EPOCH: 15032 LOSS: 40.99567323243397\n",
      "EPOCH: 15033 LOSS: 40.99567002984756\n",
      "EPOCH: 15034 LOSS: 40.99566682762066\n",
      "EPOCH: 15035 LOSS: 40.99566362575316\n",
      "EPOCH: 15036 LOSS: 40.995660424245045\n",
      "EPOCH: 15037 LOSS: 40.99565722309623\n",
      "EPOCH: 15038 LOSS: 40.99565402230664\n",
      "EPOCH: 15039 LOSS: 40.99565082187623\n",
      "EPOCH: 15040 LOSS: 40.99564762180497\n",
      "EPOCH: 15041 LOSS: 40.99564442209277\n",
      "EPOCH: 15042 LOSS: 40.995641222739565\n",
      "EPOCH: 15043 LOSS: 40.99563802374533\n",
      "EPOCH: 15044 LOSS: 40.99563482510998\n",
      "EPOCH: 15045 LOSS: 40.99563162683344\n",
      "EPOCH: 15046 LOSS: 40.9956284289157\n",
      "EPOCH: 15047 LOSS: 40.995625231356655\n",
      "EPOCH: 15048 LOSS: 40.995622034156284\n",
      "EPOCH: 15049 LOSS: 40.99561883731451\n",
      "EPOCH: 15050 LOSS: 40.99561564083125\n",
      "EPOCH: 15051 LOSS: 40.99561244470648\n",
      "EPOCH: 15052 LOSS: 40.995609248940134\n",
      "EPOCH: 15053 LOSS: 40.99560605353216\n",
      "EPOCH: 15054 LOSS: 40.99560285848246\n",
      "EPOCH: 15055 LOSS: 40.99559966379101\n",
      "EPOCH: 15056 LOSS: 40.99559646945775\n",
      "EPOCH: 15057 LOSS: 40.99559327548262\n",
      "EPOCH: 15058 LOSS: 40.995590081865565\n",
      "EPOCH: 15059 LOSS: 40.9955868886065\n",
      "EPOCH: 15060 LOSS: 40.995583695705406\n",
      "EPOCH: 15061 LOSS: 40.99558050316219\n",
      "EPOCH: 15062 LOSS: 40.995577310976806\n",
      "EPOCH: 15063 LOSS: 40.99557411914919\n",
      "EPOCH: 15064 LOSS: 40.99557092767929\n",
      "EPOCH: 15065 LOSS: 40.99556773656705\n",
      "EPOCH: 15066 LOSS: 40.995564545812414\n",
      "EPOCH: 15067 LOSS: 40.995561355415305\n",
      "EPOCH: 15068 LOSS: 40.995558165375684\n",
      "EPOCH: 15069 LOSS: 40.995554975693494\n",
      "EPOCH: 15070 LOSS: 40.99555178636865\n",
      "EPOCH: 15071 LOSS: 40.995548597401125\n",
      "EPOCH: 15072 LOSS: 40.995545408790825\n",
      "EPOCH: 15073 LOSS: 40.995542220537736\n",
      "EPOCH: 15074 LOSS: 40.99553903264177\n",
      "EPOCH: 15075 LOSS: 40.99553584510286\n",
      "EPOCH: 15076 LOSS: 40.99553265792098\n",
      "EPOCH: 15077 LOSS: 40.995529471096035\n",
      "EPOCH: 15078 LOSS: 40.995526284628006\n",
      "EPOCH: 15079 LOSS: 40.9955230985168\n",
      "EPOCH: 15080 LOSS: 40.995519912762376\n",
      "EPOCH: 15081 LOSS: 40.995516727364674\n",
      "EPOCH: 15082 LOSS: 40.995513542323636\n",
      "EPOCH: 15083 LOSS: 40.995510357639176\n",
      "EPOCH: 15084 LOSS: 40.99550717331129\n",
      "EPOCH: 15085 LOSS: 40.99550398933987\n",
      "EPOCH: 15086 LOSS: 40.99550080572489\n",
      "EPOCH: 15087 LOSS: 40.995497622466274\n",
      "EPOCH: 15088 LOSS: 40.995494439563956\n",
      "EPOCH: 15089 LOSS: 40.9954912570179\n",
      "EPOCH: 15090 LOSS: 40.99548807482805\n",
      "EPOCH: 15091 LOSS: 40.99548489299432\n",
      "EPOCH: 15092 LOSS: 40.99548171151667\n",
      "EPOCH: 15093 LOSS: 40.99547853039504\n",
      "EPOCH: 15094 LOSS: 40.99547534962936\n",
      "EPOCH: 15095 LOSS: 40.995472169219596\n",
      "EPOCH: 15096 LOSS: 40.99546898916567\n",
      "EPOCH: 15097 LOSS: 40.99546580946753\n",
      "EPOCH: 15098 LOSS: 40.9954626301251\n",
      "EPOCH: 15099 LOSS: 40.995459451138366\n",
      "EPOCH: 15100 LOSS: 40.99545627250722\n",
      "EPOCH: 15101 LOSS: 40.99545309423165\n",
      "EPOCH: 15102 LOSS: 40.99544991631154\n",
      "EPOCH: 15103 LOSS: 40.9954467387469\n",
      "EPOCH: 15104 LOSS: 40.99544356153761\n",
      "EPOCH: 15105 LOSS: 40.99544038468366\n",
      "EPOCH: 15106 LOSS: 40.99543720818496\n",
      "EPOCH: 15107 LOSS: 40.99543403204146\n",
      "EPOCH: 15108 LOSS: 40.995430856253115\n",
      "EPOCH: 15109 LOSS: 40.995427680819844\n",
      "EPOCH: 15110 LOSS: 40.995424505741624\n",
      "EPOCH: 15111 LOSS: 40.99542133101835\n",
      "EPOCH: 15112 LOSS: 40.995418156649976\n",
      "EPOCH: 15113 LOSS: 40.99541498263649\n",
      "EPOCH: 15114 LOSS: 40.99541180897778\n",
      "EPOCH: 15115 LOSS: 40.99540863567381\n",
      "EPOCH: 15116 LOSS: 40.99540546272452\n",
      "EPOCH: 15117 LOSS: 40.995402290129846\n",
      "EPOCH: 15118 LOSS: 40.995399117889754\n",
      "EPOCH: 15119 LOSS: 40.99539594600413\n",
      "EPOCH: 15120 LOSS: 40.995392774472975\n",
      "EPOCH: 15121 LOSS: 40.995389603296225\n",
      "EPOCH: 15122 LOSS: 40.995386432473786\n",
      "EPOCH: 15123 LOSS: 40.99538326200562\n",
      "EPOCH: 15124 LOSS: 40.99538009189166\n",
      "EPOCH: 15125 LOSS: 40.995376922131875\n",
      "EPOCH: 15126 LOSS: 40.995373752726195\n",
      "EPOCH: 15127 LOSS: 40.99537058367454\n",
      "EPOCH: 15128 LOSS: 40.995367414976876\n",
      "EPOCH: 15129 LOSS: 40.99536424663313\n",
      "EPOCH: 15130 LOSS: 40.99536107864325\n",
      "EPOCH: 15131 LOSS: 40.99535791100718\n",
      "EPOCH: 15132 LOSS: 40.99535474372487\n",
      "EPOCH: 15133 LOSS: 40.99535157679625\n",
      "EPOCH: 15134 LOSS: 40.99534841022126\n",
      "EPOCH: 15135 LOSS: 40.99534524399986\n",
      "EPOCH: 15136 LOSS: 40.995342078131955\n",
      "EPOCH: 15137 LOSS: 40.99533891261753\n",
      "EPOCH: 15138 LOSS: 40.9953357474565\n",
      "EPOCH: 15139 LOSS: 40.99533258264882\n",
      "EPOCH: 15140 LOSS: 40.99532941819443\n",
      "EPOCH: 15141 LOSS: 40.99532625409328\n",
      "EPOCH: 15142 LOSS: 40.99532309034528\n",
      "EPOCH: 15143 LOSS: 40.9953199269504\n",
      "EPOCH: 15144 LOSS: 40.995316763908576\n",
      "EPOCH: 15145 LOSS: 40.99531360121978\n",
      "EPOCH: 15146 LOSS: 40.99531043888389\n",
      "EPOCH: 15147 LOSS: 40.9953072769009\n",
      "EPOCH: 15148 LOSS: 40.99530411527072\n",
      "EPOCH: 15149 LOSS: 40.99530095399331\n",
      "EPOCH: 15150 LOSS: 40.99529779306863\n",
      "EPOCH: 15151 LOSS: 40.995294632496595\n",
      "EPOCH: 15152 LOSS: 40.995291472277145\n",
      "EPOCH: 15153 LOSS: 40.99528831241024\n",
      "EPOCH: 15154 LOSS: 40.99528515289582\n",
      "EPOCH: 15155 LOSS: 40.99528199373381\n",
      "EPOCH: 15156 LOSS: 40.995278834924164\n",
      "EPOCH: 15157 LOSS: 40.99527567646682\n",
      "EPOCH: 15158 LOSS: 40.995272518361745\n",
      "EPOCH: 15159 LOSS: 40.995269360608845\n",
      "EPOCH: 15160 LOSS: 40.99526620320809\n",
      "EPOCH: 15161 LOSS: 40.995263046159394\n",
      "EPOCH: 15162 LOSS: 40.99525988946273\n",
      "EPOCH: 15163 LOSS: 40.99525673311802\n",
      "EPOCH: 15164 LOSS: 40.99525357712521\n",
      "EPOCH: 15165 LOSS: 40.99525042148426\n",
      "EPOCH: 15166 LOSS: 40.99524726619508\n",
      "EPOCH: 15167 LOSS: 40.99524411125765\n",
      "EPOCH: 15168 LOSS: 40.995240956671864\n",
      "EPOCH: 15169 LOSS: 40.995237802437714\n",
      "EPOCH: 15170 LOSS: 40.99523464855511\n",
      "EPOCH: 15171 LOSS: 40.995231495024015\n",
      "EPOCH: 15172 LOSS: 40.99522834184437\n",
      "EPOCH: 15173 LOSS: 40.99522518901611\n",
      "EPOCH: 15174 LOSS: 40.995222036539154\n",
      "EPOCH: 15175 LOSS: 40.995218884413475\n",
      "EPOCH: 15176 LOSS: 40.99521573263903\n",
      "EPOCH: 15177 LOSS: 40.99521258121572\n",
      "EPOCH: 15178 LOSS: 40.99520943014352\n",
      "EPOCH: 15179 LOSS: 40.99520627942236\n",
      "EPOCH: 15180 LOSS: 40.995203129052165\n",
      "EPOCH: 15181 LOSS: 40.99519997903292\n",
      "EPOCH: 15182 LOSS: 40.99519682936453\n",
      "EPOCH: 15183 LOSS: 40.99519368004695\n",
      "EPOCH: 15184 LOSS: 40.995190531080134\n",
      "EPOCH: 15185 LOSS: 40.99518738246401\n",
      "EPOCH: 15186 LOSS: 40.99518423419852\n",
      "EPOCH: 15187 LOSS: 40.99518108628362\n",
      "EPOCH: 15188 LOSS: 40.99517793871922\n",
      "EPOCH: 15189 LOSS: 40.99517479150532\n",
      "EPOCH: 15190 LOSS: 40.99517164464181\n",
      "EPOCH: 15191 LOSS: 40.995168498128656\n",
      "EPOCH: 15192 LOSS: 40.99516535196579\n",
      "EPOCH: 15193 LOSS: 40.99516220615317\n",
      "EPOCH: 15194 LOSS: 40.99515906069072\n",
      "EPOCH: 15195 LOSS: 40.99515591557841\n",
      "EPOCH: 15196 LOSS: 40.99515277081615\n",
      "EPOCH: 15197 LOSS: 40.99514962640391\n",
      "EPOCH: 15198 LOSS: 40.99514648234161\n",
      "EPOCH: 15199 LOSS: 40.99514333862922\n",
      "EPOCH: 15200 LOSS: 40.99514019526666\n",
      "EPOCH: 15201 LOSS: 40.99513705225388\n",
      "EPOCH: 15202 LOSS: 40.99513390959081\n",
      "EPOCH: 15203 LOSS: 40.995130767277416\n",
      "EPOCH: 15204 LOSS: 40.99512762531364\n",
      "EPOCH: 15205 LOSS: 40.995124483699385\n",
      "EPOCH: 15206 LOSS: 40.995121342434665\n",
      "EPOCH: 15207 LOSS: 40.995118201519354\n",
      "EPOCH: 15208 LOSS: 40.99511506095344\n",
      "EPOCH: 15209 LOSS: 40.99511192073683\n",
      "EPOCH: 15210 LOSS: 40.9951087808695\n",
      "EPOCH: 15211 LOSS: 40.99510564135137\n",
      "EPOCH: 15212 LOSS: 40.99510250218239\n",
      "EPOCH: 15213 LOSS: 40.99509936336251\n",
      "EPOCH: 15214 LOSS: 40.99509622489167\n",
      "EPOCH: 15215 LOSS: 40.99509308676981\n",
      "EPOCH: 15216 LOSS: 40.99508994899686\n",
      "EPOCH: 15217 LOSS: 40.9950868115728\n",
      "EPOCH: 15218 LOSS: 40.99508367449753\n",
      "EPOCH: 15219 LOSS: 40.99508053777102\n",
      "EPOCH: 15220 LOSS: 40.99507740139319\n",
      "EPOCH: 15221 LOSS: 40.99507426536402\n",
      "EPOCH: 15222 LOSS: 40.99507112968342\n",
      "EPOCH: 15223 LOSS: 40.995067994351345\n",
      "EPOCH: 15224 LOSS: 40.99506485936773\n",
      "EPOCH: 15225 LOSS: 40.995061724732544\n",
      "EPOCH: 15226 LOSS: 40.99505859044568\n",
      "EPOCH: 15227 LOSS: 40.995055456507146\n",
      "EPOCH: 15228 LOSS: 40.995052322916834\n",
      "EPOCH: 15229 LOSS: 40.99504918967472\n",
      "EPOCH: 15230 LOSS: 40.995046056780716\n",
      "EPOCH: 15231 LOSS: 40.99504292423478\n",
      "EPOCH: 15232 LOSS: 40.995039792036856\n",
      "EPOCH: 15233 LOSS: 40.99503666018691\n",
      "EPOCH: 15234 LOSS: 40.99503352868483\n",
      "EPOCH: 15235 LOSS: 40.99503039753061\n",
      "EPOCH: 15236 LOSS: 40.99502726672418\n",
      "EPOCH: 15237 LOSS: 40.995024136265464\n",
      "EPOCH: 15238 LOSS: 40.99502100615443\n",
      "EPOCH: 15239 LOSS: 40.995017876391\n",
      "EPOCH: 15240 LOSS: 40.995014746975144\n",
      "EPOCH: 15241 LOSS: 40.99501161790677\n",
      "EPOCH: 15242 LOSS: 40.99500848918585\n",
      "EPOCH: 15243 LOSS: 40.995005360812314\n",
      "EPOCH: 15244 LOSS: 40.995002232786106\n",
      "EPOCH: 15245 LOSS: 40.99499910510717\n",
      "EPOCH: 15246 LOSS: 40.99499597777547\n",
      "EPOCH: 15247 LOSS: 40.994992850790915\n",
      "EPOCH: 15248 LOSS: 40.99498972415347\n",
      "EPOCH: 15249 LOSS: 40.99498659786306\n",
      "EPOCH: 15250 LOSS: 40.99498347191965\n",
      "EPOCH: 15251 LOSS: 40.994980346323175\n",
      "EPOCH: 15252 LOSS: 40.99497722107358\n",
      "EPOCH: 15253 LOSS: 40.99497409617078\n",
      "EPOCH: 15254 LOSS: 40.994970971614784\n",
      "EPOCH: 15255 LOSS: 40.99496784740546\n",
      "EPOCH: 15256 LOSS: 40.99496472354281\n",
      "EPOCH: 15257 LOSS: 40.99496160002675\n",
      "EPOCH: 15258 LOSS: 40.99495847685723\n",
      "EPOCH: 15259 LOSS: 40.99495535403417\n",
      "EPOCH: 15260 LOSS: 40.994952231557555\n",
      "EPOCH: 15261 LOSS: 40.994949109427296\n",
      "EPOCH: 15262 LOSS: 40.994945987643355\n",
      "EPOCH: 15263 LOSS: 40.994942866205655\n",
      "EPOCH: 15264 LOSS: 40.994939745114166\n",
      "EPOCH: 15265 LOSS: 40.99493662436882\n",
      "EPOCH: 15266 LOSS: 40.99493350396956\n",
      "EPOCH: 15267 LOSS: 40.99493038391632\n",
      "EPOCH: 15268 LOSS: 40.99492726420905\n",
      "EPOCH: 15269 LOSS: 40.9949241448477\n",
      "EPOCH: 15270 LOSS: 40.99492102583223\n",
      "EPOCH: 15271 LOSS: 40.99491790716253\n",
      "EPOCH: 15272 LOSS: 40.99491478883859\n",
      "EPOCH: 15273 LOSS: 40.99491167086033\n",
      "EPOCH: 15274 LOSS: 40.99490855322773\n",
      "EPOCH: 15275 LOSS: 40.99490543594068\n",
      "EPOCH: 15276 LOSS: 40.99490231899916\n",
      "EPOCH: 15277 LOSS: 40.99489920240312\n",
      "EPOCH: 15278 LOSS: 40.994896086152465\n",
      "EPOCH: 15279 LOSS: 40.99489297024716\n",
      "EPOCH: 15280 LOSS: 40.99488985468716\n",
      "EPOCH: 15281 LOSS: 40.99488673947239\n",
      "EPOCH: 15282 LOSS: 40.99488362460282\n",
      "EPOCH: 15283 LOSS: 40.99488051007837\n",
      "EPOCH: 15284 LOSS: 40.99487739589898\n",
      "EPOCH: 15285 LOSS: 40.99487428206461\n",
      "EPOCH: 15286 LOSS: 40.9948711685752\n",
      "EPOCH: 15287 LOSS: 40.994868055430686\n",
      "EPOCH: 15288 LOSS: 40.994864942631025\n",
      "EPOCH: 15289 LOSS: 40.994861830176134\n",
      "EPOCH: 15290 LOSS: 40.994858718065984\n",
      "EPOCH: 15291 LOSS: 40.99485560630052\n",
      "EPOCH: 15292 LOSS: 40.994852494879666\n",
      "EPOCH: 15293 LOSS: 40.994849383803384\n",
      "EPOCH: 15294 LOSS: 40.9948462730716\n",
      "EPOCH: 15295 LOSS: 40.99484316268428\n",
      "EPOCH: 15296 LOSS: 40.99484005264134\n",
      "EPOCH: 15297 LOSS: 40.99483694294274\n",
      "EPOCH: 15298 LOSS: 40.994833833588416\n",
      "EPOCH: 15299 LOSS: 40.994830724578335\n",
      "EPOCH: 15300 LOSS: 40.994827615912406\n",
      "EPOCH: 15301 LOSS: 40.99482450759061\n",
      "EPOCH: 15302 LOSS: 40.99482139961285\n",
      "EPOCH: 15303 LOSS: 40.99481829197912\n",
      "EPOCH: 15304 LOSS: 40.99481518468933\n",
      "EPOCH: 15305 LOSS: 40.99481207774342\n",
      "EPOCH: 15306 LOSS: 40.99480897114133\n",
      "EPOCH: 15307 LOSS: 40.99480586488304\n",
      "EPOCH: 15308 LOSS: 40.99480275896847\n",
      "EPOCH: 15309 LOSS: 40.994799653397536\n",
      "EPOCH: 15310 LOSS: 40.99479654817024\n",
      "EPOCH: 15311 LOSS: 40.99479344328649\n",
      "EPOCH: 15312 LOSS: 40.99479033874624\n",
      "EPOCH: 15313 LOSS: 40.994787234549435\n",
      "EPOCH: 15314 LOSS: 40.99478413069599\n",
      "EPOCH: 15315 LOSS: 40.99478102718591\n",
      "EPOCH: 15316 LOSS: 40.99477792401907\n",
      "EPOCH: 15317 LOSS: 40.99477482119546\n",
      "EPOCH: 15318 LOSS: 40.99477171871502\n",
      "EPOCH: 15319 LOSS: 40.99476861657768\n",
      "EPOCH: 15320 LOSS: 40.99476551478338\n",
      "EPOCH: 15321 LOSS: 40.99476241333208\n",
      "EPOCH: 15322 LOSS: 40.994759312223714\n",
      "EPOCH: 15323 LOSS: 40.99475621145825\n",
      "EPOCH: 15324 LOSS: 40.99475311103559\n",
      "EPOCH: 15325 LOSS: 40.99475001095571\n",
      "EPOCH: 15326 LOSS: 40.994746911218535\n",
      "EPOCH: 15327 LOSS: 40.99474381182402\n",
      "EPOCH: 15328 LOSS: 40.99474071277212\n",
      "EPOCH: 15329 LOSS: 40.994737614062764\n",
      "EPOCH: 15330 LOSS: 40.99473451569588\n",
      "EPOCH: 15331 LOSS: 40.99473141767143\n",
      "EPOCH: 15332 LOSS: 40.99472831998938\n",
      "EPOCH: 15333 LOSS: 40.99472522264965\n",
      "EPOCH: 15334 LOSS: 40.994722125652174\n",
      "EPOCH: 15335 LOSS: 40.99471902899691\n",
      "EPOCH: 15336 LOSS: 40.99471593268382\n",
      "EPOCH: 15337 LOSS: 40.99471283671281\n",
      "EPOCH: 15338 LOSS: 40.99470974108385\n",
      "EPOCH: 15339 LOSS: 40.99470664579688\n",
      "EPOCH: 15340 LOSS: 40.99470355085185\n",
      "EPOCH: 15341 LOSS: 40.99470045624868\n",
      "EPOCH: 15342 LOSS: 40.99469736198735\n",
      "EPOCH: 15343 LOSS: 40.994694268067775\n",
      "EPOCH: 15344 LOSS: 40.9946911744899\n",
      "EPOCH: 15345 LOSS: 40.9946880812537\n",
      "EPOCH: 15346 LOSS: 40.9946849883591\n",
      "EPOCH: 15347 LOSS: 40.994681895806025\n",
      "EPOCH: 15348 LOSS: 40.994678803594454\n",
      "EPOCH: 15349 LOSS: 40.9946757117243\n",
      "EPOCH: 15350 LOSS: 40.994672620195516\n",
      "EPOCH: 15351 LOSS: 40.994669529008064\n",
      "EPOCH: 15352 LOSS: 40.994666438161886\n",
      "EPOCH: 15353 LOSS: 40.994663347656896\n",
      "EPOCH: 15354 LOSS: 40.99466025749307\n",
      "EPOCH: 15355 LOSS: 40.99465716767033\n",
      "EPOCH: 15356 LOSS: 40.994654078188645\n",
      "EPOCH: 15357 LOSS: 40.994650989047955\n",
      "EPOCH: 15358 LOSS: 40.994647900248175\n",
      "EPOCH: 15359 LOSS: 40.99464481178929\n",
      "EPOCH: 15360 LOSS: 40.99464172367122\n",
      "EPOCH: 15361 LOSS: 40.99463863589392\n",
      "EPOCH: 15362 LOSS: 40.9946355484573\n",
      "EPOCH: 15363 LOSS: 40.99463246136137\n",
      "EPOCH: 15364 LOSS: 40.99462937460603\n",
      "EPOCH: 15365 LOSS: 40.99462628819123\n",
      "EPOCH: 15366 LOSS: 40.9946232021169\n",
      "EPOCH: 15367 LOSS: 40.994620116383025\n",
      "EPOCH: 15368 LOSS: 40.9946170309895\n",
      "EPOCH: 15369 LOSS: 40.994613945936315\n",
      "EPOCH: 15370 LOSS: 40.99461086122339\n",
      "EPOCH: 15371 LOSS: 40.994607776850685\n",
      "EPOCH: 15372 LOSS: 40.99460469281813\n",
      "EPOCH: 15373 LOSS: 40.99460160912566\n",
      "EPOCH: 15374 LOSS: 40.99459852577325\n",
      "EPOCH: 15375 LOSS: 40.994595442760826\n",
      "EPOCH: 15376 LOSS: 40.99459236008833\n",
      "EPOCH: 15377 LOSS: 40.99458927775572\n",
      "EPOCH: 15378 LOSS: 40.99458619576291\n",
      "EPOCH: 15379 LOSS: 40.9945831141099\n",
      "EPOCH: 15380 LOSS: 40.99458003279658\n",
      "EPOCH: 15381 LOSS: 40.99457695182293\n",
      "EPOCH: 15382 LOSS: 40.99457387118886\n",
      "EPOCH: 15383 LOSS: 40.99457079089435\n",
      "EPOCH: 15384 LOSS: 40.994567710939336\n",
      "EPOCH: 15385 LOSS: 40.994564631323755\n",
      "EPOCH: 15386 LOSS: 40.994561552047536\n",
      "EPOCH: 15387 LOSS: 40.994558473110665\n",
      "EPOCH: 15388 LOSS: 40.99455539451306\n",
      "EPOCH: 15389 LOSS: 40.994552316254655\n",
      "EPOCH: 15390 LOSS: 40.99454923833541\n",
      "EPOCH: 15391 LOSS: 40.99454616075529\n",
      "EPOCH: 15392 LOSS: 40.994543083514195\n",
      "EPOCH: 15393 LOSS: 40.9945400066121\n",
      "EPOCH: 15394 LOSS: 40.99453693004895\n",
      "EPOCH: 15395 LOSS: 40.99453385382468\n",
      "EPOCH: 15396 LOSS: 40.99453077793923\n",
      "EPOCH: 15397 LOSS: 40.99452770239258\n",
      "EPOCH: 15398 LOSS: 40.9945246271846\n",
      "EPOCH: 15399 LOSS: 40.994521552315334\n",
      "EPOCH: 15400 LOSS: 40.99451847778465\n",
      "EPOCH: 15401 LOSS: 40.99451540359252\n",
      "EPOCH: 15402 LOSS: 40.99451232973888\n",
      "EPOCH: 15403 LOSS: 40.994509256223694\n",
      "EPOCH: 15404 LOSS: 40.994506183046894\n",
      "EPOCH: 15405 LOSS: 40.99450311020841\n",
      "EPOCH: 15406 LOSS: 40.99450003770823\n",
      "EPOCH: 15407 LOSS: 40.994496965546254\n",
      "EPOCH: 15408 LOSS: 40.99449389372245\n",
      "EPOCH: 15409 LOSS: 40.994490822236756\n",
      "EPOCH: 15410 LOSS: 40.994487751089125\n",
      "EPOCH: 15411 LOSS: 40.994484680279484\n",
      "EPOCH: 15412 LOSS: 40.994481609807785\n",
      "EPOCH: 15413 LOSS: 40.994478539674006\n",
      "EPOCH: 15414 LOSS: 40.99447546987803\n",
      "EPOCH: 15415 LOSS: 40.99447240041986\n",
      "EPOCH: 15416 LOSS: 40.994469331299406\n",
      "EPOCH: 15417 LOSS: 40.99446626251663\n",
      "EPOCH: 15418 LOSS: 40.994463194071464\n",
      "EPOCH: 15419 LOSS: 40.994460125963876\n",
      "EPOCH: 15420 LOSS: 40.99445705819379\n",
      "EPOCH: 15421 LOSS: 40.99445399076114\n",
      "EPOCH: 15422 LOSS: 40.9944509236659\n",
      "EPOCH: 15423 LOSS: 40.99444785690798\n",
      "EPOCH: 15424 LOSS: 40.99444479048739\n",
      "EPOCH: 15425 LOSS: 40.994441724404005\n",
      "EPOCH: 15426 LOSS: 40.9944386586578\n",
      "EPOCH: 15427 LOSS: 40.994435593248724\n",
      "EPOCH: 15428 LOSS: 40.994432528176716\n",
      "EPOCH: 15429 LOSS: 40.99442946344172\n",
      "EPOCH: 15430 LOSS: 40.994426399043675\n",
      "EPOCH: 15431 LOSS: 40.99442333498254\n",
      "EPOCH: 15432 LOSS: 40.99442027125826\n",
      "EPOCH: 15433 LOSS: 40.99441720787077\n",
      "EPOCH: 15434 LOSS: 40.99441414482002\n",
      "EPOCH: 15435 LOSS: 40.99441108210594\n",
      "EPOCH: 15436 LOSS: 40.99440801972851\n",
      "EPOCH: 15437 LOSS: 40.99440495768764\n",
      "EPOCH: 15438 LOSS: 40.9944018959833\n",
      "EPOCH: 15439 LOSS: 40.99439883461543\n",
      "EPOCH: 15440 LOSS: 40.994395773583975\n",
      "EPOCH: 15441 LOSS: 40.99439271288886\n",
      "EPOCH: 15442 LOSS: 40.99438965253006\n",
      "EPOCH: 15443 LOSS: 40.994386592507496\n",
      "EPOCH: 15444 LOSS: 40.994383532821125\n",
      "EPOCH: 15445 LOSS: 40.9943804734709\n",
      "EPOCH: 15446 LOSS: 40.99437741445675\n",
      "EPOCH: 15447 LOSS: 40.99437435577864\n",
      "EPOCH: 15448 LOSS: 40.99437129743649\n",
      "EPOCH: 15449 LOSS: 40.994368239430266\n",
      "EPOCH: 15450 LOSS: 40.99436518175991\n",
      "EPOCH: 15451 LOSS: 40.99436212442535\n",
      "EPOCH: 15452 LOSS: 40.99435906742656\n",
      "EPOCH: 15453 LOSS: 40.99435601076347\n",
      "EPOCH: 15454 LOSS: 40.99435295443602\n",
      "EPOCH: 15455 LOSS: 40.994349898444156\n",
      "EPOCH: 15456 LOSS: 40.994346842787834\n",
      "EPOCH: 15457 LOSS: 40.994343787467\n",
      "EPOCH: 15458 LOSS: 40.99434073248159\n",
      "EPOCH: 15459 LOSS: 40.99433767783155\n",
      "EPOCH: 15460 LOSS: 40.994334623516835\n",
      "EPOCH: 15461 LOSS: 40.9943315695374\n",
      "EPOCH: 15462 LOSS: 40.994328515893145\n",
      "EPOCH: 15463 LOSS: 40.99432546258406\n",
      "EPOCH: 15464 LOSS: 40.99432240961007\n",
      "EPOCH: 15465 LOSS: 40.99431935697113\n",
      "EPOCH: 15466 LOSS: 40.99431630466718\n",
      "EPOCH: 15467 LOSS: 40.99431325269818\n",
      "EPOCH: 15468 LOSS: 40.994310201064046\n",
      "EPOCH: 15469 LOSS: 40.99430714976475\n",
      "EPOCH: 15470 LOSS: 40.99430409880023\n",
      "EPOCH: 15471 LOSS: 40.99430104817042\n",
      "EPOCH: 15472 LOSS: 40.99429799787529\n",
      "EPOCH: 15473 LOSS: 40.99429494791475\n",
      "EPOCH: 15474 LOSS: 40.9942918982888\n",
      "EPOCH: 15475 LOSS: 40.99428884899733\n",
      "EPOCH: 15476 LOSS: 40.99428580004031\n",
      "EPOCH: 15477 LOSS: 40.994282751417686\n",
      "EPOCH: 15478 LOSS: 40.9942797031294\n",
      "EPOCH: 15479 LOSS: 40.99427665517541\n",
      "EPOCH: 15480 LOSS: 40.99427360755564\n",
      "EPOCH: 15481 LOSS: 40.99427056027004\n",
      "EPOCH: 15482 LOSS: 40.99426751331856\n",
      "EPOCH: 15483 LOSS: 40.99426446670117\n",
      "EPOCH: 15484 LOSS: 40.99426142041777\n",
      "EPOCH: 15485 LOSS: 40.994258374468345\n",
      "EPOCH: 15486 LOSS: 40.994255328852816\n",
      "EPOCH: 15487 LOSS: 40.99425228357114\n",
      "EPOCH: 15488 LOSS: 40.99424923862327\n",
      "EPOCH: 15489 LOSS: 40.99424619400914\n",
      "EPOCH: 15490 LOSS: 40.994243149728696\n",
      "EPOCH: 15491 LOSS: 40.994240105781884\n",
      "EPOCH: 15492 LOSS: 40.99423706216865\n",
      "EPOCH: 15493 LOSS: 40.994234018888946\n",
      "EPOCH: 15494 LOSS: 40.99423097594271\n",
      "EPOCH: 15495 LOSS: 40.9942279333299\n",
      "EPOCH: 15496 LOSS: 40.99422489105045\n",
      "EPOCH: 15497 LOSS: 40.99422184910429\n",
      "EPOCH: 15498 LOSS: 40.99421880749142\n",
      "EPOCH: 15499 LOSS: 40.99421576621173\n",
      "EPOCH: 15500 LOSS: 40.99421272526519\n",
      "EPOCH: 15501 LOSS: 40.994209684651736\n",
      "EPOCH: 15502 LOSS: 40.99420664437133\n",
      "EPOCH: 15503 LOSS: 40.9942036044239\n",
      "EPOCH: 15504 LOSS: 40.994200564809404\n",
      "EPOCH: 15505 LOSS: 40.99419752552779\n",
      "EPOCH: 15506 LOSS: 40.99419448657899\n",
      "EPOCH: 15507 LOSS: 40.99419144796296\n",
      "EPOCH: 15508 LOSS: 40.99418840967965\n",
      "EPOCH: 15509 LOSS: 40.99418537172901\n",
      "EPOCH: 15510 LOSS: 40.99418233411097\n",
      "EPOCH: 15511 LOSS: 40.99417929682548\n",
      "EPOCH: 15512 LOSS: 40.99417625987247\n",
      "EPOCH: 15513 LOSS: 40.994173223251934\n",
      "EPOCH: 15514 LOSS: 40.99417018696376\n",
      "EPOCH: 15515 LOSS: 40.99416715100793\n",
      "EPOCH: 15516 LOSS: 40.9941641153844\n",
      "EPOCH: 15517 LOSS: 40.99416108009307\n",
      "EPOCH: 15518 LOSS: 40.99415804513394\n",
      "EPOCH: 15519 LOSS: 40.994155010506915\n",
      "EPOCH: 15520 LOSS: 40.99415197621197\n",
      "EPOCH: 15521 LOSS: 40.994148942249026\n",
      "EPOCH: 15522 LOSS: 40.99414590861805\n",
      "EPOCH: 15523 LOSS: 40.99414287531898\n",
      "EPOCH: 15524 LOSS: 40.99413984235176\n",
      "EPOCH: 15525 LOSS: 40.99413680971632\n",
      "EPOCH: 15526 LOSS: 40.99413377741264\n",
      "EPOCH: 15527 LOSS: 40.99413074544066\n",
      "EPOCH: 15528 LOSS: 40.99412771380029\n",
      "EPOCH: 15529 LOSS: 40.99412468249152\n",
      "EPOCH: 15530 LOSS: 40.99412165151427\n",
      "EPOCH: 15531 LOSS: 40.994118620868505\n",
      "EPOCH: 15532 LOSS: 40.994115590554145\n",
      "EPOCH: 15533 LOSS: 40.99411256057117\n",
      "EPOCH: 15534 LOSS: 40.9941095309195\n",
      "EPOCH: 15535 LOSS: 40.9941065015991\n",
      "EPOCH: 15536 LOSS: 40.99410347260989\n",
      "EPOCH: 15537 LOSS: 40.99410044395182\n",
      "EPOCH: 15538 LOSS: 40.99409741562487\n",
      "EPOCH: 15539 LOSS: 40.99409438762896\n",
      "EPOCH: 15540 LOSS: 40.994091359964045\n",
      "EPOCH: 15541 LOSS: 40.99408833263006\n",
      "EPOCH: 15542 LOSS: 40.99408530562695\n",
      "EPOCH: 15543 LOSS: 40.99408227895469\n",
      "EPOCH: 15544 LOSS: 40.99407925261319\n",
      "EPOCH: 15545 LOSS: 40.99407622660242\n",
      "EPOCH: 15546 LOSS: 40.99407320092231\n",
      "EPOCH: 15547 LOSS: 40.99407017557282\n",
      "EPOCH: 15548 LOSS: 40.99406715055389\n",
      "EPOCH: 15549 LOSS: 40.99406412586548\n",
      "EPOCH: 15550 LOSS: 40.994061101507505\n",
      "EPOCH: 15551 LOSS: 40.99405807747995\n",
      "EPOCH: 15552 LOSS: 40.994055053782716\n",
      "EPOCH: 15553 LOSS: 40.99405203041579\n",
      "EPOCH: 15554 LOSS: 40.994049007379104\n",
      "EPOCH: 15555 LOSS: 40.99404598467262\n",
      "EPOCH: 15556 LOSS: 40.99404296229625\n",
      "EPOCH: 15557 LOSS: 40.99403994024996\n",
      "EPOCH: 15558 LOSS: 40.994036918533695\n",
      "EPOCH: 15559 LOSS: 40.99403389714741\n",
      "EPOCH: 15560 LOSS: 40.99403087609103\n",
      "EPOCH: 15561 LOSS: 40.99402785536452\n",
      "EPOCH: 15562 LOSS: 40.99402483496783\n",
      "EPOCH: 15563 LOSS: 40.994021814900904\n",
      "EPOCH: 15564 LOSS: 40.99401879516366\n",
      "EPOCH: 15565 LOSS: 40.99401577575608\n",
      "EPOCH: 15566 LOSS: 40.9940127566781\n",
      "EPOCH: 15567 LOSS: 40.99400973792967\n",
      "EPOCH: 15568 LOSS: 40.994006719510736\n",
      "EPOCH: 15569 LOSS: 40.994003701421214\n",
      "EPOCH: 15570 LOSS: 40.994000683661085\n",
      "EPOCH: 15571 LOSS: 40.993997666230285\n",
      "EPOCH: 15572 LOSS: 40.993994649128766\n",
      "EPOCH: 15573 LOSS: 40.99399163235648\n",
      "EPOCH: 15574 LOSS: 40.99398861591335\n",
      "EPOCH: 15575 LOSS: 40.99398559979936\n",
      "EPOCH: 15576 LOSS: 40.993982584014404\n",
      "EPOCH: 15577 LOSS: 40.99397956855848\n",
      "EPOCH: 15578 LOSS: 40.9939765534315\n",
      "EPOCH: 15579 LOSS: 40.993973538633426\n",
      "EPOCH: 15580 LOSS: 40.993970524164205\n",
      "EPOCH: 15581 LOSS: 40.99396751002379\n",
      "EPOCH: 15582 LOSS: 40.99396449621211\n",
      "EPOCH: 15583 LOSS: 40.99396148272912\n",
      "EPOCH: 15584 LOSS: 40.99395846957477\n",
      "EPOCH: 15585 LOSS: 40.993955456749\n",
      "EPOCH: 15586 LOSS: 40.99395244425175\n",
      "EPOCH: 15587 LOSS: 40.993949432083\n",
      "EPOCH: 15588 LOSS: 40.993946420242665\n",
      "EPOCH: 15589 LOSS: 40.9939434087307\n",
      "EPOCH: 15590 LOSS: 40.99394039754705\n",
      "EPOCH: 15591 LOSS: 40.99393738669167\n",
      "EPOCH: 15592 LOSS: 40.9939343761645\n",
      "EPOCH: 15593 LOSS: 40.99393136596549\n",
      "EPOCH: 15594 LOSS: 40.993928356094585\n",
      "EPOCH: 15595 LOSS: 40.99392534655172\n",
      "EPOCH: 15596 LOSS: 40.99392233733687\n",
      "EPOCH: 15597 LOSS: 40.99391932844996\n",
      "EPOCH: 15598 LOSS: 40.99391631989094\n",
      "EPOCH: 15599 LOSS: 40.99391331165976\n",
      "EPOCH: 15600 LOSS: 40.993910303756365\n",
      "EPOCH: 15601 LOSS: 40.993907296180716\n",
      "EPOCH: 15602 LOSS: 40.99390428893272\n",
      "EPOCH: 15603 LOSS: 40.99390128201239\n",
      "EPOCH: 15604 LOSS: 40.993898275419596\n",
      "EPOCH: 15605 LOSS: 40.99389526915434\n",
      "EPOCH: 15606 LOSS: 40.99389226321655\n",
      "EPOCH: 15607 LOSS: 40.99388925760617\n",
      "EPOCH: 15608 LOSS: 40.993886252323165\n",
      "EPOCH: 15609 LOSS: 40.993883247367464\n",
      "EPOCH: 15610 LOSS: 40.993880242739\n",
      "EPOCH: 15611 LOSS: 40.99387723843777\n",
      "EPOCH: 15612 LOSS: 40.99387423446366\n",
      "EPOCH: 15613 LOSS: 40.99387123081665\n",
      "EPOCH: 15614 LOSS: 40.99386822749671\n",
      "EPOCH: 15615 LOSS: 40.993865224503736\n",
      "EPOCH: 15616 LOSS: 40.9938622218377\n",
      "EPOCH: 15617 LOSS: 40.99385921949856\n",
      "EPOCH: 15618 LOSS: 40.99385621748625\n",
      "EPOCH: 15619 LOSS: 40.99385321580072\n",
      "EPOCH: 15620 LOSS: 40.993850214441906\n",
      "EPOCH: 15621 LOSS: 40.99384721340977\n",
      "EPOCH: 15622 LOSS: 40.99384421270426\n",
      "EPOCH: 15623 LOSS: 40.993841212325314\n",
      "EPOCH: 15624 LOSS: 40.99383821227288\n",
      "EPOCH: 15625 LOSS: 40.99383521254691\n",
      "EPOCH: 15626 LOSS: 40.99383221314734\n",
      "EPOCH: 15627 LOSS: 40.99382921407414\n",
      "EPOCH: 15628 LOSS: 40.99382621532723\n",
      "EPOCH: 15629 LOSS: 40.99382321690658\n",
      "EPOCH: 15630 LOSS: 40.99382021881213\n",
      "EPOCH: 15631 LOSS: 40.99381722104381\n",
      "EPOCH: 15632 LOSS: 40.9938142236016\n",
      "EPOCH: 15633 LOSS: 40.993811226485406\n",
      "EPOCH: 15634 LOSS: 40.99380822969522\n",
      "EPOCH: 15635 LOSS: 40.993805233230944\n",
      "EPOCH: 15636 LOSS: 40.99380223709257\n",
      "EPOCH: 15637 LOSS: 40.993799241280016\n",
      "EPOCH: 15638 LOSS: 40.99379624579324\n",
      "EPOCH: 15639 LOSS: 40.993793250632166\n",
      "EPOCH: 15640 LOSS: 40.99379025579678\n",
      "EPOCH: 15641 LOSS: 40.993787261287004\n",
      "EPOCH: 15642 LOSS: 40.99378426710281\n",
      "EPOCH: 15643 LOSS: 40.993781273244124\n",
      "EPOCH: 15644 LOSS: 40.993778279710874\n",
      "EPOCH: 15645 LOSS: 40.99377528650304\n",
      "EPOCH: 15646 LOSS: 40.99377229362057\n",
      "EPOCH: 15647 LOSS: 40.993769301063395\n",
      "EPOCH: 15648 LOSS: 40.99376630883147\n",
      "EPOCH: 15649 LOSS: 40.99376331692473\n",
      "EPOCH: 15650 LOSS: 40.993760325343146\n",
      "EPOCH: 15651 LOSS: 40.99375733408664\n",
      "EPOCH: 15652 LOSS: 40.993754343155175\n",
      "EPOCH: 15653 LOSS: 40.993751352548685\n",
      "EPOCH: 15654 LOSS: 40.99374836226716\n",
      "EPOCH: 15655 LOSS: 40.9937453723105\n",
      "EPOCH: 15656 LOSS: 40.99374238267865\n",
      "EPOCH: 15657 LOSS: 40.993739393371584\n",
      "EPOCH: 15658 LOSS: 40.99373640438924\n",
      "EPOCH: 15659 LOSS: 40.99373341573157\n",
      "EPOCH: 15660 LOSS: 40.99373042739852\n",
      "EPOCH: 15661 LOSS: 40.99372743939003\n",
      "EPOCH: 15662 LOSS: 40.993724451706065\n",
      "EPOCH: 15663 LOSS: 40.993721464346535\n",
      "EPOCH: 15664 LOSS: 40.99371847731142\n",
      "EPOCH: 15665 LOSS: 40.99371549060068\n",
      "EPOCH: 15666 LOSS: 40.993712504214216\n",
      "EPOCH: 15667 LOSS: 40.993709518152\n",
      "EPOCH: 15668 LOSS: 40.993706532413995\n",
      "EPOCH: 15669 LOSS: 40.99370354700014\n",
      "EPOCH: 15670 LOSS: 40.99370056191036\n",
      "EPOCH: 15671 LOSS: 40.99369757714463\n",
      "EPOCH: 15672 LOSS: 40.99369459270289\n",
      "EPOCH: 15673 LOSS: 40.99369160858508\n",
      "EPOCH: 15674 LOSS: 40.993688624791154\n",
      "EPOCH: 15675 LOSS: 40.99368564132105\n",
      "EPOCH: 15676 LOSS: 40.99368265817473\n",
      "EPOCH: 15677 LOSS: 40.993679675352155\n",
      "EPOCH: 15678 LOSS: 40.99367669285323\n",
      "EPOCH: 15679 LOSS: 40.993673710677925\n",
      "EPOCH: 15680 LOSS: 40.99367072882619\n",
      "EPOCH: 15681 LOSS: 40.99366774729799\n",
      "EPOCH: 15682 LOSS: 40.99366476609323\n",
      "EPOCH: 15683 LOSS: 40.993661785211884\n",
      "EPOCH: 15684 LOSS: 40.99365880465389\n",
      "EPOCH: 15685 LOSS: 40.99365582441923\n",
      "EPOCH: 15686 LOSS: 40.99365284450782\n",
      "EPOCH: 15687 LOSS: 40.99364986491959\n",
      "EPOCH: 15688 LOSS: 40.993646885654535\n",
      "EPOCH: 15689 LOSS: 40.99364390671258\n",
      "EPOCH: 15690 LOSS: 40.993640928093626\n",
      "EPOCH: 15691 LOSS: 40.99363794979771\n",
      "EPOCH: 15692 LOSS: 40.993634971824726\n",
      "EPOCH: 15693 LOSS: 40.99363199417462\n",
      "EPOCH: 15694 LOSS: 40.99362901684736\n",
      "EPOCH: 15695 LOSS: 40.99362603984288\n",
      "EPOCH: 15696 LOSS: 40.993623063161124\n",
      "EPOCH: 15697 LOSS: 40.99362008680207\n",
      "EPOCH: 15698 LOSS: 40.99361711076562\n",
      "EPOCH: 15699 LOSS: 40.99361413505174\n",
      "EPOCH: 15700 LOSS: 40.99361115966042\n",
      "EPOCH: 15701 LOSS: 40.993608184591565\n",
      "EPOCH: 15702 LOSS: 40.993605209845114\n",
      "EPOCH: 15703 LOSS: 40.99360223542102\n",
      "EPOCH: 15704 LOSS: 40.99359926131926\n",
      "EPOCH: 15705 LOSS: 40.993596287539745\n",
      "EPOCH: 15706 LOSS: 40.99359331408247\n",
      "EPOCH: 15707 LOSS: 40.993590340947335\n",
      "EPOCH: 15708 LOSS: 40.993587368134314\n",
      "EPOCH: 15709 LOSS: 40.99358439564333\n",
      "EPOCH: 15710 LOSS: 40.99358142347437\n",
      "EPOCH: 15711 LOSS: 40.99357845162734\n",
      "EPOCH: 15712 LOSS: 40.993575480102216\n",
      "EPOCH: 15713 LOSS: 40.99357250889895\n",
      "EPOCH: 15714 LOSS: 40.99356953801748\n",
      "EPOCH: 15715 LOSS: 40.993566567457734\n",
      "EPOCH: 15716 LOSS: 40.993563597219705\n",
      "EPOCH: 15717 LOSS: 40.99356062730328\n",
      "EPOCH: 15718 LOSS: 40.993557657708465\n",
      "EPOCH: 15719 LOSS: 40.99355468843517\n",
      "EPOCH: 15720 LOSS: 40.993551719483385\n",
      "EPOCH: 15721 LOSS: 40.993548750852995\n",
      "EPOCH: 15722 LOSS: 40.993545782544004\n",
      "EPOCH: 15723 LOSS: 40.99354281455634\n",
      "EPOCH: 15724 LOSS: 40.99353984688995\n",
      "EPOCH: 15725 LOSS: 40.99353687954477\n",
      "EPOCH: 15726 LOSS: 40.993533912520775\n",
      "EPOCH: 15727 LOSS: 40.9935309458179\n",
      "EPOCH: 15728 LOSS: 40.993527979436095\n",
      "EPOCH: 15729 LOSS: 40.993525013375304\n",
      "EPOCH: 15730 LOSS: 40.993522047635466\n",
      "EPOCH: 15731 LOSS: 40.99351908221655\n",
      "EPOCH: 15732 LOSS: 40.99351611711849\n",
      "EPOCH: 15733 LOSS: 40.99351315234124\n",
      "EPOCH: 15734 LOSS: 40.993510187884745\n",
      "EPOCH: 15735 LOSS: 40.99350722374895\n",
      "EPOCH: 15736 LOSS: 40.99350425993382\n",
      "EPOCH: 15737 LOSS: 40.99350129643928\n",
      "EPOCH: 15738 LOSS: 40.99349833326527\n",
      "EPOCH: 15739 LOSS: 40.99349537041181\n",
      "EPOCH: 15740 LOSS: 40.993492407878755\n",
      "EPOCH: 15741 LOSS: 40.99348944566611\n",
      "EPOCH: 15742 LOSS: 40.993486483773786\n",
      "EPOCH: 15743 LOSS: 40.99348352220177\n",
      "EPOCH: 15744 LOSS: 40.99348056094999\n",
      "EPOCH: 15745 LOSS: 40.99347760001841\n",
      "EPOCH: 15746 LOSS: 40.99347463940694\n",
      "EPOCH: 15747 LOSS: 40.993471679115565\n",
      "EPOCH: 15748 LOSS: 40.99346871914422\n",
      "EPOCH: 15749 LOSS: 40.993465759492864\n",
      "EPOCH: 15750 LOSS: 40.993462800161424\n",
      "EPOCH: 15751 LOSS: 40.993459841149864\n",
      "EPOCH: 15752 LOSS: 40.993456882458126\n",
      "EPOCH: 15753 LOSS: 40.99345392408617\n",
      "EPOCH: 15754 LOSS: 40.99345096603393\n",
      "EPOCH: 15755 LOSS: 40.99344800830138\n",
      "EPOCH: 15756 LOSS: 40.99344505088841\n",
      "EPOCH: 15757 LOSS: 40.99344209379504\n",
      "EPOCH: 15758 LOSS: 40.993439137021184\n",
      "EPOCH: 15759 LOSS: 40.99343618056678\n",
      "EPOCH: 15760 LOSS: 40.99343322443179\n",
      "EPOCH: 15761 LOSS: 40.99343026861614\n",
      "EPOCH: 15762 LOSS: 40.99342731311984\n",
      "EPOCH: 15763 LOSS: 40.99342435794277\n",
      "EPOCH: 15764 LOSS: 40.993421403084916\n",
      "EPOCH: 15765 LOSS: 40.99341844854622\n",
      "EPOCH: 15766 LOSS: 40.99341549432661\n",
      "EPOCH: 15767 LOSS: 40.99341254042607\n",
      "EPOCH: 15768 LOSS: 40.99340958684452\n",
      "EPOCH: 15769 LOSS: 40.99340663358193\n",
      "EPOCH: 15770 LOSS: 40.993403680638224\n",
      "EPOCH: 15771 LOSS: 40.993400728013356\n",
      "EPOCH: 15772 LOSS: 40.99339777570731\n",
      "EPOCH: 15773 LOSS: 40.993394823719996\n",
      "EPOCH: 15774 LOSS: 40.99339187205136\n",
      "EPOCH: 15775 LOSS: 40.99338892070137\n",
      "EPOCH: 15776 LOSS: 40.99338596966998\n",
      "EPOCH: 15777 LOSS: 40.99338301895712\n",
      "EPOCH: 15778 LOSS: 40.99338006856274\n",
      "EPOCH: 15779 LOSS: 40.99337711848679\n",
      "EPOCH: 15780 LOSS: 40.99337416872925\n",
      "EPOCH: 15781 LOSS: 40.99337121929\n",
      "EPOCH: 15782 LOSS: 40.99336827016906\n",
      "EPOCH: 15783 LOSS: 40.99336532136635\n",
      "EPOCH: 15784 LOSS: 40.99336237288179\n",
      "EPOCH: 15785 LOSS: 40.993359424715386\n",
      "EPOCH: 15786 LOSS: 40.99335647686705\n",
      "EPOCH: 15787 LOSS: 40.99335352933672\n",
      "EPOCH: 15788 LOSS: 40.99335058212438\n",
      "EPOCH: 15789 LOSS: 40.993347635229945\n",
      "EPOCH: 15790 LOSS: 40.993344688653394\n",
      "EPOCH: 15791 LOSS: 40.99334174239466\n",
      "EPOCH: 15792 LOSS: 40.993338796453685\n",
      "EPOCH: 15793 LOSS: 40.99333585083043\n",
      "EPOCH: 15794 LOSS: 40.99333290552484\n",
      "EPOCH: 15795 LOSS: 40.99332996053685\n",
      "EPOCH: 15796 LOSS: 40.99332701586644\n",
      "EPOCH: 15797 LOSS: 40.99332407151353\n",
      "EPOCH: 15798 LOSS: 40.99332112747809\n",
      "EPOCH: 15799 LOSS: 40.99331818376006\n",
      "EPOCH: 15800 LOSS: 40.99331524035937\n",
      "EPOCH: 15801 LOSS: 40.993312297276006\n",
      "EPOCH: 15802 LOSS: 40.993309354509876\n",
      "EPOCH: 15803 LOSS: 40.993306412060974\n",
      "EPOCH: 15804 LOSS: 40.99330346992921\n",
      "EPOCH: 15805 LOSS: 40.99330052811454\n",
      "EPOCH: 15806 LOSS: 40.993297586616926\n",
      "EPOCH: 15807 LOSS: 40.99329464543631\n",
      "EPOCH: 15808 LOSS: 40.99329170457264\n",
      "EPOCH: 15809 LOSS: 40.99328876402588\n",
      "EPOCH: 15810 LOSS: 40.99328582379596\n",
      "EPOCH: 15811 LOSS: 40.99328288388282\n",
      "EPOCH: 15812 LOSS: 40.99327994428644\n",
      "EPOCH: 15813 LOSS: 40.993277005006746\n",
      "EPOCH: 15814 LOSS: 40.993274066043696\n",
      "EPOCH: 15815 LOSS: 40.99327112739724\n",
      "EPOCH: 15816 LOSS: 40.99326818906732\n",
      "EPOCH: 15817 LOSS: 40.99326525105386\n",
      "EPOCH: 15818 LOSS: 40.99326231335688\n",
      "EPOCH: 15819 LOSS: 40.99325937597626\n",
      "EPOCH: 15820 LOSS: 40.993256438911985\n",
      "EPOCH: 15821 LOSS: 40.993253502163995\n",
      "EPOCH: 15822 LOSS: 40.99325056573224\n",
      "EPOCH: 15823 LOSS: 40.99324762961666\n",
      "EPOCH: 15824 LOSS: 40.99324469381722\n",
      "EPOCH: 15825 LOSS: 40.99324175833384\n",
      "EPOCH: 15826 LOSS: 40.99323882316651\n",
      "EPOCH: 15827 LOSS: 40.993235888315155\n",
      "EPOCH: 15828 LOSS: 40.993232953779724\n",
      "EPOCH: 15829 LOSS: 40.99323001956019\n",
      "EPOCH: 15830 LOSS: 40.99322708565645\n",
      "EPOCH: 15831 LOSS: 40.99322415206851\n",
      "EPOCH: 15832 LOSS: 40.99322121879626\n",
      "EPOCH: 15833 LOSS: 40.9932182858397\n",
      "EPOCH: 15834 LOSS: 40.99321535319877\n",
      "EPOCH: 15835 LOSS: 40.99321242087342\n",
      "EPOCH: 15836 LOSS: 40.993209488863556\n",
      "EPOCH: 15837 LOSS: 40.99320655716919\n",
      "EPOCH: 15838 LOSS: 40.99320362579024\n",
      "EPOCH: 15839 LOSS: 40.99320069472663\n",
      "EPOCH: 15840 LOSS: 40.993197763978365\n",
      "EPOCH: 15841 LOSS: 40.99319483354537\n",
      "EPOCH: 15842 LOSS: 40.99319190342756\n",
      "EPOCH: 15843 LOSS: 40.99318897362495\n",
      "EPOCH: 15844 LOSS: 40.993186044137424\n",
      "EPOCH: 15845 LOSS: 40.993183114964985\n",
      "EPOCH: 15846 LOSS: 40.99318018610755\n",
      "EPOCH: 15847 LOSS: 40.99317725756508\n",
      "EPOCH: 15848 LOSS: 40.993174329337506\n",
      "EPOCH: 15849 LOSS: 40.99317140142481\n",
      "EPOCH: 15850 LOSS: 40.99316847382691\n",
      "EPOCH: 15851 LOSS: 40.99316554654377\n",
      "EPOCH: 15852 LOSS: 40.99316261957535\n",
      "EPOCH: 15853 LOSS: 40.993159692921566\n",
      "EPOCH: 15854 LOSS: 40.9931567665824\n",
      "EPOCH: 15855 LOSS: 40.993153840557795\n",
      "EPOCH: 15856 LOSS: 40.993150914847696\n",
      "EPOCH: 15857 LOSS: 40.99314798945205\n",
      "EPOCH: 15858 LOSS: 40.99314506437079\n",
      "EPOCH: 15859 LOSS: 40.9931421396039\n",
      "EPOCH: 15860 LOSS: 40.99313921515131\n",
      "EPOCH: 15861 LOSS: 40.993136291012966\n",
      "EPOCH: 15862 LOSS: 40.99313336718883\n",
      "EPOCH: 15863 LOSS: 40.99313044367886\n",
      "EPOCH: 15864 LOSS: 40.99312752048296\n",
      "EPOCH: 15865 LOSS: 40.99312459760111\n",
      "EPOCH: 15866 LOSS: 40.99312167503328\n",
      "EPOCH: 15867 LOSS: 40.99311875277938\n",
      "EPOCH: 15868 LOSS: 40.993115830839386\n",
      "EPOCH: 15869 LOSS: 40.99311290921324\n",
      "EPOCH: 15870 LOSS: 40.993109987900894\n",
      "EPOCH: 15871 LOSS: 40.99310706690228\n",
      "EPOCH: 15872 LOSS: 40.99310414621739\n",
      "EPOCH: 15873 LOSS: 40.99310122584612\n",
      "EPOCH: 15874 LOSS: 40.99309830578845\n",
      "EPOCH: 15875 LOSS: 40.99309538604433\n",
      "EPOCH: 15876 LOSS: 40.99309246661369\n",
      "EPOCH: 15877 LOSS: 40.99308954749651\n",
      "EPOCH: 15878 LOSS: 40.99308662869271\n",
      "EPOCH: 15879 LOSS: 40.99308371020226\n",
      "EPOCH: 15880 LOSS: 40.99308079202508\n",
      "EPOCH: 15881 LOSS: 40.99307787416117\n",
      "EPOCH: 15882 LOSS: 40.99307495661044\n",
      "EPOCH: 15883 LOSS: 40.99307203937286\n",
      "EPOCH: 15884 LOSS: 40.993069122448354\n",
      "EPOCH: 15885 LOSS: 40.9930662058369\n",
      "EPOCH: 15886 LOSS: 40.99306328953841\n",
      "EPOCH: 15887 LOSS: 40.9930603735529\n",
      "EPOCH: 15888 LOSS: 40.99305745788025\n",
      "EPOCH: 15889 LOSS: 40.99305454252044\n",
      "EPOCH: 15890 LOSS: 40.99305162747342\n",
      "EPOCH: 15891 LOSS: 40.993048712739125\n",
      "EPOCH: 15892 LOSS: 40.99304579831755\n",
      "EPOCH: 15893 LOSS: 40.99304288420858\n",
      "EPOCH: 15894 LOSS: 40.99303997041221\n",
      "EPOCH: 15895 LOSS: 40.99303705692837\n",
      "EPOCH: 15896 LOSS: 40.99303414375703\n",
      "EPOCH: 15897 LOSS: 40.99303123089812\n",
      "EPOCH: 15898 LOSS: 40.993028318351605\n",
      "EPOCH: 15899 LOSS: 40.9930254061174\n",
      "EPOCH: 15900 LOSS: 40.993022494195486\n",
      "EPOCH: 15901 LOSS: 40.9930195825858\n",
      "EPOCH: 15902 LOSS: 40.99301667128833\n",
      "EPOCH: 15903 LOSS: 40.99301376030297\n",
      "EPOCH: 15904 LOSS: 40.99301084962969\n",
      "EPOCH: 15905 LOSS: 40.99300793926846\n",
      "EPOCH: 15906 LOSS: 40.99300502921919\n",
      "EPOCH: 15907 LOSS: 40.993002119481886\n",
      "EPOCH: 15908 LOSS: 40.992999210056425\n",
      "EPOCH: 15909 LOSS: 40.99299630094283\n",
      "EPOCH: 15910 LOSS: 40.992993392140995\n",
      "EPOCH: 15911 LOSS: 40.9929904836509\n",
      "EPOCH: 15912 LOSS: 40.9929875754725\n",
      "EPOCH: 15913 LOSS: 40.99298466760571\n",
      "EPOCH: 15914 LOSS: 40.992981760050526\n",
      "EPOCH: 15915 LOSS: 40.99297885280685\n",
      "EPOCH: 15916 LOSS: 40.992975945874676\n",
      "EPOCH: 15917 LOSS: 40.992973039253926\n",
      "EPOCH: 15918 LOSS: 40.99297013294454\n",
      "EPOCH: 15919 LOSS: 40.992967226946504\n",
      "EPOCH: 15920 LOSS: 40.99296432125975\n",
      "EPOCH: 15921 LOSS: 40.992961415884224\n",
      "EPOCH: 15922 LOSS: 40.992958510819875\n",
      "EPOCH: 15923 LOSS: 40.992955606066666\n",
      "EPOCH: 15924 LOSS: 40.992952701624525\n",
      "EPOCH: 15925 LOSS: 40.99294979749343\n",
      "EPOCH: 15926 LOSS: 40.992946893673306\n",
      "EPOCH: 15927 LOSS: 40.99294399016413\n",
      "EPOCH: 15928 LOSS: 40.992941086965814\n",
      "EPOCH: 15929 LOSS: 40.992938184078334\n",
      "EPOCH: 15930 LOSS: 40.99293528150164\n",
      "EPOCH: 15931 LOSS: 40.99293237923567\n",
      "EPOCH: 15932 LOSS: 40.992929477280384\n",
      "EPOCH: 15933 LOSS: 40.99292657563572\n",
      "EPOCH: 15934 LOSS: 40.99292367430165\n",
      "EPOCH: 15935 LOSS: 40.99292077327811\n",
      "EPOCH: 15936 LOSS: 40.99291787256506\n",
      "EPOCH: 15937 LOSS: 40.99291497216241\n",
      "EPOCH: 15938 LOSS: 40.992912072070176\n",
      "EPOCH: 15939 LOSS: 40.99290917228826\n",
      "EPOCH: 15940 LOSS: 40.99290627281662\n",
      "EPOCH: 15941 LOSS: 40.992903373655224\n",
      "EPOCH: 15942 LOSS: 40.99290047480399\n",
      "EPOCH: 15943 LOSS: 40.9928975762629\n",
      "EPOCH: 15944 LOSS: 40.9928946780319\n",
      "EPOCH: 15945 LOSS: 40.99289178011092\n",
      "EPOCH: 15946 LOSS: 40.99288888249992\n",
      "EPOCH: 15947 LOSS: 40.99288598519887\n",
      "EPOCH: 15948 LOSS: 40.992883088207684\n",
      "EPOCH: 15949 LOSS: 40.99288019152634\n",
      "EPOCH: 15950 LOSS: 40.992877295154784\n",
      "EPOCH: 15951 LOSS: 40.992874399092955\n",
      "EPOCH: 15952 LOSS: 40.99287150334081\n",
      "EPOCH: 15953 LOSS: 40.992868607898295\n",
      "EPOCH: 15954 LOSS: 40.99286571276536\n",
      "EPOCH: 15955 LOSS: 40.99286281794198\n",
      "EPOCH: 15956 LOSS: 40.99285992342807\n",
      "EPOCH: 15957 LOSS: 40.9928570292236\n",
      "EPOCH: 15958 LOSS: 40.9928541353285\n",
      "EPOCH: 15959 LOSS: 40.992851241742756\n",
      "EPOCH: 15960 LOSS: 40.992848348466296\n",
      "EPOCH: 15961 LOSS: 40.99284545549905\n",
      "EPOCH: 15962 LOSS: 40.992842562841\n",
      "EPOCH: 15963 LOSS: 40.992839670492096\n",
      "EPOCH: 15964 LOSS: 40.99283677845226\n",
      "EPOCH: 15965 LOSS: 40.992833886721485\n",
      "EPOCH: 15966 LOSS: 40.992830995299684\n",
      "EPOCH: 15967 LOSS: 40.99282810418683\n",
      "EPOCH: 15968 LOSS: 40.99282521338287\n",
      "EPOCH: 15969 LOSS: 40.99282232288772\n",
      "EPOCH: 15970 LOSS: 40.992819432701374\n",
      "EPOCH: 15971 LOSS: 40.992816542823775\n",
      "EPOCH: 15972 LOSS: 40.99281365325485\n",
      "EPOCH: 15973 LOSS: 40.99281076399458\n",
      "EPOCH: 15974 LOSS: 40.9928078750429\n",
      "EPOCH: 15975 LOSS: 40.992804986399754\n",
      "EPOCH: 15976 LOSS: 40.9928020980651\n",
      "EPOCH: 15977 LOSS: 40.992799210038896\n",
      "EPOCH: 15978 LOSS: 40.99279632232107\n",
      "EPOCH: 15979 LOSS: 40.992793434911604\n",
      "EPOCH: 15980 LOSS: 40.992790547810415\n",
      "EPOCH: 15981 LOSS: 40.99278766101747\n",
      "EPOCH: 15982 LOSS: 40.99278477453274\n",
      "EPOCH: 15983 LOSS: 40.99278188835612\n",
      "EPOCH: 15984 LOSS: 40.99277900248764\n",
      "EPOCH: 15985 LOSS: 40.992776116927175\n",
      "EPOCH: 15986 LOSS: 40.992773231674704\n",
      "EPOCH: 15987 LOSS: 40.9927703467302\n",
      "EPOCH: 15988 LOSS: 40.99276746209356\n",
      "EPOCH: 15989 LOSS: 40.992764577764795\n",
      "EPOCH: 15990 LOSS: 40.992761693743816\n",
      "EPOCH: 15991 LOSS: 40.992758810030594\n",
      "EPOCH: 15992 LOSS: 40.99275592662508\n",
      "EPOCH: 15993 LOSS: 40.99275304352719\n",
      "EPOCH: 15994 LOSS: 40.992750160736925\n",
      "EPOCH: 15995 LOSS: 40.9927472782542\n",
      "EPOCH: 15996 LOSS: 40.99274439607899\n",
      "EPOCH: 15997 LOSS: 40.99274151421122\n",
      "EPOCH: 15998 LOSS: 40.99273863265084\n",
      "EPOCH: 15999 LOSS: 40.992735751397845\n",
      "EPOCH: 16000 LOSS: 40.99273287045213\n",
      "EPOCH: 16001 LOSS: 40.99272998981368\n",
      "EPOCH: 16002 LOSS: 40.99272710948242\n",
      "EPOCH: 16003 LOSS: 40.99272422945835\n",
      "EPOCH: 16004 LOSS: 40.99272134974137\n",
      "EPOCH: 16005 LOSS: 40.99271847033144\n",
      "EPOCH: 16006 LOSS: 40.99271559122853\n",
      "EPOCH: 16007 LOSS: 40.992712712432564\n",
      "EPOCH: 16008 LOSS: 40.992709833943515\n",
      "EPOCH: 16009 LOSS: 40.99270695576132\n",
      "EPOCH: 16010 LOSS: 40.99270407788595\n",
      "EPOCH: 16011 LOSS: 40.99270120031735\n",
      "EPOCH: 16012 LOSS: 40.99269832305545\n",
      "EPOCH: 16013 LOSS: 40.992695446100214\n",
      "EPOCH: 16014 LOSS: 40.99269256945159\n",
      "EPOCH: 16015 LOSS: 40.99268969310953\n",
      "EPOCH: 16016 LOSS: 40.99268681707398\n",
      "EPOCH: 16017 LOSS: 40.99268394134492\n",
      "EPOCH: 16018 LOSS: 40.99268106592227\n",
      "EPOCH: 16019 LOSS: 40.99267819080598\n",
      "EPOCH: 16020 LOSS: 40.99267531599601\n",
      "EPOCH: 16021 LOSS: 40.9926724414923\n",
      "EPOCH: 16022 LOSS: 40.992669567294826\n",
      "EPOCH: 16023 LOSS: 40.992666693403535\n",
      "EPOCH: 16024 LOSS: 40.99266381981835\n",
      "EPOCH: 16025 LOSS: 40.992660946539246\n",
      "EPOCH: 16026 LOSS: 40.99265807356616\n",
      "EPOCH: 16027 LOSS: 40.99265520089905\n",
      "EPOCH: 16028 LOSS: 40.992652328537865\n",
      "EPOCH: 16029 LOSS: 40.99264945648257\n",
      "EPOCH: 16030 LOSS: 40.99264658473308\n",
      "EPOCH: 16031 LOSS: 40.99264371328939\n",
      "EPOCH: 16032 LOSS: 40.992640842151424\n",
      "EPOCH: 16033 LOSS: 40.992637971319134\n",
      "EPOCH: 16034 LOSS: 40.99263510079247\n",
      "EPOCH: 16035 LOSS: 40.99263223057141\n",
      "EPOCH: 16036 LOSS: 40.992629360655876\n",
      "EPOCH: 16037 LOSS: 40.99262649104582\n",
      "EPOCH: 16038 LOSS: 40.992623621741195\n",
      "EPOCH: 16039 LOSS: 40.99262075274197\n",
      "EPOCH: 16040 LOSS: 40.99261788404809\n",
      "EPOCH: 16041 LOSS: 40.992615015659474\n",
      "EPOCH: 16042 LOSS: 40.9926121475761\n",
      "EPOCH: 16043 LOSS: 40.99260927979793\n",
      "EPOCH: 16044 LOSS: 40.9926064123249\n",
      "EPOCH: 16045 LOSS: 40.99260354515695\n",
      "EPOCH: 16046 LOSS: 40.99260067829407\n",
      "EPOCH: 16047 LOSS: 40.99259781173616\n",
      "EPOCH: 16048 LOSS: 40.99259494548321\n",
      "EPOCH: 16049 LOSS: 40.992592079535164\n",
      "EPOCH: 16050 LOSS: 40.99258921389195\n",
      "EPOCH: 16051 LOSS: 40.99258634855353\n",
      "EPOCH: 16052 LOSS: 40.99258348351989\n",
      "EPOCH: 16053 LOSS: 40.99258061879093\n",
      "EPOCH: 16054 LOSS: 40.992577754366636\n",
      "EPOCH: 16055 LOSS: 40.99257489024692\n",
      "EPOCH: 16056 LOSS: 40.992572026431795\n",
      "EPOCH: 16057 LOSS: 40.99256916292114\n",
      "EPOCH: 16058 LOSS: 40.99256629971497\n",
      "EPOCH: 16059 LOSS: 40.9925634368132\n",
      "EPOCH: 16060 LOSS: 40.99256057421579\n",
      "EPOCH: 16061 LOSS: 40.992557711922686\n",
      "EPOCH: 16062 LOSS: 40.99255484993385\n",
      "EPOCH: 16063 LOSS: 40.99255198824923\n",
      "EPOCH: 16064 LOSS: 40.99254912686877\n",
      "EPOCH: 16065 LOSS: 40.99254626579241\n",
      "EPOCH: 16066 LOSS: 40.99254340502015\n",
      "EPOCH: 16067 LOSS: 40.99254054455189\n",
      "EPOCH: 16068 LOSS: 40.9925376843876\n",
      "EPOCH: 16069 LOSS: 40.99253482452723\n",
      "EPOCH: 16070 LOSS: 40.992531964970745\n",
      "EPOCH: 16071 LOSS: 40.99252910571806\n",
      "EPOCH: 16072 LOSS: 40.99252624676918\n",
      "EPOCH: 16073 LOSS: 40.992523388124\n",
      "EPOCH: 16074 LOSS: 40.99252052978251\n",
      "EPOCH: 16075 LOSS: 40.992517671744636\n",
      "EPOCH: 16076 LOSS: 40.99251481401036\n",
      "EPOCH: 16077 LOSS: 40.992511956579605\n",
      "EPOCH: 16078 LOSS: 40.99250909945234\n",
      "EPOCH: 16079 LOSS: 40.992506242628494\n",
      "EPOCH: 16080 LOSS: 40.99250338610804\n",
      "EPOCH: 16081 LOSS: 40.99250052989093\n",
      "EPOCH: 16082 LOSS: 40.9924976739771\n",
      "EPOCH: 16083 LOSS: 40.992494818366524\n",
      "EPOCH: 16084 LOSS: 40.99249196305912\n",
      "EPOCH: 16085 LOSS: 40.992489108054876\n",
      "EPOCH: 16086 LOSS: 40.992486253353725\n",
      "EPOCH: 16087 LOSS: 40.9924833989556\n",
      "EPOCH: 16088 LOSS: 40.99248054486049\n",
      "EPOCH: 16089 LOSS: 40.99247769106833\n",
      "EPOCH: 16090 LOSS: 40.99247483757905\n",
      "EPOCH: 16091 LOSS: 40.99247198439264\n",
      "EPOCH: 16092 LOSS: 40.992469131509026\n",
      "EPOCH: 16093 LOSS: 40.992466278928156\n",
      "EPOCH: 16094 LOSS: 40.992463426650005\n",
      "EPOCH: 16095 LOSS: 40.99246057467451\n",
      "EPOCH: 16096 LOSS: 40.99245772300162\n",
      "EPOCH: 16097 LOSS: 40.9924548716313\n",
      "EPOCH: 16098 LOSS: 40.992452020563476\n",
      "EPOCH: 16099 LOSS: 40.99244916979812\n",
      "EPOCH: 16100 LOSS: 40.99244631933517\n",
      "EPOCH: 16101 LOSS: 40.99244346917462\n",
      "EPOCH: 16102 LOSS: 40.992440619316355\n",
      "EPOCH: 16103 LOSS: 40.99243776976036\n",
      "EPOCH: 16104 LOSS: 40.9924349205066\n",
      "EPOCH: 16105 LOSS: 40.992432071555015\n",
      "EPOCH: 16106 LOSS: 40.99242922290554\n",
      "EPOCH: 16107 LOSS: 40.99242637455815\n",
      "EPOCH: 16108 LOSS: 40.992423526512795\n",
      "EPOCH: 16109 LOSS: 40.99242067876939\n",
      "EPOCH: 16110 LOSS: 40.99241783132795\n",
      "EPOCH: 16111 LOSS: 40.992414984188365\n",
      "EPOCH: 16112 LOSS: 40.992412137350634\n",
      "EPOCH: 16113 LOSS: 40.99240929081468\n",
      "EPOCH: 16114 LOSS: 40.99240644458047\n",
      "EPOCH: 16115 LOSS: 40.99240359864794\n",
      "EPOCH: 16116 LOSS: 40.99240075301705\n",
      "EPOCH: 16117 LOSS: 40.99239790768776\n",
      "EPOCH: 16118 LOSS: 40.99239506266\n",
      "EPOCH: 16119 LOSS: 40.992392217933755\n",
      "EPOCH: 16120 LOSS: 40.99238937350894\n",
      "EPOCH: 16121 LOSS: 40.99238652938554\n",
      "EPOCH: 16122 LOSS: 40.99238368556348\n",
      "EPOCH: 16123 LOSS: 40.99238084204272\n",
      "EPOCH: 16124 LOSS: 40.99237799882323\n",
      "EPOCH: 16125 LOSS: 40.99237515590493\n",
      "EPOCH: 16126 LOSS: 40.9923723132878\n",
      "EPOCH: 16127 LOSS: 40.992369470971774\n",
      "EPOCH: 16128 LOSS: 40.992366628956816\n",
      "EPOCH: 16129 LOSS: 40.99236378724286\n",
      "EPOCH: 16130 LOSS: 40.99236094582987\n",
      "EPOCH: 16131 LOSS: 40.99235810471781\n",
      "EPOCH: 16132 LOSS: 40.9923552639066\n",
      "EPOCH: 16133 LOSS: 40.99235242339622\n",
      "EPOCH: 16134 LOSS: 40.992349583186616\n",
      "EPOCH: 16135 LOSS: 40.992346743277736\n",
      "EPOCH: 16136 LOSS: 40.992343903669536\n",
      "EPOCH: 16137 LOSS: 40.99234106436196\n",
      "EPOCH: 16138 LOSS: 40.99233822535494\n",
      "EPOCH: 16139 LOSS: 40.992335386648485\n",
      "EPOCH: 16140 LOSS: 40.992332548242516\n",
      "EPOCH: 16141 LOSS: 40.99232971013696\n",
      "EPOCH: 16142 LOSS: 40.992326872331795\n",
      "EPOCH: 16143 LOSS: 40.99232403482698\n",
      "EPOCH: 16144 LOSS: 40.99232119762245\n",
      "EPOCH: 16145 LOSS: 40.99231836071817\n",
      "EPOCH: 16146 LOSS: 40.99231552411409\n",
      "EPOCH: 16147 LOSS: 40.99231268781014\n",
      "EPOCH: 16148 LOSS: 40.99230985180628\n",
      "EPOCH: 16149 LOSS: 40.99230701610251\n",
      "EPOCH: 16150 LOSS: 40.99230418069871\n",
      "EPOCH: 16151 LOSS: 40.99230134559489\n",
      "EPOCH: 16152 LOSS: 40.992298510790945\n",
      "EPOCH: 16153 LOSS: 40.992295676286886\n",
      "EPOCH: 16154 LOSS: 40.992292842082634\n",
      "EPOCH: 16155 LOSS: 40.992290008178145\n",
      "EPOCH: 16156 LOSS: 40.992287174573356\n",
      "EPOCH: 16157 LOSS: 40.99228434126826\n",
      "EPOCH: 16158 LOSS: 40.99228150826278\n",
      "EPOCH: 16159 LOSS: 40.99227867555683\n",
      "EPOCH: 16160 LOSS: 40.99227584315045\n",
      "EPOCH: 16161 LOSS: 40.992273011043515\n",
      "EPOCH: 16162 LOSS: 40.99227017923604\n",
      "EPOCH: 16163 LOSS: 40.99226734772792\n",
      "EPOCH: 16164 LOSS: 40.99226451651914\n",
      "EPOCH: 16165 LOSS: 40.99226168560965\n",
      "EPOCH: 16166 LOSS: 40.99225885499939\n",
      "EPOCH: 16167 LOSS: 40.99225602468832\n",
      "EPOCH: 16168 LOSS: 40.992253194676394\n",
      "EPOCH: 16169 LOSS: 40.99225036496354\n",
      "EPOCH: 16170 LOSS: 40.99224753554975\n",
      "EPOCH: 16171 LOSS: 40.99224470643496\n",
      "EPOCH: 16172 LOSS: 40.99224187761911\n",
      "EPOCH: 16173 LOSS: 40.99223904910217\n",
      "EPOCH: 16174 LOSS: 40.99223622088407\n",
      "EPOCH: 16175 LOSS: 40.992233392964785\n",
      "EPOCH: 16176 LOSS: 40.99223056534426\n",
      "EPOCH: 16177 LOSS: 40.99222773802245\n",
      "EPOCH: 16178 LOSS: 40.99222491099928\n",
      "EPOCH: 16179 LOSS: 40.992222084274744\n",
      "EPOCH: 16180 LOSS: 40.99221925784877\n",
      "EPOCH: 16181 LOSS: 40.9922164317213\n",
      "EPOCH: 16182 LOSS: 40.99221360589233\n",
      "EPOCH: 16183 LOSS: 40.99221078036176\n",
      "EPOCH: 16184 LOSS: 40.99220795512958\n",
      "EPOCH: 16185 LOSS: 40.992205130195714\n",
      "EPOCH: 16186 LOSS: 40.99220230556013\n",
      "EPOCH: 16187 LOSS: 40.9921994812228\n",
      "EPOCH: 16188 LOSS: 40.99219665718364\n",
      "EPOCH: 16189 LOSS: 40.99219383344261\n",
      "EPOCH: 16190 LOSS: 40.99219100999969\n",
      "EPOCH: 16191 LOSS: 40.992188186854804\n",
      "EPOCH: 16192 LOSS: 40.99218536400791\n",
      "EPOCH: 16193 LOSS: 40.992182541458966\n",
      "EPOCH: 16194 LOSS: 40.992179719207925\n",
      "EPOCH: 16195 LOSS: 40.99217689725473\n",
      "EPOCH: 16196 LOSS: 40.99217407559932\n",
      "EPOCH: 16197 LOSS: 40.99217125424168\n",
      "EPOCH: 16198 LOSS: 40.99216843318177\n",
      "EPOCH: 16199 LOSS: 40.992165612419484\n",
      "EPOCH: 16200 LOSS: 40.99216279195483\n",
      "EPOCH: 16201 LOSS: 40.99215997178777\n",
      "EPOCH: 16202 LOSS: 40.992157151918185\n",
      "EPOCH: 16203 LOSS: 40.99215433234609\n",
      "EPOCH: 16204 LOSS: 40.99215151307141\n",
      "EPOCH: 16205 LOSS: 40.992148694094126\n",
      "EPOCH: 16206 LOSS: 40.99214587541415\n",
      "EPOCH: 16207 LOSS: 40.992143057031456\n",
      "EPOCH: 16208 LOSS: 40.99214023894601\n",
      "EPOCH: 16209 LOSS: 40.99213742115774\n",
      "EPOCH: 16210 LOSS: 40.992134603666614\n",
      "EPOCH: 16211 LOSS: 40.992131786472584\n",
      "EPOCH: 16212 LOSS: 40.99212896957559\n",
      "EPOCH: 16213 LOSS: 40.99212615297558\n",
      "EPOCH: 16214 LOSS: 40.992123336672535\n",
      "EPOCH: 16215 LOSS: 40.99212052066637\n",
      "EPOCH: 16216 LOSS: 40.992117704957074\n",
      "EPOCH: 16217 LOSS: 40.99211488954459\n",
      "EPOCH: 16218 LOSS: 40.99211207442886\n",
      "EPOCH: 16219 LOSS: 40.992109259609826\n",
      "EPOCH: 16220 LOSS: 40.99210644508748\n",
      "EPOCH: 16221 LOSS: 40.99210363086173\n",
      "EPOCH: 16222 LOSS: 40.99210081693255\n",
      "EPOCH: 16223 LOSS: 40.992098003299915\n",
      "EPOCH: 16224 LOSS: 40.99209518996374\n",
      "EPOCH: 16225 LOSS: 40.992092376924\n",
      "EPOCH: 16226 LOSS: 40.992089564180624\n",
      "EPOCH: 16227 LOSS: 40.992086751733595\n",
      "EPOCH: 16228 LOSS: 40.99208393958284\n",
      "EPOCH: 16229 LOSS: 40.992081127728326\n",
      "EPOCH: 16230 LOSS: 40.99207831617001\n",
      "EPOCH: 16231 LOSS: 40.992075504907824\n",
      "EPOCH: 16232 LOSS: 40.992072693941736\n",
      "EPOCH: 16233 LOSS: 40.9920698832717\n",
      "EPOCH: 16234 LOSS: 40.99206707289767\n",
      "EPOCH: 16235 LOSS: 40.992064262819596\n",
      "EPOCH: 16236 LOSS: 40.99206145303742\n",
      "EPOCH: 16237 LOSS: 40.992058643551104\n",
      "EPOCH: 16238 LOSS: 40.9920558343606\n",
      "EPOCH: 16239 LOSS: 40.99205302546586\n",
      "EPOCH: 16240 LOSS: 40.99205021686684\n",
      "EPOCH: 16241 LOSS: 40.992047408563494\n",
      "EPOCH: 16242 LOSS: 40.99204460055577\n",
      "EPOCH: 16243 LOSS: 40.99204179284362\n",
      "EPOCH: 16244 LOSS: 40.992038985426994\n",
      "EPOCH: 16245 LOSS: 40.99203617830587\n",
      "EPOCH: 16246 LOSS: 40.992033371480154\n",
      "EPOCH: 16247 LOSS: 40.99203056494984\n",
      "EPOCH: 16248 LOSS: 40.99202775871486\n",
      "EPOCH: 16249 LOSS: 40.99202495277518\n",
      "EPOCH: 16250 LOSS: 40.99202214713073\n",
      "EPOCH: 16251 LOSS: 40.9920193417815\n",
      "EPOCH: 16252 LOSS: 40.992016536727405\n",
      "EPOCH: 16253 LOSS: 40.99201373196842\n",
      "EPOCH: 16254 LOSS: 40.992010927504495\n",
      "EPOCH: 16255 LOSS: 40.99200812333557\n",
      "EPOCH: 16256 LOSS: 40.992005319461626\n",
      "EPOCH: 16257 LOSS: 40.99200251588259\n",
      "EPOCH: 16258 LOSS: 40.99199971259844\n",
      "EPOCH: 16259 LOSS: 40.99199690960908\n",
      "EPOCH: 16260 LOSS: 40.991994106914504\n",
      "EPOCH: 16261 LOSS: 40.99199130451467\n",
      "EPOCH: 16262 LOSS: 40.991988502409505\n",
      "EPOCH: 16263 LOSS: 40.99198570059899\n",
      "EPOCH: 16264 LOSS: 40.99198289908303\n",
      "EPOCH: 16265 LOSS: 40.991980097861635\n",
      "EPOCH: 16266 LOSS: 40.99197729693472\n",
      "EPOCH: 16267 LOSS: 40.99197449630226\n",
      "EPOCH: 16268 LOSS: 40.991971695964196\n",
      "EPOCH: 16269 LOSS: 40.991968895920486\n",
      "EPOCH: 16270 LOSS: 40.99196609617107\n",
      "EPOCH: 16271 LOSS: 40.99196329671592\n",
      "EPOCH: 16272 LOSS: 40.991960497554984\n",
      "EPOCH: 16273 LOSS: 40.99195769868821\n",
      "EPOCH: 16274 LOSS: 40.99195490011554\n",
      "EPOCH: 16275 LOSS: 40.99195210183696\n",
      "EPOCH: 16276 LOSS: 40.991949303852394\n",
      "EPOCH: 16277 LOSS: 40.991946506161796\n",
      "EPOCH: 16278 LOSS: 40.991943708765135\n",
      "EPOCH: 16279 LOSS: 40.99194091166236\n",
      "EPOCH: 16280 LOSS: 40.991938114853426\n",
      "EPOCH: 16281 LOSS: 40.99193531833827\n",
      "EPOCH: 16282 LOSS: 40.991932522116855\n",
      "EPOCH: 16283 LOSS: 40.991929726189134\n",
      "EPOCH: 16284 LOSS: 40.99192693055507\n",
      "EPOCH: 16285 LOSS: 40.991924135214596\n",
      "EPOCH: 16286 LOSS: 40.99192134016768\n",
      "EPOCH: 16287 LOSS: 40.99191854541428\n",
      "EPOCH: 16288 LOSS: 40.991915750954334\n",
      "EPOCH: 16289 LOSS: 40.991912956787814\n",
      "EPOCH: 16290 LOSS: 40.99191016291463\n",
      "EPOCH: 16291 LOSS: 40.99190736933479\n",
      "EPOCH: 16292 LOSS: 40.99190457604822\n",
      "EPOCH: 16293 LOSS: 40.99190178305487\n",
      "EPOCH: 16294 LOSS: 40.9918989903547\n",
      "EPOCH: 16295 LOSS: 40.991896197947675\n",
      "EPOCH: 16296 LOSS: 40.991893405833736\n",
      "EPOCH: 16297 LOSS: 40.99189061401283\n",
      "EPOCH: 16298 LOSS: 40.99188782248492\n",
      "EPOCH: 16299 LOSS: 40.99188503124995\n",
      "EPOCH: 16300 LOSS: 40.991882240307895\n",
      "EPOCH: 16301 LOSS: 40.99187944965867\n",
      "EPOCH: 16302 LOSS: 40.991876659302264\n",
      "EPOCH: 16303 LOSS: 40.99187386923863\n",
      "EPOCH: 16304 LOSS: 40.9918710794677\n",
      "EPOCH: 16305 LOSS: 40.99186828998941\n",
      "EPOCH: 16306 LOSS: 40.99186550080377\n",
      "EPOCH: 16307 LOSS: 40.99186271191069\n",
      "EPOCH: 16308 LOSS: 40.991859923310145\n",
      "EPOCH: 16309 LOSS: 40.99185713500208\n",
      "EPOCH: 16310 LOSS: 40.99185434698644\n",
      "EPOCH: 16311 LOSS: 40.99185155926318\n",
      "EPOCH: 16312 LOSS: 40.99184877183228\n",
      "EPOCH: 16313 LOSS: 40.991845984693654\n",
      "EPOCH: 16314 LOSS: 40.99184319784727\n",
      "EPOCH: 16315 LOSS: 40.99184041129311\n",
      "EPOCH: 16316 LOSS: 40.99183762503108\n",
      "EPOCH: 16317 LOSS: 40.99183483906117\n",
      "EPOCH: 16318 LOSS: 40.99183205338331\n",
      "EPOCH: 16319 LOSS: 40.99182926799749\n",
      "EPOCH: 16320 LOSS: 40.99182648290362\n",
      "EPOCH: 16321 LOSS: 40.99182369810167\n",
      "EPOCH: 16322 LOSS: 40.99182091359158\n",
      "EPOCH: 16323 LOSS: 40.99181812937333\n",
      "EPOCH: 16324 LOSS: 40.99181534544685\n",
      "EPOCH: 16325 LOSS: 40.99181256181214\n",
      "EPOCH: 16326 LOSS: 40.99180977846909\n",
      "EPOCH: 16327 LOSS: 40.991806995417676\n",
      "EPOCH: 16328 LOSS: 40.99180421265786\n",
      "EPOCH: 16329 LOSS: 40.991801430189604\n",
      "EPOCH: 16330 LOSS: 40.991798648012846\n",
      "EPOCH: 16331 LOSS: 40.99179586612753\n",
      "EPOCH: 16332 LOSS: 40.99179308453363\n",
      "EPOCH: 16333 LOSS: 40.99179030323111\n",
      "EPOCH: 16334 LOSS: 40.99178752221989\n",
      "EPOCH: 16335 LOSS: 40.99178474149994\n",
      "EPOCH: 16336 LOSS: 40.99178196107121\n",
      "EPOCH: 16337 LOSS: 40.991779180933676\n",
      "EPOCH: 16338 LOSS: 40.991776401087265\n",
      "EPOCH: 16339 LOSS: 40.99177362153193\n",
      "EPOCH: 16340 LOSS: 40.99177084226764\n",
      "EPOCH: 16341 LOSS: 40.99176806329433\n",
      "EPOCH: 16342 LOSS: 40.99176528461197\n",
      "EPOCH: 16343 LOSS: 40.99176250622051\n",
      "EPOCH: 16344 LOSS: 40.99175972811991\n",
      "EPOCH: 16345 LOSS: 40.991756950310126\n",
      "EPOCH: 16346 LOSS: 40.991754172791076\n",
      "EPOCH: 16347 LOSS: 40.991751395562744\n",
      "EPOCH: 16348 LOSS: 40.99174861862509\n",
      "EPOCH: 16349 LOSS: 40.99174584197805\n",
      "EPOCH: 16350 LOSS: 40.99174306562159\n",
      "EPOCH: 16351 LOSS: 40.99174028955564\n",
      "EPOCH: 16352 LOSS: 40.991737513780194\n",
      "EPOCH: 16353 LOSS: 40.99173473829518\n",
      "EPOCH: 16354 LOSS: 40.99173196310055\n",
      "EPOCH: 16355 LOSS: 40.99172918819626\n",
      "EPOCH: 16356 LOSS: 40.99172641358227\n",
      "EPOCH: 16357 LOSS: 40.99172363925854\n",
      "EPOCH: 16358 LOSS: 40.991720865225005\n",
      "EPOCH: 16359 LOSS: 40.99171809148163\n",
      "EPOCH: 16360 LOSS: 40.991715318028376\n",
      "EPOCH: 16361 LOSS: 40.99171254486517\n",
      "EPOCH: 16362 LOSS: 40.99170977199199\n",
      "EPOCH: 16363 LOSS: 40.991706999408784\n",
      "EPOCH: 16364 LOSS: 40.99170422711552\n",
      "EPOCH: 16365 LOSS: 40.99170145511212\n",
      "EPOCH: 16366 LOSS: 40.991698683398546\n",
      "EPOCH: 16367 LOSS: 40.99169591197479\n",
      "EPOCH: 16368 LOSS: 40.991693140840766\n",
      "EPOCH: 16369 LOSS: 40.99169036999644\n",
      "EPOCH: 16370 LOSS: 40.991687599441754\n",
      "EPOCH: 16371 LOSS: 40.99168482917668\n",
      "EPOCH: 16372 LOSS: 40.99168205920116\n",
      "EPOCH: 16373 LOSS: 40.991679289515154\n",
      "EPOCH: 16374 LOSS: 40.99167652011862\n",
      "EPOCH: 16375 LOSS: 40.99167375101149\n",
      "EPOCH: 16376 LOSS: 40.99167098219374\n",
      "EPOCH: 16377 LOSS: 40.991668213665335\n",
      "EPOCH: 16378 LOSS: 40.991665445426186\n",
      "EPOCH: 16379 LOSS: 40.991662677476285\n",
      "EPOCH: 16380 LOSS: 40.99165990981559\n",
      "EPOCH: 16381 LOSS: 40.99165714244402\n",
      "EPOCH: 16382 LOSS: 40.991654375361534\n",
      "EPOCH: 16383 LOSS: 40.991651608568134\n",
      "EPOCH: 16384 LOSS: 40.99164884206371\n",
      "EPOCH: 16385 LOSS: 40.991646075848266\n",
      "EPOCH: 16386 LOSS: 40.99164330992173\n",
      "EPOCH: 16387 LOSS: 40.991640544284046\n",
      "EPOCH: 16388 LOSS: 40.99163777893519\n",
      "EPOCH: 16389 LOSS: 40.99163501387512\n",
      "EPOCH: 16390 LOSS: 40.99163224910379\n",
      "EPOCH: 16391 LOSS: 40.99162948462113\n",
      "EPOCH: 16392 LOSS: 40.9916267204271\n",
      "EPOCH: 16393 LOSS: 40.99162395652167\n",
      "EPOCH: 16394 LOSS: 40.99162119290479\n",
      "EPOCH: 16395 LOSS: 40.991618429576405\n",
      "EPOCH: 16396 LOSS: 40.991615666536475\n",
      "EPOCH: 16397 LOSS: 40.99161290378495\n",
      "EPOCH: 16398 LOSS: 40.991610141321786\n",
      "EPOCH: 16399 LOSS: 40.99160737914695\n",
      "EPOCH: 16400 LOSS: 40.99160461726038\n",
      "EPOCH: 16401 LOSS: 40.99160185566202\n",
      "EPOCH: 16402 LOSS: 40.991599094351855\n",
      "EPOCH: 16403 LOSS: 40.99159633332981\n",
      "EPOCH: 16404 LOSS: 40.991593572595875\n",
      "EPOCH: 16405 LOSS: 40.991590812149965\n",
      "EPOCH: 16406 LOSS: 40.99158805199205\n",
      "EPOCH: 16407 LOSS: 40.991585292122096\n",
      "EPOCH: 16408 LOSS: 40.99158253254005\n",
      "EPOCH: 16409 LOSS: 40.991579773245846\n",
      "EPOCH: 16410 LOSS: 40.99157701423947\n",
      "EPOCH: 16411 LOSS: 40.99157425552083\n",
      "EPOCH: 16412 LOSS: 40.99157149708994\n",
      "EPOCH: 16413 LOSS: 40.99156873894672\n",
      "EPOCH: 16414 LOSS: 40.99156598109113\n",
      "EPOCH: 16415 LOSS: 40.99156322352311\n",
      "EPOCH: 16416 LOSS: 40.99156046624264\n",
      "EPOCH: 16417 LOSS: 40.99155770924966\n",
      "EPOCH: 16418 LOSS: 40.991554952544114\n",
      "EPOCH: 16419 LOSS: 40.99155219612599\n",
      "EPOCH: 16420 LOSS: 40.991549439995204\n",
      "EPOCH: 16421 LOSS: 40.99154668415173\n",
      "EPOCH: 16422 LOSS: 40.99154392859553\n",
      "EPOCH: 16423 LOSS: 40.99154117332654\n",
      "EPOCH: 16424 LOSS: 40.99153841834474\n",
      "EPOCH: 16425 LOSS: 40.99153566365004\n",
      "EPOCH: 16426 LOSS: 40.99153290924244\n",
      "EPOCH: 16427 LOSS: 40.99153015512186\n",
      "EPOCH: 16428 LOSS: 40.99152740128829\n",
      "EPOCH: 16429 LOSS: 40.99152464774165\n",
      "EPOCH: 16430 LOSS: 40.99152189448189\n",
      "EPOCH: 16431 LOSS: 40.991519141509\n",
      "EPOCH: 16432 LOSS: 40.99151638882292\n",
      "EPOCH: 16433 LOSS: 40.991513636423605\n",
      "EPOCH: 16434 LOSS: 40.99151088431101\n",
      "EPOCH: 16435 LOSS: 40.99150813248508\n",
      "EPOCH: 16436 LOSS: 40.99150538094577\n",
      "EPOCH: 16437 LOSS: 40.99150262969303\n",
      "EPOCH: 16438 LOSS: 40.991499878726856\n",
      "EPOCH: 16439 LOSS: 40.99149712804714\n",
      "EPOCH: 16440 LOSS: 40.99149437765387\n",
      "EPOCH: 16441 LOSS: 40.991491627547006\n",
      "EPOCH: 16442 LOSS: 40.99148887772649\n",
      "EPOCH: 16443 LOSS: 40.991486128192285\n",
      "EPOCH: 16444 LOSS: 40.99148337894434\n",
      "EPOCH: 16445 LOSS: 40.991480629982604\n",
      "EPOCH: 16446 LOSS: 40.99147788130704\n",
      "EPOCH: 16447 LOSS: 40.9914751329176\n",
      "EPOCH: 16448 LOSS: 40.99147238481423\n",
      "EPOCH: 16449 LOSS: 40.991469636996904\n",
      "EPOCH: 16450 LOSS: 40.99146688946557\n",
      "EPOCH: 16451 LOSS: 40.99146414222018\n",
      "EPOCH: 16452 LOSS: 40.99146139526067\n",
      "EPOCH: 16453 LOSS: 40.99145864858701\n",
      "EPOCH: 16454 LOSS: 40.99145590219917\n",
      "EPOCH: 16455 LOSS: 40.99145315609708\n",
      "EPOCH: 16456 LOSS: 40.991450410280734\n",
      "EPOCH: 16457 LOSS: 40.99144766475003\n",
      "EPOCH: 16458 LOSS: 40.99144491950495\n",
      "EPOCH: 16459 LOSS: 40.991442174545455\n",
      "EPOCH: 16460 LOSS: 40.99143942987149\n",
      "EPOCH: 16461 LOSS: 40.99143668548302\n",
      "EPOCH: 16462 LOSS: 40.99143394137999\n",
      "EPOCH: 16463 LOSS: 40.991431197562356\n",
      "EPOCH: 16464 LOSS: 40.99142845403007\n",
      "EPOCH: 16465 LOSS: 40.99142571078309\n",
      "EPOCH: 16466 LOSS: 40.9914229678214\n",
      "EPOCH: 16467 LOSS: 40.99142022514489\n",
      "EPOCH: 16468 LOSS: 40.99141748275357\n",
      "EPOCH: 16469 LOSS: 40.99141474064736\n",
      "EPOCH: 16470 LOSS: 40.99141199882625\n",
      "EPOCH: 16471 LOSS: 40.99140925729016\n",
      "EPOCH: 16472 LOSS: 40.99140651603906\n",
      "EPOCH: 16473 LOSS: 40.991403775072925\n",
      "EPOCH: 16474 LOSS: 40.99140103439167\n",
      "EPOCH: 16475 LOSS: 40.991398293995275\n",
      "EPOCH: 16476 LOSS: 40.99139555388368\n",
      "EPOCH: 16477 LOSS: 40.99139281405685\n",
      "EPOCH: 16478 LOSS: 40.99139007451474\n",
      "EPOCH: 16479 LOSS: 40.991387335257315\n",
      "EPOCH: 16480 LOSS: 40.99138459628452\n",
      "EPOCH: 16481 LOSS: 40.991381857596295\n",
      "EPOCH: 16482 LOSS: 40.9913791191926\n",
      "EPOCH: 16483 LOSS: 40.991376381073415\n",
      "EPOCH: 16484 LOSS: 40.99137364323866\n",
      "EPOCH: 16485 LOSS: 40.99137090568832\n",
      "EPOCH: 16486 LOSS: 40.991368168422326\n",
      "EPOCH: 16487 LOSS: 40.99136543144066\n",
      "EPOCH: 16488 LOSS: 40.99136269474323\n",
      "EPOCH: 16489 LOSS: 40.991359958330065\n",
      "EPOCH: 16490 LOSS: 40.991357222201046\n",
      "EPOCH: 16491 LOSS: 40.99135448635617\n",
      "EPOCH: 16492 LOSS: 40.99135175079536\n",
      "EPOCH: 16493 LOSS: 40.99134901551861\n",
      "EPOCH: 16494 LOSS: 40.99134628052586\n",
      "EPOCH: 16495 LOSS: 40.99134354581706\n",
      "EPOCH: 16496 LOSS: 40.99134081139215\n",
      "EPOCH: 16497 LOSS: 40.991338077251115\n",
      "EPOCH: 16498 LOSS: 40.991335343393885\n",
      "EPOCH: 16499 LOSS: 40.99133260982043\n",
      "EPOCH: 16500 LOSS: 40.991329876530685\n",
      "EPOCH: 16501 LOSS: 40.99132714352464\n",
      "EPOCH: 16502 LOSS: 40.991324410802235\n",
      "EPOCH: 16503 LOSS: 40.99132167836341\n",
      "EPOCH: 16504 LOSS: 40.99131894620813\n",
      "EPOCH: 16505 LOSS: 40.991316214336365\n",
      "EPOCH: 16506 LOSS: 40.99131348274804\n",
      "EPOCH: 16507 LOSS: 40.99131075144313\n",
      "EPOCH: 16508 LOSS: 40.991308020421585\n",
      "EPOCH: 16509 LOSS: 40.99130528968335\n",
      "EPOCH: 16510 LOSS: 40.9913025592284\n",
      "EPOCH: 16511 LOSS: 40.99129982905669\n",
      "EPOCH: 16512 LOSS: 40.99129709916816\n",
      "EPOCH: 16513 LOSS: 40.99129436956275\n",
      "EPOCH: 16514 LOSS: 40.99129164024045\n",
      "EPOCH: 16515 LOSS: 40.991288911201195\n",
      "EPOCH: 16516 LOSS: 40.99128618244497\n",
      "EPOCH: 16517 LOSS: 40.99128345397169\n",
      "EPOCH: 16518 LOSS: 40.991280725781316\n",
      "EPOCH: 16519 LOSS: 40.99127799787382\n",
      "EPOCH: 16520 LOSS: 40.99127527024915\n",
      "EPOCH: 16521 LOSS: 40.991272542907275\n",
      "EPOCH: 16522 LOSS: 40.99126981584813\n",
      "EPOCH: 16523 LOSS: 40.99126708907167\n",
      "EPOCH: 16524 LOSS: 40.99126436257785\n",
      "EPOCH: 16525 LOSS: 40.99126163636664\n",
      "EPOCH: 16526 LOSS: 40.99125891043799\n",
      "EPOCH: 16527 LOSS: 40.99125618479186\n",
      "EPOCH: 16528 LOSS: 40.99125345942818\n",
      "EPOCH: 16529 LOSS: 40.991250734346934\n",
      "EPOCH: 16530 LOSS: 40.99124800954805\n",
      "EPOCH: 16531 LOSS: 40.991245285031525\n",
      "EPOCH: 16532 LOSS: 40.99124256079726\n",
      "EPOCH: 16533 LOSS: 40.99123983684526\n",
      "EPOCH: 16534 LOSS: 40.991237113175444\n",
      "EPOCH: 16535 LOSS: 40.99123438978779\n",
      "EPOCH: 16536 LOSS: 40.99123166668225\n",
      "EPOCH: 16537 LOSS: 40.99122894385877\n",
      "EPOCH: 16538 LOSS: 40.991226221317305\n",
      "EPOCH: 16539 LOSS: 40.991223499057824\n",
      "EPOCH: 16540 LOSS: 40.99122077708027\n",
      "EPOCH: 16541 LOSS: 40.99121805538461\n",
      "EPOCH: 16542 LOSS: 40.99121533397077\n",
      "EPOCH: 16543 LOSS: 40.99121261283874\n",
      "EPOCH: 16544 LOSS: 40.99120989198846\n",
      "EPOCH: 16545 LOSS: 40.99120717141989\n",
      "EPOCH: 16546 LOSS: 40.99120445113298\n",
      "EPOCH: 16547 LOSS: 40.991201731127674\n",
      "EPOCH: 16548 LOSS: 40.99119901140394\n",
      "EPOCH: 16549 LOSS: 40.991196291961764\n",
      "EPOCH: 16550 LOSS: 40.99119357280105\n",
      "EPOCH: 16551 LOSS: 40.99119085392178\n",
      "EPOCH: 16552 LOSS: 40.99118813532391\n",
      "EPOCH: 16553 LOSS: 40.99118541700737\n",
      "EPOCH: 16554 LOSS: 40.99118269897215\n",
      "EPOCH: 16555 LOSS: 40.991179981218195\n",
      "EPOCH: 16556 LOSS: 40.99117726374545\n",
      "EPOCH: 16557 LOSS: 40.991174546553864\n",
      "EPOCH: 16558 LOSS: 40.99117182964344\n",
      "EPOCH: 16559 LOSS: 40.99116911301405\n",
      "EPOCH: 16560 LOSS: 40.99116639666575\n",
      "EPOCH: 16561 LOSS: 40.99116368059842\n",
      "EPOCH: 16562 LOSS: 40.991160964812025\n",
      "EPOCH: 16563 LOSS: 40.99115824930656\n",
      "EPOCH: 16564 LOSS: 40.991155534081926\n",
      "EPOCH: 16565 LOSS: 40.991152819138115\n",
      "EPOCH: 16566 LOSS: 40.99115010447508\n",
      "EPOCH: 16567 LOSS: 40.99114739009279\n",
      "EPOCH: 16568 LOSS: 40.99114467599115\n",
      "EPOCH: 16569 LOSS: 40.991141962170175\n",
      "EPOCH: 16570 LOSS: 40.99113924862976\n",
      "EPOCH: 16571 LOSS: 40.99113653536991\n",
      "EPOCH: 16572 LOSS: 40.99113382239057\n",
      "EPOCH: 16573 LOSS: 40.99113110969168\n",
      "EPOCH: 16574 LOSS: 40.9911283972732\n",
      "EPOCH: 16575 LOSS: 40.9911256851351\n",
      "EPOCH: 16576 LOSS: 40.99112297327733\n",
      "EPOCH: 16577 LOSS: 40.991120261699834\n",
      "EPOCH: 16578 LOSS: 40.99111755040258\n",
      "EPOCH: 16579 LOSS: 40.99111483938552\n",
      "EPOCH: 16580 LOSS: 40.991112128648595\n",
      "EPOCH: 16581 LOSS: 40.99110941819178\n",
      "EPOCH: 16582 LOSS: 40.99110670801504\n",
      "EPOCH: 16583 LOSS: 40.991103998118284\n",
      "EPOCH: 16584 LOSS: 40.991101288501525\n",
      "EPOCH: 16585 LOSS: 40.991098579164685\n",
      "EPOCH: 16586 LOSS: 40.99109587010771\n",
      "EPOCH: 16587 LOSS: 40.99109316133061\n",
      "EPOCH: 16588 LOSS: 40.99109045283329\n",
      "EPOCH: 16589 LOSS: 40.9910877446157\n",
      "EPOCH: 16590 LOSS: 40.99108503667783\n",
      "EPOCH: 16591 LOSS: 40.99108232901962\n",
      "EPOCH: 16592 LOSS: 40.99107962164102\n",
      "EPOCH: 16593 LOSS: 40.991076914542006\n",
      "EPOCH: 16594 LOSS: 40.991074207722505\n",
      "EPOCH: 16595 LOSS: 40.99107150118249\n",
      "EPOCH: 16596 LOSS: 40.99106879492191\n",
      "EPOCH: 16597 LOSS: 40.99106608894073\n",
      "EPOCH: 16598 LOSS: 40.99106338323892\n",
      "EPOCH: 16599 LOSS: 40.99106067781638\n",
      "EPOCH: 16600 LOSS: 40.99105797267312\n",
      "EPOCH: 16601 LOSS: 40.99105526780909\n",
      "EPOCH: 16602 LOSS: 40.9910525632242\n",
      "EPOCH: 16603 LOSS: 40.99104985891847\n",
      "EPOCH: 16604 LOSS: 40.99104715489182\n",
      "EPOCH: 16605 LOSS: 40.991044451144205\n",
      "EPOCH: 16606 LOSS: 40.991041747675595\n",
      "EPOCH: 16607 LOSS: 40.991039044485916\n",
      "EPOCH: 16608 LOSS: 40.99103634157516\n",
      "EPOCH: 16609 LOSS: 40.99103363894328\n",
      "EPOCH: 16610 LOSS: 40.99103093659021\n",
      "EPOCH: 16611 LOSS: 40.99102823451592\n",
      "EPOCH: 16612 LOSS: 40.99102553272036\n",
      "EPOCH: 16613 LOSS: 40.99102283120348\n",
      "EPOCH: 16614 LOSS: 40.991020129965236\n",
      "EPOCH: 16615 LOSS: 40.991017429005616\n",
      "EPOCH: 16616 LOSS: 40.99101472832454\n",
      "EPOCH: 16617 LOSS: 40.991012027921975\n",
      "EPOCH: 16618 LOSS: 40.99100932779787\n",
      "EPOCH: 16619 LOSS: 40.99100662795221\n",
      "EPOCH: 16620 LOSS: 40.99100392838491\n",
      "EPOCH: 16621 LOSS: 40.99100122909594\n",
      "EPOCH: 16622 LOSS: 40.990998530085285\n",
      "EPOCH: 16623 LOSS: 40.99099583135287\n",
      "EPOCH: 16624 LOSS: 40.99099313289864\n",
      "EPOCH: 16625 LOSS: 40.99099043472258\n",
      "EPOCH: 16626 LOSS: 40.990987736824636\n",
      "EPOCH: 16627 LOSS: 40.99098503920476\n",
      "EPOCH: 16628 LOSS: 40.99098234186292\n",
      "EPOCH: 16629 LOSS: 40.99097964479906\n",
      "EPOCH: 16630 LOSS: 40.990976948013135\n",
      "EPOCH: 16631 LOSS: 40.99097425150511\n",
      "EPOCH: 16632 LOSS: 40.99097155527494\n",
      "EPOCH: 16633 LOSS: 40.99096885932255\n",
      "EPOCH: 16634 LOSS: 40.99096616364795\n",
      "EPOCH: 16635 LOSS: 40.99096346825105\n",
      "EPOCH: 16636 LOSS: 40.99096077313183\n",
      "EPOCH: 16637 LOSS: 40.99095807829025\n",
      "EPOCH: 16638 LOSS: 40.99095538372625\n",
      "EPOCH: 16639 LOSS: 40.990952689439816\n",
      "EPOCH: 16640 LOSS: 40.99094999543085\n",
      "EPOCH: 16641 LOSS: 40.99094730169936\n",
      "EPOCH: 16642 LOSS: 40.99094460824527\n",
      "EPOCH: 16643 LOSS: 40.99094191506855\n",
      "EPOCH: 16644 LOSS: 40.99093922216915\n",
      "EPOCH: 16645 LOSS: 40.99093652954705\n",
      "EPOCH: 16646 LOSS: 40.99093383720216\n",
      "EPOCH: 16647 LOSS: 40.99093114513448\n",
      "EPOCH: 16648 LOSS: 40.99092845334394\n",
      "EPOCH: 16649 LOSS: 40.9909257618305\n",
      "EPOCH: 16650 LOSS: 40.99092307059413\n",
      "EPOCH: 16651 LOSS: 40.99092037963477\n",
      "EPOCH: 16652 LOSS: 40.99091768895239\n",
      "EPOCH: 16653 LOSS: 40.990914998546934\n",
      "EPOCH: 16654 LOSS: 40.99091230841836\n",
      "EPOCH: 16655 LOSS: 40.99090961856665\n",
      "EPOCH: 16656 LOSS: 40.99090692899172\n",
      "EPOCH: 16657 LOSS: 40.990904239693535\n",
      "EPOCH: 16658 LOSS: 40.99090155067209\n",
      "EPOCH: 16659 LOSS: 40.99089886192728\n",
      "EPOCH: 16660 LOSS: 40.9908961734591\n",
      "EPOCH: 16661 LOSS: 40.990893485267506\n",
      "EPOCH: 16662 LOSS: 40.99089079735245\n",
      "EPOCH: 16663 LOSS: 40.99088810971388\n",
      "EPOCH: 16664 LOSS: 40.99088542235176\n",
      "EPOCH: 16665 LOSS: 40.99088273526604\n",
      "EPOCH: 16666 LOSS: 40.990880048456695\n",
      "EPOCH: 16667 LOSS: 40.99087736192364\n",
      "EPOCH: 16668 LOSS: 40.990874675666895\n",
      "EPOCH: 16669 LOSS: 40.99087198968635\n",
      "EPOCH: 16670 LOSS: 40.99086930398199\n",
      "EPOCH: 16671 LOSS: 40.99086661855379\n",
      "EPOCH: 16672 LOSS: 40.99086393340169\n",
      "EPOCH: 16673 LOSS: 40.990861248525626\n",
      "EPOCH: 16674 LOSS: 40.990858563925585\n",
      "EPOCH: 16675 LOSS: 40.990855879601504\n",
      "EPOCH: 16676 LOSS: 40.99085319555334\n",
      "EPOCH: 16677 LOSS: 40.990850511781076\n",
      "EPOCH: 16678 LOSS: 40.99084782828464\n",
      "EPOCH: 16679 LOSS: 40.99084514506399\n",
      "EPOCH: 16680 LOSS: 40.990842462119105\n",
      "EPOCH: 16681 LOSS: 40.990839779449914\n",
      "EPOCH: 16682 LOSS: 40.99083709705639\n",
      "EPOCH: 16683 LOSS: 40.99083441493848\n",
      "EPOCH: 16684 LOSS: 40.99083173309616\n",
      "EPOCH: 16685 LOSS: 40.99082905152936\n",
      "EPOCH: 16686 LOSS: 40.99082637023804\n",
      "EPOCH: 16687 LOSS: 40.99082368922218\n",
      "EPOCH: 16688 LOSS: 40.99082100848171\n",
      "EPOCH: 16689 LOSS: 40.9908183280166\n",
      "EPOCH: 16690 LOSS: 40.990815647826814\n",
      "EPOCH: 16691 LOSS: 40.99081296791228\n",
      "EPOCH: 16692 LOSS: 40.990810288272996\n",
      "EPOCH: 16693 LOSS: 40.99080760890887\n",
      "EPOCH: 16694 LOSS: 40.9908049298199\n",
      "EPOCH: 16695 LOSS: 40.990802251006016\n",
      "EPOCH: 16696 LOSS: 40.990799572467196\n",
      "EPOCH: 16697 LOSS: 40.99079689420338\n",
      "EPOCH: 16698 LOSS: 40.99079421621453\n",
      "EPOCH: 16699 LOSS: 40.99079153850061\n",
      "EPOCH: 16700 LOSS: 40.99078886106157\n",
      "EPOCH: 16701 LOSS: 40.990786183897356\n",
      "EPOCH: 16702 LOSS: 40.99078350700794\n",
      "EPOCH: 16703 LOSS: 40.99078083039327\n",
      "EPOCH: 16704 LOSS: 40.9907781540533\n",
      "EPOCH: 16705 LOSS: 40.990775477988\n",
      "EPOCH: 16706 LOSS: 40.99077280219731\n",
      "EPOCH: 16707 LOSS: 40.9907701266812\n",
      "EPOCH: 16708 LOSS: 40.99076745143963\n",
      "EPOCH: 16709 LOSS: 40.99076477647256\n",
      "EPOCH: 16710 LOSS: 40.9907621017799\n",
      "EPOCH: 16711 LOSS: 40.99075942736167\n",
      "EPOCH: 16712 LOSS: 40.99075675321778\n",
      "EPOCH: 16713 LOSS: 40.990754079348214\n",
      "EPOCH: 16714 LOSS: 40.99075140575293\n",
      "EPOCH: 16715 LOSS: 40.990748732431854\n",
      "EPOCH: 16716 LOSS: 40.99074605938499\n",
      "EPOCH: 16717 LOSS: 40.99074338661225\n",
      "EPOCH: 16718 LOSS: 40.9907407141136\n",
      "EPOCH: 16719 LOSS: 40.99073804188903\n",
      "EPOCH: 16720 LOSS: 40.990735369938456\n",
      "EPOCH: 16721 LOSS: 40.990732698261844\n",
      "EPOCH: 16722 LOSS: 40.990730026859175\n",
      "EPOCH: 16723 LOSS: 40.990727355730385\n",
      "EPOCH: 16724 LOSS: 40.990724684875424\n",
      "EPOCH: 16725 LOSS: 40.99072201429427\n",
      "EPOCH: 16726 LOSS: 40.99071934398686\n",
      "EPOCH: 16727 LOSS: 40.99071667395317\n",
      "EPOCH: 16728 LOSS: 40.99071400419314\n",
      "EPOCH: 16729 LOSS: 40.99071133470672\n",
      "EPOCH: 16730 LOSS: 40.9907086654939\n",
      "EPOCH: 16731 LOSS: 40.99070599655461\n",
      "EPOCH: 16732 LOSS: 40.9907033278888\n",
      "EPOCH: 16733 LOSS: 40.99070065949646\n",
      "EPOCH: 16734 LOSS: 40.990697991377516\n",
      "EPOCH: 16735 LOSS: 40.990695323531945\n",
      "EPOCH: 16736 LOSS: 40.99069265595969\n",
      "EPOCH: 16737 LOSS: 40.99068998866071\n",
      "EPOCH: 16738 LOSS: 40.99068732163498\n",
      "EPOCH: 16739 LOSS: 40.990684654882415\n",
      "EPOCH: 16740 LOSS: 40.99068198840301\n",
      "EPOCH: 16741 LOSS: 40.99067932219672\n",
      "EPOCH: 16742 LOSS: 40.99067665626347\n",
      "EPOCH: 16743 LOSS: 40.990673990603256\n",
      "EPOCH: 16744 LOSS: 40.99067132521601\n",
      "EPOCH: 16745 LOSS: 40.990668660101704\n",
      "EPOCH: 16746 LOSS: 40.990665995260294\n",
      "EPOCH: 16747 LOSS: 40.9906633306917\n",
      "EPOCH: 16748 LOSS: 40.99066066639594\n",
      "EPOCH: 16749 LOSS: 40.990658002372946\n",
      "EPOCH: 16750 LOSS: 40.990655338622645\n",
      "EPOCH: 16751 LOSS: 40.99065267514503\n",
      "EPOCH: 16752 LOSS: 40.99065001194005\n",
      "EPOCH: 16753 LOSS: 40.990647349007645\n",
      "EPOCH: 16754 LOSS: 40.99064468634779\n",
      "EPOCH: 16755 LOSS: 40.99064202396043\n",
      "EPOCH: 16756 LOSS: 40.99063936184555\n",
      "EPOCH: 16757 LOSS: 40.99063670000309\n",
      "EPOCH: 16758 LOSS: 40.99063403843298\n",
      "EPOCH: 16759 LOSS: 40.990631377135216\n",
      "EPOCH: 16760 LOSS: 40.99062871610973\n",
      "EPOCH: 16761 LOSS: 40.99062605535649\n",
      "EPOCH: 16762 LOSS: 40.99062339487546\n",
      "EPOCH: 16763 LOSS: 40.99062073466658\n",
      "EPOCH: 16764 LOSS: 40.99061807472983\n",
      "EPOCH: 16765 LOSS: 40.990615415065136\n",
      "EPOCH: 16766 LOSS: 40.99061275567247\n",
      "EPOCH: 16767 LOSS: 40.990610096551805\n",
      "EPOCH: 16768 LOSS: 40.990607437703076\n",
      "EPOCH: 16769 LOSS: 40.99060477912625\n",
      "EPOCH: 16770 LOSS: 40.99060212082129\n",
      "EPOCH: 16771 LOSS: 40.99059946278812\n",
      "EPOCH: 16772 LOSS: 40.99059680502675\n",
      "EPOCH: 16773 LOSS: 40.990594147537095\n",
      "EPOCH: 16774 LOSS: 40.99059149031912\n",
      "EPOCH: 16775 LOSS: 40.990588833372804\n",
      "EPOCH: 16776 LOSS: 40.99058617669809\n",
      "EPOCH: 16777 LOSS: 40.99058352029492\n",
      "EPOCH: 16778 LOSS: 40.99058086416326\n",
      "EPOCH: 16779 LOSS: 40.990578208303106\n",
      "EPOCH: 16780 LOSS: 40.99057555271436\n",
      "EPOCH: 16781 LOSS: 40.990572897397\n",
      "EPOCH: 16782 LOSS: 40.990570242350984\n",
      "EPOCH: 16783 LOSS: 40.990567587576294\n",
      "EPOCH: 16784 LOSS: 40.99056493307283\n",
      "EPOCH: 16785 LOSS: 40.990562278840606\n",
      "EPOCH: 16786 LOSS: 40.99055962487954\n",
      "EPOCH: 16787 LOSS: 40.990556971189605\n",
      "EPOCH: 16788 LOSS: 40.99055431777076\n",
      "EPOCH: 16789 LOSS: 40.990551664622956\n",
      "EPOCH: 16790 LOSS: 40.99054901174616\n",
      "EPOCH: 16791 LOSS: 40.99054635914032\n",
      "EPOCH: 16792 LOSS: 40.9905437068054\n",
      "EPOCH: 16793 LOSS: 40.99054105474135\n",
      "EPOCH: 16794 LOSS: 40.99053840294813\n",
      "EPOCH: 16795 LOSS: 40.9905357514257\n",
      "EPOCH: 16796 LOSS: 40.990533100174034\n",
      "EPOCH: 16797 LOSS: 40.990530449193045\n",
      "EPOCH: 16798 LOSS: 40.990527798482724\n",
      "EPOCH: 16799 LOSS: 40.990525148043034\n",
      "EPOCH: 16800 LOSS: 40.99052249787391\n",
      "EPOCH: 16801 LOSS: 40.990519847975314\n",
      "EPOCH: 16802 LOSS: 40.9905171983472\n",
      "EPOCH: 16803 LOSS: 40.99051454898955\n",
      "EPOCH: 16804 LOSS: 40.99051189990229\n",
      "EPOCH: 16805 LOSS: 40.9905092510854\n",
      "EPOCH: 16806 LOSS: 40.990506602538844\n",
      "EPOCH: 16807 LOSS: 40.99050395426255\n",
      "EPOCH: 16808 LOSS: 40.99050130625648\n",
      "EPOCH: 16809 LOSS: 40.99049865852062\n",
      "EPOCH: 16810 LOSS: 40.9904960110549\n",
      "EPOCH: 16811 LOSS: 40.990493363859294\n",
      "EPOCH: 16812 LOSS: 40.99049071693375\n",
      "EPOCH: 16813 LOSS: 40.99048807027822\n",
      "EPOCH: 16814 LOSS: 40.99048542389268\n",
      "EPOCH: 16815 LOSS: 40.99048277777706\n",
      "EPOCH: 16816 LOSS: 40.990480131931356\n",
      "EPOCH: 16817 LOSS: 40.99047748635547\n",
      "EPOCH: 16818 LOSS: 40.99047484104943\n",
      "EPOCH: 16819 LOSS: 40.99047219601314\n",
      "EPOCH: 16820 LOSS: 40.990469551246576\n",
      "EPOCH: 16821 LOSS: 40.99046690674969\n",
      "EPOCH: 16822 LOSS: 40.99046426252244\n",
      "EPOCH: 16823 LOSS: 40.99046161856478\n",
      "EPOCH: 16824 LOSS: 40.99045897487669\n",
      "EPOCH: 16825 LOSS: 40.9904563314581\n",
      "EPOCH: 16826 LOSS: 40.99045368830899\n",
      "EPOCH: 16827 LOSS: 40.990451045429296\n",
      "EPOCH: 16828 LOSS: 40.990448402819\n",
      "EPOCH: 16829 LOSS: 40.99044576047803\n",
      "EPOCH: 16830 LOSS: 40.99044311840636\n",
      "EPOCH: 16831 LOSS: 40.99044047660396\n",
      "EPOCH: 16832 LOSS: 40.99043783507077\n",
      "EPOCH: 16833 LOSS: 40.990435193806746\n",
      "EPOCH: 16834 LOSS: 40.99043255281185\n",
      "EPOCH: 16835 LOSS: 40.99042991208604\n",
      "EPOCH: 16836 LOSS: 40.99042727162927\n",
      "EPOCH: 16837 LOSS: 40.99042463144154\n",
      "EPOCH: 16838 LOSS: 40.99042199152273\n",
      "EPOCH: 16839 LOSS: 40.99041935187284\n",
      "EPOCH: 16840 LOSS: 40.99041671249184\n",
      "EPOCH: 16841 LOSS: 40.99041407337967\n",
      "EPOCH: 16842 LOSS: 40.990411434536284\n",
      "EPOCH: 16843 LOSS: 40.99040879596167\n",
      "EPOCH: 16844 LOSS: 40.99040615765573\n",
      "EPOCH: 16845 LOSS: 40.99040351961847\n",
      "EPOCH: 16846 LOSS: 40.99040088184983\n",
      "EPOCH: 16847 LOSS: 40.99039824434978\n",
      "EPOCH: 16848 LOSS: 40.990395607118245\n",
      "EPOCH: 16849 LOSS: 40.9903929701552\n",
      "EPOCH: 16850 LOSS: 40.990390333460624\n",
      "EPOCH: 16851 LOSS: 40.990387697034464\n",
      "EPOCH: 16852 LOSS: 40.99038506087666\n",
      "EPOCH: 16853 LOSS: 40.99038242498719\n",
      "EPOCH: 16854 LOSS: 40.990379789365996\n",
      "EPOCH: 16855 LOSS: 40.990377154013046\n",
      "EPOCH: 16856 LOSS: 40.9903745189283\n",
      "EPOCH: 16857 LOSS: 40.99037188411172\n",
      "EPOCH: 16858 LOSS: 40.990369249563216\n",
      "EPOCH: 16859 LOSS: 40.99036661528281\n",
      "EPOCH: 16860 LOSS: 40.990363981270434\n",
      "EPOCH: 16861 LOSS: 40.99036134752605\n",
      "EPOCH: 16862 LOSS: 40.99035871404959\n",
      "EPOCH: 16863 LOSS: 40.99035608084105\n",
      "EPOCH: 16864 LOSS: 40.99035344790036\n",
      "EPOCH: 16865 LOSS: 40.99035081522753\n",
      "EPOCH: 16866 LOSS: 40.99034818282244\n",
      "EPOCH: 16867 LOSS: 40.990345550685085\n",
      "EPOCH: 16868 LOSS: 40.99034291881543\n",
      "EPOCH: 16869 LOSS: 40.990340287213414\n",
      "EPOCH: 16870 LOSS: 40.99033765587902\n",
      "EPOCH: 16871 LOSS: 40.99033502481219\n",
      "EPOCH: 16872 LOSS: 40.99033239401289\n",
      "EPOCH: 16873 LOSS: 40.99032976348106\n",
      "EPOCH: 16874 LOSS: 40.99032713321669\n",
      "EPOCH: 16875 LOSS: 40.99032450321971\n",
      "EPOCH: 16876 LOSS: 40.99032187349005\n",
      "EPOCH: 16877 LOSS: 40.990319244027745\n",
      "EPOCH: 16878 LOSS: 40.99031661483271\n",
      "EPOCH: 16879 LOSS: 40.99031398590489\n",
      "EPOCH: 16880 LOSS: 40.990311357244266\n",
      "EPOCH: 16881 LOSS: 40.99030872885079\n",
      "EPOCH: 16882 LOSS: 40.99030610072441\n",
      "EPOCH: 16883 LOSS: 40.99030347286509\n",
      "EPOCH: 16884 LOSS: 40.9903008452728\n",
      "EPOCH: 16885 LOSS: 40.99029821794748\n",
      "EPOCH: 16886 LOSS: 40.990295590889104\n",
      "EPOCH: 16887 LOSS: 40.99029296409761\n",
      "EPOCH: 16888 LOSS: 40.990290337572986\n",
      "EPOCH: 16889 LOSS: 40.990287711315155\n",
      "EPOCH: 16890 LOSS: 40.990285085324075\n",
      "EPOCH: 16891 LOSS: 40.990282459599754\n",
      "EPOCH: 16892 LOSS: 40.990279834142115\n",
      "EPOCH: 16893 LOSS: 40.99027720895109\n",
      "EPOCH: 16894 LOSS: 40.99027458402669\n",
      "EPOCH: 16895 LOSS: 40.99027195936884\n",
      "EPOCH: 16896 LOSS: 40.99026933497751\n",
      "EPOCH: 16897 LOSS: 40.990266710852644\n",
      "EPOCH: 16898 LOSS: 40.99026408699422\n",
      "EPOCH: 16899 LOSS: 40.99026146340219\n",
      "EPOCH: 16900 LOSS: 40.99025884007651\n",
      "EPOCH: 16901 LOSS: 40.99025621701712\n",
      "EPOCH: 16902 LOSS: 40.990253594224\n",
      "EPOCH: 16903 LOSS: 40.99025097169711\n",
      "EPOCH: 16904 LOSS: 40.9902483494364\n",
      "EPOCH: 16905 LOSS: 40.99024572744183\n",
      "EPOCH: 16906 LOSS: 40.99024310571334\n",
      "EPOCH: 16907 LOSS: 40.99024048425092\n",
      "EPOCH: 16908 LOSS: 40.990237863054524\n",
      "EPOCH: 16909 LOSS: 40.990235242124086\n",
      "EPOCH: 16910 LOSS: 40.99023262145959\n",
      "EPOCH: 16911 LOSS: 40.99023000106098\n",
      "EPOCH: 16912 LOSS: 40.9902273809282\n",
      "EPOCH: 16913 LOSS: 40.990224761061235\n",
      "EPOCH: 16914 LOSS: 40.99022214146003\n",
      "EPOCH: 16915 LOSS: 40.99021952212456\n",
      "EPOCH: 16916 LOSS: 40.99021690305476\n",
      "EPOCH: 16917 LOSS: 40.99021428425058\n",
      "EPOCH: 16918 LOSS: 40.99021166571202\n",
      "EPOCH: 16919 LOSS: 40.990209047439\n",
      "EPOCH: 16920 LOSS: 40.9902064294315\n",
      "EPOCH: 16921 LOSS: 40.99020381168948\n",
      "EPOCH: 16922 LOSS: 40.99020119421287\n",
      "EPOCH: 16923 LOSS: 40.990198577001664\n",
      "EPOCH: 16924 LOSS: 40.9901959600558\n",
      "EPOCH: 16925 LOSS: 40.99019334337523\n",
      "EPOCH: 16926 LOSS: 40.990190726959916\n",
      "EPOCH: 16927 LOSS: 40.99018811080985\n",
      "EPOCH: 16928 LOSS: 40.990185494924944\n",
      "EPOCH: 16929 LOSS: 40.99018287930518\n",
      "EPOCH: 16930 LOSS: 40.990180263950506\n",
      "EPOCH: 16931 LOSS: 40.99017764886088\n",
      "EPOCH: 16932 LOSS: 40.99017503403627\n",
      "EPOCH: 16933 LOSS: 40.99017241947665\n",
      "EPOCH: 16934 LOSS: 40.99016980518195\n",
      "EPOCH: 16935 LOSS: 40.99016719115211\n",
      "EPOCH: 16936 LOSS: 40.99016457738714\n",
      "EPOCH: 16937 LOSS: 40.990161963886976\n",
      "EPOCH: 16938 LOSS: 40.99015935065158\n",
      "EPOCH: 16939 LOSS: 40.99015673768089\n",
      "EPOCH: 16940 LOSS: 40.99015412497488\n",
      "EPOCH: 16941 LOSS: 40.9901515125335\n",
      "EPOCH: 16942 LOSS: 40.99014890035673\n",
      "EPOCH: 16943 LOSS: 40.99014628844452\n",
      "EPOCH: 16944 LOSS: 40.99014367679681\n",
      "EPOCH: 16945 LOSS: 40.99014106541358\n",
      "EPOCH: 16946 LOSS: 40.99013845429477\n",
      "EPOCH: 16947 LOSS: 40.990135843440356\n",
      "EPOCH: 16948 LOSS: 40.9901332328503\n",
      "EPOCH: 16949 LOSS: 40.99013062252453\n",
      "EPOCH: 16950 LOSS: 40.99012801246303\n",
      "EPOCH: 16951 LOSS: 40.99012540266575\n",
      "EPOCH: 16952 LOSS: 40.990122793132656\n",
      "EPOCH: 16953 LOSS: 40.9901201838637\n",
      "EPOCH: 16954 LOSS: 40.99011757485883\n",
      "EPOCH: 16955 LOSS: 40.99011496611803\n",
      "EPOCH: 16956 LOSS: 40.99011235764125\n",
      "EPOCH: 16957 LOSS: 40.99010974942841\n",
      "EPOCH: 16958 LOSS: 40.990107141479555\n",
      "EPOCH: 16959 LOSS: 40.99010453379455\n",
      "EPOCH: 16960 LOSS: 40.99010192637341\n",
      "EPOCH: 16961 LOSS: 40.99009931921607\n",
      "EPOCH: 16962 LOSS: 40.9900967123225\n",
      "EPOCH: 16963 LOSS: 40.99009410569266\n",
      "EPOCH: 16964 LOSS: 40.9900914993265\n",
      "EPOCH: 16965 LOSS: 40.990088893223984\n",
      "EPOCH: 16966 LOSS: 40.990086287385054\n",
      "EPOCH: 16967 LOSS: 40.99008368180969\n",
      "EPOCH: 16968 LOSS: 40.99008107649786\n",
      "EPOCH: 16969 LOSS: 40.99007847144951\n",
      "EPOCH: 16970 LOSS: 40.99007586666456\n",
      "EPOCH: 16971 LOSS: 40.99007326214303\n",
      "EPOCH: 16972 LOSS: 40.990070657884836\n",
      "EPOCH: 16973 LOSS: 40.99006805388996\n",
      "EPOCH: 16974 LOSS: 40.99006545015837\n",
      "EPOCH: 16975 LOSS: 40.990062846689995\n",
      "EPOCH: 16976 LOSS: 40.990060243484805\n",
      "EPOCH: 16977 LOSS: 40.99005764054277\n",
      "EPOCH: 16978 LOSS: 40.99005503786384\n",
      "EPOCH: 16979 LOSS: 40.99005243544796\n",
      "EPOCH: 16980 LOSS: 40.9900498332951\n",
      "EPOCH: 16981 LOSS: 40.99004723140524\n",
      "EPOCH: 16982 LOSS: 40.990044629778296\n",
      "EPOCH: 16983 LOSS: 40.990042028414265\n",
      "EPOCH: 16984 LOSS: 40.99003942731309\n",
      "EPOCH: 16985 LOSS: 40.99003682647472\n",
      "EPOCH: 16986 LOSS: 40.99003422589916\n",
      "EPOCH: 16987 LOSS: 40.990031625586276\n",
      "EPOCH: 16988 LOSS: 40.99002902553612\n",
      "EPOCH: 16989 LOSS: 40.99002642574862\n",
      "EPOCH: 16990 LOSS: 40.99002382622371\n",
      "EPOCH: 16991 LOSS: 40.99002122696138\n",
      "EPOCH: 16992 LOSS: 40.990018627961575\n",
      "EPOCH: 16993 LOSS: 40.99001602922425\n",
      "EPOCH: 16994 LOSS: 40.990013430749386\n",
      "EPOCH: 16995 LOSS: 40.99001083253691\n",
      "EPOCH: 16996 LOSS: 40.990008234586796\n",
      "EPOCH: 16997 LOSS: 40.990005636899\n",
      "EPOCH: 16998 LOSS: 40.9900030394735\n",
      "EPOCH: 16999 LOSS: 40.99000044231023\n",
      "EPOCH: 17000 LOSS: 40.989997845409164\n",
      "EPOCH: 17001 LOSS: 40.98999524877024\n",
      "EPOCH: 17002 LOSS: 40.98999265239345\n",
      "EPOCH: 17003 LOSS: 40.98999005627872\n",
      "EPOCH: 17004 LOSS: 40.98998746042602\n",
      "EPOCH: 17005 LOSS: 40.98998486483532\n",
      "EPOCH: 17006 LOSS: 40.989982269506584\n",
      "EPOCH: 17007 LOSS: 40.989979674439745\n",
      "EPOCH: 17008 LOSS: 40.98997707963479\n",
      "EPOCH: 17009 LOSS: 40.98997448509163\n",
      "EPOCH: 17010 LOSS: 40.989971890810274\n",
      "EPOCH: 17011 LOSS: 40.98996929679066\n",
      "EPOCH: 17012 LOSS: 40.98996670303278\n",
      "EPOCH: 17013 LOSS: 40.98996410953654\n",
      "EPOCH: 17014 LOSS: 40.9899615163019\n",
      "EPOCH: 17015 LOSS: 40.98995892332887\n",
      "EPOCH: 17016 LOSS: 40.989956330617375\n",
      "EPOCH: 17017 LOSS: 40.98995373816739\n",
      "EPOCH: 17018 LOSS: 40.98995114597885\n",
      "EPOCH: 17019 LOSS: 40.98994855405171\n",
      "EPOCH: 17020 LOSS: 40.989945962385974\n",
      "EPOCH: 17021 LOSS: 40.989943370981564\n",
      "EPOCH: 17022 LOSS: 40.98994077983845\n",
      "EPOCH: 17023 LOSS: 40.9899381889566\n",
      "EPOCH: 17024 LOSS: 40.98993559833595\n",
      "EPOCH: 17025 LOSS: 40.989933007976475\n",
      "EPOCH: 17026 LOSS: 40.989930417878135\n",
      "EPOCH: 17027 LOSS: 40.98992782804088\n",
      "EPOCH: 17028 LOSS: 40.98992523846467\n",
      "EPOCH: 17029 LOSS: 40.98992264914948\n",
      "EPOCH: 17030 LOSS: 40.989920060095244\n",
      "EPOCH: 17031 LOSS: 40.98991747130194\n",
      "EPOCH: 17032 LOSS: 40.98991488276951\n",
      "EPOCH: 17033 LOSS: 40.98991229449795\n",
      "EPOCH: 17034 LOSS: 40.98990970648718\n",
      "EPOCH: 17035 LOSS: 40.98990711873717\n",
      "EPOCH: 17036 LOSS: 40.98990453124788\n",
      "EPOCH: 17037 LOSS: 40.98990194401928\n",
      "EPOCH: 17038 LOSS: 40.989899357051314\n",
      "EPOCH: 17039 LOSS: 40.98989677034395\n",
      "EPOCH: 17040 LOSS: 40.989894183897135\n",
      "EPOCH: 17041 LOSS: 40.98989159771085\n",
      "EPOCH: 17042 LOSS: 40.98988901178504\n",
      "EPOCH: 17043 LOSS: 40.98988642611966\n",
      "EPOCH: 17044 LOSS: 40.989883840714676\n",
      "EPOCH: 17045 LOSS: 40.989881255570054\n",
      "EPOCH: 17046 LOSS: 40.98987867068574\n",
      "EPOCH: 17047 LOSS: 40.9898760860617\n",
      "EPOCH: 17048 LOSS: 40.989873501697886\n",
      "EPOCH: 17049 LOSS: 40.98987091759426\n",
      "EPOCH: 17050 LOSS: 40.98986833375079\n",
      "EPOCH: 17051 LOSS: 40.98986575016744\n",
      "EPOCH: 17052 LOSS: 40.98986316684415\n",
      "EPOCH: 17053 LOSS: 40.989860583780896\n",
      "EPOCH: 17054 LOSS: 40.98985800097762\n",
      "EPOCH: 17055 LOSS: 40.98985541843429\n",
      "EPOCH: 17056 LOSS: 40.989852836150874\n",
      "EPOCH: 17057 LOSS: 40.98985025412732\n",
      "EPOCH: 17058 LOSS: 40.98984767236358\n",
      "EPOCH: 17059 LOSS: 40.98984509085963\n",
      "EPOCH: 17060 LOSS: 40.98984250961543\n",
      "EPOCH: 17061 LOSS: 40.98983992863093\n",
      "EPOCH: 17062 LOSS: 40.98983734790609\n",
      "EPOCH: 17063 LOSS: 40.98983476744087\n",
      "EPOCH: 17064 LOSS: 40.98983218723524\n",
      "EPOCH: 17065 LOSS: 40.989829607289124\n",
      "EPOCH: 17066 LOSS: 40.98982702760252\n",
      "EPOCH: 17067 LOSS: 40.98982444817538\n",
      "EPOCH: 17068 LOSS: 40.98982186900767\n",
      "EPOCH: 17069 LOSS: 40.98981929009932\n",
      "EPOCH: 17070 LOSS: 40.98981671145031\n",
      "EPOCH: 17071 LOSS: 40.989814133060584\n",
      "EPOCH: 17072 LOSS: 40.98981155493014\n",
      "EPOCH: 17073 LOSS: 40.989808977058885\n",
      "EPOCH: 17074 LOSS: 40.98980639944682\n",
      "EPOCH: 17075 LOSS: 40.98980382209389\n",
      "EPOCH: 17076 LOSS: 40.98980124500004\n",
      "EPOCH: 17077 LOSS: 40.98979866816528\n",
      "EPOCH: 17078 LOSS: 40.98979609158947\n",
      "EPOCH: 17079 LOSS: 40.989793515272666\n",
      "EPOCH: 17080 LOSS: 40.9897909392148\n",
      "EPOCH: 17081 LOSS: 40.98978836341581\n",
      "EPOCH: 17082 LOSS: 40.98978578787567\n",
      "EPOCH: 17083 LOSS: 40.98978321259434\n",
      "EPOCH: 17084 LOSS: 40.98978063757179\n",
      "EPOCH: 17085 LOSS: 40.989778062807964\n",
      "EPOCH: 17086 LOSS: 40.989775488302826\n",
      "EPOCH: 17087 LOSS: 40.98977291405632\n",
      "EPOCH: 17088 LOSS: 40.98977034006842\n",
      "EPOCH: 17089 LOSS: 40.989767766339114\n",
      "EPOCH: 17090 LOSS: 40.98976519286832\n",
      "EPOCH: 17091 LOSS: 40.989762619656005\n",
      "EPOCH: 17092 LOSS: 40.98976004670213\n",
      "EPOCH: 17093 LOSS: 40.98975747400668\n",
      "EPOCH: 17094 LOSS: 40.98975490156957\n",
      "EPOCH: 17095 LOSS: 40.98975232939081\n",
      "EPOCH: 17096 LOSS: 40.98974975747031\n",
      "EPOCH: 17097 LOSS: 40.98974718580808\n",
      "EPOCH: 17098 LOSS: 40.98974461440403\n",
      "EPOCH: 17099 LOSS: 40.98974204325813\n",
      "EPOCH: 17100 LOSS: 40.98973947237037\n",
      "EPOCH: 17101 LOSS: 40.9897369017407\n",
      "EPOCH: 17102 LOSS: 40.98973433136905\n",
      "EPOCH: 17103 LOSS: 40.9897317612554\n",
      "EPOCH: 17104 LOSS: 40.989729191399725\n",
      "EPOCH: 17105 LOSS: 40.989726621801964\n",
      "EPOCH: 17106 LOSS: 40.98972405246209\n",
      "EPOCH: 17107 LOSS: 40.98972148338004\n",
      "EPOCH: 17108 LOSS: 40.989718914555795\n",
      "EPOCH: 17109 LOSS: 40.98971634598931\n",
      "EPOCH: 17110 LOSS: 40.98971377768054\n",
      "EPOCH: 17111 LOSS: 40.98971120962944\n",
      "EPOCH: 17112 LOSS: 40.989708641835975\n",
      "EPOCH: 17113 LOSS: 40.98970607430013\n",
      "EPOCH: 17114 LOSS: 40.989703507021844\n",
      "EPOCH: 17115 LOSS: 40.98970094000105\n",
      "EPOCH: 17116 LOSS: 40.98969837323773\n",
      "EPOCH: 17117 LOSS: 40.98969580673187\n",
      "EPOCH: 17118 LOSS: 40.9896932404834\n",
      "EPOCH: 17119 LOSS: 40.989690674492266\n",
      "EPOCH: 17120 LOSS: 40.98968810875845\n",
      "EPOCH: 17121 LOSS: 40.98968554328194\n",
      "EPOCH: 17122 LOSS: 40.989682978062625\n",
      "EPOCH: 17123 LOSS: 40.98968041310053\n",
      "EPOCH: 17124 LOSS: 40.98967784839557\n",
      "EPOCH: 17125 LOSS: 40.98967528394775\n",
      "EPOCH: 17126 LOSS: 40.98967271975698\n",
      "EPOCH: 17127 LOSS: 40.98967015582324\n",
      "EPOCH: 17128 LOSS: 40.98966759214652\n",
      "EPOCH: 17129 LOSS: 40.98966502872673\n",
      "EPOCH: 17130 LOSS: 40.98966246556387\n",
      "EPOCH: 17131 LOSS: 40.98965990265787\n",
      "EPOCH: 17132 LOSS: 40.98965734000871\n",
      "EPOCH: 17133 LOSS: 40.98965477761634\n",
      "EPOCH: 17134 LOSS: 40.9896522154807\n",
      "EPOCH: 17135 LOSS: 40.98964965360181\n",
      "EPOCH: 17136 LOSS: 40.98964709197956\n",
      "EPOCH: 17137 LOSS: 40.98964453061396\n",
      "EPOCH: 17138 LOSS: 40.989641969504945\n",
      "EPOCH: 17139 LOSS: 40.98963940865248\n",
      "EPOCH: 17140 LOSS: 40.989636848056534\n",
      "EPOCH: 17141 LOSS: 40.98963428771705\n",
      "EPOCH: 17142 LOSS: 40.98963172763401\n",
      "EPOCH: 17143 LOSS: 40.989629167807365\n",
      "EPOCH: 17144 LOSS: 40.989626608237046\n",
      "EPOCH: 17145 LOSS: 40.98962404892306\n",
      "EPOCH: 17146 LOSS: 40.98962148986534\n",
      "EPOCH: 17147 LOSS: 40.98961893106383\n",
      "EPOCH: 17148 LOSS: 40.98961637251854\n",
      "EPOCH: 17149 LOSS: 40.9896138142294\n",
      "EPOCH: 17150 LOSS: 40.98961125619635\n",
      "EPOCH: 17151 LOSS: 40.98960869841939\n",
      "EPOCH: 17152 LOSS: 40.989606140898445\n",
      "EPOCH: 17153 LOSS: 40.989603583633496\n",
      "EPOCH: 17154 LOSS: 40.9896010266245\n",
      "EPOCH: 17155 LOSS: 40.98959846987141\n",
      "EPOCH: 17156 LOSS: 40.9895959133742\n",
      "EPOCH: 17157 LOSS: 40.989593357132826\n",
      "EPOCH: 17158 LOSS: 40.989590801147216\n",
      "EPOCH: 17159 LOSS: 40.98958824541737\n",
      "EPOCH: 17160 LOSS: 40.98958568994324\n",
      "EPOCH: 17161 LOSS: 40.98958313472478\n",
      "EPOCH: 17162 LOSS: 40.989580579761956\n",
      "EPOCH: 17163 LOSS: 40.98957802505471\n",
      "EPOCH: 17164 LOSS: 40.98957547060303\n",
      "EPOCH: 17165 LOSS: 40.98957291640685\n",
      "EPOCH: 17166 LOSS: 40.98957036246614\n",
      "EPOCH: 17167 LOSS: 40.98956780878085\n",
      "EPOCH: 17168 LOSS: 40.989565255350975\n",
      "EPOCH: 17169 LOSS: 40.98956270217644\n",
      "EPOCH: 17170 LOSS: 40.989560149257215\n",
      "EPOCH: 17171 LOSS: 40.98955759659326\n",
      "EPOCH: 17172 LOSS: 40.989555044184556\n",
      "EPOCH: 17173 LOSS: 40.989552492031024\n",
      "EPOCH: 17174 LOSS: 40.98954994013265\n",
      "EPOCH: 17175 LOSS: 40.98954738848939\n",
      "EPOCH: 17176 LOSS: 40.98954483710121\n",
      "EPOCH: 17177 LOSS: 40.98954228596804\n",
      "EPOCH: 17178 LOSS: 40.989539735089885\n",
      "EPOCH: 17179 LOSS: 40.98953718446667\n",
      "EPOCH: 17180 LOSS: 40.98953463409837\n",
      "EPOCH: 17181 LOSS: 40.989532083984955\n",
      "EPOCH: 17182 LOSS: 40.989529534126355\n",
      "EPOCH: 17183 LOSS: 40.989526984522556\n",
      "EPOCH: 17184 LOSS: 40.989524435173514\n",
      "EPOCH: 17185 LOSS: 40.98952188607918\n",
      "EPOCH: 17186 LOSS: 40.98951933723953\n",
      "EPOCH: 17187 LOSS: 40.9895167886545\n",
      "EPOCH: 17188 LOSS: 40.98951424032407\n",
      "EPOCH: 17189 LOSS: 40.98951169224821\n",
      "EPOCH: 17190 LOSS: 40.98950914442685\n",
      "EPOCH: 17191 LOSS: 40.98950659685997\n",
      "EPOCH: 17192 LOSS: 40.98950404954751\n",
      "EPOCH: 17193 LOSS: 40.989501502489475\n",
      "EPOCH: 17194 LOSS: 40.989498955685775\n",
      "EPOCH: 17195 LOSS: 40.9894964091364\n",
      "EPOCH: 17196 LOSS: 40.9894938628413\n",
      "EPOCH: 17197 LOSS: 40.98949131680044\n",
      "EPOCH: 17198 LOSS: 40.98948877101377\n",
      "EPOCH: 17199 LOSS: 40.98948622548126\n",
      "EPOCH: 17200 LOSS: 40.98948368020288\n",
      "EPOCH: 17201 LOSS: 40.98948113517856\n",
      "EPOCH: 17202 LOSS: 40.98947859040828\n",
      "EPOCH: 17203 LOSS: 40.989476045892026\n",
      "EPOCH: 17204 LOSS: 40.9894735016297\n",
      "EPOCH: 17205 LOSS: 40.989470957621315\n",
      "EPOCH: 17206 LOSS: 40.98946841386679\n",
      "EPOCH: 17207 LOSS: 40.98946587036613\n",
      "EPOCH: 17208 LOSS: 40.98946332711924\n",
      "EPOCH: 17209 LOSS: 40.98946078412614\n",
      "EPOCH: 17210 LOSS: 40.98945824138674\n",
      "EPOCH: 17211 LOSS: 40.98945569890104\n",
      "EPOCH: 17212 LOSS: 40.98945315666898\n",
      "EPOCH: 17213 LOSS: 40.98945061469051\n",
      "EPOCH: 17214 LOSS: 40.98944807296562\n",
      "EPOCH: 17215 LOSS: 40.98944553149424\n",
      "EPOCH: 17216 LOSS: 40.98944299027636\n",
      "EPOCH: 17217 LOSS: 40.989440449311914\n",
      "EPOCH: 17218 LOSS: 40.98943790860088\n",
      "EPOCH: 17219 LOSS: 40.98943536814319\n",
      "EPOCH: 17220 LOSS: 40.98943282793885\n",
      "EPOCH: 17221 LOSS: 40.989430287987794\n",
      "EPOCH: 17222 LOSS: 40.989427748289984\n",
      "EPOCH: 17223 LOSS: 40.98942520884536\n",
      "EPOCH: 17224 LOSS: 40.989422669653926\n",
      "EPOCH: 17225 LOSS: 40.989420130715615\n",
      "EPOCH: 17226 LOSS: 40.9894175920304\n",
      "EPOCH: 17227 LOSS: 40.98941505359822\n",
      "EPOCH: 17228 LOSS: 40.989412515419076\n",
      "EPOCH: 17229 LOSS: 40.98940997749287\n",
      "EPOCH: 17230 LOSS: 40.9894074398196\n",
      "EPOCH: 17231 LOSS: 40.98940490239925\n",
      "EPOCH: 17232 LOSS: 40.98940236523173\n",
      "EPOCH: 17233 LOSS: 40.98939982831702\n",
      "EPOCH: 17234 LOSS: 40.989397291655095\n",
      "EPOCH: 17235 LOSS: 40.98939475524591\n",
      "EPOCH: 17236 LOSS: 40.989392219089396\n",
      "EPOCH: 17237 LOSS: 40.98938968318555\n",
      "EPOCH: 17238 LOSS: 40.98938714753433\n",
      "EPOCH: 17239 LOSS: 40.989384612135666\n",
      "EPOCH: 17240 LOSS: 40.98938207698954\n",
      "EPOCH: 17241 LOSS: 40.989379542095925\n",
      "EPOCH: 17242 LOSS: 40.98937700745478\n",
      "EPOCH: 17243 LOSS: 40.98937447306603\n",
      "EPOCH: 17244 LOSS: 40.989371938929665\n",
      "EPOCH: 17245 LOSS: 40.98936940504565\n",
      "EPOCH: 17246 LOSS: 40.98936687141392\n",
      "EPOCH: 17247 LOSS: 40.98936433803446\n",
      "EPOCH: 17248 LOSS: 40.98936180490722\n",
      "EPOCH: 17249 LOSS: 40.98935927203216\n",
      "EPOCH: 17250 LOSS: 40.98935673940925\n",
      "EPOCH: 17251 LOSS: 40.989354207038446\n",
      "EPOCH: 17252 LOSS: 40.98935167491969\n",
      "EPOCH: 17253 LOSS: 40.98934914305298\n",
      "EPOCH: 17254 LOSS: 40.98934661143825\n",
      "EPOCH: 17255 LOSS: 40.98934408007547\n",
      "EPOCH: 17256 LOSS: 40.98934154896459\n",
      "EPOCH: 17257 LOSS: 40.98933901810558\n",
      "EPOCH: 17258 LOSS: 40.98933648749839\n",
      "EPOCH: 17259 LOSS: 40.989333957143\n",
      "EPOCH: 17260 LOSS: 40.98933142703936\n",
      "EPOCH: 17261 LOSS: 40.989328897187434\n",
      "EPOCH: 17262 LOSS: 40.98932636758718\n",
      "EPOCH: 17263 LOSS: 40.98932383823855\n",
      "EPOCH: 17264 LOSS: 40.989321309141516\n",
      "EPOCH: 17265 LOSS: 40.98931878029605\n",
      "EPOCH: 17266 LOSS: 40.989316251702085\n",
      "EPOCH: 17267 LOSS: 40.9893137233596\n",
      "EPOCH: 17268 LOSS: 40.989311195268556\n",
      "EPOCH: 17269 LOSS: 40.989308667428915\n",
      "EPOCH: 17270 LOSS: 40.98930613984062\n",
      "EPOCH: 17271 LOSS: 40.98930361250365\n",
      "EPOCH: 17272 LOSS: 40.98930108541796\n",
      "EPOCH: 17273 LOSS: 40.98929855858351\n",
      "EPOCH: 17274 LOSS: 40.989296032000254\n",
      "EPOCH: 17275 LOSS: 40.98929350566818\n",
      "EPOCH: 17276 LOSS: 40.98929097958721\n",
      "EPOCH: 17277 LOSS: 40.98928845375734\n",
      "EPOCH: 17278 LOSS: 40.989285928178504\n",
      "EPOCH: 17279 LOSS: 40.98928340285069\n",
      "EPOCH: 17280 LOSS: 40.98928087777382\n",
      "EPOCH: 17281 LOSS: 40.98927835294788\n",
      "EPOCH: 17282 LOSS: 40.98927582837284\n",
      "EPOCH: 17283 LOSS: 40.98927330404865\n",
      "EPOCH: 17284 LOSS: 40.98927077997527\n",
      "EPOCH: 17285 LOSS: 40.989268256152656\n",
      "EPOCH: 17286 LOSS: 40.98926573258077\n",
      "EPOCH: 17287 LOSS: 40.989263209259605\n",
      "EPOCH: 17288 LOSS: 40.98926068618906\n",
      "EPOCH: 17289 LOSS: 40.98925816336916\n",
      "EPOCH: 17290 LOSS: 40.989255640799826\n",
      "EPOCH: 17291 LOSS: 40.98925311848102\n",
      "EPOCH: 17292 LOSS: 40.98925059641272\n",
      "EPOCH: 17293 LOSS: 40.98924807459487\n",
      "EPOCH: 17294 LOSS: 40.98924555302746\n",
      "EPOCH: 17295 LOSS: 40.98924303171043\n",
      "EPOCH: 17296 LOSS: 40.98924051064371\n",
      "EPOCH: 17297 LOSS: 40.98923798982733\n",
      "EPOCH: 17298 LOSS: 40.989235469261196\n",
      "EPOCH: 17299 LOSS: 40.98923294894529\n",
      "EPOCH: 17300 LOSS: 40.98923042887956\n",
      "EPOCH: 17301 LOSS: 40.989227909064\n",
      "EPOCH: 17302 LOSS: 40.989225389498536\n",
      "EPOCH: 17303 LOSS: 40.989222870183134\n",
      "EPOCH: 17304 LOSS: 40.98922035111778\n",
      "EPOCH: 17305 LOSS: 40.989217832302415\n",
      "EPOCH: 17306 LOSS: 40.989215313737\n",
      "EPOCH: 17307 LOSS: 40.989212795421494\n",
      "EPOCH: 17308 LOSS: 40.98921027735586\n",
      "EPOCH: 17309 LOSS: 40.989207759540065\n",
      "EPOCH: 17310 LOSS: 40.989205241974076\n",
      "EPOCH: 17311 LOSS: 40.98920272465783\n",
      "EPOCH: 17312 LOSS: 40.98920020759131\n",
      "EPOCH: 17313 LOSS: 40.98919769077448\n",
      "EPOCH: 17314 LOSS: 40.98919517420728\n",
      "EPOCH: 17315 LOSS: 40.9891926578897\n",
      "EPOCH: 17316 LOSS: 40.98919014182165\n",
      "EPOCH: 17317 LOSS: 40.98918762600315\n",
      "EPOCH: 17318 LOSS: 40.98918511043414\n",
      "EPOCH: 17319 LOSS: 40.98918259511457\n",
      "EPOCH: 17320 LOSS: 40.989180080044406\n",
      "EPOCH: 17321 LOSS: 40.98917756522361\n",
      "EPOCH: 17322 LOSS: 40.98917505065215\n",
      "EPOCH: 17323 LOSS: 40.98917253632998\n",
      "EPOCH: 17324 LOSS: 40.98917002225707\n",
      "EPOCH: 17325 LOSS: 40.98916750843338\n",
      "EPOCH: 17326 LOSS: 40.989164994858854\n",
      "EPOCH: 17327 LOSS: 40.989162481533455\n",
      "EPOCH: 17328 LOSS: 40.98915996845717\n",
      "EPOCH: 17329 LOSS: 40.98915745562993\n",
      "EPOCH: 17330 LOSS: 40.98915494305172\n",
      "EPOCH: 17331 LOSS: 40.989152430722505\n",
      "EPOCH: 17332 LOSS: 40.98914991864223\n",
      "EPOCH: 17333 LOSS: 40.989147406810844\n",
      "EPOCH: 17334 LOSS: 40.98914489522832\n",
      "EPOCH: 17335 LOSS: 40.98914238389464\n",
      "EPOCH: 17336 LOSS: 40.98913987280974\n",
      "EPOCH: 17337 LOSS: 40.98913736197358\n",
      "EPOCH: 17338 LOSS: 40.98913485138615\n",
      "EPOCH: 17339 LOSS: 40.98913234104738\n",
      "EPOCH: 17340 LOSS: 40.98912983095725\n",
      "EPOCH: 17341 LOSS: 40.98912732111571\n",
      "EPOCH: 17342 LOSS: 40.98912481152273\n",
      "EPOCH: 17343 LOSS: 40.989122302178274\n",
      "EPOCH: 17344 LOSS: 40.98911979308228\n",
      "EPOCH: 17345 LOSS: 40.98911728423474\n",
      "EPOCH: 17346 LOSS: 40.9891147756356\n",
      "EPOCH: 17347 LOSS: 40.98911226728482\n",
      "EPOCH: 17348 LOSS: 40.989109759182355\n",
      "EPOCH: 17349 LOSS: 40.98910725132818\n",
      "EPOCH: 17350 LOSS: 40.989104743722265\n",
      "EPOCH: 17351 LOSS: 40.989102236364545\n",
      "EPOCH: 17352 LOSS: 40.98909972925501\n",
      "EPOCH: 17353 LOSS: 40.989097222393596\n",
      "EPOCH: 17354 LOSS: 40.98909471578028\n",
      "EPOCH: 17355 LOSS: 40.989092209415\n",
      "EPOCH: 17356 LOSS: 40.98908970329776\n",
      "EPOCH: 17357 LOSS: 40.989087197428475\n",
      "EPOCH: 17358 LOSS: 40.989084691807136\n",
      "EPOCH: 17359 LOSS: 40.989082186433706\n",
      "EPOCH: 17360 LOSS: 40.98907968130813\n",
      "EPOCH: 17361 LOSS: 40.98907717643037\n",
      "EPOCH: 17362 LOSS: 40.98907467180041\n",
      "EPOCH: 17363 LOSS: 40.989072167418186\n",
      "EPOCH: 17364 LOSS: 40.98906966328367\n",
      "EPOCH: 17365 LOSS: 40.98906715939681\n",
      "EPOCH: 17366 LOSS: 40.989064655757616\n",
      "EPOCH: 17367 LOSS: 40.989062152365975\n",
      "EPOCH: 17368 LOSS: 40.98905964922191\n",
      "EPOCH: 17369 LOSS: 40.98905714632534\n",
      "EPOCH: 17370 LOSS: 40.98905464367627\n",
      "EPOCH: 17371 LOSS: 40.98905214127462\n",
      "EPOCH: 17372 LOSS: 40.989049639120374\n",
      "EPOCH: 17373 LOSS: 40.9890471372135\n",
      "EPOCH: 17374 LOSS: 40.98904463555393\n",
      "EPOCH: 17375 LOSS: 40.989042134141656\n",
      "EPOCH: 17376 LOSS: 40.98903963297663\n",
      "EPOCH: 17377 LOSS: 40.98903713205881\n",
      "EPOCH: 17378 LOSS: 40.98903463138815\n",
      "EPOCH: 17379 LOSS: 40.98903213096462\n",
      "EPOCH: 17380 LOSS: 40.98902963078819\n",
      "EPOCH: 17381 LOSS: 40.989027130858815\n",
      "EPOCH: 17382 LOSS: 40.989024631176434\n",
      "EPOCH: 17383 LOSS: 40.98902213174105\n",
      "EPOCH: 17384 LOSS: 40.9890196325526\n",
      "EPOCH: 17385 LOSS: 40.98901713361106\n",
      "EPOCH: 17386 LOSS: 40.98901463491637\n",
      "EPOCH: 17387 LOSS: 40.98901213646849\n",
      "EPOCH: 17388 LOSS: 40.98900963826742\n",
      "EPOCH: 17389 LOSS: 40.989007140313085\n",
      "EPOCH: 17390 LOSS: 40.98900464260545\n",
      "EPOCH: 17391 LOSS: 40.9890021451445\n",
      "EPOCH: 17392 LOSS: 40.98899964793016\n",
      "EPOCH: 17393 LOSS: 40.98899715096243\n",
      "EPOCH: 17394 LOSS: 40.98899465424125\n",
      "EPOCH: 17395 LOSS: 40.98899215776658\n",
      "EPOCH: 17396 LOSS: 40.98898966153841\n",
      "EPOCH: 17397 LOSS: 40.98898716555667\n",
      "EPOCH: 17398 LOSS: 40.98898466982132\n",
      "EPOCH: 17399 LOSS: 40.98898217433235\n",
      "EPOCH: 17400 LOSS: 40.988979679089695\n",
      "EPOCH: 17401 LOSS: 40.98897718409333\n",
      "EPOCH: 17402 LOSS: 40.98897468934321\n",
      "EPOCH: 17403 LOSS: 40.98897219483929\n",
      "EPOCH: 17404 LOSS: 40.988969700581556\n",
      "EPOCH: 17405 LOSS: 40.98896720656995\n",
      "EPOCH: 17406 LOSS: 40.98896471280445\n",
      "EPOCH: 17407 LOSS: 40.988962219285014\n",
      "EPOCH: 17408 LOSS: 40.988959726011586\n",
      "EPOCH: 17409 LOSS: 40.98895723298412\n",
      "EPOCH: 17410 LOSS: 40.988954740202615\n",
      "EPOCH: 17411 LOSS: 40.988952247667015\n",
      "EPOCH: 17412 LOSS: 40.988949755377284\n",
      "EPOCH: 17413 LOSS: 40.98894726333338\n",
      "EPOCH: 17414 LOSS: 40.988944771535266\n",
      "EPOCH: 17415 LOSS: 40.9889422799829\n",
      "EPOCH: 17416 LOSS: 40.98893978867625\n",
      "EPOCH: 17417 LOSS: 40.98893729761527\n",
      "EPOCH: 17418 LOSS: 40.98893480679993\n",
      "EPOCH: 17419 LOSS: 40.98893231623019\n",
      "EPOCH: 17420 LOSS: 40.98892982590601\n",
      "EPOCH: 17421 LOSS: 40.988927335827356\n",
      "EPOCH: 17422 LOSS: 40.98892484599419\n",
      "EPOCH: 17423 LOSS: 40.98892235640647\n",
      "EPOCH: 17424 LOSS: 40.98891986706414\n",
      "EPOCH: 17425 LOSS: 40.9889173779672\n",
      "EPOCH: 17426 LOSS: 40.98891488911558\n",
      "EPOCH: 17427 LOSS: 40.98891240050928\n",
      "EPOCH: 17428 LOSS: 40.988909912148216\n",
      "EPOCH: 17429 LOSS: 40.98890742403237\n",
      "EPOCH: 17430 LOSS: 40.988904936161696\n",
      "EPOCH: 17431 LOSS: 40.98890244853618\n",
      "EPOCH: 17432 LOSS: 40.98889996115578\n",
      "EPOCH: 17433 LOSS: 40.98889747402041\n",
      "EPOCH: 17434 LOSS: 40.988894987130095\n",
      "EPOCH: 17435 LOSS: 40.98889250048477\n",
      "EPOCH: 17436 LOSS: 40.98889001408439\n",
      "EPOCH: 17437 LOSS: 40.98888752792891\n",
      "EPOCH: 17438 LOSS: 40.98888504201833\n",
      "EPOCH: 17439 LOSS: 40.98888255635258\n",
      "EPOCH: 17440 LOSS: 40.988880070931614\n",
      "EPOCH: 17441 LOSS: 40.988877585755425\n",
      "EPOCH: 17442 LOSS: 40.988875100823954\n",
      "EPOCH: 17443 LOSS: 40.98887261613717\n",
      "EPOCH: 17444 LOSS: 40.988870131695045\n",
      "EPOCH: 17445 LOSS: 40.98886764749753\n",
      "EPOCH: 17446 LOSS: 40.98886516354457\n",
      "EPOCH: 17447 LOSS: 40.988862679836146\n",
      "EPOCH: 17448 LOSS: 40.98886019637223\n",
      "EPOCH: 17449 LOSS: 40.98885771315277\n",
      "EPOCH: 17450 LOSS: 40.98885523017772\n",
      "EPOCH: 17451 LOSS: 40.98885274744707\n",
      "EPOCH: 17452 LOSS: 40.988850264960746\n",
      "EPOCH: 17453 LOSS: 40.98884778271874\n",
      "EPOCH: 17454 LOSS: 40.988845300720996\n",
      "EPOCH: 17455 LOSS: 40.988842818967484\n",
      "EPOCH: 17456 LOSS: 40.988840337458164\n",
      "EPOCH: 17457 LOSS: 40.988837856193\n",
      "EPOCH: 17458 LOSS: 40.98883537517196\n",
      "EPOCH: 17459 LOSS: 40.988832894394996\n",
      "EPOCH: 17460 LOSS: 40.988830413862075\n",
      "EPOCH: 17461 LOSS: 40.98882793357315\n",
      "EPOCH: 17462 LOSS: 40.9888254535282\n",
      "EPOCH: 17463 LOSS: 40.98882297372717\n",
      "EPOCH: 17464 LOSS: 40.98882049417003\n",
      "EPOCH: 17465 LOSS: 40.98881801485675\n",
      "EPOCH: 17466 LOSS: 40.98881553578728\n",
      "EPOCH: 17467 LOSS: 40.9888130569616\n",
      "EPOCH: 17468 LOSS: 40.988810578379635\n",
      "EPOCH: 17469 LOSS: 40.98880810004138\n",
      "EPOCH: 17470 LOSS: 40.988805621946796\n",
      "EPOCH: 17471 LOSS: 40.98880314409583\n",
      "EPOCH: 17472 LOSS: 40.98880066648843\n",
      "EPOCH: 17473 LOSS: 40.98879818912463\n",
      "EPOCH: 17474 LOSS: 40.988795712004304\n",
      "EPOCH: 17475 LOSS: 40.988793235127474\n",
      "EPOCH: 17476 LOSS: 40.988790758494055\n",
      "EPOCH: 17477 LOSS: 40.988788282104046\n",
      "EPOCH: 17478 LOSS: 40.98878580595742\n",
      "EPOCH: 17479 LOSS: 40.98878333005409\n",
      "EPOCH: 17480 LOSS: 40.98878085439406\n",
      "EPOCH: 17481 LOSS: 40.988778378977266\n",
      "EPOCH: 17482 LOSS: 40.98877590380369\n",
      "EPOCH: 17483 LOSS: 40.98877342887329\n",
      "EPOCH: 17484 LOSS: 40.988770954186016\n",
      "EPOCH: 17485 LOSS: 40.98876847974184\n",
      "EPOCH: 17486 LOSS: 40.988766005540725\n",
      "EPOCH: 17487 LOSS: 40.988763531582634\n",
      "EPOCH: 17488 LOSS: 40.988761057867535\n",
      "EPOCH: 17489 LOSS: 40.98875858439537\n",
      "EPOCH: 17490 LOSS: 40.988756111166126\n",
      "EPOCH: 17491 LOSS: 40.98875363817974\n",
      "EPOCH: 17492 LOSS: 40.9887511654362\n",
      "EPOCH: 17493 LOSS: 40.988748692935445\n",
      "EPOCH: 17494 LOSS: 40.988746220677456\n",
      "EPOCH: 17495 LOSS: 40.98874374866218\n",
      "EPOCH: 17496 LOSS: 40.988741276889584\n",
      "EPOCH: 17497 LOSS: 40.988738805359645\n",
      "EPOCH: 17498 LOSS: 40.988736334072314\n",
      "EPOCH: 17499 LOSS: 40.98873386302755\n",
      "EPOCH: 17500 LOSS: 40.98873139222531\n",
      "EPOCH: 17501 LOSS: 40.98872892166558\n",
      "EPOCH: 17502 LOSS: 40.9887264513483\n",
      "EPOCH: 17503 LOSS: 40.988723981273424\n",
      "EPOCH: 17504 LOSS: 40.988721511440964\n",
      "EPOCH: 17505 LOSS: 40.98871904185083\n",
      "EPOCH: 17506 LOSS: 40.988716572503\n",
      "EPOCH: 17507 LOSS: 40.98871410339744\n",
      "EPOCH: 17508 LOSS: 40.98871163453413\n",
      "EPOCH: 17509 LOSS: 40.98870916591299\n",
      "EPOCH: 17510 LOSS: 40.98870669753402\n",
      "EPOCH: 17511 LOSS: 40.988704229397165\n",
      "EPOCH: 17512 LOSS: 40.9887017615024\n",
      "EPOCH: 17513 LOSS: 40.98869929384967\n",
      "EPOCH: 17514 LOSS: 40.988696826438954\n",
      "EPOCH: 17515 LOSS: 40.988694359270205\n",
      "EPOCH: 17516 LOSS: 40.9886918923434\n",
      "EPOCH: 17517 LOSS: 40.988689425658464\n",
      "EPOCH: 17518 LOSS: 40.9886869592154\n",
      "EPOCH: 17519 LOSS: 40.98868449301416\n",
      "EPOCH: 17520 LOSS: 40.98868202705469\n",
      "EPOCH: 17521 LOSS: 40.98867956133699\n",
      "EPOCH: 17522 LOSS: 40.988677095860965\n",
      "EPOCH: 17523 LOSS: 40.988674630626626\n",
      "EPOCH: 17524 LOSS: 40.988672165633915\n",
      "EPOCH: 17525 LOSS: 40.98866970088281\n",
      "EPOCH: 17526 LOSS: 40.988667236373246\n",
      "EPOCH: 17527 LOSS: 40.988664772105224\n",
      "EPOCH: 17528 LOSS: 40.98866230807866\n",
      "EPOCH: 17529 LOSS: 40.988659844293565\n",
      "EPOCH: 17530 LOSS: 40.98865738074986\n",
      "EPOCH: 17531 LOSS: 40.98865491744753\n",
      "EPOCH: 17532 LOSS: 40.988652454386546\n",
      "EPOCH: 17533 LOSS: 40.98864999156686\n",
      "EPOCH: 17534 LOSS: 40.98864752898841\n",
      "EPOCH: 17535 LOSS: 40.9886450666512\n",
      "EPOCH: 17536 LOSS: 40.98864260455517\n",
      "EPOCH: 17537 LOSS: 40.98864014270028\n",
      "EPOCH: 17538 LOSS: 40.98863768108651\n",
      "EPOCH: 17539 LOSS: 40.98863521971379\n",
      "EPOCH: 17540 LOSS: 40.98863275858212\n",
      "EPOCH: 17541 LOSS: 40.98863029769143\n",
      "EPOCH: 17542 LOSS: 40.98862783704175\n",
      "EPOCH: 17543 LOSS: 40.98862537663295\n",
      "EPOCH: 17544 LOSS: 40.98862291646505\n",
      "EPOCH: 17545 LOSS: 40.98862045653798\n",
      "EPOCH: 17546 LOSS: 40.98861799685174\n",
      "EPOCH: 17547 LOSS: 40.98861553740627\n",
      "EPOCH: 17548 LOSS: 40.988613078201524\n",
      "EPOCH: 17549 LOSS: 40.988610619237505\n",
      "EPOCH: 17550 LOSS: 40.98860816051413\n",
      "EPOCH: 17551 LOSS: 40.98860570203138\n",
      "EPOCH: 17552 LOSS: 40.988603243789214\n",
      "EPOCH: 17553 LOSS: 40.98860078578761\n",
      "EPOCH: 17554 LOSS: 40.988598328026505\n",
      "EPOCH: 17555 LOSS: 40.988595870505875\n",
      "EPOCH: 17556 LOSS: 40.988593413225686\n",
      "EPOCH: 17557 LOSS: 40.98859095618592\n",
      "EPOCH: 17558 LOSS: 40.98858849938648\n",
      "EPOCH: 17559 LOSS: 40.98858604282741\n",
      "EPOCH: 17560 LOSS: 40.988583586508604\n",
      "EPOCH: 17561 LOSS: 40.98858113043005\n",
      "EPOCH: 17562 LOSS: 40.98857867459172\n",
      "EPOCH: 17563 LOSS: 40.98857621899357\n",
      "EPOCH: 17564 LOSS: 40.988573763635536\n",
      "EPOCH: 17565 LOSS: 40.988571308517635\n",
      "EPOCH: 17566 LOSS: 40.988568853639805\n",
      "EPOCH: 17567 LOSS: 40.98856639900197\n",
      "EPOCH: 17568 LOSS: 40.98856394460415\n",
      "EPOCH: 17569 LOSS: 40.98856149044629\n",
      "EPOCH: 17570 LOSS: 40.988559036528336\n",
      "EPOCH: 17571 LOSS: 40.98855658285027\n",
      "EPOCH: 17572 LOSS: 40.98855412941205\n",
      "EPOCH: 17573 LOSS: 40.98855167621363\n",
      "EPOCH: 17574 LOSS: 40.98854922325499\n",
      "EPOCH: 17575 LOSS: 40.988546770536075\n",
      "EPOCH: 17576 LOSS: 40.98854431805686\n",
      "EPOCH: 17577 LOSS: 40.9885418658173\n",
      "EPOCH: 17578 LOSS: 40.98853941381736\n",
      "EPOCH: 17579 LOSS: 40.98853696205701\n",
      "EPOCH: 17580 LOSS: 40.98853451053621\n",
      "EPOCH: 17581 LOSS: 40.98853205925491\n",
      "EPOCH: 17582 LOSS: 40.9885296082131\n",
      "EPOCH: 17583 LOSS: 40.9885271574107\n",
      "EPOCH: 17584 LOSS: 40.98852470684771\n",
      "EPOCH: 17585 LOSS: 40.98852225652411\n",
      "EPOCH: 17586 LOSS: 40.988519806439804\n",
      "EPOCH: 17587 LOSS: 40.988517356594784\n",
      "EPOCH: 17588 LOSS: 40.98851490698904\n",
      "EPOCH: 17589 LOSS: 40.98851245762249\n",
      "EPOCH: 17590 LOSS: 40.988510008495126\n",
      "EPOCH: 17591 LOSS: 40.9885075596069\n",
      "EPOCH: 17592 LOSS: 40.988505110957774\n",
      "EPOCH: 17593 LOSS: 40.988502662547724\n",
      "EPOCH: 17594 LOSS: 40.9885002143767\n",
      "EPOCH: 17595 LOSS: 40.988497766444674\n",
      "EPOCH: 17596 LOSS: 40.98849531875159\n",
      "EPOCH: 17597 LOSS: 40.98849287129743\n",
      "EPOCH: 17598 LOSS: 40.98849042408216\n",
      "EPOCH: 17599 LOSS: 40.98848797710572\n",
      "EPOCH: 17600 LOSS: 40.988485530368095\n",
      "EPOCH: 17601 LOSS: 40.98848308386925\n",
      "EPOCH: 17602 LOSS: 40.988480637609115\n",
      "EPOCH: 17603 LOSS: 40.988478191587696\n",
      "EPOCH: 17604 LOSS: 40.988475745804934\n",
      "EPOCH: 17605 LOSS: 40.9884733002608\n",
      "EPOCH: 17606 LOSS: 40.98847085495524\n",
      "EPOCH: 17607 LOSS: 40.98846840988824\n",
      "EPOCH: 17608 LOSS: 40.98846596505975\n",
      "EPOCH: 17609 LOSS: 40.988463520469736\n",
      "EPOCH: 17610 LOSS: 40.988461076118156\n",
      "EPOCH: 17611 LOSS: 40.988458632005\n",
      "EPOCH: 17612 LOSS: 40.988456188130186\n",
      "EPOCH: 17613 LOSS: 40.988453744493704\n",
      "EPOCH: 17614 LOSS: 40.98845130109553\n",
      "EPOCH: 17615 LOSS: 40.98844885793559\n",
      "EPOCH: 17616 LOSS: 40.988446415013875\n",
      "EPOCH: 17617 LOSS: 40.98844397233034\n",
      "EPOCH: 17618 LOSS: 40.988441529884966\n",
      "EPOCH: 17619 LOSS: 40.98843908767768\n",
      "EPOCH: 17620 LOSS: 40.988436645708475\n",
      "EPOCH: 17621 LOSS: 40.9884342039773\n",
      "EPOCH: 17622 LOSS: 40.98843176248412\n",
      "EPOCH: 17623 LOSS: 40.98842932122891\n",
      "EPOCH: 17624 LOSS: 40.98842688021161\n",
      "EPOCH: 17625 LOSS: 40.9884244394322\n",
      "EPOCH: 17626 LOSS: 40.988421998890644\n",
      "EPOCH: 17627 LOSS: 40.98841955858691\n",
      "EPOCH: 17628 LOSS: 40.98841711852095\n",
      "EPOCH: 17629 LOSS: 40.98841467869273\n",
      "EPOCH: 17630 LOSS: 40.98841223910221\n",
      "EPOCH: 17631 LOSS: 40.98840979974936\n",
      "EPOCH: 17632 LOSS: 40.98840736063413\n",
      "EPOCH: 17633 LOSS: 40.9884049217565\n",
      "EPOCH: 17634 LOSS: 40.98840248311643\n",
      "EPOCH: 17635 LOSS: 40.98840004471387\n",
      "EPOCH: 17636 LOSS: 40.988397606548816\n",
      "EPOCH: 17637 LOSS: 40.988395168621174\n",
      "EPOCH: 17638 LOSS: 40.98839273093097\n",
      "EPOCH: 17639 LOSS: 40.988390293478105\n",
      "EPOCH: 17640 LOSS: 40.98838785626262\n",
      "EPOCH: 17641 LOSS: 40.98838541928441\n",
      "EPOCH: 17642 LOSS: 40.988382982543484\n",
      "EPOCH: 17643 LOSS: 40.988380546039764\n",
      "EPOCH: 17644 LOSS: 40.98837810977325\n",
      "EPOCH: 17645 LOSS: 40.988375673743874\n",
      "EPOCH: 17646 LOSS: 40.98837323795162\n",
      "EPOCH: 17647 LOSS: 40.98837080239645\n",
      "EPOCH: 17648 LOSS: 40.988368367078316\n",
      "EPOCH: 17649 LOSS: 40.988365931997194\n",
      "EPOCH: 17650 LOSS: 40.988363497153046\n",
      "EPOCH: 17651 LOSS: 40.988361062545835\n",
      "EPOCH: 17652 LOSS: 40.98835862817552\n",
      "EPOCH: 17653 LOSS: 40.98835619404205\n",
      "EPOCH: 17654 LOSS: 40.98835376014542\n",
      "EPOCH: 17655 LOSS: 40.98835132648558\n",
      "EPOCH: 17656 LOSS: 40.98834889306248\n",
      "EPOCH: 17657 LOSS: 40.98834645987609\n",
      "EPOCH: 17658 LOSS: 40.9883440269264\n",
      "EPOCH: 17659 LOSS: 40.98834159421334\n",
      "EPOCH: 17660 LOSS: 40.988339161736874\n",
      "EPOCH: 17661 LOSS: 40.98833672949698\n",
      "EPOCH: 17662 LOSS: 40.988334297493644\n",
      "EPOCH: 17663 LOSS: 40.98833186572678\n",
      "EPOCH: 17664 LOSS: 40.98832943419638\n",
      "EPOCH: 17665 LOSS: 40.98832700290239\n",
      "EPOCH: 17666 LOSS: 40.98832457184481\n",
      "EPOCH: 17667 LOSS: 40.98832214102356\n",
      "EPOCH: 17668 LOSS: 40.98831971043863\n",
      "EPOCH: 17669 LOSS: 40.98831728008997\n",
      "EPOCH: 17670 LOSS: 40.98831484997757\n",
      "EPOCH: 17671 LOSS: 40.98831242010136\n",
      "EPOCH: 17672 LOSS: 40.98830999046132\n",
      "EPOCH: 17673 LOSS: 40.988307561057404\n",
      "EPOCH: 17674 LOSS: 40.98830513188959\n",
      "EPOCH: 17675 LOSS: 40.98830270295782\n",
      "EPOCH: 17676 LOSS: 40.98830027426207\n",
      "EPOCH: 17677 LOSS: 40.988297845802336\n",
      "EPOCH: 17678 LOSS: 40.988295417578534\n",
      "EPOCH: 17679 LOSS: 40.98829298959065\n",
      "EPOCH: 17680 LOSS: 40.988290561838625\n",
      "EPOCH: 17681 LOSS: 40.988288134322445\n",
      "EPOCH: 17682 LOSS: 40.98828570704208\n",
      "EPOCH: 17683 LOSS: 40.988283279997475\n",
      "EPOCH: 17684 LOSS: 40.98828085318861\n",
      "EPOCH: 17685 LOSS: 40.98827842661543\n",
      "EPOCH: 17686 LOSS: 40.9882760002779\n",
      "EPOCH: 17687 LOSS: 40.988273574176006\n",
      "EPOCH: 17688 LOSS: 40.98827114830968\n",
      "EPOCH: 17689 LOSS: 40.98826872267891\n",
      "EPOCH: 17690 LOSS: 40.988266297283666\n",
      "EPOCH: 17691 LOSS: 40.988263872123895\n",
      "EPOCH: 17692 LOSS: 40.988261447199534\n",
      "EPOCH: 17693 LOSS: 40.98825902251061\n",
      "EPOCH: 17694 LOSS: 40.98825659805705\n",
      "EPOCH: 17695 LOSS: 40.98825417383881\n",
      "EPOCH: 17696 LOSS: 40.98825174985586\n",
      "EPOCH: 17697 LOSS: 40.98824932610819\n",
      "EPOCH: 17698 LOSS: 40.98824690259572\n",
      "EPOCH: 17699 LOSS: 40.988244479318446\n",
      "EPOCH: 17700 LOSS: 40.988242056276334\n",
      "EPOCH: 17701 LOSS: 40.988239633469306\n",
      "EPOCH: 17702 LOSS: 40.98823721089738\n",
      "EPOCH: 17703 LOSS: 40.98823478856048\n",
      "EPOCH: 17704 LOSS: 40.98823236645859\n",
      "EPOCH: 17705 LOSS: 40.98822994459166\n",
      "EPOCH: 17706 LOSS: 40.988227522959676\n",
      "EPOCH: 17707 LOSS: 40.98822510156259\n",
      "EPOCH: 17708 LOSS: 40.98822268040035\n",
      "EPOCH: 17709 LOSS: 40.98822025947294\n",
      "EPOCH: 17710 LOSS: 40.98821783878033\n",
      "EPOCH: 17711 LOSS: 40.988215418322426\n",
      "EPOCH: 17712 LOSS: 40.98821299809929\n",
      "EPOCH: 17713 LOSS: 40.98821057811081\n",
      "EPOCH: 17714 LOSS: 40.98820815835698\n",
      "EPOCH: 17715 LOSS: 40.98820573883775\n",
      "EPOCH: 17716 LOSS: 40.988203319553094\n",
      "EPOCH: 17717 LOSS: 40.988200900502974\n",
      "EPOCH: 17718 LOSS: 40.988198481687334\n",
      "EPOCH: 17719 LOSS: 40.98819606310617\n",
      "EPOCH: 17720 LOSS: 40.98819364475945\n",
      "EPOCH: 17721 LOSS: 40.98819122664709\n",
      "EPOCH: 17722 LOSS: 40.988188808769095\n",
      "EPOCH: 17723 LOSS: 40.98818639112541\n",
      "EPOCH: 17724 LOSS: 40.98818397371602\n",
      "EPOCH: 17725 LOSS: 40.988181556540866\n",
      "EPOCH: 17726 LOSS: 40.98817913959992\n",
      "EPOCH: 17727 LOSS: 40.988176722893144\n",
      "EPOCH: 17728 LOSS: 40.98817430642052\n",
      "EPOCH: 17729 LOSS: 40.988171890182\n",
      "EPOCH: 17730 LOSS: 40.988169474177525\n",
      "EPOCH: 17731 LOSS: 40.98816705840708\n",
      "EPOCH: 17732 LOSS: 40.98816464287064\n",
      "EPOCH: 17733 LOSS: 40.98816222756815\n",
      "EPOCH: 17734 LOSS: 40.988159812499596\n",
      "EPOCH: 17735 LOSS: 40.9881573976649\n",
      "EPOCH: 17736 LOSS: 40.98815498306407\n",
      "EPOCH: 17737 LOSS: 40.98815256869706\n",
      "EPOCH: 17738 LOSS: 40.98815015456381\n",
      "EPOCH: 17739 LOSS: 40.98814774066429\n",
      "EPOCH: 17740 LOSS: 40.988145326998485\n",
      "EPOCH: 17741 LOSS: 40.98814291356636\n",
      "EPOCH: 17742 LOSS: 40.98814050036787\n",
      "EPOCH: 17743 LOSS: 40.98813808740297\n",
      "EPOCH: 17744 LOSS: 40.988135674671625\n",
      "EPOCH: 17745 LOSS: 40.988133262173804\n",
      "EPOCH: 17746 LOSS: 40.98813084990948\n",
      "EPOCH: 17747 LOSS: 40.988128437878615\n",
      "EPOCH: 17748 LOSS: 40.98812602608114\n",
      "EPOCH: 17749 LOSS: 40.988123614517065\n",
      "EPOCH: 17750 LOSS: 40.98812120318634\n",
      "EPOCH: 17751 LOSS: 40.988118792088926\n",
      "EPOCH: 17752 LOSS: 40.988116381224756\n",
      "EPOCH: 17753 LOSS: 40.988113970593844\n",
      "EPOCH: 17754 LOSS: 40.98811156019614\n",
      "EPOCH: 17755 LOSS: 40.9881091500316\n",
      "EPOCH: 17756 LOSS: 40.98810674010017\n",
      "EPOCH: 17757 LOSS: 40.988104330401846\n",
      "EPOCH: 17758 LOSS: 40.98810192093657\n",
      "EPOCH: 17759 LOSS: 40.98809951170434\n",
      "EPOCH: 17760 LOSS: 40.98809710270508\n",
      "EPOCH: 17761 LOSS: 40.98809469393878\n",
      "EPOCH: 17762 LOSS: 40.98809228540537\n",
      "EPOCH: 17763 LOSS: 40.98808987710487\n",
      "EPOCH: 17764 LOSS: 40.9880874690372\n",
      "EPOCH: 17765 LOSS: 40.98808506120233\n",
      "EPOCH: 17766 LOSS: 40.98808265360022\n",
      "EPOCH: 17767 LOSS: 40.988080246230865\n",
      "EPOCH: 17768 LOSS: 40.9880778390942\n",
      "EPOCH: 17769 LOSS: 40.9880754321902\n",
      "EPOCH: 17770 LOSS: 40.98807302551884\n",
      "EPOCH: 17771 LOSS: 40.988070619080055\n",
      "EPOCH: 17772 LOSS: 40.98806821287384\n",
      "EPOCH: 17773 LOSS: 40.98806580690015\n",
      "EPOCH: 17774 LOSS: 40.988063401158925\n",
      "EPOCH: 17775 LOSS: 40.98806099565015\n",
      "EPOCH: 17776 LOSS: 40.988058590373804\n",
      "EPOCH: 17777 LOSS: 40.98805618532983\n",
      "EPOCH: 17778 LOSS: 40.98805378051817\n",
      "EPOCH: 17779 LOSS: 40.98805137593885\n",
      "EPOCH: 17780 LOSS: 40.98804897159178\n",
      "EPOCH: 17781 LOSS: 40.988046567476964\n",
      "EPOCH: 17782 LOSS: 40.988044163594324\n",
      "EPOCH: 17783 LOSS: 40.98804175994386\n",
      "EPOCH: 17784 LOSS: 40.98803935652552\n",
      "EPOCH: 17785 LOSS: 40.98803695333929\n",
      "EPOCH: 17786 LOSS: 40.98803455038509\n",
      "EPOCH: 17787 LOSS: 40.98803214766291\n",
      "EPOCH: 17788 LOSS: 40.98802974517271\n",
      "EPOCH: 17789 LOSS: 40.988027342914485\n",
      "EPOCH: 17790 LOSS: 40.98802494088816\n",
      "EPOCH: 17791 LOSS: 40.98802253909371\n",
      "EPOCH: 17792 LOSS: 40.988020137531116\n",
      "EPOCH: 17793 LOSS: 40.98801773620029\n",
      "EPOCH: 17794 LOSS: 40.98801533510126\n",
      "EPOCH: 17795 LOSS: 40.98801293423397\n",
      "EPOCH: 17796 LOSS: 40.98801053359837\n",
      "EPOCH: 17797 LOSS: 40.98800813319443\n",
      "EPOCH: 17798 LOSS: 40.98800573302211\n",
      "EPOCH: 17799 LOSS: 40.988003333081394\n",
      "EPOCH: 17800 LOSS: 40.98800093337225\n",
      "EPOCH: 17801 LOSS: 40.98799853389461\n",
      "EPOCH: 17802 LOSS: 40.98799613464845\n",
      "EPOCH: 17803 LOSS: 40.98799373563375\n",
      "EPOCH: 17804 LOSS: 40.98799133685047\n",
      "EPOCH: 17805 LOSS: 40.987988938298564\n",
      "EPOCH: 17806 LOSS: 40.987986539977996\n",
      "EPOCH: 17807 LOSS: 40.987984141888724\n",
      "EPOCH: 17808 LOSS: 40.98798174403073\n",
      "EPOCH: 17809 LOSS: 40.987979346403975\n",
      "EPOCH: 17810 LOSS: 40.98797694900843\n",
      "EPOCH: 17811 LOSS: 40.98797455184405\n",
      "EPOCH: 17812 LOSS: 40.98797215491077\n",
      "EPOCH: 17813 LOSS: 40.98796975820862\n",
      "EPOCH: 17814 LOSS: 40.98796736173752\n",
      "EPOCH: 17815 LOSS: 40.98796496549743\n",
      "EPOCH: 17816 LOSS: 40.987962569488346\n",
      "EPOCH: 17817 LOSS: 40.98796017371019\n",
      "EPOCH: 17818 LOSS: 40.98795777816297\n",
      "EPOCH: 17819 LOSS: 40.98795538284662\n",
      "EPOCH: 17820 LOSS: 40.98795298776111\n",
      "EPOCH: 17821 LOSS: 40.98795059290643\n",
      "EPOCH: 17822 LOSS: 40.98794819828251\n",
      "EPOCH: 17823 LOSS: 40.98794580388934\n",
      "EPOCH: 17824 LOSS: 40.98794340972686\n",
      "EPOCH: 17825 LOSS: 40.98794101579506\n",
      "EPOCH: 17826 LOSS: 40.98793862209389\n",
      "EPOCH: 17827 LOSS: 40.98793622862331\n",
      "EPOCH: 17828 LOSS: 40.98793383538331\n",
      "EPOCH: 17829 LOSS: 40.98793144237381\n",
      "EPOCH: 17830 LOSS: 40.987929049594825\n",
      "EPOCH: 17831 LOSS: 40.98792665704628\n",
      "EPOCH: 17832 LOSS: 40.987924264728164\n",
      "EPOCH: 17833 LOSS: 40.98792187264043\n",
      "EPOCH: 17834 LOSS: 40.987919480783034\n",
      "EPOCH: 17835 LOSS: 40.98791708915598\n",
      "EPOCH: 17836 LOSS: 40.98791469775917\n",
      "EPOCH: 17837 LOSS: 40.98791230659262\n",
      "EPOCH: 17838 LOSS: 40.98790991565629\n",
      "EPOCH: 17839 LOSS: 40.98790752495011\n",
      "EPOCH: 17840 LOSS: 40.98790513447408\n",
      "EPOCH: 17841 LOSS: 40.98790274422815\n",
      "EPOCH: 17842 LOSS: 40.987900354212286\n",
      "EPOCH: 17843 LOSS: 40.98789796442646\n",
      "EPOCH: 17844 LOSS: 40.98789557487062\n",
      "EPOCH: 17845 LOSS: 40.98789318554474\n",
      "EPOCH: 17846 LOSS: 40.987890796448795\n",
      "EPOCH: 17847 LOSS: 40.98788840758273\n",
      "EPOCH: 17848 LOSS: 40.98788601894652\n",
      "EPOCH: 17849 LOSS: 40.98788363054014\n",
      "EPOCH: 17850 LOSS: 40.98788124236353\n",
      "EPOCH: 17851 LOSS: 40.98787885441667\n",
      "EPOCH: 17852 LOSS: 40.98787646669955\n",
      "EPOCH: 17853 LOSS: 40.98787407921206\n",
      "EPOCH: 17854 LOSS: 40.98787169195425\n",
      "EPOCH: 17855 LOSS: 40.98786930492605\n",
      "EPOCH: 17856 LOSS: 40.9878669181274\n",
      "EPOCH: 17857 LOSS: 40.98786453155829\n",
      "EPOCH: 17858 LOSS: 40.98786214521869\n",
      "EPOCH: 17859 LOSS: 40.987859759108545\n",
      "EPOCH: 17860 LOSS: 40.98785737322785\n",
      "EPOCH: 17861 LOSS: 40.98785498757653\n",
      "EPOCH: 17862 LOSS: 40.9878526021546\n",
      "EPOCH: 17863 LOSS: 40.98785021696197\n",
      "EPOCH: 17864 LOSS: 40.98784783199864\n",
      "EPOCH: 17865 LOSS: 40.987845447264554\n",
      "EPOCH: 17866 LOSS: 40.98784306275971\n",
      "EPOCH: 17867 LOSS: 40.98784067848403\n",
      "EPOCH: 17868 LOSS: 40.98783829443751\n",
      "EPOCH: 17869 LOSS: 40.98783591062009\n",
      "EPOCH: 17870 LOSS: 40.98783352703178\n",
      "EPOCH: 17871 LOSS: 40.987831143672494\n",
      "EPOCH: 17872 LOSS: 40.98782876054222\n",
      "EPOCH: 17873 LOSS: 40.98782637764093\n",
      "EPOCH: 17874 LOSS: 40.987823994968565\n",
      "EPOCH: 17875 LOSS: 40.9878216125251\n",
      "EPOCH: 17876 LOSS: 40.9878192303105\n",
      "EPOCH: 17877 LOSS: 40.98781684832474\n",
      "EPOCH: 17878 LOSS: 40.987814466567784\n",
      "EPOCH: 17879 LOSS: 40.98781208503958\n",
      "EPOCH: 17880 LOSS: 40.98780970374012\n",
      "EPOCH: 17881 LOSS: 40.98780732266935\n",
      "EPOCH: 17882 LOSS: 40.98780494182723\n",
      "EPOCH: 17883 LOSS: 40.987802561213734\n",
      "EPOCH: 17884 LOSS: 40.98780018082881\n",
      "EPOCH: 17885 LOSS: 40.98779780067247\n",
      "EPOCH: 17886 LOSS: 40.98779542074464\n",
      "EPOCH: 17887 LOSS: 40.98779304104528\n",
      "EPOCH: 17888 LOSS: 40.98779066157438\n",
      "EPOCH: 17889 LOSS: 40.98778828233187\n",
      "EPOCH: 17890 LOSS: 40.98778590331776\n",
      "EPOCH: 17891 LOSS: 40.987783524532\n",
      "EPOCH: 17892 LOSS: 40.98778114597452\n",
      "EPOCH: 17893 LOSS: 40.987778767645324\n",
      "EPOCH: 17894 LOSS: 40.98777638954437\n",
      "EPOCH: 17895 LOSS: 40.987774011671604\n",
      "EPOCH: 17896 LOSS: 40.98777163402703\n",
      "EPOCH: 17897 LOSS: 40.987769256610584\n",
      "EPOCH: 17898 LOSS: 40.987766879422196\n",
      "EPOCH: 17899 LOSS: 40.98776450246192\n",
      "EPOCH: 17900 LOSS: 40.987762125729645\n",
      "EPOCH: 17901 LOSS: 40.98775974922536\n",
      "EPOCH: 17902 LOSS: 40.987757372949034\n",
      "EPOCH: 17903 LOSS: 40.98775499690064\n",
      "EPOCH: 17904 LOSS: 40.98775262108012\n",
      "EPOCH: 17905 LOSS: 40.987750245487476\n",
      "EPOCH: 17906 LOSS: 40.98774787012263\n",
      "EPOCH: 17907 LOSS: 40.98774549498557\n",
      "EPOCH: 17908 LOSS: 40.98774312007627\n",
      "EPOCH: 17909 LOSS: 40.98774074539466\n",
      "EPOCH: 17910 LOSS: 40.98773837094075\n",
      "EPOCH: 17911 LOSS: 40.98773599671447\n",
      "EPOCH: 17912 LOSS: 40.9877336227158\n",
      "EPOCH: 17913 LOSS: 40.98773124894469\n",
      "EPOCH: 17914 LOSS: 40.987728875401146\n",
      "EPOCH: 17915 LOSS: 40.987726502085074\n",
      "EPOCH: 17916 LOSS: 40.987724128996504\n",
      "EPOCH: 17917 LOSS: 40.98772175613534\n",
      "EPOCH: 17918 LOSS: 40.98771938350159\n",
      "EPOCH: 17919 LOSS: 40.9877170110952\n",
      "EPOCH: 17920 LOSS: 40.98771463891613\n",
      "EPOCH: 17921 LOSS: 40.987712266964365\n",
      "EPOCH: 17922 LOSS: 40.98770989523985\n",
      "EPOCH: 17923 LOSS: 40.98770752374257\n",
      "EPOCH: 17924 LOSS: 40.98770515247247\n",
      "EPOCH: 17925 LOSS: 40.98770278142953\n",
      "EPOCH: 17926 LOSS: 40.98770041061371\n",
      "EPOCH: 17927 LOSS: 40.98769804002498\n",
      "EPOCH: 17928 LOSS: 40.98769566966329\n",
      "EPOCH: 17929 LOSS: 40.98769329952863\n",
      "EPOCH: 17930 LOSS: 40.98769092962094\n",
      "EPOCH: 17931 LOSS: 40.98768855994018\n",
      "EPOCH: 17932 LOSS: 40.98768619048635\n",
      "EPOCH: 17933 LOSS: 40.987683821259395\n",
      "EPOCH: 17934 LOSS: 40.987681452259295\n",
      "EPOCH: 17935 LOSS: 40.987679083485986\n",
      "EPOCH: 17936 LOSS: 40.98767671493945\n",
      "EPOCH: 17937 LOSS: 40.98767434661964\n",
      "EPOCH: 17938 LOSS: 40.98767197852657\n",
      "EPOCH: 17939 LOSS: 40.98766961066012\n",
      "EPOCH: 17940 LOSS: 40.98766724302034\n",
      "EPOCH: 17941 LOSS: 40.98766487560714\n",
      "EPOCH: 17942 LOSS: 40.98766250842051\n",
      "EPOCH: 17943 LOSS: 40.98766014146041\n",
      "EPOCH: 17944 LOSS: 40.9876577747268\n",
      "EPOCH: 17945 LOSS: 40.98765540821964\n",
      "EPOCH: 17946 LOSS: 40.98765304193891\n",
      "EPOCH: 17947 LOSS: 40.9876506758846\n",
      "EPOCH: 17948 LOSS: 40.98764831005661\n",
      "EPOCH: 17949 LOSS: 40.987645944454954\n",
      "EPOCH: 17950 LOSS: 40.98764357907959\n",
      "EPOCH: 17951 LOSS: 40.98764121393047\n",
      "EPOCH: 17952 LOSS: 40.98763884900757\n",
      "EPOCH: 17953 LOSS: 40.987636484310855\n",
      "EPOCH: 17954 LOSS: 40.98763411984027\n",
      "EPOCH: 17955 LOSS: 40.987631755595814\n",
      "EPOCH: 17956 LOSS: 40.98762939157744\n",
      "EPOCH: 17957 LOSS: 40.98762702778509\n",
      "EPOCH: 17958 LOSS: 40.98762466421877\n",
      "EPOCH: 17959 LOSS: 40.98762230087841\n",
      "EPOCH: 17960 LOSS: 40.98761993776401\n",
      "EPOCH: 17961 LOSS: 40.987617574875486\n",
      "EPOCH: 17962 LOSS: 40.987615212212845\n",
      "EPOCH: 17963 LOSS: 40.98761284977605\n",
      "EPOCH: 17964 LOSS: 40.98761048756505\n",
      "EPOCH: 17965 LOSS: 40.987608125579825\n",
      "EPOCH: 17966 LOSS: 40.98760576382031\n",
      "EPOCH: 17967 LOSS: 40.9876034022865\n",
      "EPOCH: 17968 LOSS: 40.987601040978376\n",
      "EPOCH: 17969 LOSS: 40.98759867989586\n",
      "EPOCH: 17970 LOSS: 40.98759631903893\n",
      "EPOCH: 17971 LOSS: 40.98759395840758\n",
      "EPOCH: 17972 LOSS: 40.98759159800176\n",
      "EPOCH: 17973 LOSS: 40.98758923782141\n",
      "EPOCH: 17974 LOSS: 40.98758687786651\n",
      "EPOCH: 17975 LOSS: 40.987584518137055\n",
      "EPOCH: 17976 LOSS: 40.98758215863298\n",
      "EPOCH: 17977 LOSS: 40.98757979935426\n",
      "EPOCH: 17978 LOSS: 40.98757744030085\n",
      "EPOCH: 17979 LOSS: 40.98757508147273\n",
      "EPOCH: 17980 LOSS: 40.98757272286986\n",
      "EPOCH: 17981 LOSS: 40.98757036449219\n",
      "EPOCH: 17982 LOSS: 40.9875680063397\n",
      "EPOCH: 17983 LOSS: 40.98756564841238\n",
      "EPOCH: 17984 LOSS: 40.98756329071014\n",
      "EPOCH: 17985 LOSS: 40.987560933233\n",
      "EPOCH: 17986 LOSS: 40.9875585759809\n",
      "EPOCH: 17987 LOSS: 40.98755621895381\n",
      "EPOCH: 17988 LOSS: 40.98755386215168\n",
      "EPOCH: 17989 LOSS: 40.9875515055745\n",
      "EPOCH: 17990 LOSS: 40.98754914922222\n",
      "EPOCH: 17991 LOSS: 40.987546793094815\n",
      "EPOCH: 17992 LOSS: 40.987544437192234\n",
      "EPOCH: 17993 LOSS: 40.98754208151447\n",
      "EPOCH: 17994 LOSS: 40.987539726061456\n",
      "EPOCH: 17995 LOSS: 40.987537370833195\n",
      "EPOCH: 17996 LOSS: 40.98753501582962\n",
      "EPOCH: 17997 LOSS: 40.98753266105069\n",
      "EPOCH: 17998 LOSS: 40.987530306496424\n",
      "EPOCH: 17999 LOSS: 40.98752795216673\n",
      "EPOCH: 18000 LOSS: 40.98752559806161\n",
      "EPOCH: 18001 LOSS: 40.98752324418102\n",
      "EPOCH: 18002 LOSS: 40.98752089052492\n",
      "EPOCH: 18003 LOSS: 40.987518537093266\n",
      "EPOCH: 18004 LOSS: 40.987516183886044\n",
      "EPOCH: 18005 LOSS: 40.9875138309032\n",
      "EPOCH: 18006 LOSS: 40.987511478144725\n",
      "EPOCH: 18007 LOSS: 40.98750912561056\n",
      "EPOCH: 18008 LOSS: 40.98750677330069\n",
      "EPOCH: 18009 LOSS: 40.987504421215064\n",
      "EPOCH: 18010 LOSS: 40.98750206935366\n",
      "EPOCH: 18011 LOSS: 40.98749971771643\n",
      "EPOCH: 18012 LOSS: 40.98749736630336\n",
      "EPOCH: 18013 LOSS: 40.987495015114405\n",
      "EPOCH: 18014 LOSS: 40.987492664149514\n",
      "EPOCH: 18015 LOSS: 40.987490313408685\n",
      "EPOCH: 18016 LOSS: 40.987487962891876\n",
      "EPOCH: 18017 LOSS: 40.98748561259902\n",
      "EPOCH: 18018 LOSS: 40.98748326253013\n",
      "EPOCH: 18019 LOSS: 40.98748091268515\n",
      "EPOCH: 18020 LOSS: 40.987478563064016\n",
      "EPOCH: 18021 LOSS: 40.98747621366674\n",
      "EPOCH: 18022 LOSS: 40.98747386449328\n",
      "EPOCH: 18023 LOSS: 40.98747151554359\n",
      "EPOCH: 18024 LOSS: 40.987469166817625\n",
      "EPOCH: 18025 LOSS: 40.98746681831537\n",
      "EPOCH: 18026 LOSS: 40.987464470036784\n",
      "EPOCH: 18027 LOSS: 40.987462121981835\n",
      "EPOCH: 18028 LOSS: 40.98745977415048\n",
      "EPOCH: 18029 LOSS: 40.98745742654271\n",
      "EPOCH: 18030 LOSS: 40.98745507915845\n",
      "EPOCH: 18031 LOSS: 40.98745273199769\n",
      "EPOCH: 18032 LOSS: 40.98745038506043\n",
      "EPOCH: 18033 LOSS: 40.98744803834656\n",
      "EPOCH: 18034 LOSS: 40.98744569185612\n",
      "EPOCH: 18035 LOSS: 40.987443345589014\n",
      "EPOCH: 18036 LOSS: 40.987440999545235\n",
      "EPOCH: 18037 LOSS: 40.98743865372476\n",
      "EPOCH: 18038 LOSS: 40.98743630812754\n",
      "EPOCH: 18039 LOSS: 40.98743396275356\n",
      "EPOCH: 18040 LOSS: 40.98743161760276\n",
      "EPOCH: 18041 LOSS: 40.987429272675115\n",
      "EPOCH: 18042 LOSS: 40.987426927970596\n",
      "EPOCH: 18043 LOSS: 40.98742458348917\n",
      "EPOCH: 18044 LOSS: 40.98742223923079\n",
      "EPOCH: 18045 LOSS: 40.98741989519545\n",
      "EPOCH: 18046 LOSS: 40.98741755138308\n",
      "EPOCH: 18047 LOSS: 40.987415207793674\n",
      "EPOCH: 18048 LOSS: 40.98741286442717\n",
      "EPOCH: 18049 LOSS: 40.987410521283564\n",
      "EPOCH: 18050 LOSS: 40.987408178362806\n",
      "EPOCH: 18051 LOSS: 40.98740583566487\n",
      "EPOCH: 18052 LOSS: 40.98740349318971\n",
      "EPOCH: 18053 LOSS: 40.987401150937295\n",
      "EPOCH: 18054 LOSS: 40.9873988089076\n",
      "EPOCH: 18055 LOSS: 40.98739646710058\n",
      "EPOCH: 18056 LOSS: 40.98739412551622\n",
      "EPOCH: 18057 LOSS: 40.987391784154454\n",
      "EPOCH: 18058 LOSS: 40.98738944301529\n",
      "EPOCH: 18059 LOSS: 40.987387102098644\n",
      "EPOCH: 18060 LOSS: 40.98738476140452\n",
      "EPOCH: 18061 LOSS: 40.987382420932875\n",
      "EPOCH: 18062 LOSS: 40.98738008068368\n",
      "EPOCH: 18063 LOSS: 40.98737774065687\n",
      "EPOCH: 18064 LOSS: 40.98737540085246\n",
      "EPOCH: 18065 LOSS: 40.98737306127038\n",
      "EPOCH: 18066 LOSS: 40.987370721910594\n",
      "EPOCH: 18067 LOSS: 40.9873683827731\n",
      "EPOCH: 18068 LOSS: 40.98736604385784\n",
      "EPOCH: 18069 LOSS: 40.987363705164775\n",
      "EPOCH: 18070 LOSS: 40.9873613666939\n",
      "EPOCH: 18071 LOSS: 40.98735902844514\n",
      "EPOCH: 18072 LOSS: 40.987356690418494\n",
      "EPOCH: 18073 LOSS: 40.98735435261391\n",
      "EPOCH: 18074 LOSS: 40.98735201503138\n",
      "EPOCH: 18075 LOSS: 40.987349677670835\n",
      "EPOCH: 18076 LOSS: 40.98734734053226\n",
      "EPOCH: 18077 LOSS: 40.98734500361563\n",
      "EPOCH: 18078 LOSS: 40.98734266692089\n",
      "EPOCH: 18079 LOSS: 40.987340330448006\n",
      "EPOCH: 18080 LOSS: 40.98733799419696\n",
      "EPOCH: 18081 LOSS: 40.98733565816771\n",
      "EPOCH: 18082 LOSS: 40.98733332236024\n",
      "EPOCH: 18083 LOSS: 40.98733098677448\n",
      "EPOCH: 18084 LOSS: 40.98732865141043\n",
      "EPOCH: 18085 LOSS: 40.98732631626805\n",
      "EPOCH: 18086 LOSS: 40.9873239813473\n",
      "EPOCH: 18087 LOSS: 40.98732164664812\n",
      "EPOCH: 18088 LOSS: 40.987319312170506\n",
      "EPOCH: 18089 LOSS: 40.98731697791444\n",
      "EPOCH: 18090 LOSS: 40.987314643879856\n",
      "EPOCH: 18091 LOSS: 40.98731231006673\n",
      "EPOCH: 18092 LOSS: 40.98730997647503\n",
      "EPOCH: 18093 LOSS: 40.98730764310472\n",
      "EPOCH: 18094 LOSS: 40.98730530995577\n",
      "EPOCH: 18095 LOSS: 40.987302977028136\n",
      "EPOCH: 18096 LOSS: 40.98730064432182\n",
      "EPOCH: 18097 LOSS: 40.987298311836746\n",
      "EPOCH: 18098 LOSS: 40.98729597957289\n",
      "EPOCH: 18099 LOSS: 40.98729364753023\n",
      "EPOCH: 18100 LOSS: 40.98729131570872\n",
      "EPOCH: 18101 LOSS: 40.98728898410833\n",
      "EPOCH: 18102 LOSS: 40.987286652729054\n",
      "EPOCH: 18103 LOSS: 40.987284321570804\n",
      "EPOCH: 18104 LOSS: 40.98728199063358\n",
      "EPOCH: 18105 LOSS: 40.98727965991734\n",
      "EPOCH: 18106 LOSS: 40.98727732942207\n",
      "EPOCH: 18107 LOSS: 40.9872749991477\n",
      "EPOCH: 18108 LOSS: 40.98727266909424\n",
      "EPOCH: 18109 LOSS: 40.987270339261606\n",
      "EPOCH: 18110 LOSS: 40.98726800964981\n",
      "EPOCH: 18111 LOSS: 40.9872656802588\n",
      "EPOCH: 18112 LOSS: 40.987263351088515\n",
      "EPOCH: 18113 LOSS: 40.98726102213897\n",
      "EPOCH: 18114 LOSS: 40.987258693410105\n",
      "EPOCH: 18115 LOSS: 40.987256364901896\n",
      "EPOCH: 18116 LOSS: 40.9872540366143\n",
      "EPOCH: 18117 LOSS: 40.98725170854728\n",
      "EPOCH: 18118 LOSS: 40.98724938070083\n",
      "EPOCH: 18119 LOSS: 40.98724705307486\n",
      "EPOCH: 18120 LOSS: 40.9872447256694\n",
      "EPOCH: 18121 LOSS: 40.98724239848438\n",
      "EPOCH: 18122 LOSS: 40.98724007151977\n",
      "EPOCH: 18123 LOSS: 40.987237744775555\n",
      "EPOCH: 18124 LOSS: 40.98723541825168\n",
      "EPOCH: 18125 LOSS: 40.98723309194811\n",
      "EPOCH: 18126 LOSS: 40.98723076586484\n",
      "EPOCH: 18127 LOSS: 40.9872284400018\n",
      "EPOCH: 18128 LOSS: 40.987226114358975\n",
      "EPOCH: 18129 LOSS: 40.98722378893635\n",
      "EPOCH: 18130 LOSS: 40.98722146373384\n",
      "EPOCH: 18131 LOSS: 40.98721913875147\n",
      "EPOCH: 18132 LOSS: 40.987216813989164\n",
      "EPOCH: 18133 LOSS: 40.98721448944691\n",
      "EPOCH: 18134 LOSS: 40.987212165124674\n",
      "EPOCH: 18135 LOSS: 40.987209841022405\n",
      "EPOCH: 18136 LOSS: 40.98720751714009\n",
      "EPOCH: 18137 LOSS: 40.987205193477664\n",
      "EPOCH: 18138 LOSS: 40.987202870035134\n",
      "EPOCH: 18139 LOSS: 40.98720054681246\n",
      "EPOCH: 18140 LOSS: 40.98719822380959\n",
      "EPOCH: 18141 LOSS: 40.98719590102648\n",
      "EPOCH: 18142 LOSS: 40.98719357846312\n",
      "EPOCH: 18143 LOSS: 40.98719125611946\n",
      "EPOCH: 18144 LOSS: 40.987188933995505\n",
      "EPOCH: 18145 LOSS: 40.987186612091186\n",
      "EPOCH: 18146 LOSS: 40.987184290406475\n",
      "EPOCH: 18147 LOSS: 40.98718196894134\n",
      "EPOCH: 18148 LOSS: 40.987179647695726\n",
      "EPOCH: 18149 LOSS: 40.98717732666964\n",
      "EPOCH: 18150 LOSS: 40.98717500586305\n",
      "EPOCH: 18151 LOSS: 40.98717268527586\n",
      "EPOCH: 18152 LOSS: 40.987170364908124\n",
      "EPOCH: 18153 LOSS: 40.98716804475973\n",
      "EPOCH: 18154 LOSS: 40.9871657248307\n",
      "EPOCH: 18155 LOSS: 40.98716340512097\n",
      "EPOCH: 18156 LOSS: 40.98716108563052\n",
      "EPOCH: 18157 LOSS: 40.9871587663593\n",
      "EPOCH: 18158 LOSS: 40.9871564473073\n",
      "EPOCH: 18159 LOSS: 40.987154128474465\n",
      "EPOCH: 18160 LOSS: 40.98715180986079\n",
      "EPOCH: 18161 LOSS: 40.9871494914662\n",
      "EPOCH: 18162 LOSS: 40.98714717329071\n",
      "EPOCH: 18163 LOSS: 40.98714485533425\n",
      "EPOCH: 18164 LOSS: 40.987142537596796\n",
      "EPOCH: 18165 LOSS: 40.9871402200783\n",
      "EPOCH: 18166 LOSS: 40.98713790277878\n",
      "EPOCH: 18167 LOSS: 40.98713558569815\n",
      "EPOCH: 18168 LOSS: 40.9871332688364\n",
      "EPOCH: 18169 LOSS: 40.987130952193496\n",
      "EPOCH: 18170 LOSS: 40.98712863576939\n",
      "EPOCH: 18171 LOSS: 40.98712631956408\n",
      "EPOCH: 18172 LOSS: 40.98712400357748\n",
      "EPOCH: 18173 LOSS: 40.987121687809605\n",
      "EPOCH: 18174 LOSS: 40.987119372260395\n",
      "EPOCH: 18175 LOSS: 40.98711705692985\n",
      "EPOCH: 18176 LOSS: 40.9871147418179\n",
      "EPOCH: 18177 LOSS: 40.98711242692451\n",
      "EPOCH: 18178 LOSS: 40.987110112249695\n",
      "EPOCH: 18179 LOSS: 40.98710779779337\n",
      "EPOCH: 18180 LOSS: 40.9871054835555\n",
      "EPOCH: 18181 LOSS: 40.98710316953611\n",
      "EPOCH: 18182 LOSS: 40.98710085573511\n",
      "EPOCH: 18183 LOSS: 40.98709854215248\n",
      "EPOCH: 18184 LOSS: 40.987096228788204\n",
      "EPOCH: 18185 LOSS: 40.98709391564224\n",
      "EPOCH: 18186 LOSS: 40.98709160271454\n",
      "EPOCH: 18187 LOSS: 40.9870892900051\n",
      "EPOCH: 18188 LOSS: 40.98708697751385\n",
      "EPOCH: 18189 LOSS: 40.98708466524079\n",
      "EPOCH: 18190 LOSS: 40.987082353185855\n",
      "EPOCH: 18191 LOSS: 40.98708004134906\n",
      "EPOCH: 18192 LOSS: 40.98707772973033\n",
      "EPOCH: 18193 LOSS: 40.98707541832963\n",
      "EPOCH: 18194 LOSS: 40.98707310714694\n",
      "EPOCH: 18195 LOSS: 40.98707079618224\n",
      "EPOCH: 18196 LOSS: 40.987068485435486\n",
      "EPOCH: 18197 LOSS: 40.98706617490663\n",
      "EPOCH: 18198 LOSS: 40.98706386459566\n",
      "EPOCH: 18199 LOSS: 40.98706155450253\n",
      "EPOCH: 18200 LOSS: 40.98705924462722\n",
      "EPOCH: 18201 LOSS: 40.98705693496969\n",
      "EPOCH: 18202 LOSS: 40.987054625529886\n",
      "EPOCH: 18203 LOSS: 40.987052316307825\n",
      "EPOCH: 18204 LOSS: 40.98705000730341\n",
      "EPOCH: 18205 LOSS: 40.987047698516655\n",
      "EPOCH: 18206 LOSS: 40.98704538994751\n",
      "EPOCH: 18207 LOSS: 40.98704308159596\n",
      "EPOCH: 18208 LOSS: 40.987040773461935\n",
      "EPOCH: 18209 LOSS: 40.98703846554544\n",
      "EPOCH: 18210 LOSS: 40.987036157846404\n",
      "EPOCH: 18211 LOSS: 40.987033850364824\n",
      "EPOCH: 18212 LOSS: 40.987031543100656\n",
      "EPOCH: 18213 LOSS: 40.98702923605389\n",
      "EPOCH: 18214 LOSS: 40.987026929224456\n",
      "EPOCH: 18215 LOSS: 40.98702462261234\n",
      "EPOCH: 18216 LOSS: 40.98702231621749\n",
      "EPOCH: 18217 LOSS: 40.98702001003991\n",
      "EPOCH: 18218 LOSS: 40.98701770407954\n",
      "EPOCH: 18219 LOSS: 40.987015398336354\n",
      "EPOCH: 18220 LOSS: 40.98701309281031\n",
      "EPOCH: 18221 LOSS: 40.987010787501404\n",
      "EPOCH: 18222 LOSS: 40.98700848240955\n",
      "EPOCH: 18223 LOSS: 40.98700617753476\n",
      "EPOCH: 18224 LOSS: 40.98700387287698\n",
      "EPOCH: 18225 LOSS: 40.987001568436206\n",
      "EPOCH: 18226 LOSS: 40.98699926421236\n",
      "EPOCH: 18227 LOSS: 40.98699696020546\n",
      "EPOCH: 18228 LOSS: 40.98699465641541\n",
      "EPOCH: 18229 LOSS: 40.986992352842236\n",
      "EPOCH: 18230 LOSS: 40.98699004948588\n",
      "EPOCH: 18231 LOSS: 40.98698774634631\n",
      "EPOCH: 18232 LOSS: 40.98698544342349\n",
      "EPOCH: 18233 LOSS: 40.9869831407174\n",
      "EPOCH: 18234 LOSS: 40.98698083822799\n",
      "EPOCH: 18235 LOSS: 40.98697853595523\n",
      "EPOCH: 18236 LOSS: 40.9869762338991\n",
      "EPOCH: 18237 LOSS: 40.98697393205954\n",
      "EPOCH: 18238 LOSS: 40.98697163043657\n",
      "EPOCH: 18239 LOSS: 40.9869693290301\n",
      "EPOCH: 18240 LOSS: 40.98696702784012\n",
      "EPOCH: 18241 LOSS: 40.98696472686661\n",
      "EPOCH: 18242 LOSS: 40.98696242610953\n",
      "EPOCH: 18243 LOSS: 40.986960125568814\n",
      "EPOCH: 18244 LOSS: 40.98695782524449\n",
      "EPOCH: 18245 LOSS: 40.986955525136466\n",
      "EPOCH: 18246 LOSS: 40.98695322524475\n",
      "EPOCH: 18247 LOSS: 40.986950925569275\n",
      "EPOCH: 18248 LOSS: 40.986948626110056\n",
      "EPOCH: 18249 LOSS: 40.986946326867\n",
      "EPOCH: 18250 LOSS: 40.986944027840124\n",
      "EPOCH: 18251 LOSS: 40.986941729029375\n",
      "EPOCH: 18252 LOSS: 40.98693943043472\n",
      "EPOCH: 18253 LOSS: 40.98693713205612\n",
      "EPOCH: 18254 LOSS: 40.98693483389357\n",
      "EPOCH: 18255 LOSS: 40.98693253594699\n",
      "EPOCH: 18256 LOSS: 40.986930238216395\n",
      "EPOCH: 18257 LOSS: 40.98692794070172\n",
      "EPOCH: 18258 LOSS: 40.98692564340297\n",
      "EPOCH: 18259 LOSS: 40.986923346320054\n",
      "EPOCH: 18260 LOSS: 40.98692104945299\n",
      "EPOCH: 18261 LOSS: 40.986918752801714\n",
      "EPOCH: 18262 LOSS: 40.9869164563662\n",
      "EPOCH: 18263 LOSS: 40.986914160146455\n",
      "EPOCH: 18264 LOSS: 40.98691186414237\n",
      "EPOCH: 18265 LOSS: 40.98690956835398\n",
      "EPOCH: 18266 LOSS: 40.986907272781224\n",
      "EPOCH: 18267 LOSS: 40.98690497742407\n",
      "EPOCH: 18268 LOSS: 40.98690268228249\n",
      "EPOCH: 18269 LOSS: 40.98690038735643\n",
      "EPOCH: 18270 LOSS: 40.986898092645895\n",
      "EPOCH: 18271 LOSS: 40.986895798150826\n",
      "EPOCH: 18272 LOSS: 40.986893503871194\n",
      "EPOCH: 18273 LOSS: 40.986891209806984\n",
      "EPOCH: 18274 LOSS: 40.986888915958154\n",
      "EPOCH: 18275 LOSS: 40.98688662232463\n",
      "EPOCH: 18276 LOSS: 40.98688432890645\n",
      "EPOCH: 18277 LOSS: 40.98688203570353\n",
      "EPOCH: 18278 LOSS: 40.98687974271584\n",
      "EPOCH: 18279 LOSS: 40.98687744994339\n",
      "EPOCH: 18280 LOSS: 40.9868751573861\n",
      "EPOCH: 18281 LOSS: 40.98687286504398\n",
      "EPOCH: 18282 LOSS: 40.98687057291694\n",
      "EPOCH: 18283 LOSS: 40.986868281005\n",
      "EPOCH: 18284 LOSS: 40.9868659893081\n",
      "EPOCH: 18285 LOSS: 40.98686369782622\n",
      "EPOCH: 18286 LOSS: 40.98686140655933\n",
      "EPOCH: 18287 LOSS: 40.98685911550738\n",
      "EPOCH: 18288 LOSS: 40.98685682467035\n",
      "EPOCH: 18289 LOSS: 40.986854534048206\n",
      "EPOCH: 18290 LOSS: 40.986852243640925\n",
      "EPOCH: 18291 LOSS: 40.98684995344844\n",
      "EPOCH: 18292 LOSS: 40.986847663470755\n",
      "EPOCH: 18293 LOSS: 40.98684537370782\n",
      "EPOCH: 18294 LOSS: 40.9868430841596\n",
      "EPOCH: 18295 LOSS: 40.986840794826094\n",
      "EPOCH: 18296 LOSS: 40.986838505707226\n",
      "EPOCH: 18297 LOSS: 40.98683621680297\n",
      "EPOCH: 18298 LOSS: 40.986833928113334\n",
      "EPOCH: 18299 LOSS: 40.98683163963824\n",
      "EPOCH: 18300 LOSS: 40.98682935137768\n",
      "EPOCH: 18301 LOSS: 40.98682706333159\n",
      "EPOCH: 18302 LOSS: 40.9868247755\n",
      "EPOCH: 18303 LOSS: 40.98682248788281\n",
      "EPOCH: 18304 LOSS: 40.986820200480025\n",
      "EPOCH: 18305 LOSS: 40.9868179132916\n",
      "EPOCH: 18306 LOSS: 40.986815626317515\n",
      "EPOCH: 18307 LOSS: 40.98681333955771\n",
      "EPOCH: 18308 LOSS: 40.98681105301221\n",
      "EPOCH: 18309 LOSS: 40.98680876668091\n",
      "EPOCH: 18310 LOSS: 40.98680648056382\n",
      "EPOCH: 18311 LOSS: 40.98680419466089\n",
      "EPOCH: 18312 LOSS: 40.98680190897211\n",
      "EPOCH: 18313 LOSS: 40.98679962349742\n",
      "EPOCH: 18314 LOSS: 40.986797338236805\n",
      "EPOCH: 18315 LOSS: 40.986795053190235\n",
      "EPOCH: 18316 LOSS: 40.98679276835766\n",
      "EPOCH: 18317 LOSS: 40.986790483739064\n",
      "EPOCH: 18318 LOSS: 40.98678819933441\n",
      "EPOCH: 18319 LOSS: 40.98678591514367\n",
      "EPOCH: 18320 LOSS: 40.9867836311668\n",
      "EPOCH: 18321 LOSS: 40.986781347403785\n",
      "EPOCH: 18322 LOSS: 40.98677906385457\n",
      "EPOCH: 18323 LOSS: 40.986776780519136\n",
      "EPOCH: 18324 LOSS: 40.98677449739745\n",
      "EPOCH: 18325 LOSS: 40.98677221448948\n",
      "EPOCH: 18326 LOSS: 40.98676993179517\n",
      "EPOCH: 18327 LOSS: 40.986767649314544\n",
      "EPOCH: 18328 LOSS: 40.98676536704751\n",
      "EPOCH: 18329 LOSS: 40.98676308499407\n",
      "EPOCH: 18330 LOSS: 40.98676080315418\n",
      "EPOCH: 18331 LOSS: 40.98675852152782\n",
      "EPOCH: 18332 LOSS: 40.98675624011493\n",
      "EPOCH: 18333 LOSS: 40.986753958915514\n",
      "EPOCH: 18334 LOSS: 40.98675167792949\n",
      "EPOCH: 18335 LOSS: 40.986749397156885\n",
      "EPOCH: 18336 LOSS: 40.98674711659763\n",
      "EPOCH: 18337 LOSS: 40.98674483625169\n",
      "EPOCH: 18338 LOSS: 40.986742556119054\n",
      "EPOCH: 18339 LOSS: 40.98674027619968\n",
      "EPOCH: 18340 LOSS: 40.986737996493545\n",
      "EPOCH: 18341 LOSS: 40.986735717000585\n",
      "EPOCH: 18342 LOSS: 40.9867334377208\n",
      "EPOCH: 18343 LOSS: 40.98673115865414\n",
      "EPOCH: 18344 LOSS: 40.98672887980059\n",
      "EPOCH: 18345 LOSS: 40.986726601160086\n",
      "EPOCH: 18346 LOSS: 40.98672432273265\n",
      "EPOCH: 18347 LOSS: 40.98672204451819\n",
      "EPOCH: 18348 LOSS: 40.98671976651671\n",
      "EPOCH: 18349 LOSS: 40.986717488728175\n",
      "EPOCH: 18350 LOSS: 40.98671521115253\n",
      "EPOCH: 18351 LOSS: 40.98671293378976\n",
      "EPOCH: 18352 LOSS: 40.986710656639836\n",
      "EPOCH: 18353 LOSS: 40.986708379702726\n",
      "EPOCH: 18354 LOSS: 40.98670610297839\n",
      "EPOCH: 18355 LOSS: 40.986703826466794\n",
      "EPOCH: 18356 LOSS: 40.9867015501679\n",
      "EPOCH: 18357 LOSS: 40.9866992740817\n",
      "EPOCH: 18358 LOSS: 40.986696998208146\n",
      "EPOCH: 18359 LOSS: 40.9866947225472\n",
      "EPOCH: 18360 LOSS: 40.986692447098854\n",
      "EPOCH: 18361 LOSS: 40.986690171863046\n",
      "EPOCH: 18362 LOSS: 40.986687896839754\n",
      "EPOCH: 18363 LOSS: 40.986685622028936\n",
      "EPOCH: 18364 LOSS: 40.98668334743061\n",
      "EPOCH: 18365 LOSS: 40.986681073044686\n",
      "EPOCH: 18366 LOSS: 40.98667879887115\n",
      "EPOCH: 18367 LOSS: 40.98667652490998\n",
      "EPOCH: 18368 LOSS: 40.98667425116113\n",
      "EPOCH: 18369 LOSS: 40.98667197762457\n",
      "EPOCH: 18370 LOSS: 40.98666970430027\n",
      "EPOCH: 18371 LOSS: 40.98666743118821\n",
      "EPOCH: 18372 LOSS: 40.98666515828834\n",
      "EPOCH: 18373 LOSS: 40.98666288560063\n",
      "EPOCH: 18374 LOSS: 40.98666061312505\n",
      "EPOCH: 18375 LOSS: 40.98665834086159\n",
      "EPOCH: 18376 LOSS: 40.9866560688102\n",
      "EPOCH: 18377 LOSS: 40.98665379697082\n",
      "EPOCH: 18378 LOSS: 40.98665152534346\n",
      "EPOCH: 18379 LOSS: 40.98664925392807\n",
      "EPOCH: 18380 LOSS: 40.98664698272463\n",
      "EPOCH: 18381 LOSS: 40.98664471173308\n",
      "EPOCH: 18382 LOSS: 40.98664244095343\n",
      "EPOCH: 18383 LOSS: 40.9866401703856\n",
      "EPOCH: 18384 LOSS: 40.986637900029585\n",
      "EPOCH: 18385 LOSS: 40.986635629885356\n",
      "EPOCH: 18386 LOSS: 40.98663335995289\n",
      "EPOCH: 18387 LOSS: 40.98663109023211\n",
      "EPOCH: 18388 LOSS: 40.986628820723034\n",
      "EPOCH: 18389 LOSS: 40.9866265514256\n",
      "EPOCH: 18390 LOSS: 40.98662428233979\n",
      "EPOCH: 18391 LOSS: 40.986622013465556\n",
      "EPOCH: 18392 LOSS: 40.986619744802894\n",
      "EPOCH: 18393 LOSS: 40.98661747635175\n",
      "EPOCH: 18394 LOSS: 40.98661520811209\n",
      "EPOCH: 18395 LOSS: 40.98661294008389\n",
      "EPOCH: 18396 LOSS: 40.98661067226712\n",
      "EPOCH: 18397 LOSS: 40.98660840466175\n",
      "EPOCH: 18398 LOSS: 40.986606137267735\n",
      "EPOCH: 18399 LOSS: 40.98660387008507\n",
      "EPOCH: 18400 LOSS: 40.986601603113684\n",
      "EPOCH: 18401 LOSS: 40.98659933635358\n",
      "EPOCH: 18402 LOSS: 40.9865970698047\n",
      "EPOCH: 18403 LOSS: 40.98659480346703\n",
      "EPOCH: 18404 LOSS: 40.98659253734052\n",
      "EPOCH: 18405 LOSS: 40.98659027142517\n",
      "EPOCH: 18406 LOSS: 40.986588005720904\n",
      "EPOCH: 18407 LOSS: 40.986585740227724\n",
      "EPOCH: 18408 LOSS: 40.986583474945604\n",
      "EPOCH: 18409 LOSS: 40.98658120987448\n",
      "EPOCH: 18410 LOSS: 40.98657894501433\n",
      "EPOCH: 18411 LOSS: 40.98657668036513\n",
      "EPOCH: 18412 LOSS: 40.98657441592685\n",
      "EPOCH: 18413 LOSS: 40.98657215169948\n",
      "EPOCH: 18414 LOSS: 40.98656988768292\n",
      "EPOCH: 18415 LOSS: 40.98656762387721\n",
      "EPOCH: 18416 LOSS: 40.98656536028226\n",
      "EPOCH: 18417 LOSS: 40.98656309689807\n",
      "EPOCH: 18418 LOSS: 40.986560833724646\n",
      "EPOCH: 18419 LOSS: 40.98655857076187\n",
      "EPOCH: 18420 LOSS: 40.98655630800977\n",
      "EPOCH: 18421 LOSS: 40.9865540454683\n",
      "EPOCH: 18422 LOSS: 40.98655178313743\n",
      "EPOCH: 18423 LOSS: 40.98654952101713\n",
      "EPOCH: 18424 LOSS: 40.98654725910734\n",
      "EPOCH: 18425 LOSS: 40.986544997408075\n",
      "EPOCH: 18426 LOSS: 40.98654273591927\n",
      "EPOCH: 18427 LOSS: 40.986540474640904\n",
      "EPOCH: 18428 LOSS: 40.98653821357294\n",
      "EPOCH: 18429 LOSS: 40.98653595271536\n",
      "EPOCH: 18430 LOSS: 40.98653369206813\n",
      "EPOCH: 18431 LOSS: 40.98653143163118\n",
      "EPOCH: 18432 LOSS: 40.98652917140453\n",
      "EPOCH: 18433 LOSS: 40.986526911388125\n",
      "EPOCH: 18434 LOSS: 40.98652465158193\n",
      "EPOCH: 18435 LOSS: 40.98652239198593\n",
      "EPOCH: 18436 LOSS: 40.98652013260006\n",
      "EPOCH: 18437 LOSS: 40.98651787342433\n",
      "EPOCH: 18438 LOSS: 40.98651561445869\n",
      "EPOCH: 18439 LOSS: 40.98651335570311\n",
      "EPOCH: 18440 LOSS: 40.98651109715753\n",
      "EPOCH: 18441 LOSS: 40.98650883882197\n",
      "EPOCH: 18442 LOSS: 40.98650658069634\n",
      "EPOCH: 18443 LOSS: 40.98650432278066\n",
      "EPOCH: 18444 LOSS: 40.986502065074866\n",
      "EPOCH: 18445 LOSS: 40.986499807578966\n",
      "EPOCH: 18446 LOSS: 40.98649755029287\n",
      "EPOCH: 18447 LOSS: 40.986495293216585\n",
      "EPOCH: 18448 LOSS: 40.98649303635007\n",
      "EPOCH: 18449 LOSS: 40.986490779693305\n",
      "EPOCH: 18450 LOSS: 40.98648852324624\n",
      "EPOCH: 18451 LOSS: 40.986486267008836\n",
      "EPOCH: 18452 LOSS: 40.9864840109811\n",
      "EPOCH: 18453 LOSS: 40.986481755162956\n",
      "EPOCH: 18454 LOSS: 40.986479499554406\n",
      "EPOCH: 18455 LOSS: 40.98647724415541\n",
      "EPOCH: 18456 LOSS: 40.98647498896592\n",
      "EPOCH: 18457 LOSS: 40.986472733985906\n",
      "EPOCH: 18458 LOSS: 40.986470479215356\n",
      "EPOCH: 18459 LOSS: 40.986468224654246\n",
      "EPOCH: 18460 LOSS: 40.986465970302504\n",
      "EPOCH: 18461 LOSS: 40.986463716160124\n",
      "EPOCH: 18462 LOSS: 40.98646146222708\n",
      "EPOCH: 18463 LOSS: 40.98645920850334\n",
      "EPOCH: 18464 LOSS: 40.98645695498885\n",
      "EPOCH: 18465 LOSS: 40.986454701683584\n",
      "EPOCH: 18466 LOSS: 40.98645244858755\n",
      "EPOCH: 18467 LOSS: 40.986450195700655\n",
      "EPOCH: 18468 LOSS: 40.98644794302291\n",
      "EPOCH: 18469 LOSS: 40.98644569055425\n",
      "EPOCH: 18470 LOSS: 40.98644343829469\n",
      "EPOCH: 18471 LOSS: 40.98644118624418\n",
      "EPOCH: 18472 LOSS: 40.986438934402656\n",
      "EPOCH: 18473 LOSS: 40.986436682770126\n",
      "EPOCH: 18474 LOSS: 40.98643443134654\n",
      "EPOCH: 18475 LOSS: 40.98643218013187\n",
      "EPOCH: 18476 LOSS: 40.98642992912609\n",
      "EPOCH: 18477 LOSS: 40.986427678329164\n",
      "EPOCH: 18478 LOSS: 40.98642542774106\n",
      "EPOCH: 18479 LOSS: 40.98642317736173\n",
      "EPOCH: 18480 LOSS: 40.986420927191176\n",
      "EPOCH: 18481 LOSS: 40.98641867722935\n",
      "EPOCH: 18482 LOSS: 40.98641642747623\n",
      "EPOCH: 18483 LOSS: 40.98641417793175\n",
      "EPOCH: 18484 LOSS: 40.986411928595906\n",
      "EPOCH: 18485 LOSS: 40.986409679468686\n",
      "EPOCH: 18486 LOSS: 40.98640743055002\n",
      "EPOCH: 18487 LOSS: 40.986405181839885\n",
      "EPOCH: 18488 LOSS: 40.98640293333827\n",
      "EPOCH: 18489 LOSS: 40.986400685045126\n",
      "EPOCH: 18490 LOSS: 40.98639843696042\n",
      "EPOCH: 18491 LOSS: 40.98639618908413\n",
      "EPOCH: 18492 LOSS: 40.98639394141623\n",
      "EPOCH: 18493 LOSS: 40.986391693956676\n",
      "EPOCH: 18494 LOSS: 40.98638944670543\n",
      "EPOCH: 18495 LOSS: 40.98638719966247\n",
      "EPOCH: 18496 LOSS: 40.98638495282778\n",
      "EPOCH: 18497 LOSS: 40.98638270620132\n",
      "EPOCH: 18498 LOSS: 40.986380459783035\n",
      "EPOCH: 18499 LOSS: 40.986378213572905\n",
      "EPOCH: 18500 LOSS: 40.98637596757092\n",
      "EPOCH: 18501 LOSS: 40.98637372177703\n",
      "EPOCH: 18502 LOSS: 40.986371476191195\n",
      "EPOCH: 18503 LOSS: 40.986369230813416\n",
      "EPOCH: 18504 LOSS: 40.98636698564361\n",
      "EPOCH: 18505 LOSS: 40.98636474068181\n",
      "EPOCH: 18506 LOSS: 40.986362495927935\n",
      "EPOCH: 18507 LOSS: 40.98636025138198\n",
      "EPOCH: 18508 LOSS: 40.98635800704389\n",
      "EPOCH: 18509 LOSS: 40.98635576291365\n",
      "EPOCH: 18510 LOSS: 40.98635351899122\n",
      "EPOCH: 18511 LOSS: 40.986351275276604\n",
      "EPOCH: 18512 LOSS: 40.98634903176972\n",
      "EPOCH: 18513 LOSS: 40.98634678847054\n",
      "EPOCH: 18514 LOSS: 40.98634454537907\n",
      "EPOCH: 18515 LOSS: 40.98634230249525\n",
      "EPOCH: 18516 LOSS: 40.98634005981908\n",
      "EPOCH: 18517 LOSS: 40.986337817350474\n",
      "EPOCH: 18518 LOSS: 40.986335575089456\n",
      "EPOCH: 18519 LOSS: 40.98633333303596\n",
      "EPOCH: 18520 LOSS: 40.98633109118998\n",
      "EPOCH: 18521 LOSS: 40.98632884955147\n",
      "EPOCH: 18522 LOSS: 40.98632660812039\n",
      "EPOCH: 18523 LOSS: 40.98632436689671\n",
      "EPOCH: 18524 LOSS: 40.98632212588042\n",
      "EPOCH: 18525 LOSS: 40.986319885071474\n",
      "EPOCH: 18526 LOSS: 40.98631764446985\n",
      "EPOCH: 18527 LOSS: 40.9863154040755\n",
      "EPOCH: 18528 LOSS: 40.98631316388841\n",
      "EPOCH: 18529 LOSS: 40.98631092390852\n",
      "EPOCH: 18530 LOSS: 40.98630868413585\n",
      "EPOCH: 18531 LOSS: 40.986306444570324\n",
      "EPOCH: 18532 LOSS: 40.98630420521191\n",
      "EPOCH: 18533 LOSS: 40.98630196606061\n",
      "EPOCH: 18534 LOSS: 40.986299727116375\n",
      "EPOCH: 18535 LOSS: 40.986297488379165\n",
      "EPOCH: 18536 LOSS: 40.98629524984897\n",
      "EPOCH: 18537 LOSS: 40.98629301152573\n",
      "EPOCH: 18538 LOSS: 40.986290773409436\n",
      "EPOCH: 18539 LOSS: 40.98628853550006\n",
      "EPOCH: 18540 LOSS: 40.986286297797555\n",
      "EPOCH: 18541 LOSS: 40.986284060301884\n",
      "EPOCH: 18542 LOSS: 40.986281823013044\n",
      "EPOCH: 18543 LOSS: 40.98627958593098\n",
      "EPOCH: 18544 LOSS: 40.98627734905566\n",
      "EPOCH: 18545 LOSS: 40.98627511238708\n",
      "EPOCH: 18546 LOSS: 40.98627287592517\n",
      "EPOCH: 18547 LOSS: 40.98627063966994\n",
      "EPOCH: 18548 LOSS: 40.986268403621324\n",
      "EPOCH: 18549 LOSS: 40.98626616777931\n",
      "EPOCH: 18550 LOSS: 40.98626393214387\n",
      "EPOCH: 18551 LOSS: 40.986261696714955\n",
      "EPOCH: 18552 LOSS: 40.98625946149255\n",
      "EPOCH: 18553 LOSS: 40.98625722647662\n",
      "EPOCH: 18554 LOSS: 40.98625499166712\n",
      "EPOCH: 18555 LOSS: 40.98625275706403\n",
      "EPOCH: 18556 LOSS: 40.98625052266732\n",
      "EPOCH: 18557 LOSS: 40.98624828847697\n",
      "EPOCH: 18558 LOSS: 40.98624605449291\n",
      "EPOCH: 18559 LOSS: 40.98624382071517\n",
      "EPOCH: 18560 LOSS: 40.98624158714366\n",
      "EPOCH: 18561 LOSS: 40.98623935377839\n",
      "EPOCH: 18562 LOSS: 40.98623712061929\n",
      "EPOCH: 18563 LOSS: 40.98623488766638\n",
      "EPOCH: 18564 LOSS: 40.98623265491959\n",
      "EPOCH: 18565 LOSS: 40.986230422378895\n",
      "EPOCH: 18566 LOSS: 40.98622819004427\n",
      "EPOCH: 18567 LOSS: 40.98622595791568\n",
      "EPOCH: 18568 LOSS: 40.9862237259931\n",
      "EPOCH: 18569 LOSS: 40.98622149427649\n",
      "EPOCH: 18570 LOSS: 40.98621926276583\n",
      "EPOCH: 18571 LOSS: 40.98621703146107\n",
      "EPOCH: 18572 LOSS: 40.986214800362205\n",
      "EPOCH: 18573 LOSS: 40.98621256946919\n",
      "EPOCH: 18574 LOSS: 40.98621033878199\n",
      "EPOCH: 18575 LOSS: 40.986208108300595\n",
      "EPOCH: 18576 LOSS: 40.986205878024926\n",
      "EPOCH: 18577 LOSS: 40.986203647955016\n",
      "EPOCH: 18578 LOSS: 40.986201418090786\n",
      "EPOCH: 18579 LOSS: 40.986199188432224\n",
      "EPOCH: 18580 LOSS: 40.98619695897929\n",
      "EPOCH: 18581 LOSS: 40.98619472973197\n",
      "EPOCH: 18582 LOSS: 40.986192500690215\n",
      "EPOCH: 18583 LOSS: 40.986190271854014\n",
      "EPOCH: 18584 LOSS: 40.986188043223315\n",
      "EPOCH: 18585 LOSS: 40.98618581479808\n",
      "EPOCH: 18586 LOSS: 40.986183586578306\n",
      "EPOCH: 18587 LOSS: 40.98618135856397\n",
      "EPOCH: 18588 LOSS: 40.98617913075499\n",
      "EPOCH: 18589 LOSS: 40.986176903151375\n",
      "EPOCH: 18590 LOSS: 40.9861746757531\n",
      "EPOCH: 18591 LOSS: 40.98617244856009\n",
      "EPOCH: 18592 LOSS: 40.98617022157237\n",
      "EPOCH: 18593 LOSS: 40.98616799478987\n",
      "EPOCH: 18594 LOSS: 40.98616576821257\n",
      "EPOCH: 18595 LOSS: 40.98616354184043\n",
      "EPOCH: 18596 LOSS: 40.986161315673456\n",
      "EPOCH: 18597 LOSS: 40.98615908971158\n",
      "EPOCH: 18598 LOSS: 40.98615686395477\n",
      "EPOCH: 18599 LOSS: 40.98615463840301\n",
      "EPOCH: 18600 LOSS: 40.98615241305627\n",
      "EPOCH: 18601 LOSS: 40.98615018791452\n",
      "EPOCH: 18602 LOSS: 40.98614796297772\n",
      "EPOCH: 18603 LOSS: 40.98614573824584\n",
      "EPOCH: 18604 LOSS: 40.986143513718865\n",
      "EPOCH: 18605 LOSS: 40.98614128939672\n",
      "EPOCH: 18606 LOSS: 40.98613906527944\n",
      "EPOCH: 18607 LOSS: 40.98613684136693\n",
      "EPOCH: 18608 LOSS: 40.98613461765922\n",
      "EPOCH: 18609 LOSS: 40.98613239415623\n",
      "EPOCH: 18610 LOSS: 40.98613017085794\n",
      "EPOCH: 18611 LOSS: 40.986127947764345\n",
      "EPOCH: 18612 LOSS: 40.98612572487539\n",
      "EPOCH: 18613 LOSS: 40.98612350219106\n",
      "EPOCH: 18614 LOSS: 40.9861212797113\n",
      "EPOCH: 18615 LOSS: 40.986119057436106\n",
      "EPOCH: 18616 LOSS: 40.986116835365436\n",
      "EPOCH: 18617 LOSS: 40.98611461349924\n",
      "EPOCH: 18618 LOSS: 40.986112391837516\n",
      "EPOCH: 18619 LOSS: 40.986110170380215\n",
      "EPOCH: 18620 LOSS: 40.986107949127316\n",
      "EPOCH: 18621 LOSS: 40.98610572807879\n",
      "EPOCH: 18622 LOSS: 40.9861035072346\n",
      "EPOCH: 18623 LOSS: 40.986101286594725\n",
      "EPOCH: 18624 LOSS: 40.98609906615911\n",
      "EPOCH: 18625 LOSS: 40.98609684592775\n",
      "EPOCH: 18626 LOSS: 40.98609462590062\n",
      "EPOCH: 18627 LOSS: 40.98609240607765\n",
      "EPOCH: 18628 LOSS: 40.986090186458846\n",
      "EPOCH: 18629 LOSS: 40.98608796704417\n",
      "EPOCH: 18630 LOSS: 40.986085747833584\n",
      "EPOCH: 18631 LOSS: 40.98608352882705\n",
      "EPOCH: 18632 LOSS: 40.98608131002456\n",
      "EPOCH: 18633 LOSS: 40.98607909142605\n",
      "EPOCH: 18634 LOSS: 40.98607687303154\n",
      "EPOCH: 18635 LOSS: 40.98607465484096\n",
      "EPOCH: 18636 LOSS: 40.98607243685427\n",
      "EPOCH: 18637 LOSS: 40.98607021907147\n",
      "EPOCH: 18638 LOSS: 40.98606800149252\n",
      "EPOCH: 18639 LOSS: 40.986065784117386\n",
      "EPOCH: 18640 LOSS: 40.98606356694603\n",
      "EPOCH: 18641 LOSS: 40.986061349978435\n",
      "EPOCH: 18642 LOSS: 40.98605913321456\n",
      "EPOCH: 18643 LOSS: 40.98605691665439\n",
      "EPOCH: 18644 LOSS: 40.98605470029787\n",
      "EPOCH: 18645 LOSS: 40.98605248414499\n",
      "EPOCH: 18646 LOSS: 40.98605026819571\n",
      "EPOCH: 18647 LOSS: 40.98604805245001\n",
      "EPOCH: 18648 LOSS: 40.98604583690785\n",
      "EPOCH: 18649 LOSS: 40.98604362156918\n",
      "EPOCH: 18650 LOSS: 40.986041406434005\n",
      "EPOCH: 18651 LOSS: 40.986039191502286\n",
      "EPOCH: 18652 LOSS: 40.98603697677396\n",
      "EPOCH: 18653 LOSS: 40.98603476224905\n",
      "EPOCH: 18654 LOSS: 40.98603254792748\n",
      "EPOCH: 18655 LOSS: 40.98603033380925\n",
      "EPOCH: 18656 LOSS: 40.98602811989431\n",
      "EPOCH: 18657 LOSS: 40.98602590618263\n",
      "EPOCH: 18658 LOSS: 40.986023692674195\n",
      "EPOCH: 18659 LOSS: 40.986021479368944\n",
      "EPOCH: 18660 LOSS: 40.986019266266894\n",
      "EPOCH: 18661 LOSS: 40.98601705336797\n",
      "EPOCH: 18662 LOSS: 40.986014840672176\n",
      "EPOCH: 18663 LOSS: 40.98601262817945\n",
      "EPOCH: 18664 LOSS: 40.98601041588978\n",
      "EPOCH: 18665 LOSS: 40.98600820380314\n",
      "EPOCH: 18666 LOSS: 40.986005991919484\n",
      "EPOCH: 18667 LOSS: 40.98600378023879\n",
      "EPOCH: 18668 LOSS: 40.98600156876101\n",
      "EPOCH: 18669 LOSS: 40.98599935748615\n",
      "EPOCH: 18670 LOSS: 40.98599714641415\n",
      "EPOCH: 18671 LOSS: 40.985994935544994\n",
      "EPOCH: 18672 LOSS: 40.98599272487864\n",
      "EPOCH: 18673 LOSS: 40.985990514415064\n",
      "EPOCH: 18674 LOSS: 40.98598830415423\n",
      "EPOCH: 18675 LOSS: 40.98598609409612\n",
      "EPOCH: 18676 LOSS: 40.9859838842407\n",
      "EPOCH: 18677 LOSS: 40.98598167458793\n",
      "EPOCH: 18678 LOSS: 40.98597946513779\n",
      "EPOCH: 18679 LOSS: 40.98597725589024\n",
      "EPOCH: 18680 LOSS: 40.98597504684526\n",
      "EPOCH: 18681 LOSS: 40.98597283800281\n",
      "EPOCH: 18682 LOSS: 40.98597062936287\n",
      "EPOCH: 18683 LOSS: 40.985968420925396\n",
      "EPOCH: 18684 LOSS: 40.98596621269036\n",
      "EPOCH: 18685 LOSS: 40.98596400465775\n",
      "EPOCH: 18686 LOSS: 40.98596179682751\n",
      "EPOCH: 18687 LOSS: 40.985959589199624\n",
      "EPOCH: 18688 LOSS: 40.98595738177408\n",
      "EPOCH: 18689 LOSS: 40.98595517455081\n",
      "EPOCH: 18690 LOSS: 40.985952967529784\n",
      "EPOCH: 18691 LOSS: 40.985950760711006\n",
      "EPOCH: 18692 LOSS: 40.985948554094435\n",
      "EPOCH: 18693 LOSS: 40.98594634768002\n",
      "EPOCH: 18694 LOSS: 40.98594414146775\n",
      "EPOCH: 18695 LOSS: 40.98594193545758\n",
      "EPOCH: 18696 LOSS: 40.98593972964951\n",
      "EPOCH: 18697 LOSS: 40.985937524043486\n",
      "EPOCH: 18698 LOSS: 40.98593531863945\n",
      "EPOCH: 18699 LOSS: 40.985933113437426\n",
      "EPOCH: 18700 LOSS: 40.98593090843735\n",
      "EPOCH: 18701 LOSS: 40.98592870363921\n",
      "EPOCH: 18702 LOSS: 40.98592649904296\n",
      "EPOCH: 18703 LOSS: 40.98592429464858\n",
      "EPOCH: 18704 LOSS: 40.98592209045603\n",
      "EPOCH: 18705 LOSS: 40.98591988646528\n",
      "EPOCH: 18706 LOSS: 40.985917682676316\n",
      "EPOCH: 18707 LOSS: 40.98591547908909\n",
      "EPOCH: 18708 LOSS: 40.985913275703595\n",
      "EPOCH: 18709 LOSS: 40.98591107251977\n",
      "EPOCH: 18710 LOSS: 40.98590886953761\n",
      "EPOCH: 18711 LOSS: 40.985906666757046\n",
      "EPOCH: 18712 LOSS: 40.98590446417812\n",
      "EPOCH: 18713 LOSS: 40.98590226180072\n",
      "EPOCH: 18714 LOSS: 40.98590005962487\n",
      "EPOCH: 18715 LOSS: 40.98589785765052\n",
      "EPOCH: 18716 LOSS: 40.98589565587765\n",
      "EPOCH: 18717 LOSS: 40.98589345430622\n",
      "EPOCH: 18718 LOSS: 40.98589125293619\n",
      "EPOCH: 18719 LOSS: 40.98588905176756\n",
      "EPOCH: 18720 LOSS: 40.985886850800256\n",
      "EPOCH: 18721 LOSS: 40.98588465003429\n",
      "EPOCH: 18722 LOSS: 40.98588244946963\n",
      "EPOCH: 18723 LOSS: 40.98588024910621\n",
      "EPOCH: 18724 LOSS: 40.98587804894403\n",
      "EPOCH: 18725 LOSS: 40.98587584898304\n",
      "EPOCH: 18726 LOSS: 40.98587364922324\n",
      "EPOCH: 18727 LOSS: 40.98587144966457\n",
      "EPOCH: 18728 LOSS: 40.98586925030701\n",
      "EPOCH: 18729 LOSS: 40.985867051150535\n",
      "EPOCH: 18730 LOSS: 40.9858648521951\n",
      "EPOCH: 18731 LOSS: 40.985862653440684\n",
      "EPOCH: 18732 LOSS: 40.98586045488726\n",
      "EPOCH: 18733 LOSS: 40.98585825653482\n",
      "EPOCH: 18734 LOSS: 40.98585605838328\n",
      "EPOCH: 18735 LOSS: 40.98585386043264\n",
      "EPOCH: 18736 LOSS: 40.9858516626829\n",
      "EPOCH: 18737 LOSS: 40.985849465133974\n",
      "EPOCH: 18738 LOSS: 40.98584726778584\n",
      "EPOCH: 18739 LOSS: 40.985845070638526\n",
      "EPOCH: 18740 LOSS: 40.98584287369194\n",
      "EPOCH: 18741 LOSS: 40.98584067694607\n",
      "EPOCH: 18742 LOSS: 40.9858384804009\n",
      "EPOCH: 18743 LOSS: 40.985836284056376\n",
      "EPOCH: 18744 LOSS: 40.98583408791249\n",
      "EPOCH: 18745 LOSS: 40.985831891969205\n",
      "EPOCH: 18746 LOSS: 40.98582969622648\n",
      "EPOCH: 18747 LOSS: 40.985827500684294\n",
      "EPOCH: 18748 LOSS: 40.9858253053426\n",
      "EPOCH: 18749 LOSS: 40.985823110201416\n",
      "EPOCH: 18750 LOSS: 40.98582091526067\n",
      "EPOCH: 18751 LOSS: 40.98581872052033\n",
      "EPOCH: 18752 LOSS: 40.9858165259804\n",
      "EPOCH: 18753 LOSS: 40.98581433164081\n",
      "EPOCH: 18754 LOSS: 40.985812137501554\n",
      "EPOCH: 18755 LOSS: 40.985809943562586\n",
      "EPOCH: 18756 LOSS: 40.98580774982389\n",
      "EPOCH: 18757 LOSS: 40.98580555628544\n",
      "EPOCH: 18758 LOSS: 40.985803362947195\n",
      "EPOCH: 18759 LOSS: 40.985801169809136\n",
      "EPOCH: 18760 LOSS: 40.98579897687121\n",
      "EPOCH: 18761 LOSS: 40.985796784133406\n",
      "EPOCH: 18762 LOSS: 40.98579459159569\n",
      "EPOCH: 18763 LOSS: 40.98579239925804\n",
      "EPOCH: 18764 LOSS: 40.98579020712042\n",
      "EPOCH: 18765 LOSS: 40.985788015182784\n",
      "EPOCH: 18766 LOSS: 40.98578582344511\n",
      "EPOCH: 18767 LOSS: 40.985783631907395\n",
      "EPOCH: 18768 LOSS: 40.98578144056958\n",
      "EPOCH: 18769 LOSS: 40.98577924943163\n",
      "EPOCH: 18770 LOSS: 40.985777058493554\n",
      "EPOCH: 18771 LOSS: 40.98577486775529\n",
      "EPOCH: 18772 LOSS: 40.9857726772168\n",
      "EPOCH: 18773 LOSS: 40.985770486878074\n",
      "EPOCH: 18774 LOSS: 40.98576829673908\n",
      "EPOCH: 18775 LOSS: 40.98576610679979\n",
      "EPOCH: 18776 LOSS: 40.985763917060154\n",
      "EPOCH: 18777 LOSS: 40.98576172752016\n",
      "EPOCH: 18778 LOSS: 40.98575953817979\n",
      "EPOCH: 18779 LOSS: 40.98575734903899\n",
      "EPOCH: 18780 LOSS: 40.985755160097746\n",
      "EPOCH: 18781 LOSS: 40.98575297135602\n",
      "EPOCH: 18782 LOSS: 40.98575078281377\n",
      "EPOCH: 18783 LOSS: 40.98574859447098\n",
      "EPOCH: 18784 LOSS: 40.985746406327635\n",
      "EPOCH: 18785 LOSS: 40.98574421838367\n",
      "EPOCH: 18786 LOSS: 40.985742030639095\n",
      "EPOCH: 18787 LOSS: 40.98573984309384\n",
      "EPOCH: 18788 LOSS: 40.98573765574791\n",
      "EPOCH: 18789 LOSS: 40.98573546860125\n",
      "EPOCH: 18790 LOSS: 40.98573328165387\n",
      "EPOCH: 18791 LOSS: 40.98573109490568\n",
      "EPOCH: 18792 LOSS: 40.98572890835668\n",
      "EPOCH: 18793 LOSS: 40.98572672200685\n",
      "EPOCH: 18794 LOSS: 40.985724535856164\n",
      "EPOCH: 18795 LOSS: 40.98572234990456\n",
      "EPOCH: 18796 LOSS: 40.98572016415204\n",
      "EPOCH: 18797 LOSS: 40.98571797859856\n",
      "EPOCH: 18798 LOSS: 40.98571579324407\n",
      "EPOCH: 18799 LOSS: 40.9857136080886\n",
      "EPOCH: 18800 LOSS: 40.98571142313206\n",
      "EPOCH: 18801 LOSS: 40.985709238374454\n",
      "EPOCH: 18802 LOSS: 40.98570705381573\n",
      "EPOCH: 18803 LOSS: 40.98570486945587\n",
      "EPOCH: 18804 LOSS: 40.98570268529485\n",
      "EPOCH: 18805 LOSS: 40.98570050133263\n",
      "EPOCH: 18806 LOSS: 40.98569831756919\n",
      "EPOCH: 18807 LOSS: 40.985696134004485\n",
      "EPOCH: 18808 LOSS: 40.98569395063849\n",
      "EPOCH: 18809 LOSS: 40.98569176747119\n",
      "EPOCH: 18810 LOSS: 40.98568958450254\n",
      "EPOCH: 18811 LOSS: 40.98568740173252\n",
      "EPOCH: 18812 LOSS: 40.985685219161105\n",
      "EPOCH: 18813 LOSS: 40.98568303678823\n",
      "EPOCH: 18814 LOSS: 40.98568085461391\n",
      "EPOCH: 18815 LOSS: 40.985678672638095\n",
      "EPOCH: 18816 LOSS: 40.985676490860754\n",
      "EPOCH: 18817 LOSS: 40.985674309281855\n",
      "EPOCH: 18818 LOSS: 40.985672127901374\n",
      "EPOCH: 18819 LOSS: 40.98566994671929\n",
      "EPOCH: 18820 LOSS: 40.985667765735556\n",
      "EPOCH: 18821 LOSS: 40.985665584950134\n",
      "EPOCH: 18822 LOSS: 40.985663404363045\n",
      "EPOCH: 18823 LOSS: 40.985661223974205\n",
      "EPOCH: 18824 LOSS: 40.98565904378361\n",
      "EPOCH: 18825 LOSS: 40.98565686379123\n",
      "EPOCH: 18826 LOSS: 40.98565468399702\n",
      "EPOCH: 18827 LOSS: 40.98565250440095\n",
      "EPOCH: 18828 LOSS: 40.98565032500302\n",
      "EPOCH: 18829 LOSS: 40.985648145803175\n",
      "EPOCH: 18830 LOSS: 40.9856459668014\n",
      "EPOCH: 18831 LOSS: 40.98564378799764\n",
      "EPOCH: 18832 LOSS: 40.985641609391905\n",
      "EPOCH: 18833 LOSS: 40.98563943098412\n",
      "EPOCH: 18834 LOSS: 40.9856372527743\n",
      "EPOCH: 18835 LOSS: 40.98563507476237\n",
      "EPOCH: 18836 LOSS: 40.98563289694833\n",
      "EPOCH: 18837 LOSS: 40.98563071933215\n",
      "EPOCH: 18838 LOSS: 40.9856285419138\n",
      "EPOCH: 18839 LOSS: 40.985626364693246\n",
      "EPOCH: 18840 LOSS: 40.98562418767044\n",
      "EPOCH: 18841 LOSS: 40.98562201084538\n",
      "EPOCH: 18842 LOSS: 40.98561983421803\n",
      "EPOCH: 18843 LOSS: 40.98561765778835\n",
      "EPOCH: 18844 LOSS: 40.98561548155632\n",
      "EPOCH: 18845 LOSS: 40.98561330552191\n",
      "EPOCH: 18846 LOSS: 40.98561112968509\n",
      "EPOCH: 18847 LOSS: 40.985608954045816\n",
      "EPOCH: 18848 LOSS: 40.985606778604094\n",
      "EPOCH: 18849 LOSS: 40.985604603359846\n",
      "EPOCH: 18850 LOSS: 40.98560242831308\n",
      "EPOCH: 18851 LOSS: 40.98560025346376\n",
      "EPOCH: 18852 LOSS: 40.98559807881185\n",
      "EPOCH: 18853 LOSS: 40.98559590435732\n",
      "EPOCH: 18854 LOSS: 40.985593730100135\n",
      "EPOCH: 18855 LOSS: 40.985591556040276\n",
      "EPOCH: 18856 LOSS: 40.985589382177714\n",
      "EPOCH: 18857 LOSS: 40.98558720851241\n",
      "EPOCH: 18858 LOSS: 40.985585035044345\n",
      "EPOCH: 18859 LOSS: 40.98558286177348\n",
      "EPOCH: 18860 LOSS: 40.98558068869981\n",
      "EPOCH: 18861 LOSS: 40.98557851582326\n",
      "EPOCH: 18862 LOSS: 40.98557634314383\n",
      "EPOCH: 18863 LOSS: 40.98557417066151\n",
      "EPOCH: 18864 LOSS: 40.98557199837622\n",
      "EPOCH: 18865 LOSS: 40.98556982628797\n",
      "EPOCH: 18866 LOSS: 40.98556765439672\n",
      "EPOCH: 18867 LOSS: 40.985565482702434\n",
      "EPOCH: 18868 LOSS: 40.98556331120508\n",
      "EPOCH: 18869 LOSS: 40.98556113990466\n",
      "EPOCH: 18870 LOSS: 40.985558968801094\n",
      "EPOCH: 18871 LOSS: 40.9855567978944\n",
      "EPOCH: 18872 LOSS: 40.98555462718452\n",
      "EPOCH: 18873 LOSS: 40.985552456671435\n",
      "EPOCH: 18874 LOSS: 40.98555028635511\n",
      "EPOCH: 18875 LOSS: 40.985548116235506\n",
      "EPOCH: 18876 LOSS: 40.98554594631264\n",
      "EPOCH: 18877 LOSS: 40.985543776586425\n",
      "EPOCH: 18878 LOSS: 40.98554160705686\n",
      "EPOCH: 18879 LOSS: 40.985539437723915\n",
      "EPOCH: 18880 LOSS: 40.98553726858755\n",
      "EPOCH: 18881 LOSS: 40.98553509964774\n",
      "EPOCH: 18882 LOSS: 40.98553293090447\n",
      "EPOCH: 18883 LOSS: 40.9855307623577\n",
      "EPOCH: 18884 LOSS: 40.98552859400738\n",
      "EPOCH: 18885 LOSS: 40.98552642585352\n",
      "EPOCH: 18886 LOSS: 40.98552425789606\n",
      "EPOCH: 18887 LOSS: 40.98552209013499\n",
      "EPOCH: 18888 LOSS: 40.98551992257026\n",
      "EPOCH: 18889 LOSS: 40.98551775520187\n",
      "EPOCH: 18890 LOSS: 40.98551558802977\n",
      "EPOCH: 18891 LOSS: 40.98551342105392\n",
      "EPOCH: 18892 LOSS: 40.98551125427433\n",
      "EPOCH: 18893 LOSS: 40.98550908769092\n",
      "EPOCH: 18894 LOSS: 40.9855069213037\n",
      "EPOCH: 18895 LOSS: 40.985504755112636\n",
      "EPOCH: 18896 LOSS: 40.98550258911767\n",
      "EPOCH: 18897 LOSS: 40.985500423318804\n",
      "EPOCH: 18898 LOSS: 40.985498257715996\n",
      "EPOCH: 18899 LOSS: 40.98549609230922\n",
      "EPOCH: 18900 LOSS: 40.98549392709843\n",
      "EPOCH: 18901 LOSS: 40.98549176208363\n",
      "EPOCH: 18902 LOSS: 40.98548959726476\n",
      "EPOCH: 18903 LOSS: 40.98548743264182\n",
      "EPOCH: 18904 LOSS: 40.985485268214745\n",
      "EPOCH: 18905 LOSS: 40.98548310398353\n",
      "EPOCH: 18906 LOSS: 40.98548093994815\n",
      "EPOCH: 18907 LOSS: 40.98547877610856\n",
      "EPOCH: 18908 LOSS: 40.98547661246474\n",
      "EPOCH: 18909 LOSS: 40.98547444901665\n",
      "EPOCH: 18910 LOSS: 40.98547228576428\n",
      "EPOCH: 18911 LOSS: 40.985470122707575\n",
      "EPOCH: 18912 LOSS: 40.98546795984653\n",
      "EPOCH: 18913 LOSS: 40.98546579718111\n",
      "EPOCH: 18914 LOSS: 40.985463634711266\n",
      "EPOCH: 18915 LOSS: 40.985461472436995\n",
      "EPOCH: 18916 LOSS: 40.98545931035826\n",
      "EPOCH: 18917 LOSS: 40.98545714847502\n",
      "EPOCH: 18918 LOSS: 40.98545498678727\n",
      "EPOCH: 18919 LOSS: 40.98545282529495\n",
      "EPOCH: 18920 LOSS: 40.985450663998066\n",
      "EPOCH: 18921 LOSS: 40.985448502896546\n",
      "EPOCH: 18922 LOSS: 40.98544634199039\n",
      "EPOCH: 18923 LOSS: 40.985444181279576\n",
      "EPOCH: 18924 LOSS: 40.985442020764054\n",
      "EPOCH: 18925 LOSS: 40.9854398604438\n",
      "EPOCH: 18926 LOSS: 40.9854377003188\n",
      "EPOCH: 18927 LOSS: 40.98543554038901\n",
      "EPOCH: 18928 LOSS: 40.9854333806544\n",
      "EPOCH: 18929 LOSS: 40.985431221114936\n",
      "EPOCH: 18930 LOSS: 40.9854290617706\n",
      "EPOCH: 18931 LOSS: 40.98542690262137\n",
      "EPOCH: 18932 LOSS: 40.98542474366721\n",
      "EPOCH: 18933 LOSS: 40.985422584908086\n",
      "EPOCH: 18934 LOSS: 40.985420426343964\n",
      "EPOCH: 18935 LOSS: 40.98541826797482\n",
      "EPOCH: 18936 LOSS: 40.98541610980064\n",
      "EPOCH: 18937 LOSS: 40.98541395182138\n",
      "EPOCH: 18938 LOSS: 40.985411794037006\n",
      "EPOCH: 18939 LOSS: 40.9854096364475\n",
      "EPOCH: 18940 LOSS: 40.985407479052824\n",
      "EPOCH: 18941 LOSS: 40.98540532185295\n",
      "EPOCH: 18942 LOSS: 40.98540316484787\n",
      "EPOCH: 18943 LOSS: 40.98540100803753\n",
      "EPOCH: 18944 LOSS: 40.98539885142189\n",
      "EPOCH: 18945 LOSS: 40.985396695000965\n",
      "EPOCH: 18946 LOSS: 40.98539453877469\n",
      "EPOCH: 18947 LOSS: 40.985392382743036\n",
      "EPOCH: 18948 LOSS: 40.985390226906006\n",
      "EPOCH: 18949 LOSS: 40.98538807126355\n",
      "EPOCH: 18950 LOSS: 40.98538591581563\n",
      "EPOCH: 18951 LOSS: 40.98538376056222\n",
      "EPOCH: 18952 LOSS: 40.98538160550329\n",
      "EPOCH: 18953 LOSS: 40.98537945063883\n",
      "EPOCH: 18954 LOSS: 40.9853772959688\n",
      "EPOCH: 18955 LOSS: 40.98537514149318\n",
      "EPOCH: 18956 LOSS: 40.98537298721192\n",
      "EPOCH: 18957 LOSS: 40.985370833124996\n",
      "EPOCH: 18958 LOSS: 40.98536867923238\n",
      "EPOCH: 18959 LOSS: 40.98536652553406\n",
      "EPOCH: 18960 LOSS: 40.98536437203\n",
      "EPOCH: 18961 LOSS: 40.985362218720155\n",
      "EPOCH: 18962 LOSS: 40.98536006560451\n",
      "EPOCH: 18963 LOSS: 40.98535791268303\n",
      "EPOCH: 18964 LOSS: 40.985355759955695\n",
      "EPOCH: 18965 LOSS: 40.98535360742247\n",
      "EPOCH: 18966 LOSS: 40.98535145508332\n",
      "EPOCH: 18967 LOSS: 40.985349302938225\n",
      "EPOCH: 18968 LOSS: 40.98534715098715\n",
      "EPOCH: 18969 LOSS: 40.98534499923008\n",
      "EPOCH: 18970 LOSS: 40.98534284766697\n",
      "EPOCH: 18971 LOSS: 40.985340696297804\n",
      "EPOCH: 18972 LOSS: 40.98533854512254\n",
      "EPOCH: 18973 LOSS: 40.98533639414115\n",
      "EPOCH: 18974 LOSS: 40.98533424335362\n",
      "EPOCH: 18975 LOSS: 40.98533209275991\n",
      "EPOCH: 18976 LOSS: 40.98532994235998\n",
      "EPOCH: 18977 LOSS: 40.985327792153825\n",
      "EPOCH: 18978 LOSS: 40.9853256421414\n",
      "EPOCH: 18979 LOSS: 40.98532349232269\n",
      "EPOCH: 18980 LOSS: 40.98532134269763\n",
      "EPOCH: 18981 LOSS: 40.98531919326625\n",
      "EPOCH: 18982 LOSS: 40.98531704402848\n",
      "EPOCH: 18983 LOSS: 40.9853148949843\n",
      "EPOCH: 18984 LOSS: 40.98531274613369\n",
      "EPOCH: 18985 LOSS: 40.98531059747659\n",
      "EPOCH: 18986 LOSS: 40.98530844901302\n",
      "EPOCH: 18987 LOSS: 40.985306300742906\n",
      "EPOCH: 18988 LOSS: 40.985304152666245\n",
      "EPOCH: 18989 LOSS: 40.985302004783016\n",
      "EPOCH: 18990 LOSS: 40.98529985709316\n",
      "EPOCH: 18991 LOSS: 40.98529770959666\n",
      "EPOCH: 18992 LOSS: 40.9852955622935\n",
      "EPOCH: 18993 LOSS: 40.98529341518364\n",
      "EPOCH: 18994 LOSS: 40.98529126826704\n",
      "EPOCH: 18995 LOSS: 40.98528912154371\n",
      "EPOCH: 18996 LOSS: 40.98528697501359\n",
      "EPOCH: 18997 LOSS: 40.98528482867664\n",
      "EPOCH: 18998 LOSS: 40.985282682532876\n",
      "EPOCH: 18999 LOSS: 40.98528053658222\n",
      "EPOCH: 19000 LOSS: 40.985278390824675\n",
      "EPOCH: 19001 LOSS: 40.98527624526021\n",
      "EPOCH: 19002 LOSS: 40.985274099888784\n",
      "EPOCH: 19003 LOSS: 40.985271954710356\n",
      "EPOCH: 19004 LOSS: 40.98526980972494\n",
      "EPOCH: 19005 LOSS: 40.985267664932465\n",
      "EPOCH: 19006 LOSS: 40.98526552033292\n",
      "EPOCH: 19007 LOSS: 40.98526337592628\n",
      "EPOCH: 19008 LOSS: 40.985261231712514\n",
      "EPOCH: 19009 LOSS: 40.985259087691574\n",
      "EPOCH: 19010 LOSS: 40.985256943863476\n",
      "EPOCH: 19011 LOSS: 40.98525480022814\n",
      "EPOCH: 19012 LOSS: 40.985252656785576\n",
      "EPOCH: 19013 LOSS: 40.985250513535725\n",
      "EPOCH: 19014 LOSS: 40.98524837047859\n",
      "EPOCH: 19015 LOSS: 40.98524622761411\n",
      "EPOCH: 19016 LOSS: 40.985244084942295\n",
      "EPOCH: 19017 LOSS: 40.98524194246306\n",
      "EPOCH: 19018 LOSS: 40.98523980017643\n",
      "EPOCH: 19019 LOSS: 40.985237658082355\n",
      "EPOCH: 19020 LOSS: 40.98523551618081\n",
      "EPOCH: 19021 LOSS: 40.98523337447176\n",
      "EPOCH: 19022 LOSS: 40.985231232955186\n",
      "EPOCH: 19023 LOSS: 40.98522909163106\n",
      "EPOCH: 19024 LOSS: 40.985226950499325\n",
      "EPOCH: 19025 LOSS: 40.985224809559995\n",
      "EPOCH: 19026 LOSS: 40.985222668813016\n",
      "EPOCH: 19027 LOSS: 40.98522052825835\n",
      "EPOCH: 19028 LOSS: 40.98521838789599\n",
      "EPOCH: 19029 LOSS: 40.98521624772591\n",
      "EPOCH: 19030 LOSS: 40.985214107748064\n",
      "EPOCH: 19031 LOSS: 40.98521196796243\n",
      "EPOCH: 19032 LOSS: 40.985209828368966\n",
      "EPOCH: 19033 LOSS: 40.98520768896769\n",
      "EPOCH: 19034 LOSS: 40.98520554975852\n",
      "EPOCH: 19035 LOSS: 40.98520341074146\n",
      "EPOCH: 19036 LOSS: 40.985201271916466\n",
      "EPOCH: 19037 LOSS: 40.9851991332835\n",
      "EPOCH: 19038 LOSS: 40.98519699484256\n",
      "EPOCH: 19039 LOSS: 40.985194856593594\n",
      "EPOCH: 19040 LOSS: 40.985192718536595\n",
      "EPOCH: 19041 LOSS: 40.985190580671514\n",
      "EPOCH: 19042 LOSS: 40.98518844299835\n",
      "EPOCH: 19043 LOSS: 40.98518630551705\n",
      "EPOCH: 19044 LOSS: 40.98518416822758\n",
      "EPOCH: 19045 LOSS: 40.98518203112992\n",
      "EPOCH: 19046 LOSS: 40.98517989422406\n",
      "EPOCH: 19047 LOSS: 40.985177757509945\n",
      "EPOCH: 19048 LOSS: 40.98517562098756\n",
      "EPOCH: 19049 LOSS: 40.985173484656876\n",
      "EPOCH: 19050 LOSS: 40.98517134851787\n",
      "EPOCH: 19051 LOSS: 40.98516921257049\n",
      "EPOCH: 19052 LOSS: 40.98516707681473\n",
      "EPOCH: 19053 LOSS: 40.98516494125057\n",
      "EPOCH: 19054 LOSS: 40.98516280587796\n",
      "EPOCH: 19055 LOSS: 40.98516067069687\n",
      "EPOCH: 19056 LOSS: 40.98515853570729\n",
      "EPOCH: 19057 LOSS: 40.985156400909176\n",
      "EPOCH: 19058 LOSS: 40.9851542663025\n",
      "EPOCH: 19059 LOSS: 40.98515213188725\n",
      "EPOCH: 19060 LOSS: 40.98514999766336\n",
      "EPOCH: 19061 LOSS: 40.985147863630864\n",
      "EPOCH: 19062 LOSS: 40.98514572978968\n",
      "EPOCH: 19063 LOSS: 40.985143596139785\n",
      "EPOCH: 19064 LOSS: 40.98514146268118\n",
      "EPOCH: 19065 LOSS: 40.98513932941381\n",
      "EPOCH: 19066 LOSS: 40.985137196337654\n",
      "EPOCH: 19067 LOSS: 40.9851350634527\n",
      "EPOCH: 19068 LOSS: 40.98513293075889\n",
      "EPOCH: 19069 LOSS: 40.98513079825622\n",
      "EPOCH: 19070 LOSS: 40.98512866594465\n",
      "EPOCH: 19071 LOSS: 40.98512653382415\n",
      "EPOCH: 19072 LOSS: 40.985124401894694\n",
      "EPOCH: 19073 LOSS: 40.98512227015627\n",
      "EPOCH: 19074 LOSS: 40.98512013860882\n",
      "EPOCH: 19075 LOSS: 40.98511800725232\n",
      "EPOCH: 19076 LOSS: 40.98511587608678\n",
      "EPOCH: 19077 LOSS: 40.985113745112116\n",
      "EPOCH: 19078 LOSS: 40.985111614328346\n",
      "EPOCH: 19079 LOSS: 40.985109483735414\n",
      "EPOCH: 19080 LOSS: 40.9851073533333\n",
      "EPOCH: 19081 LOSS: 40.98510522312198\n",
      "EPOCH: 19082 LOSS: 40.98510309310143\n",
      "EPOCH: 19083 LOSS: 40.98510096327159\n",
      "EPOCH: 19084 LOSS: 40.98509883363248\n",
      "EPOCH: 19085 LOSS: 40.98509670418402\n",
      "EPOCH: 19086 LOSS: 40.98509457492624\n",
      "EPOCH: 19087 LOSS: 40.98509244585905\n",
      "EPOCH: 19088 LOSS: 40.98509031698248\n",
      "EPOCH: 19089 LOSS: 40.985088188296466\n",
      "EPOCH: 19090 LOSS: 40.98508605980098\n",
      "EPOCH: 19091 LOSS: 40.98508393149601\n",
      "EPOCH: 19092 LOSS: 40.985081803381505\n",
      "EPOCH: 19093 LOSS: 40.985079675457456\n",
      "EPOCH: 19094 LOSS: 40.98507754772382\n",
      "EPOCH: 19095 LOSS: 40.98507542018059\n",
      "EPOCH: 19096 LOSS: 40.98507329282773\n",
      "EPOCH: 19097 LOSS: 40.985071165665204\n",
      "EPOCH: 19098 LOSS: 40.985069038692984\n",
      "EPOCH: 19099 LOSS: 40.98506691191105\n",
      "EPOCH: 19100 LOSS: 40.985064785319366\n",
      "EPOCH: 19101 LOSS: 40.98506265891791\n",
      "EPOCH: 19102 LOSS: 40.98506053270664\n",
      "EPOCH: 19103 LOSS: 40.98505840668554\n",
      "EPOCH: 19104 LOSS: 40.98505628085459\n",
      "EPOCH: 19105 LOSS: 40.985054155213746\n",
      "EPOCH: 19106 LOSS: 40.98505202976299\n",
      "EPOCH: 19107 LOSS: 40.985049904502276\n",
      "EPOCH: 19108 LOSS: 40.985047779431596\n",
      "EPOCH: 19109 LOSS: 40.98504565455092\n",
      "EPOCH: 19110 LOSS: 40.985043529860214\n",
      "EPOCH: 19111 LOSS: 40.98504140535944\n",
      "EPOCH: 19112 LOSS: 40.98503928104861\n",
      "EPOCH: 19113 LOSS: 40.98503715692764\n",
      "EPOCH: 19114 LOSS: 40.985035032996535\n",
      "EPOCH: 19115 LOSS: 40.98503290925525\n",
      "EPOCH: 19116 LOSS: 40.985030785703785\n",
      "EPOCH: 19117 LOSS: 40.98502866234207\n",
      "EPOCH: 19118 LOSS: 40.98502653917012\n",
      "EPOCH: 19119 LOSS: 40.98502441618788\n",
      "EPOCH: 19120 LOSS: 40.98502229339533\n",
      "EPOCH: 19121 LOSS: 40.98502017079246\n",
      "EPOCH: 19122 LOSS: 40.985018048379196\n",
      "EPOCH: 19123 LOSS: 40.98501592615555\n",
      "EPOCH: 19124 LOSS: 40.98501380412146\n",
      "EPOCH: 19125 LOSS: 40.98501168227695\n",
      "EPOCH: 19126 LOSS: 40.98500956062195\n",
      "EPOCH: 19127 LOSS: 40.98500743915642\n",
      "EPOCH: 19128 LOSS: 40.985005317880365\n",
      "EPOCH: 19129 LOSS: 40.98500319679377\n",
      "EPOCH: 19130 LOSS: 40.98500107589655\n",
      "EPOCH: 19131 LOSS: 40.984998955188736\n",
      "EPOCH: 19132 LOSS: 40.984996834670255\n",
      "EPOCH: 19133 LOSS: 40.98499471434112\n",
      "EPOCH: 19134 LOSS: 40.984992594201266\n",
      "EPOCH: 19135 LOSS: 40.984990474250665\n",
      "EPOCH: 19136 LOSS: 40.98498835448933\n",
      "EPOCH: 19137 LOSS: 40.9849862349172\n",
      "EPOCH: 19138 LOSS: 40.98498411553426\n",
      "EPOCH: 19139 LOSS: 40.98498199634045\n",
      "EPOCH: 19140 LOSS: 40.98497987733579\n",
      "EPOCH: 19141 LOSS: 40.98497775852022\n",
      "EPOCH: 19142 LOSS: 40.98497563989373\n",
      "EPOCH: 19143 LOSS: 40.98497352145628\n",
      "EPOCH: 19144 LOSS: 40.984971403207844\n",
      "EPOCH: 19145 LOSS: 40.984969285148395\n",
      "EPOCH: 19146 LOSS: 40.9849671672779\n",
      "EPOCH: 19147 LOSS: 40.98496504959634\n",
      "EPOCH: 19148 LOSS: 40.984962932103684\n",
      "EPOCH: 19149 LOSS: 40.984960814799905\n",
      "EPOCH: 19150 LOSS: 40.984958697684974\n",
      "EPOCH: 19151 LOSS: 40.984956580758876\n",
      "EPOCH: 19152 LOSS: 40.98495446402154\n",
      "EPOCH: 19153 LOSS: 40.98495234747299\n",
      "EPOCH: 19154 LOSS: 40.98495023111316\n",
      "EPOCH: 19155 LOSS: 40.98494811494204\n",
      "EPOCH: 19156 LOSS: 40.9849459989596\n",
      "EPOCH: 19157 LOSS: 40.984943883165826\n",
      "EPOCH: 19158 LOSS: 40.98494176756068\n",
      "EPOCH: 19159 LOSS: 40.984939652144114\n",
      "EPOCH: 19160 LOSS: 40.98493753691612\n",
      "EPOCH: 19161 LOSS: 40.984935421876656\n",
      "EPOCH: 19162 LOSS: 40.98493330702572\n",
      "EPOCH: 19163 LOSS: 40.98493119236325\n",
      "EPOCH: 19164 LOSS: 40.98492907788925\n",
      "EPOCH: 19165 LOSS: 40.98492696360367\n",
      "EPOCH: 19166 LOSS: 40.9849248495065\n",
      "EPOCH: 19167 LOSS: 40.9849227355977\n",
      "EPOCH: 19168 LOSS: 40.98492062187724\n",
      "EPOCH: 19169 LOSS: 40.9849185083451\n",
      "EPOCH: 19170 LOSS: 40.98491639500125\n",
      "EPOCH: 19171 LOSS: 40.984914281845654\n",
      "EPOCH: 19172 LOSS: 40.98491216887829\n",
      "EPOCH: 19173 LOSS: 40.98491005609914\n",
      "EPOCH: 19174 LOSS: 40.98490794350816\n",
      "EPOCH: 19175 LOSS: 40.98490583110534\n",
      "EPOCH: 19176 LOSS: 40.984903718890635\n",
      "EPOCH: 19177 LOSS: 40.984901606864014\n",
      "EPOCH: 19178 LOSS: 40.98489949502548\n",
      "EPOCH: 19179 LOSS: 40.984897383374964\n",
      "EPOCH: 19180 LOSS: 40.98489527191247\n",
      "EPOCH: 19181 LOSS: 40.98489316063795\n",
      "EPOCH: 19182 LOSS: 40.98489104955141\n",
      "EPOCH: 19183 LOSS: 40.98488893865276\n",
      "EPOCH: 19184 LOSS: 40.98488682794203\n",
      "EPOCH: 19185 LOSS: 40.98488471741916\n",
      "EPOCH: 19186 LOSS: 40.98488260708413\n",
      "EPOCH: 19187 LOSS: 40.98488049693694\n",
      "EPOCH: 19188 LOSS: 40.98487838697753\n",
      "EPOCH: 19189 LOSS: 40.984876277205856\n",
      "EPOCH: 19190 LOSS: 40.984874167621925\n",
      "EPOCH: 19191 LOSS: 40.984872058225726\n",
      "EPOCH: 19192 LOSS: 40.984869949017174\n",
      "EPOCH: 19193 LOSS: 40.98486783999627\n",
      "EPOCH: 19194 LOSS: 40.984865731163\n",
      "EPOCH: 19195 LOSS: 40.984863622517324\n",
      "EPOCH: 19196 LOSS: 40.98486151405919\n",
      "EPOCH: 19197 LOSS: 40.984859405788626\n",
      "EPOCH: 19198 LOSS: 40.98485729770557\n",
      "EPOCH: 19199 LOSS: 40.98485518980998\n",
      "EPOCH: 19200 LOSS: 40.98485308210184\n",
      "EPOCH: 19201 LOSS: 40.984850974581136\n",
      "EPOCH: 19202 LOSS: 40.98484886724784\n",
      "EPOCH: 19203 LOSS: 40.984846760101895\n",
      "EPOCH: 19204 LOSS: 40.9848446531433\n",
      "EPOCH: 19205 LOSS: 40.984842546372036\n",
      "EPOCH: 19206 LOSS: 40.98484043978805\n",
      "EPOCH: 19207 LOSS: 40.98483833339132\n",
      "EPOCH: 19208 LOSS: 40.98483622718182\n",
      "EPOCH: 19209 LOSS: 40.98483412115953\n",
      "EPOCH: 19210 LOSS: 40.984832015324415\n",
      "EPOCH: 19211 LOSS: 40.98482990967646\n",
      "EPOCH: 19212 LOSS: 40.98482780421563\n",
      "EPOCH: 19213 LOSS: 40.98482569894187\n",
      "EPOCH: 19214 LOSS: 40.9848235938552\n",
      "EPOCH: 19215 LOSS: 40.984821488955546\n",
      "EPOCH: 19216 LOSS: 40.984819384242925\n",
      "EPOCH: 19217 LOSS: 40.984817279717284\n",
      "EPOCH: 19218 LOSS: 40.984815175378586\n",
      "EPOCH: 19219 LOSS: 40.98481307122683\n",
      "EPOCH: 19220 LOSS: 40.98481096726198\n",
      "EPOCH: 19221 LOSS: 40.98480886348398\n",
      "EPOCH: 19222 LOSS: 40.98480675989283\n",
      "EPOCH: 19223 LOSS: 40.98480465648852\n",
      "EPOCH: 19224 LOSS: 40.98480255327098\n",
      "EPOCH: 19225 LOSS: 40.984800450240215\n",
      "EPOCH: 19226 LOSS: 40.98479834739618\n",
      "EPOCH: 19227 LOSS: 40.98479624473886\n",
      "EPOCH: 19228 LOSS: 40.984794142268214\n",
      "EPOCH: 19229 LOSS: 40.98479203998421\n",
      "EPOCH: 19230 LOSS: 40.98478993788684\n",
      "EPOCH: 19231 LOSS: 40.984787835976064\n",
      "EPOCH: 19232 LOSS: 40.98478573425186\n",
      "EPOCH: 19233 LOSS: 40.9847836327142\n",
      "EPOCH: 19234 LOSS: 40.98478153136304\n",
      "EPOCH: 19235 LOSS: 40.98477943019839\n",
      "EPOCH: 19236 LOSS: 40.98477732922018\n",
      "EPOCH: 19237 LOSS: 40.98477522842842\n",
      "EPOCH: 19238 LOSS: 40.98477312782305\n",
      "EPOCH: 19239 LOSS: 40.984771027404065\n",
      "EPOCH: 19240 LOSS: 40.984768927171416\n",
      "EPOCH: 19241 LOSS: 40.9847668271251\n",
      "EPOCH: 19242 LOSS: 40.98476472726507\n",
      "EPOCH: 19243 LOSS: 40.98476262759131\n",
      "EPOCH: 19244 LOSS: 40.984760528103784\n",
      "EPOCH: 19245 LOSS: 40.98475842880248\n",
      "EPOCH: 19246 LOSS: 40.98475632968734\n",
      "EPOCH: 19247 LOSS: 40.984754230758384\n",
      "EPOCH: 19248 LOSS: 40.98475213201554\n",
      "EPOCH: 19249 LOSS: 40.9847500334588\n",
      "EPOCH: 19250 LOSS: 40.98474793508814\n",
      "EPOCH: 19251 LOSS: 40.984745836903514\n",
      "EPOCH: 19252 LOSS: 40.98474373890491\n",
      "EPOCH: 19253 LOSS: 40.9847416410923\n",
      "EPOCH: 19254 LOSS: 40.98473954346568\n",
      "EPOCH: 19255 LOSS: 40.984737446024965\n",
      "EPOCH: 19256 LOSS: 40.984735348770165\n",
      "EPOCH: 19257 LOSS: 40.98473325170124\n",
      "EPOCH: 19258 LOSS: 40.984731154818164\n",
      "EPOCH: 19259 LOSS: 40.984729058120934\n",
      "EPOCH: 19260 LOSS: 40.984726961609496\n",
      "EPOCH: 19261 LOSS: 40.98472486528382\n",
      "EPOCH: 19262 LOSS: 40.984722769143914\n",
      "EPOCH: 19263 LOSS: 40.9847206731897\n",
      "EPOCH: 19264 LOSS: 40.98471857742119\n",
      "EPOCH: 19265 LOSS: 40.98471648183832\n",
      "EPOCH: 19266 LOSS: 40.98471438644111\n",
      "EPOCH: 19267 LOSS: 40.984712291229506\n",
      "EPOCH: 19268 LOSS: 40.98471019620347\n",
      "EPOCH: 19269 LOSS: 40.984708101363\n",
      "EPOCH: 19270 LOSS: 40.984706006708045\n",
      "EPOCH: 19271 LOSS: 40.98470391223859\n",
      "EPOCH: 19272 LOSS: 40.98470181795459\n",
      "EPOCH: 19273 LOSS: 40.98469972385604\n",
      "EPOCH: 19274 LOSS: 40.984697629942914\n",
      "EPOCH: 19275 LOSS: 40.98469553621518\n",
      "EPOCH: 19276 LOSS: 40.98469344267278\n",
      "EPOCH: 19277 LOSS: 40.98469134931575\n",
      "EPOCH: 19278 LOSS: 40.98468925614401\n",
      "EPOCH: 19279 LOSS: 40.98468716315756\n",
      "EPOCH: 19280 LOSS: 40.98468507035632\n",
      "EPOCH: 19281 LOSS: 40.98468297774035\n",
      "EPOCH: 19282 LOSS: 40.98468088530956\n",
      "EPOCH: 19283 LOSS: 40.98467879306393\n",
      "EPOCH: 19284 LOSS: 40.98467670100345\n",
      "EPOCH: 19285 LOSS: 40.98467460912809\n",
      "EPOCH: 19286 LOSS: 40.984672517437815\n",
      "EPOCH: 19287 LOSS: 40.98467042593259\n",
      "EPOCH: 19288 LOSS: 40.98466833461241\n",
      "EPOCH: 19289 LOSS: 40.984666243477236\n",
      "EPOCH: 19290 LOSS: 40.98466415252703\n",
      "EPOCH: 19291 LOSS: 40.98466206176178\n",
      "EPOCH: 19292 LOSS: 40.98465997118146\n",
      "EPOCH: 19293 LOSS: 40.98465788078603\n",
      "EPOCH: 19294 LOSS: 40.98465579057546\n",
      "EPOCH: 19295 LOSS: 40.98465370054976\n",
      "EPOCH: 19296 LOSS: 40.98465161070884\n",
      "EPOCH: 19297 LOSS: 40.98464952105272\n",
      "EPOCH: 19298 LOSS: 40.98464743158136\n",
      "EPOCH: 19299 LOSS: 40.984645342294726\n",
      "EPOCH: 19300 LOSS: 40.984643253192814\n",
      "EPOCH: 19301 LOSS: 40.984641164275565\n",
      "EPOCH: 19302 LOSS: 40.98463907554299\n",
      "EPOCH: 19303 LOSS: 40.98463698699501\n",
      "EPOCH: 19304 LOSS: 40.98463489863164\n",
      "EPOCH: 19305 LOSS: 40.98463281045284\n",
      "EPOCH: 19306 LOSS: 40.984630722458576\n",
      "EPOCH: 19307 LOSS: 40.98462863464883\n",
      "EPOCH: 19308 LOSS: 40.98462654702358\n",
      "EPOCH: 19309 LOSS: 40.98462445958276\n",
      "EPOCH: 19310 LOSS: 40.984622372326406\n",
      "EPOCH: 19311 LOSS: 40.984620285254444\n",
      "EPOCH: 19312 LOSS: 40.98461819836687\n",
      "EPOCH: 19313 LOSS: 40.98461611166364\n",
      "EPOCH: 19314 LOSS: 40.98461402514472\n",
      "EPOCH: 19315 LOSS: 40.984611938810126\n",
      "EPOCH: 19316 LOSS: 40.984609852659794\n",
      "EPOCH: 19317 LOSS: 40.984607766693685\n",
      "EPOCH: 19318 LOSS: 40.98460568091183\n",
      "EPOCH: 19319 LOSS: 40.98460359531412\n",
      "EPOCH: 19320 LOSS: 40.9846015099006\n",
      "EPOCH: 19321 LOSS: 40.98459942467121\n",
      "EPOCH: 19322 LOSS: 40.98459733962591\n",
      "EPOCH: 19323 LOSS: 40.98459525476471\n",
      "EPOCH: 19324 LOSS: 40.98459317008755\n",
      "EPOCH: 19325 LOSS: 40.98459108559442\n",
      "EPOCH: 19326 LOSS: 40.98458900128529\n",
      "EPOCH: 19327 LOSS: 40.98458691716013\n",
      "EPOCH: 19328 LOSS: 40.98458483321892\n",
      "EPOCH: 19329 LOSS: 40.98458274946162\n",
      "EPOCH: 19330 LOSS: 40.98458066588822\n",
      "EPOCH: 19331 LOSS: 40.984578582498656\n",
      "EPOCH: 19332 LOSS: 40.984576499292956\n",
      "EPOCH: 19333 LOSS: 40.984574416271066\n",
      "EPOCH: 19334 LOSS: 40.984572333432936\n",
      "EPOCH: 19335 LOSS: 40.98457025077858\n",
      "EPOCH: 19336 LOSS: 40.984568168307945\n",
      "EPOCH: 19337 LOSS: 40.984566086021005\n",
      "EPOCH: 19338 LOSS: 40.984564003917754\n",
      "EPOCH: 19339 LOSS: 40.98456192199812\n",
      "EPOCH: 19340 LOSS: 40.98455984026212\n",
      "EPOCH: 19341 LOSS: 40.98455775870973\n",
      "EPOCH: 19342 LOSS: 40.98455567734088\n",
      "EPOCH: 19343 LOSS: 40.98455359615559\n",
      "EPOCH: 19344 LOSS: 40.9845515151538\n",
      "EPOCH: 19345 LOSS: 40.98454943433549\n",
      "EPOCH: 19346 LOSS: 40.98454735370064\n",
      "EPOCH: 19347 LOSS: 40.984545273249225\n",
      "EPOCH: 19348 LOSS: 40.98454319298119\n",
      "EPOCH: 19349 LOSS: 40.98454111289657\n",
      "EPOCH: 19350 LOSS: 40.98453903299528\n",
      "EPOCH: 19351 LOSS: 40.984536953277306\n",
      "EPOCH: 19352 LOSS: 40.98453487374263\n",
      "EPOCH: 19353 LOSS: 40.984532794391214\n",
      "EPOCH: 19354 LOSS: 40.98453071522306\n",
      "EPOCH: 19355 LOSS: 40.984528636238096\n",
      "EPOCH: 19356 LOSS: 40.98452655743634\n",
      "EPOCH: 19357 LOSS: 40.98452447881774\n",
      "EPOCH: 19358 LOSS: 40.98452240038226\n",
      "EPOCH: 19359 LOSS: 40.984520322129896\n",
      "EPOCH: 19360 LOSS: 40.98451824406062\n",
      "EPOCH: 19361 LOSS: 40.98451616617439\n",
      "EPOCH: 19362 LOSS: 40.98451408847116\n",
      "EPOCH: 19363 LOSS: 40.98451201095096\n",
      "EPOCH: 19364 LOSS: 40.98450993361372\n",
      "EPOCH: 19365 LOSS: 40.98450785645944\n",
      "EPOCH: 19366 LOSS: 40.984505779488046\n",
      "EPOCH: 19367 LOSS: 40.98450370269957\n",
      "EPOCH: 19368 LOSS: 40.98450162609395\n",
      "EPOCH: 19369 LOSS: 40.984499549671156\n",
      "EPOCH: 19370 LOSS: 40.984497473431176\n",
      "EPOCH: 19371 LOSS: 40.98449539737399\n",
      "EPOCH: 19372 LOSS: 40.98449332149954\n",
      "EPOCH: 19373 LOSS: 40.98449124580784\n",
      "EPOCH: 19374 LOSS: 40.98448917029883\n",
      "EPOCH: 19375 LOSS: 40.98448709497249\n",
      "EPOCH: 19376 LOSS: 40.98448501982882\n",
      "EPOCH: 19377 LOSS: 40.98448294486776\n",
      "EPOCH: 19378 LOSS: 40.98448087008929\n",
      "EPOCH: 19379 LOSS: 40.98447879549339\n",
      "EPOCH: 19380 LOSS: 40.98447672108003\n",
      "EPOCH: 19381 LOSS: 40.98447464684919\n",
      "EPOCH: 19382 LOSS: 40.98447257280084\n",
      "EPOCH: 19383 LOSS: 40.98447049893493\n",
      "EPOCH: 19384 LOSS: 40.984468425251464\n",
      "EPOCH: 19385 LOSS: 40.98446635175041\n",
      "EPOCH: 19386 LOSS: 40.984464278431744\n",
      "EPOCH: 19387 LOSS: 40.98446220529541\n",
      "EPOCH: 19388 LOSS: 40.98446013234141\n",
      "EPOCH: 19389 LOSS: 40.98445805956972\n",
      "EPOCH: 19390 LOSS: 40.984455986980294\n",
      "EPOCH: 19391 LOSS: 40.98445391457312\n",
      "EPOCH: 19392 LOSS: 40.98445184234815\n",
      "EPOCH: 19393 LOSS: 40.98444977030539\n",
      "EPOCH: 19394 LOSS: 40.984447698444775\n",
      "EPOCH: 19395 LOSS: 40.9844456267663\n",
      "EPOCH: 19396 LOSS: 40.98444355526995\n",
      "EPOCH: 19397 LOSS: 40.98444148395568\n",
      "EPOCH: 19398 LOSS: 40.98443941282346\n",
      "EPOCH: 19399 LOSS: 40.98443734187329\n",
      "EPOCH: 19400 LOSS: 40.98443527110511\n",
      "EPOCH: 19401 LOSS: 40.98443320051892\n",
      "EPOCH: 19402 LOSS: 40.98443113011467\n",
      "EPOCH: 19403 LOSS: 40.984429059892356\n",
      "EPOCH: 19404 LOSS: 40.98442698985193\n",
      "EPOCH: 19405 LOSS: 40.98442491999336\n",
      "EPOCH: 19406 LOSS: 40.98442285031666\n",
      "EPOCH: 19407 LOSS: 40.98442078082177\n",
      "EPOCH: 19408 LOSS: 40.98441871150867\n",
      "EPOCH: 19409 LOSS: 40.984416642377326\n",
      "EPOCH: 19410 LOSS: 40.98441457342771\n",
      "EPOCH: 19411 LOSS: 40.984412504659836\n",
      "EPOCH: 19412 LOSS: 40.98441043607363\n",
      "EPOCH: 19413 LOSS: 40.98440836766908\n",
      "EPOCH: 19414 LOSS: 40.98440629944616\n",
      "EPOCH: 19415 LOSS: 40.98440423140485\n",
      "EPOCH: 19416 LOSS: 40.9844021635451\n",
      "EPOCH: 19417 LOSS: 40.98440009586691\n",
      "EPOCH: 19418 LOSS: 40.98439802837025\n",
      "EPOCH: 19419 LOSS: 40.98439596105508\n",
      "EPOCH: 19420 LOSS: 40.98439389392138\n",
      "EPOCH: 19421 LOSS: 40.984391826969116\n",
      "EPOCH: 19422 LOSS: 40.98438976019828\n",
      "EPOCH: 19423 LOSS: 40.98438769360884\n",
      "EPOCH: 19424 LOSS: 40.98438562720074\n",
      "EPOCH: 19425 LOSS: 40.98438356097399\n",
      "EPOCH: 19426 LOSS: 40.984381494928556\n",
      "EPOCH: 19427 LOSS: 40.984379429064404\n",
      "EPOCH: 19428 LOSS: 40.9843773633815\n",
      "EPOCH: 19429 LOSS: 40.984375297879836\n",
      "EPOCH: 19430 LOSS: 40.98437323255938\n",
      "EPOCH: 19431 LOSS: 40.984371167420086\n",
      "EPOCH: 19432 LOSS: 40.98436910246195\n",
      "EPOCH: 19433 LOSS: 40.98436703768493\n",
      "EPOCH: 19434 LOSS: 40.984364973089015\n",
      "EPOCH: 19435 LOSS: 40.984362908674164\n",
      "EPOCH: 19436 LOSS: 40.98436084444038\n",
      "EPOCH: 19437 LOSS: 40.98435878038759\n",
      "EPOCH: 19438 LOSS: 40.98435671651579\n",
      "EPOCH: 19439 LOSS: 40.984354652824955\n",
      "EPOCH: 19440 LOSS: 40.98435258931506\n",
      "EPOCH: 19441 LOSS: 40.98435052598608\n",
      "EPOCH: 19442 LOSS: 40.984348462837985\n",
      "EPOCH: 19443 LOSS: 40.98434639987075\n",
      "EPOCH: 19444 LOSS: 40.98434433708434\n",
      "EPOCH: 19445 LOSS: 40.984342274478756\n",
      "EPOCH: 19446 LOSS: 40.9843402120539\n",
      "EPOCH: 19447 LOSS: 40.98433814980984\n",
      "EPOCH: 19448 LOSS: 40.984336087746485\n",
      "EPOCH: 19449 LOSS: 40.984334025863845\n",
      "EPOCH: 19450 LOSS: 40.98433196416187\n",
      "EPOCH: 19451 LOSS: 40.98432990264052\n",
      "EPOCH: 19452 LOSS: 40.984327841299816\n",
      "EPOCH: 19453 LOSS: 40.98432578013969\n",
      "EPOCH: 19454 LOSS: 40.984323719160145\n",
      "EPOCH: 19455 LOSS: 40.984321658361125\n",
      "EPOCH: 19456 LOSS: 40.98431959774261\n",
      "EPOCH: 19457 LOSS: 40.984317537304605\n",
      "EPOCH: 19458 LOSS: 40.98431547704705\n",
      "EPOCH: 19459 LOSS: 40.984313416969925\n",
      "EPOCH: 19460 LOSS: 40.98431135707321\n",
      "EPOCH: 19461 LOSS: 40.98430929735687\n",
      "EPOCH: 19462 LOSS: 40.98430723782087\n",
      "EPOCH: 19463 LOSS: 40.984305178465235\n",
      "EPOCH: 19464 LOSS: 40.984303119289876\n",
      "EPOCH: 19465 LOSS: 40.984301060294804\n",
      "EPOCH: 19466 LOSS: 40.98429900147997\n",
      "EPOCH: 19467 LOSS: 40.98429694284536\n",
      "EPOCH: 19468 LOSS: 40.984294884390934\n",
      "EPOCH: 19469 LOSS: 40.984292826116686\n",
      "EPOCH: 19470 LOSS: 40.98429076802259\n",
      "EPOCH: 19471 LOSS: 40.9842887101086\n",
      "EPOCH: 19472 LOSS: 40.984286652374706\n",
      "EPOCH: 19473 LOSS: 40.98428459482088\n",
      "EPOCH: 19474 LOSS: 40.984282537447065\n",
      "EPOCH: 19475 LOSS: 40.984280480253275\n",
      "EPOCH: 19476 LOSS: 40.98427842323947\n",
      "EPOCH: 19477 LOSS: 40.984276366405616\n",
      "EPOCH: 19478 LOSS: 40.98427430975171\n",
      "EPOCH: 19479 LOSS: 40.984272253277695\n",
      "EPOCH: 19480 LOSS: 40.98427019698355\n",
      "EPOCH: 19481 LOSS: 40.984268140869275\n",
      "EPOCH: 19482 LOSS: 40.98426608493481\n",
      "EPOCH: 19483 LOSS: 40.98426402918017\n",
      "EPOCH: 19484 LOSS: 40.98426197360528\n",
      "EPOCH: 19485 LOSS: 40.98425991821014\n",
      "EPOCH: 19486 LOSS: 40.98425786299471\n",
      "EPOCH: 19487 LOSS: 40.984255807958974\n",
      "EPOCH: 19488 LOSS: 40.98425375310292\n",
      "EPOCH: 19489 LOSS: 40.984251698426505\n",
      "EPOCH: 19490 LOSS: 40.98424964392969\n",
      "EPOCH: 19491 LOSS: 40.98424758961249\n",
      "EPOCH: 19492 LOSS: 40.98424553547483\n",
      "EPOCH: 19493 LOSS: 40.984243481516714\n",
      "EPOCH: 19494 LOSS: 40.9842414277381\n",
      "EPOCH: 19495 LOSS: 40.98423937413897\n",
      "EPOCH: 19496 LOSS: 40.98423732071931\n",
      "EPOCH: 19497 LOSS: 40.984235267479065\n",
      "EPOCH: 19498 LOSS: 40.98423321441822\n",
      "EPOCH: 19499 LOSS: 40.98423116153676\n",
      "EPOCH: 19500 LOSS: 40.98422910883464\n",
      "EPOCH: 19501 LOSS: 40.98422705631186\n",
      "EPOCH: 19502 LOSS: 40.984225003968376\n",
      "EPOCH: 19503 LOSS: 40.98422295180418\n",
      "EPOCH: 19504 LOSS: 40.984220899819206\n",
      "EPOCH: 19505 LOSS: 40.984218848013455\n",
      "EPOCH: 19506 LOSS: 40.98421679638689\n",
      "EPOCH: 19507 LOSS: 40.984214744939514\n",
      "EPOCH: 19508 LOSS: 40.98421269367127\n",
      "EPOCH: 19509 LOSS: 40.984210642582134\n",
      "EPOCH: 19510 LOSS: 40.9842085916721\n",
      "EPOCH: 19511 LOSS: 40.9842065409411\n",
      "EPOCH: 19512 LOSS: 40.98420449038915\n",
      "EPOCH: 19513 LOSS: 40.98420244001622\n",
      "EPOCH: 19514 LOSS: 40.984200389822256\n",
      "EPOCH: 19515 LOSS: 40.98419833980727\n",
      "EPOCH: 19516 LOSS: 40.984196289971216\n",
      "EPOCH: 19517 LOSS: 40.984194240314054\n",
      "EPOCH: 19518 LOSS: 40.984192190835785\n",
      "EPOCH: 19519 LOSS: 40.984190141536345\n",
      "EPOCH: 19520 LOSS: 40.98418809241575\n",
      "EPOCH: 19521 LOSS: 40.98418604347393\n",
      "EPOCH: 19522 LOSS: 40.98418399471091\n",
      "EPOCH: 19523 LOSS: 40.984181946126625\n",
      "EPOCH: 19524 LOSS: 40.98417989772106\n",
      "EPOCH: 19525 LOSS: 40.9841778494942\n",
      "EPOCH: 19526 LOSS: 40.984175801446\n",
      "EPOCH: 19527 LOSS: 40.98417375357646\n",
      "EPOCH: 19528 LOSS: 40.98417170588552\n",
      "EPOCH: 19529 LOSS: 40.98416965837317\n",
      "EPOCH: 19530 LOSS: 40.984167611039396\n",
      "EPOCH: 19531 LOSS: 40.98416556388415\n",
      "EPOCH: 19532 LOSS: 40.984163516907415\n",
      "EPOCH: 19533 LOSS: 40.984161470109164\n",
      "EPOCH: 19534 LOSS: 40.98415942348938\n",
      "EPOCH: 19535 LOSS: 40.984157377048014\n",
      "EPOCH: 19536 LOSS: 40.98415533078509\n",
      "EPOCH: 19537 LOSS: 40.98415328470051\n",
      "EPOCH: 19538 LOSS: 40.98415123879431\n",
      "EPOCH: 19539 LOSS: 40.98414919306642\n",
      "EPOCH: 19540 LOSS: 40.98414714751684\n",
      "EPOCH: 19541 LOSS: 40.98414510214555\n",
      "EPOCH: 19542 LOSS: 40.98414305695249\n",
      "EPOCH: 19543 LOSS: 40.984141011937666\n",
      "EPOCH: 19544 LOSS: 40.98413896710104\n",
      "EPOCH: 19545 LOSS: 40.98413692244259\n",
      "EPOCH: 19546 LOSS: 40.98413487796228\n",
      "EPOCH: 19547 LOSS: 40.9841328336601\n",
      "EPOCH: 19548 LOSS: 40.984130789536\n",
      "EPOCH: 19549 LOSS: 40.98412874558997\n",
      "EPOCH: 19550 LOSS: 40.984126701821985\n",
      "EPOCH: 19551 LOSS: 40.98412465823202\n",
      "EPOCH: 19552 LOSS: 40.98412261482004\n",
      "EPOCH: 19553 LOSS: 40.98412057158603\n",
      "EPOCH: 19554 LOSS: 40.98411852852994\n",
      "EPOCH: 19555 LOSS: 40.98411648565179\n",
      "EPOCH: 19556 LOSS: 40.984114442951515\n",
      "EPOCH: 19557 LOSS: 40.98411240042907\n",
      "EPOCH: 19558 LOSS: 40.98411035808449\n",
      "EPOCH: 19559 LOSS: 40.98410831591771\n",
      "EPOCH: 19560 LOSS: 40.98410627392873\n",
      "EPOCH: 19561 LOSS: 40.984104232117474\n",
      "EPOCH: 19562 LOSS: 40.98410219048397\n",
      "EPOCH: 19563 LOSS: 40.98410014902815\n",
      "EPOCH: 19564 LOSS: 40.98409810775003\n",
      "EPOCH: 19565 LOSS: 40.98409606664953\n",
      "EPOCH: 19566 LOSS: 40.984094025726684\n",
      "EPOCH: 19567 LOSS: 40.98409198498143\n",
      "EPOCH: 19568 LOSS: 40.98408994441376\n",
      "EPOCH: 19569 LOSS: 40.98408790402362\n",
      "EPOCH: 19570 LOSS: 40.984085863811\n",
      "EPOCH: 19571 LOSS: 40.98408382377589\n",
      "EPOCH: 19572 LOSS: 40.98408178391823\n",
      "EPOCH: 19573 LOSS: 40.984079744238045\n",
      "EPOCH: 19574 LOSS: 40.98407770473524\n",
      "EPOCH: 19575 LOSS: 40.98407566540986\n",
      "EPOCH: 19576 LOSS: 40.98407362626183\n",
      "EPOCH: 19577 LOSS: 40.98407158729113\n",
      "EPOCH: 19578 LOSS: 40.98406954849776\n",
      "EPOCH: 19579 LOSS: 40.98406750988167\n",
      "EPOCH: 19580 LOSS: 40.98406547144284\n",
      "EPOCH: 19581 LOSS: 40.98406343318126\n",
      "EPOCH: 19582 LOSS: 40.98406139509687\n",
      "EPOCH: 19583 LOSS: 40.98405935718969\n",
      "EPOCH: 19584 LOSS: 40.98405731945965\n",
      "EPOCH: 19585 LOSS: 40.98405528190675\n",
      "EPOCH: 19586 LOSS: 40.984053244530955\n",
      "EPOCH: 19587 LOSS: 40.98405120733223\n",
      "EPOCH: 19588 LOSS: 40.98404917031057\n",
      "EPOCH: 19589 LOSS: 40.984047133465936\n",
      "EPOCH: 19590 LOSS: 40.98404509679831\n",
      "EPOCH: 19591 LOSS: 40.98404306030765\n",
      "EPOCH: 19592 LOSS: 40.98404102399396\n",
      "EPOCH: 19593 LOSS: 40.984038987857176\n",
      "EPOCH: 19594 LOSS: 40.984036951897295\n",
      "EPOCH: 19595 LOSS: 40.98403491611429\n",
      "EPOCH: 19596 LOSS: 40.98403288050813\n",
      "EPOCH: 19597 LOSS: 40.98403084507879\n",
      "EPOCH: 19598 LOSS: 40.984028809826256\n",
      "EPOCH: 19599 LOSS: 40.984026774750475\n",
      "EPOCH: 19600 LOSS: 40.98402473985146\n",
      "EPOCH: 19601 LOSS: 40.98402270512916\n",
      "EPOCH: 19602 LOSS: 40.98402067058355\n",
      "EPOCH: 19603 LOSS: 40.9840186362146\n",
      "EPOCH: 19604 LOSS: 40.984016602022294\n",
      "EPOCH: 19605 LOSS: 40.984014568006614\n",
      "EPOCH: 19606 LOSS: 40.984012534167505\n",
      "EPOCH: 19607 LOSS: 40.98401050050498\n",
      "EPOCH: 19608 LOSS: 40.984008467018974\n",
      "EPOCH: 19609 LOSS: 40.98400643370948\n",
      "EPOCH: 19610 LOSS: 40.98400440057648\n",
      "EPOCH: 19611 LOSS: 40.984002367619944\n",
      "EPOCH: 19612 LOSS: 40.984000334839834\n",
      "EPOCH: 19613 LOSS: 40.98399830223613\n",
      "EPOCH: 19614 LOSS: 40.98399626980881\n",
      "EPOCH: 19615 LOSS: 40.983994237557866\n",
      "EPOCH: 19616 LOSS: 40.983992205483254\n",
      "EPOCH: 19617 LOSS: 40.983990173584914\n",
      "EPOCH: 19618 LOSS: 40.98398814186288\n",
      "EPOCH: 19619 LOSS: 40.98398611031709\n",
      "EPOCH: 19620 LOSS: 40.983984078947536\n",
      "EPOCH: 19621 LOSS: 40.983982047754175\n",
      "EPOCH: 19622 LOSS: 40.983980016737\n",
      "EPOCH: 19623 LOSS: 40.983977985895976\n",
      "EPOCH: 19624 LOSS: 40.98397595523109\n",
      "EPOCH: 19625 LOSS: 40.98397392474226\n",
      "EPOCH: 19626 LOSS: 40.98397189442953\n",
      "EPOCH: 19627 LOSS: 40.98396986429287\n",
      "EPOCH: 19628 LOSS: 40.98396783433222\n",
      "EPOCH: 19629 LOSS: 40.98396580454755\n",
      "EPOCH: 19630 LOSS: 40.98396377493887\n",
      "EPOCH: 19631 LOSS: 40.98396174550612\n",
      "EPOCH: 19632 LOSS: 40.98395971624929\n",
      "EPOCH: 19633 LOSS: 40.98395768716836\n",
      "EPOCH: 19634 LOSS: 40.98395565826331\n",
      "EPOCH: 19635 LOSS: 40.98395362953408\n",
      "EPOCH: 19636 LOSS: 40.983951600980674\n",
      "EPOCH: 19637 LOSS: 40.98394957260308\n",
      "EPOCH: 19638 LOSS: 40.98394754440124\n",
      "EPOCH: 19639 LOSS: 40.98394551637513\n",
      "EPOCH: 19640 LOSS: 40.983943488524744\n",
      "EPOCH: 19641 LOSS: 40.98394146085003\n",
      "EPOCH: 19642 LOSS: 40.983939433351004\n",
      "EPOCH: 19643 LOSS: 40.98393740602761\n",
      "EPOCH: 19644 LOSS: 40.983935378879806\n",
      "EPOCH: 19645 LOSS: 40.98393335190762\n",
      "EPOCH: 19646 LOSS: 40.983931325110966\n",
      "EPOCH: 19647 LOSS: 40.983929298489876\n",
      "EPOCH: 19648 LOSS: 40.98392727204427\n",
      "EPOCH: 19649 LOSS: 40.983925245774174\n",
      "EPOCH: 19650 LOSS: 40.9839232196795\n",
      "EPOCH: 19651 LOSS: 40.98392119376028\n",
      "EPOCH: 19652 LOSS: 40.98391916801647\n",
      "EPOCH: 19653 LOSS: 40.98391714244803\n",
      "EPOCH: 19654 LOSS: 40.98391511705495\n",
      "EPOCH: 19655 LOSS: 40.98391309183721\n",
      "EPOCH: 19656 LOSS: 40.98391106679477\n",
      "EPOCH: 19657 LOSS: 40.9839090419276\n",
      "EPOCH: 19658 LOSS: 40.98390701723569\n",
      "EPOCH: 19659 LOSS: 40.983904992719005\n",
      "EPOCH: 19660 LOSS: 40.98390296837752\n",
      "EPOCH: 19661 LOSS: 40.983900944211214\n",
      "EPOCH: 19662 LOSS: 40.98389892022007\n",
      "EPOCH: 19663 LOSS: 40.98389689640403\n",
      "EPOCH: 19664 LOSS: 40.98389487276311\n",
      "EPOCH: 19665 LOSS: 40.98389284929725\n",
      "EPOCH: 19666 LOSS: 40.98389082600644\n",
      "EPOCH: 19667 LOSS: 40.98388880289066\n",
      "EPOCH: 19668 LOSS: 40.98388677994987\n",
      "EPOCH: 19669 LOSS: 40.983884757184065\n",
      "EPOCH: 19670 LOSS: 40.983882734593195\n",
      "EPOCH: 19671 LOSS: 40.98388071217725\n",
      "EPOCH: 19672 LOSS: 40.98387868993621\n",
      "EPOCH: 19673 LOSS: 40.983876667870035\n",
      "EPOCH: 19674 LOSS: 40.98387464597867\n",
      "EPOCH: 19675 LOSS: 40.983872624262176\n",
      "EPOCH: 19676 LOSS: 40.98387060272046\n",
      "EPOCH: 19677 LOSS: 40.983868581353505\n",
      "EPOCH: 19678 LOSS: 40.9838665601613\n",
      "EPOCH: 19679 LOSS: 40.983864539143795\n",
      "EPOCH: 19680 LOSS: 40.98386251830099\n",
      "EPOCH: 19681 LOSS: 40.98386049763286\n",
      "EPOCH: 19682 LOSS: 40.983858477139385\n",
      "EPOCH: 19683 LOSS: 40.983856456820504\n",
      "EPOCH: 19684 LOSS: 40.98385443667622\n",
      "EPOCH: 19685 LOSS: 40.98385241670648\n",
      "EPOCH: 19686 LOSS: 40.983850396911315\n",
      "EPOCH: 19687 LOSS: 40.983848377290634\n",
      "EPOCH: 19688 LOSS: 40.98384635784445\n",
      "EPOCH: 19689 LOSS: 40.98384433857272\n",
      "EPOCH: 19690 LOSS: 40.98384231947544\n",
      "EPOCH: 19691 LOSS: 40.983840300552565\n",
      "EPOCH: 19692 LOSS: 40.9838382818041\n",
      "EPOCH: 19693 LOSS: 40.983836263229975\n",
      "EPOCH: 19694 LOSS: 40.98383424483018\n",
      "EPOCH: 19695 LOSS: 40.983832226604704\n",
      "EPOCH: 19696 LOSS: 40.98383020855351\n",
      "EPOCH: 19697 LOSS: 40.98382819067659\n",
      "EPOCH: 19698 LOSS: 40.98382617297387\n",
      "EPOCH: 19699 LOSS: 40.98382415544538\n",
      "EPOCH: 19700 LOSS: 40.98382213809107\n",
      "EPOCH: 19701 LOSS: 40.98382012091091\n",
      "EPOCH: 19702 LOSS: 40.98381810390491\n",
      "EPOCH: 19703 LOSS: 40.983816087072995\n",
      "EPOCH: 19704 LOSS: 40.983814070415164\n",
      "EPOCH: 19705 LOSS: 40.98381205393139\n",
      "EPOCH: 19706 LOSS: 40.983810037621645\n",
      "EPOCH: 19707 LOSS: 40.98380802148591\n",
      "EPOCH: 19708 LOSS: 40.98380600552416\n",
      "EPOCH: 19709 LOSS: 40.983803989736344\n",
      "EPOCH: 19710 LOSS: 40.983801974122485\n",
      "EPOCH: 19711 LOSS: 40.98379995868251\n",
      "EPOCH: 19712 LOSS: 40.98379794341643\n",
      "EPOCH: 19713 LOSS: 40.9837959283242\n",
      "EPOCH: 19714 LOSS: 40.983793913405776\n",
      "EPOCH: 19715 LOSS: 40.98379189866118\n",
      "EPOCH: 19716 LOSS: 40.983789884090356\n",
      "EPOCH: 19717 LOSS: 40.98378786969327\n",
      "EPOCH: 19718 LOSS: 40.98378585546993\n",
      "EPOCH: 19719 LOSS: 40.98378384142029\n",
      "EPOCH: 19720 LOSS: 40.98378182754431\n",
      "EPOCH: 19721 LOSS: 40.983779813842\n",
      "EPOCH: 19722 LOSS: 40.98377780031329\n",
      "EPOCH: 19723 LOSS: 40.983775786958205\n",
      "EPOCH: 19724 LOSS: 40.983773773776704\n",
      "EPOCH: 19725 LOSS: 40.98377176076872\n",
      "EPOCH: 19726 LOSS: 40.98376974793429\n",
      "EPOCH: 19727 LOSS: 40.98376773527335\n",
      "EPOCH: 19728 LOSS: 40.98376572278587\n",
      "EPOCH: 19729 LOSS: 40.98376371047185\n",
      "EPOCH: 19730 LOSS: 40.983761698331264\n",
      "EPOCH: 19731 LOSS: 40.98375968636405\n",
      "EPOCH: 19732 LOSS: 40.98375767457023\n",
      "EPOCH: 19733 LOSS: 40.98375566294975\n",
      "EPOCH: 19734 LOSS: 40.983753651502596\n",
      "EPOCH: 19735 LOSS: 40.983751640228746\n",
      "EPOCH: 19736 LOSS: 40.98374962912816\n",
      "EPOCH: 19737 LOSS: 40.98374761820083\n",
      "EPOCH: 19738 LOSS: 40.9837456074467\n",
      "EPOCH: 19739 LOSS: 40.98374359686579\n",
      "EPOCH: 19740 LOSS: 40.98374158645803\n",
      "EPOCH: 19741 LOSS: 40.98373957622343\n",
      "EPOCH: 19742 LOSS: 40.98373756616195\n",
      "EPOCH: 19743 LOSS: 40.98373555627356\n",
      "EPOCH: 19744 LOSS: 40.98373354655825\n",
      "EPOCH: 19745 LOSS: 40.983731537015984\n",
      "EPOCH: 19746 LOSS: 40.98372952764674\n",
      "EPOCH: 19747 LOSS: 40.98372751845048\n",
      "EPOCH: 19748 LOSS: 40.98372550942719\n",
      "EPOCH: 19749 LOSS: 40.98372350057684\n",
      "EPOCH: 19750 LOSS: 40.98372149189942\n",
      "EPOCH: 19751 LOSS: 40.98371948339491\n",
      "EPOCH: 19752 LOSS: 40.98371747506326\n",
      "EPOCH: 19753 LOSS: 40.98371546690443\n",
      "EPOCH: 19754 LOSS: 40.98371345891844\n",
      "EPOCH: 19755 LOSS: 40.983711451105236\n",
      "EPOCH: 19756 LOSS: 40.98370944346481\n",
      "EPOCH: 19757 LOSS: 40.98370743599711\n",
      "EPOCH: 19758 LOSS: 40.983705428702145\n",
      "EPOCH: 19759 LOSS: 40.983703421579854\n",
      "EPOCH: 19760 LOSS: 40.98370141463026\n",
      "EPOCH: 19761 LOSS: 40.983699407853294\n",
      "EPOCH: 19762 LOSS: 40.983697401248946\n",
      "EPOCH: 19763 LOSS: 40.98369539481719\n",
      "EPOCH: 19764 LOSS: 40.983693388557995\n",
      "EPOCH: 19765 LOSS: 40.98369138247135\n",
      "EPOCH: 19766 LOSS: 40.98368937655722\n",
      "EPOCH: 19767 LOSS: 40.98368737081559\n",
      "EPOCH: 19768 LOSS: 40.983685365246416\n",
      "EPOCH: 19769 LOSS: 40.98368335984969\n",
      "EPOCH: 19770 LOSS: 40.983681354625375\n",
      "EPOCH: 19771 LOSS: 40.98367934957348\n",
      "EPOCH: 19772 LOSS: 40.9836773446939\n",
      "EPOCH: 19773 LOSS: 40.9836753399867\n",
      "EPOCH: 19774 LOSS: 40.98367333545182\n",
      "EPOCH: 19775 LOSS: 40.98367133108922\n",
      "EPOCH: 19776 LOSS: 40.98366932689888\n",
      "EPOCH: 19777 LOSS: 40.98366732288079\n",
      "EPOCH: 19778 LOSS: 40.98366531903493\n",
      "EPOCH: 19779 LOSS: 40.983663315361234\n",
      "EPOCH: 19780 LOSS: 40.98366131185971\n",
      "EPOCH: 19781 LOSS: 40.983659308530335\n",
      "EPOCH: 19782 LOSS: 40.983657305373086\n",
      "EPOCH: 19783 LOSS: 40.983655302387916\n",
      "EPOCH: 19784 LOSS: 40.98365329957481\n",
      "EPOCH: 19785 LOSS: 40.98365129693376\n",
      "EPOCH: 19786 LOSS: 40.98364929446471\n",
      "EPOCH: 19787 LOSS: 40.98364729216767\n",
      "EPOCH: 19788 LOSS: 40.98364529004258\n",
      "EPOCH: 19789 LOSS: 40.983643288089446\n",
      "EPOCH: 19790 LOSS: 40.98364128630821\n",
      "EPOCH: 19791 LOSS: 40.983639284698874\n",
      "EPOCH: 19792 LOSS: 40.9836372832614\n",
      "EPOCH: 19793 LOSS: 40.98363528199579\n",
      "EPOCH: 19794 LOSS: 40.98363328090197\n",
      "EPOCH: 19795 LOSS: 40.983631279979946\n",
      "EPOCH: 19796 LOSS: 40.983629279229696\n",
      "EPOCH: 19797 LOSS: 40.983627278651184\n",
      "EPOCH: 19798 LOSS: 40.983625278244396\n",
      "EPOCH: 19799 LOSS: 40.9836232780093\n",
      "EPOCH: 19800 LOSS: 40.98362127794585\n",
      "EPOCH: 19801 LOSS: 40.98361927805408\n",
      "EPOCH: 19802 LOSS: 40.98361727833389\n",
      "EPOCH: 19803 LOSS: 40.983615278785294\n",
      "EPOCH: 19804 LOSS: 40.98361327940828\n",
      "EPOCH: 19805 LOSS: 40.98361128020281\n",
      "EPOCH: 19806 LOSS: 40.98360928116886\n",
      "EPOCH: 19807 LOSS: 40.983607282306394\n",
      "EPOCH: 19808 LOSS: 40.98360528361539\n",
      "EPOCH: 19809 LOSS: 40.983603285095825\n",
      "EPOCH: 19810 LOSS: 40.9836012867477\n",
      "EPOCH: 19811 LOSS: 40.98359928857096\n",
      "EPOCH: 19812 LOSS: 40.983597290565584\n",
      "EPOCH: 19813 LOSS: 40.98359529273155\n",
      "EPOCH: 19814 LOSS: 40.98359329506883\n",
      "EPOCH: 19815 LOSS: 40.98359129757742\n",
      "EPOCH: 19816 LOSS: 40.983589300257265\n",
      "EPOCH: 19817 LOSS: 40.983587303108344\n",
      "EPOCH: 19818 LOSS: 40.98358530613066\n",
      "EPOCH: 19819 LOSS: 40.98358330932416\n",
      "EPOCH: 19820 LOSS: 40.983581312688834\n",
      "EPOCH: 19821 LOSS: 40.98357931622465\n",
      "EPOCH: 19822 LOSS: 40.983577319931584\n",
      "EPOCH: 19823 LOSS: 40.98357532380962\n",
      "EPOCH: 19824 LOSS: 40.98357332785871\n",
      "EPOCH: 19825 LOSS: 40.98357133207886\n",
      "EPOCH: 19826 LOSS: 40.98356933647001\n",
      "EPOCH: 19827 LOSS: 40.983567341032185\n",
      "EPOCH: 19828 LOSS: 40.9835653457653\n",
      "EPOCH: 19829 LOSS: 40.98356335066937\n",
      "EPOCH: 19830 LOSS: 40.983561355744364\n",
      "EPOCH: 19831 LOSS: 40.983559360990256\n",
      "EPOCH: 19832 LOSS: 40.98355736640703\n",
      "EPOCH: 19833 LOSS: 40.98355537199464\n",
      "EPOCH: 19834 LOSS: 40.983553377753054\n",
      "EPOCH: 19835 LOSS: 40.98355138368228\n",
      "EPOCH: 19836 LOSS: 40.983549389782276\n",
      "EPOCH: 19837 LOSS: 40.983547396053034\n",
      "EPOCH: 19838 LOSS: 40.9835454024945\n",
      "EPOCH: 19839 LOSS: 40.983543409106666\n",
      "EPOCH: 19840 LOSS: 40.98354141588949\n",
      "EPOCH: 19841 LOSS: 40.98353942284299\n",
      "EPOCH: 19842 LOSS: 40.983537429967086\n",
      "EPOCH: 19843 LOSS: 40.9835354372618\n",
      "EPOCH: 19844 LOSS: 40.98353344472708\n",
      "EPOCH: 19845 LOSS: 40.9835314523629\n",
      "EPOCH: 19846 LOSS: 40.98352946016925\n",
      "EPOCH: 19847 LOSS: 40.98352746814611\n",
      "EPOCH: 19848 LOSS: 40.98352547629344\n",
      "EPOCH: 19849 LOSS: 40.98352348461122\n",
      "EPOCH: 19850 LOSS: 40.98352149309942\n",
      "EPOCH: 19851 LOSS: 40.983519501758025\n",
      "EPOCH: 19852 LOSS: 40.983517510587\n",
      "EPOCH: 19853 LOSS: 40.983515519586334\n",
      "EPOCH: 19854 LOSS: 40.983513528755985\n",
      "EPOCH: 19855 LOSS: 40.983511538095954\n",
      "EPOCH: 19856 LOSS: 40.98350954760619\n",
      "EPOCH: 19857 LOSS: 40.98350755728667\n",
      "EPOCH: 19858 LOSS: 40.983505567137385\n",
      "EPOCH: 19859 LOSS: 40.9835035771583\n",
      "EPOCH: 19860 LOSS: 40.98350158734941\n",
      "EPOCH: 19861 LOSS: 40.98349959771065\n",
      "EPOCH: 19862 LOSS: 40.98349760824205\n",
      "EPOCH: 19863 LOSS: 40.98349561894351\n",
      "EPOCH: 19864 LOSS: 40.98349362981509\n",
      "EPOCH: 19865 LOSS: 40.98349164085669\n",
      "EPOCH: 19866 LOSS: 40.98348965206836\n",
      "EPOCH: 19867 LOSS: 40.983487663450006\n",
      "EPOCH: 19868 LOSS: 40.98348567500165\n",
      "EPOCH: 19869 LOSS: 40.98348368672323\n",
      "EPOCH: 19870 LOSS: 40.98348169861474\n",
      "EPOCH: 19871 LOSS: 40.98347971067618\n",
      "EPOCH: 19872 LOSS: 40.98347772290749\n",
      "EPOCH: 19873 LOSS: 40.98347573530867\n",
      "EPOCH: 19874 LOSS: 40.98347374787967\n",
      "EPOCH: 19875 LOSS: 40.983471760620475\n",
      "EPOCH: 19876 LOSS: 40.98346977353108\n",
      "EPOCH: 19877 LOSS: 40.98346778661144\n",
      "EPOCH: 19878 LOSS: 40.983465799861534\n",
      "EPOCH: 19879 LOSS: 40.98346381328132\n",
      "EPOCH: 19880 LOSS: 40.98346182687081\n",
      "EPOCH: 19881 LOSS: 40.983459840629976\n",
      "EPOCH: 19882 LOSS: 40.98345785455874\n",
      "EPOCH: 19883 LOSS: 40.98345586865715\n",
      "EPOCH: 19884 LOSS: 40.98345388292513\n",
      "EPOCH: 19885 LOSS: 40.98345189736267\n",
      "EPOCH: 19886 LOSS: 40.98344991196976\n",
      "EPOCH: 19887 LOSS: 40.98344792674635\n",
      "EPOCH: 19888 LOSS: 40.98344594169244\n",
      "EPOCH: 19889 LOSS: 40.98344395680799\n",
      "EPOCH: 19890 LOSS: 40.983441972092976\n",
      "EPOCH: 19891 LOSS: 40.983439987547385\n",
      "EPOCH: 19892 LOSS: 40.983438003171194\n",
      "EPOCH: 19893 LOSS: 40.98343601896435\n",
      "EPOCH: 19894 LOSS: 40.98343403492686\n",
      "EPOCH: 19895 LOSS: 40.98343205105867\n",
      "EPOCH: 19896 LOSS: 40.98343006735978\n",
      "EPOCH: 19897 LOSS: 40.98342808383018\n",
      "EPOCH: 19898 LOSS: 40.983426100469785\n",
      "EPOCH: 19899 LOSS: 40.98342411727864\n",
      "EPOCH: 19900 LOSS: 40.983422134256685\n",
      "EPOCH: 19901 LOSS: 40.98342015140389\n",
      "EPOCH: 19902 LOSS: 40.98341816872025\n",
      "EPOCH: 19903 LOSS: 40.98341618620573\n",
      "EPOCH: 19904 LOSS: 40.9834142038603\n",
      "EPOCH: 19905 LOSS: 40.98341222168395\n",
      "EPOCH: 19906 LOSS: 40.98341023967664\n",
      "EPOCH: 19907 LOSS: 40.98340825783836\n",
      "EPOCH: 19908 LOSS: 40.98340627616908\n",
      "EPOCH: 19909 LOSS: 40.983404294668766\n",
      "EPOCH: 19910 LOSS: 40.983402313337415\n",
      "EPOCH: 19911 LOSS: 40.983400332174966\n",
      "EPOCH: 19912 LOSS: 40.98339835118142\n",
      "EPOCH: 19913 LOSS: 40.983396370356765\n",
      "EPOCH: 19914 LOSS: 40.98339438970096\n",
      "EPOCH: 19915 LOSS: 40.983392409214\n",
      "EPOCH: 19916 LOSS: 40.98339042889582\n",
      "EPOCH: 19917 LOSS: 40.98338844874642\n",
      "EPOCH: 19918 LOSS: 40.98338646876576\n",
      "EPOCH: 19919 LOSS: 40.98338448895386\n",
      "EPOCH: 19920 LOSS: 40.98338250931066\n",
      "EPOCH: 19921 LOSS: 40.98338052983611\n",
      "EPOCH: 19922 LOSS: 40.983378550530254\n",
      "EPOCH: 19923 LOSS: 40.98337657139303\n",
      "EPOCH: 19924 LOSS: 40.9833745924244\n",
      "EPOCH: 19925 LOSS: 40.98337261362434\n",
      "EPOCH: 19926 LOSS: 40.98337063499285\n",
      "EPOCH: 19927 LOSS: 40.983368656529905\n",
      "EPOCH: 19928 LOSS: 40.983366678235456\n",
      "EPOCH: 19929 LOSS: 40.98336470010951\n",
      "EPOCH: 19930 LOSS: 40.983362722152016\n",
      "EPOCH: 19931 LOSS: 40.983360744362955\n",
      "EPOCH: 19932 LOSS: 40.9833587667423\n",
      "EPOCH: 19933 LOSS: 40.983356789290035\n",
      "EPOCH: 19934 LOSS: 40.983354812006155\n",
      "EPOCH: 19935 LOSS: 40.98335283489059\n",
      "EPOCH: 19936 LOSS: 40.98335085794336\n",
      "EPOCH: 19937 LOSS: 40.98334888116441\n",
      "EPOCH: 19938 LOSS: 40.98334690455372\n",
      "EPOCH: 19939 LOSS: 40.983344928111286\n",
      "EPOCH: 19940 LOSS: 40.98334295183706\n",
      "EPOCH: 19941 LOSS: 40.983340975731025\n",
      "EPOCH: 19942 LOSS: 40.983338999793176\n",
      "EPOCH: 19943 LOSS: 40.98333702402346\n",
      "EPOCH: 19944 LOSS: 40.983335048421864\n",
      "EPOCH: 19945 LOSS: 40.98333307298837\n",
      "EPOCH: 19946 LOSS: 40.983331097722946\n",
      "EPOCH: 19947 LOSS: 40.98332912262556\n",
      "EPOCH: 19948 LOSS: 40.983327147696215\n",
      "EPOCH: 19949 LOSS: 40.983325172934855\n",
      "EPOCH: 19950 LOSS: 40.98332319834148\n",
      "EPOCH: 19951 LOSS: 40.98332122391605\n",
      "EPOCH: 19952 LOSS: 40.98331924965855\n",
      "EPOCH: 19953 LOSS: 40.983317275568936\n",
      "EPOCH: 19954 LOSS: 40.983315301647224\n",
      "EPOCH: 19955 LOSS: 40.98331332789335\n",
      "EPOCH: 19956 LOSS: 40.983311354307304\n",
      "EPOCH: 19957 LOSS: 40.98330938088907\n",
      "EPOCH: 19958 LOSS: 40.98330740763862\n",
      "EPOCH: 19959 LOSS: 40.9833054345559\n",
      "EPOCH: 19960 LOSS: 40.98330346164094\n",
      "EPOCH: 19961 LOSS: 40.98330148889367\n",
      "EPOCH: 19962 LOSS: 40.983299516314105\n",
      "EPOCH: 19963 LOSS: 40.9832975439022\n",
      "EPOCH: 19964 LOSS: 40.98329557165792\n",
      "EPOCH: 19965 LOSS: 40.98329359958124\n",
      "EPOCH: 19966 LOSS: 40.98329162767216\n",
      "EPOCH: 19967 LOSS: 40.98328965593063\n",
      "EPOCH: 19968 LOSS: 40.98328768435664\n",
      "EPOCH: 19969 LOSS: 40.98328571295018\n",
      "EPOCH: 19970 LOSS: 40.9832837417112\n",
      "EPOCH: 19971 LOSS: 40.98328177063967\n",
      "EPOCH: 19972 LOSS: 40.98327979973561\n",
      "EPOCH: 19973 LOSS: 40.98327782899895\n",
      "EPOCH: 19974 LOSS: 40.983275858429685\n",
      "EPOCH: 19975 LOSS: 40.98327388802779\n",
      "EPOCH: 19976 LOSS: 40.98327191779323\n",
      "EPOCH: 19977 LOSS: 40.98326994772603\n",
      "EPOCH: 19978 LOSS: 40.983267977826074\n",
      "EPOCH: 19979 LOSS: 40.98326600809342\n",
      "EPOCH: 19980 LOSS: 40.98326403852801\n",
      "EPOCH: 19981 LOSS: 40.98326206912982\n",
      "EPOCH: 19982 LOSS: 40.98326009989883\n",
      "EPOCH: 19983 LOSS: 40.98325813083502\n",
      "EPOCH: 19984 LOSS: 40.98325616193835\n",
      "EPOCH: 19985 LOSS: 40.983254193208815\n",
      "EPOCH: 19986 LOSS: 40.983252224646385\n",
      "EPOCH: 19987 LOSS: 40.98325025625103\n",
      "EPOCH: 19988 LOSS: 40.983248288022736\n",
      "EPOCH: 19989 LOSS: 40.98324631996147\n",
      "EPOCH: 19990 LOSS: 40.98324435206722\n",
      "EPOCH: 19991 LOSS: 40.983242384339924\n",
      "EPOCH: 19992 LOSS: 40.98324041677961\n",
      "EPOCH: 19993 LOSS: 40.98323844938623\n",
      "EPOCH: 19994 LOSS: 40.983236482159754\n",
      "EPOCH: 19995 LOSS: 40.98323451510014\n",
      "EPOCH: 19996 LOSS: 40.98323254820742\n",
      "EPOCH: 19997 LOSS: 40.983230581481536\n",
      "EPOCH: 19998 LOSS: 40.98322861492246\n",
      "EPOCH: 19999 LOSS: 40.98322664853016\n",
      "EPOCH: 20000 LOSS: 40.98322468230466\n",
      "EPOCH: 20001 LOSS: 40.983222716245876\n",
      "EPOCH: 20002 LOSS: 40.98322075035381\n",
      "EPOCH: 20003 LOSS: 40.98321878462844\n",
      "EPOCH: 20004 LOSS: 40.98321681906974\n",
      "EPOCH: 20005 LOSS: 40.98321485367768\n",
      "EPOCH: 20006 LOSS: 40.98321288845225\n",
      "EPOCH: 20007 LOSS: 40.983210923393415\n",
      "EPOCH: 20008 LOSS: 40.98320895850116\n",
      "EPOCH: 20009 LOSS: 40.98320699377544\n",
      "EPOCH: 20010 LOSS: 40.98320502921625\n",
      "EPOCH: 20011 LOSS: 40.983203064823556\n",
      "EPOCH: 20012 LOSS: 40.983201100597356\n",
      "EPOCH: 20013 LOSS: 40.98319913653758\n",
      "EPOCH: 20014 LOSS: 40.98319717264427\n",
      "EPOCH: 20015 LOSS: 40.98319520891734\n",
      "EPOCH: 20016 LOSS: 40.9831932453568\n",
      "EPOCH: 20017 LOSS: 40.983191281962604\n",
      "EPOCH: 20018 LOSS: 40.98318931873475\n",
      "EPOCH: 20019 LOSS: 40.98318735567321\n",
      "EPOCH: 20020 LOSS: 40.98318539277795\n",
      "EPOCH: 20021 LOSS: 40.98318343004897\n",
      "EPOCH: 20022 LOSS: 40.983181467486176\n",
      "EPOCH: 20023 LOSS: 40.98317950508964\n",
      "EPOCH: 20024 LOSS: 40.983177542859295\n",
      "EPOCH: 20025 LOSS: 40.98317558079508\n",
      "EPOCH: 20026 LOSS: 40.98317361889704\n",
      "EPOCH: 20027 LOSS: 40.98317165716509\n",
      "EPOCH: 20028 LOSS: 40.983169695599244\n",
      "EPOCH: 20029 LOSS: 40.983167734199476\n",
      "EPOCH: 20030 LOSS: 40.98316577296575\n",
      "EPOCH: 20031 LOSS: 40.98316381189804\n",
      "EPOCH: 20032 LOSS: 40.983161850996325\n",
      "EPOCH: 20033 LOSS: 40.98315989026058\n",
      "EPOCH: 20034 LOSS: 40.98315792969079\n",
      "EPOCH: 20035 LOSS: 40.98315596928693\n",
      "EPOCH: 20036 LOSS: 40.983154009048974\n",
      "EPOCH: 20037 LOSS: 40.98315204897689\n",
      "EPOCH: 20038 LOSS: 40.98315008907066\n",
      "EPOCH: 20039 LOSS: 40.98314812933026\n",
      "EPOCH: 20040 LOSS: 40.98314616975568\n",
      "EPOCH: 20041 LOSS: 40.98314421034685\n",
      "EPOCH: 20042 LOSS: 40.9831422511038\n",
      "EPOCH: 20043 LOSS: 40.98314029202648\n",
      "EPOCH: 20044 LOSS: 40.98313833311487\n",
      "EPOCH: 20045 LOSS: 40.983136374368954\n",
      "EPOCH: 20046 LOSS: 40.98313441578869\n",
      "EPOCH: 20047 LOSS: 40.983132457374055\n",
      "EPOCH: 20048 LOSS: 40.98313049912505\n",
      "EPOCH: 20049 LOSS: 40.98312854104164\n",
      "EPOCH: 20050 LOSS: 40.98312658312379\n",
      "EPOCH: 20051 LOSS: 40.983124625371474\n",
      "EPOCH: 20052 LOSS: 40.9831226677847\n",
      "EPOCH: 20053 LOSS: 40.98312071036341\n",
      "EPOCH: 20054 LOSS: 40.98311875310759\n",
      "EPOCH: 20055 LOSS: 40.983116796017214\n",
      "EPOCH: 20056 LOSS: 40.98311483909226\n",
      "EPOCH: 20057 LOSS: 40.98311288233272\n",
      "EPOCH: 20058 LOSS: 40.98311092573854\n",
      "EPOCH: 20059 LOSS: 40.983108969309725\n",
      "EPOCH: 20060 LOSS: 40.98310701304624\n",
      "EPOCH: 20061 LOSS: 40.98310505694805\n",
      "EPOCH: 20062 LOSS: 40.98310310101514\n",
      "EPOCH: 20063 LOSS: 40.98310114524749\n",
      "EPOCH: 20064 LOSS: 40.983099189645074\n",
      "EPOCH: 20065 LOSS: 40.98309723420787\n",
      "EPOCH: 20066 LOSS: 40.98309527893585\n",
      "EPOCH: 20067 LOSS: 40.983093323828996\n",
      "EPOCH: 20068 LOSS: 40.983091368887266\n",
      "EPOCH: 20069 LOSS: 40.983089414110665\n",
      "EPOCH: 20070 LOSS: 40.98308745949916\n",
      "EPOCH: 20071 LOSS: 40.9830855050527\n",
      "EPOCH: 20072 LOSS: 40.9830835507713\n",
      "EPOCH: 20073 LOSS: 40.98308159665491\n",
      "EPOCH: 20074 LOSS: 40.98307964270352\n",
      "EPOCH: 20075 LOSS: 40.98307768891709\n",
      "EPOCH: 20076 LOSS: 40.98307573529563\n",
      "EPOCH: 20077 LOSS: 40.983073781839096\n",
      "EPOCH: 20078 LOSS: 40.98307182854745\n",
      "EPOCH: 20079 LOSS: 40.98306987542067\n",
      "EPOCH: 20080 LOSS: 40.98306792245875\n",
      "EPOCH: 20081 LOSS: 40.98306596966166\n",
      "EPOCH: 20082 LOSS: 40.98306401702938\n",
      "EPOCH: 20083 LOSS: 40.98306206456189\n",
      "EPOCH: 20084 LOSS: 40.98306011225914\n",
      "EPOCH: 20085 LOSS: 40.98305816012113\n",
      "EPOCH: 20086 LOSS: 40.983056208147836\n",
      "EPOCH: 20087 LOSS: 40.98305425633922\n",
      "EPOCH: 20088 LOSS: 40.98305230469528\n",
      "EPOCH: 20089 LOSS: 40.983050353215965\n",
      "EPOCH: 20090 LOSS: 40.983048401901264\n",
      "EPOCH: 20091 LOSS: 40.983046450751175\n",
      "EPOCH: 20092 LOSS: 40.98304449976565\n",
      "EPOCH: 20093 LOSS: 40.98304254894466\n",
      "EPOCH: 20094 LOSS: 40.9830405982882\n",
      "EPOCH: 20095 LOSS: 40.98303864779622\n",
      "EPOCH: 20096 LOSS: 40.98303669746873\n",
      "EPOCH: 20097 LOSS: 40.98303474730568\n",
      "EPOCH: 20098 LOSS: 40.98303279730706\n",
      "EPOCH: 20099 LOSS: 40.98303084747285\n",
      "EPOCH: 20100 LOSS: 40.98302889780301\n",
      "EPOCH: 20101 LOSS: 40.983026948297535\n",
      "EPOCH: 20102 LOSS: 40.983024998956374\n",
      "EPOCH: 20103 LOSS: 40.98302304977954\n",
      "EPOCH: 20104 LOSS: 40.98302110076696\n",
      "EPOCH: 20105 LOSS: 40.98301915191867\n",
      "EPOCH: 20106 LOSS: 40.983017203234624\n",
      "EPOCH: 20107 LOSS: 40.983015254714765\n",
      "EPOCH: 20108 LOSS: 40.98301330635912\n",
      "EPOCH: 20109 LOSS: 40.98301135816762\n",
      "EPOCH: 20110 LOSS: 40.98300941014028\n",
      "EPOCH: 20111 LOSS: 40.98300746227706\n",
      "EPOCH: 20112 LOSS: 40.9830055145779\n",
      "EPOCH: 20113 LOSS: 40.98300356704286\n",
      "EPOCH: 20114 LOSS: 40.98300161967183\n",
      "EPOCH: 20115 LOSS: 40.98299967246485\n",
      "EPOCH: 20116 LOSS: 40.98299772542186\n",
      "EPOCH: 20117 LOSS: 40.98299577854285\n",
      "EPOCH: 20118 LOSS: 40.982993831827784\n",
      "EPOCH: 20119 LOSS: 40.98299188527666\n",
      "EPOCH: 20120 LOSS: 40.98298993888946\n",
      "EPOCH: 20121 LOSS: 40.9829879926661\n",
      "EPOCH: 20122 LOSS: 40.98298604660663\n",
      "EPOCH: 20123 LOSS: 40.98298410071099\n",
      "EPOCH: 20124 LOSS: 40.982982154979176\n",
      "EPOCH: 20125 LOSS: 40.982980209411124\n",
      "EPOCH: 20126 LOSS: 40.98297826400684\n",
      "EPOCH: 20127 LOSS: 40.98297631876631\n",
      "EPOCH: 20128 LOSS: 40.9829743736895\n",
      "EPOCH: 20129 LOSS: 40.98297242877638\n",
      "EPOCH: 20130 LOSS: 40.98297048402692\n",
      "EPOCH: 20131 LOSS: 40.98296853944113\n",
      "EPOCH: 20132 LOSS: 40.98296659501895\n",
      "EPOCH: 20133 LOSS: 40.98296465076037\n",
      "EPOCH: 20134 LOSS: 40.982962706665376\n",
      "EPOCH: 20135 LOSS: 40.98296076273393\n",
      "EPOCH: 20136 LOSS: 40.98295881896601\n",
      "EPOCH: 20137 LOSS: 40.982956875361594\n",
      "EPOCH: 20138 LOSS: 40.98295493192067\n",
      "EPOCH: 20139 LOSS: 40.982952988643206\n",
      "EPOCH: 20140 LOSS: 40.98295104552917\n",
      "EPOCH: 20141 LOSS: 40.98294910257856\n",
      "EPOCH: 20142 LOSS: 40.98294715979132\n",
      "EPOCH: 20143 LOSS: 40.98294521716745\n",
      "EPOCH: 20144 LOSS: 40.98294327470694\n",
      "EPOCH: 20145 LOSS: 40.98294133240973\n",
      "EPOCH: 20146 LOSS: 40.98293939027583\n",
      "EPOCH: 20147 LOSS: 40.982937448305194\n",
      "EPOCH: 20148 LOSS: 40.9829355064978\n",
      "EPOCH: 20149 LOSS: 40.98293356485364\n",
      "EPOCH: 20150 LOSS: 40.98293162337268\n",
      "EPOCH: 20151 LOSS: 40.98292968205489\n",
      "EPOCH: 20152 LOSS: 40.98292774090027\n",
      "EPOCH: 20153 LOSS: 40.98292579990876\n",
      "EPOCH: 20154 LOSS: 40.98292385908038\n",
      "EPOCH: 20155 LOSS: 40.98292191841507\n",
      "EPOCH: 20156 LOSS: 40.98291997791283\n",
      "EPOCH: 20157 LOSS: 40.98291803757361\n",
      "EPOCH: 20158 LOSS: 40.98291609739742\n",
      "EPOCH: 20159 LOSS: 40.9829141573842\n",
      "EPOCH: 20160 LOSS: 40.98291221753398\n",
      "EPOCH: 20161 LOSS: 40.98291027784668\n",
      "EPOCH: 20162 LOSS: 40.98290833832231\n",
      "EPOCH: 20163 LOSS: 40.982906398960836\n",
      "EPOCH: 20164 LOSS: 40.98290445976224\n",
      "EPOCH: 20165 LOSS: 40.98290252072647\n",
      "EPOCH: 20166 LOSS: 40.98290058185355\n",
      "EPOCH: 20167 LOSS: 40.982898643143415\n",
      "EPOCH: 20168 LOSS: 40.98289670459607\n",
      "EPOCH: 20169 LOSS: 40.98289476621149\n",
      "EPOCH: 20170 LOSS: 40.98289282798963\n",
      "EPOCH: 20171 LOSS: 40.982890889930495\n",
      "EPOCH: 20172 LOSS: 40.982888952034045\n",
      "EPOCH: 20173 LOSS: 40.982887014300246\n",
      "EPOCH: 20174 LOSS: 40.98288507672908\n",
      "EPOCH: 20175 LOSS: 40.98288313932055\n",
      "EPOCH: 20176 LOSS: 40.982881202074594\n",
      "EPOCH: 20177 LOSS: 40.982879264991226\n",
      "EPOCH: 20178 LOSS: 40.982877328070416\n",
      "EPOCH: 20179 LOSS: 40.98287539131209\n",
      "EPOCH: 20180 LOSS: 40.9828734547163\n",
      "EPOCH: 20181 LOSS: 40.98287151828296\n",
      "EPOCH: 20182 LOSS: 40.98286958201207\n",
      "EPOCH: 20183 LOSS: 40.98286764590364\n",
      "EPOCH: 20184 LOSS: 40.9828657099576\n",
      "EPOCH: 20185 LOSS: 40.982863774173936\n",
      "EPOCH: 20186 LOSS: 40.98286183855263\n",
      "EPOCH: 20187 LOSS: 40.98285990309367\n",
      "EPOCH: 20188 LOSS: 40.98285796779702\n",
      "EPOCH: 20189 LOSS: 40.98285603266267\n",
      "EPOCH: 20190 LOSS: 40.982854097690584\n",
      "EPOCH: 20191 LOSS: 40.98285216288073\n",
      "EPOCH: 20192 LOSS: 40.982850228233104\n",
      "EPOCH: 20193 LOSS: 40.98284829374767\n",
      "EPOCH: 20194 LOSS: 40.982846359424414\n",
      "EPOCH: 20195 LOSS: 40.982844425263295\n",
      "EPOCH: 20196 LOSS: 40.98284249126431\n",
      "EPOCH: 20197 LOSS: 40.98284055742745\n",
      "EPOCH: 20198 LOSS: 40.982838623752656\n",
      "EPOCH: 20199 LOSS: 40.982836690239914\n",
      "EPOCH: 20200 LOSS: 40.98283475688919\n",
      "EPOCH: 20201 LOSS: 40.982832823700505\n",
      "EPOCH: 20202 LOSS: 40.982830890673796\n",
      "EPOCH: 20203 LOSS: 40.98282895780906\n",
      "EPOCH: 20204 LOSS: 40.98282702510626\n",
      "EPOCH: 20205 LOSS: 40.98282509256538\n",
      "EPOCH: 20206 LOSS: 40.982823160186385\n",
      "EPOCH: 20207 LOSS: 40.982821227969254\n",
      "EPOCH: 20208 LOSS: 40.982819295914\n",
      "EPOCH: 20209 LOSS: 40.98281736402055\n",
      "EPOCH: 20210 LOSS: 40.98281543228891\n",
      "EPOCH: 20211 LOSS: 40.98281350071905\n",
      "EPOCH: 20212 LOSS: 40.98281156931094\n",
      "EPOCH: 20213 LOSS: 40.98280963806456\n",
      "EPOCH: 20214 LOSS: 40.9828077069799\n",
      "EPOCH: 20215 LOSS: 40.982805776056914\n",
      "EPOCH: 20216 LOSS: 40.98280384529559\n",
      "EPOCH: 20217 LOSS: 40.98280191469591\n",
      "EPOCH: 20218 LOSS: 40.98279998425785\n",
      "EPOCH: 20219 LOSS: 40.98279805398137\n",
      "EPOCH: 20220 LOSS: 40.982796123866464\n",
      "EPOCH: 20221 LOSS: 40.98279419391312\n",
      "EPOCH: 20222 LOSS: 40.982792264121294\n",
      "EPOCH: 20223 LOSS: 40.982790334490964\n",
      "EPOCH: 20224 LOSS: 40.982788405022106\n",
      "EPOCH: 20225 LOSS: 40.98278647571472\n",
      "EPOCH: 20226 LOSS: 40.98278454656875\n",
      "EPOCH: 20227 LOSS: 40.98278261758419\n",
      "EPOCH: 20228 LOSS: 40.98278068876101\n",
      "EPOCH: 20229 LOSS: 40.9827787600992\n",
      "EPOCH: 20230 LOSS: 40.98277683159873\n",
      "EPOCH: 20231 LOSS: 40.982774903259575\n",
      "EPOCH: 20232 LOSS: 40.9827729750817\n",
      "EPOCH: 20233 LOSS: 40.982771047065114\n",
      "EPOCH: 20234 LOSS: 40.98276911920975\n",
      "EPOCH: 20235 LOSS: 40.982767191515634\n",
      "EPOCH: 20236 LOSS: 40.9827652639827\n",
      "EPOCH: 20237 LOSS: 40.982763336610944\n",
      "EPOCH: 20238 LOSS: 40.982761409400354\n",
      "EPOCH: 20239 LOSS: 40.982759482350886\n",
      "EPOCH: 20240 LOSS: 40.98275755546253\n",
      "EPOCH: 20241 LOSS: 40.982755628735255\n",
      "EPOCH: 20242 LOSS: 40.98275370216904\n",
      "EPOCH: 20243 LOSS: 40.98275177576386\n",
      "EPOCH: 20244 LOSS: 40.98274984951969\n",
      "EPOCH: 20245 LOSS: 40.982747923436534\n",
      "EPOCH: 20246 LOSS: 40.98274599751433\n",
      "EPOCH: 20247 LOSS: 40.982744071753075\n",
      "EPOCH: 20248 LOSS: 40.98274214615275\n",
      "EPOCH: 20249 LOSS: 40.982740220713325\n",
      "EPOCH: 20250 LOSS: 40.98273829543477\n",
      "EPOCH: 20251 LOSS: 40.98273637031708\n",
      "EPOCH: 20252 LOSS: 40.982734445360194\n",
      "EPOCH: 20253 LOSS: 40.98273252056414\n",
      "EPOCH: 20254 LOSS: 40.98273059592887\n",
      "EPOCH: 20255 LOSS: 40.98272867145435\n",
      "EPOCH: 20256 LOSS: 40.98272674714056\n",
      "EPOCH: 20257 LOSS: 40.98272482298752\n",
      "EPOCH: 20258 LOSS: 40.98272289899514\n",
      "EPOCH: 20259 LOSS: 40.98272097516344\n",
      "EPOCH: 20260 LOSS: 40.982719051492396\n",
      "EPOCH: 20261 LOSS: 40.98271712798198\n",
      "EPOCH: 20262 LOSS: 40.98271520463213\n",
      "EPOCH: 20263 LOSS: 40.9827132814429\n",
      "EPOCH: 20264 LOSS: 40.9827113584142\n",
      "EPOCH: 20265 LOSS: 40.98270943554604\n",
      "EPOCH: 20266 LOSS: 40.98270751283838\n",
      "EPOCH: 20267 LOSS: 40.98270559029122\n",
      "EPOCH: 20268 LOSS: 40.98270366790452\n",
      "EPOCH: 20269 LOSS: 40.98270174567825\n",
      "EPOCH: 20270 LOSS: 40.98269982361241\n",
      "EPOCH: 20271 LOSS: 40.98269790170695\n",
      "EPOCH: 20272 LOSS: 40.98269597996186\n",
      "EPOCH: 20273 LOSS: 40.98269405837712\n",
      "EPOCH: 20274 LOSS: 40.98269213695272\n",
      "EPOCH: 20275 LOSS: 40.98269021568861\n",
      "EPOCH: 20276 LOSS: 40.982688294584776\n",
      "EPOCH: 20277 LOSS: 40.982686373641215\n",
      "EPOCH: 20278 LOSS: 40.98268445285785\n",
      "EPOCH: 20279 LOSS: 40.982682532234755\n",
      "EPOCH: 20280 LOSS: 40.98268061177179\n",
      "EPOCH: 20281 LOSS: 40.98267869146902\n",
      "EPOCH: 20282 LOSS: 40.98267677132639\n",
      "EPOCH: 20283 LOSS: 40.98267485134387\n",
      "EPOCH: 20284 LOSS: 40.98267293152145\n",
      "EPOCH: 20285 LOSS: 40.9826710118591\n",
      "EPOCH: 20286 LOSS: 40.98266909235681\n",
      "EPOCH: 20287 LOSS: 40.98266717301453\n",
      "EPOCH: 20288 LOSS: 40.982665253832266\n",
      "EPOCH: 20289 LOSS: 40.98266333480998\n",
      "EPOCH: 20290 LOSS: 40.98266141594766\n",
      "EPOCH: 20291 LOSS: 40.982659497245265\n",
      "EPOCH: 20292 LOSS: 40.9826575787028\n",
      "EPOCH: 20293 LOSS: 40.982655660320205\n",
      "EPOCH: 20294 LOSS: 40.98265374209748\n",
      "EPOCH: 20295 LOSS: 40.98265182403461\n",
      "EPOCH: 20296 LOSS: 40.982649906131556\n",
      "EPOCH: 20297 LOSS: 40.98264798838831\n",
      "EPOCH: 20298 LOSS: 40.98264607080482\n",
      "EPOCH: 20299 LOSS: 40.98264415338109\n",
      "EPOCH: 20300 LOSS: 40.98264223611709\n",
      "EPOCH: 20301 LOSS: 40.9826403190128\n",
      "EPOCH: 20302 LOSS: 40.98263840206819\n",
      "EPOCH: 20303 LOSS: 40.982636485283265\n",
      "EPOCH: 20304 LOSS: 40.982634568657936\n",
      "EPOCH: 20305 LOSS: 40.98263265219225\n",
      "EPOCH: 20306 LOSS: 40.98263073588616\n",
      "EPOCH: 20307 LOSS: 40.98262881973962\n",
      "EPOCH: 20308 LOSS: 40.982626903752646\n",
      "EPOCH: 20309 LOSS: 40.98262498792519\n",
      "EPOCH: 20310 LOSS: 40.982623072257226\n",
      "EPOCH: 20311 LOSS: 40.98262115674876\n",
      "EPOCH: 20312 LOSS: 40.982619241399746\n",
      "EPOCH: 20313 LOSS: 40.982617326210146\n",
      "EPOCH: 20314 LOSS: 40.98261541117998\n",
      "EPOCH: 20315 LOSS: 40.9826134963092\n",
      "EPOCH: 20316 LOSS: 40.982611581597766\n",
      "EPOCH: 20317 LOSS: 40.98260966704569\n",
      "EPOCH: 20318 LOSS: 40.98260775265294\n",
      "EPOCH: 20319 LOSS: 40.98260583841946\n",
      "EPOCH: 20320 LOSS: 40.98260392434528\n",
      "EPOCH: 20321 LOSS: 40.98260201043034\n",
      "EPOCH: 20322 LOSS: 40.98260009667463\n",
      "EPOCH: 20323 LOSS: 40.982598183078125\n",
      "EPOCH: 20324 LOSS: 40.982596269640794\n",
      "EPOCH: 20325 LOSS: 40.98259435636263\n",
      "EPOCH: 20326 LOSS: 40.982592443243604\n",
      "EPOCH: 20327 LOSS: 40.98259053028371\n",
      "EPOCH: 20328 LOSS: 40.9825886174829\n",
      "EPOCH: 20329 LOSS: 40.98258670484114\n",
      "EPOCH: 20330 LOSS: 40.98258479235844\n",
      "EPOCH: 20331 LOSS: 40.98258288003477\n",
      "EPOCH: 20332 LOSS: 40.98258096787008\n",
      "EPOCH: 20333 LOSS: 40.98257905586439\n",
      "EPOCH: 20334 LOSS: 40.98257714401764\n",
      "EPOCH: 20335 LOSS: 40.98257523232982\n",
      "EPOCH: 20336 LOSS: 40.98257332080094\n",
      "EPOCH: 20337 LOSS: 40.98257140943093\n",
      "EPOCH: 20338 LOSS: 40.982569498219775\n",
      "EPOCH: 20339 LOSS: 40.98256758716747\n",
      "EPOCH: 20340 LOSS: 40.98256567627398\n",
      "EPOCH: 20341 LOSS: 40.98256376553929\n",
      "EPOCH: 20342 LOSS: 40.98256185496338\n",
      "EPOCH: 20343 LOSS: 40.982559944546225\n",
      "EPOCH: 20344 LOSS: 40.98255803428779\n",
      "EPOCH: 20345 LOSS: 40.982556124188065\n",
      "EPOCH: 20346 LOSS: 40.98255421424703\n",
      "EPOCH: 20347 LOSS: 40.98255230446463\n",
      "EPOCH: 20348 LOSS: 40.98255039484089\n",
      "EPOCH: 20349 LOSS: 40.98254848537577\n",
      "EPOCH: 20350 LOSS: 40.982546576069225\n",
      "EPOCH: 20351 LOSS: 40.98254466692127\n",
      "EPOCH: 20352 LOSS: 40.98254275793185\n",
      "EPOCH: 20353 LOSS: 40.98254084910095\n",
      "EPOCH: 20354 LOSS: 40.98253894042856\n",
      "EPOCH: 20355 LOSS: 40.98253703191466\n",
      "EPOCH: 20356 LOSS: 40.98253512355922\n",
      "EPOCH: 20357 LOSS: 40.98253321536218\n",
      "EPOCH: 20358 LOSS: 40.98253130732358\n",
      "EPOCH: 20359 LOSS: 40.98252939944337\n",
      "EPOCH: 20360 LOSS: 40.9825274917215\n",
      "EPOCH: 20361 LOSS: 40.982525584158\n",
      "EPOCH: 20362 LOSS: 40.98252367675282\n",
      "EPOCH: 20363 LOSS: 40.98252176950594\n",
      "EPOCH: 20364 LOSS: 40.982519862417334\n",
      "EPOCH: 20365 LOSS: 40.98251795548697\n",
      "EPOCH: 20366 LOSS: 40.98251604871486\n",
      "EPOCH: 20367 LOSS: 40.982514142100925\n",
      "EPOCH: 20368 LOSS: 40.9825122356452\n",
      "EPOCH: 20369 LOSS: 40.98251032934764\n",
      "EPOCH: 20370 LOSS: 40.982508423208216\n",
      "EPOCH: 20371 LOSS: 40.98250651722691\n",
      "EPOCH: 20372 LOSS: 40.9825046114037\n",
      "EPOCH: 20373 LOSS: 40.982502705738554\n",
      "EPOCH: 20374 LOSS: 40.982500800231485\n",
      "EPOCH: 20375 LOSS: 40.98249889488242\n",
      "EPOCH: 20376 LOSS: 40.98249698969137\n",
      "EPOCH: 20377 LOSS: 40.982495084658304\n",
      "EPOCH: 20378 LOSS: 40.98249317978319\n",
      "EPOCH: 20379 LOSS: 40.98249127506602\n",
      "EPOCH: 20380 LOSS: 40.982489370506755\n",
      "EPOCH: 20381 LOSS: 40.9824874661054\n",
      "EPOCH: 20382 LOSS: 40.982485561861914\n",
      "EPOCH: 20383 LOSS: 40.98248365777627\n",
      "EPOCH: 20384 LOSS: 40.982481753848454\n",
      "EPOCH: 20385 LOSS: 40.98247985007845\n",
      "EPOCH: 20386 LOSS: 40.98247794646621\n",
      "EPOCH: 20387 LOSS: 40.98247604301173\n",
      "EPOCH: 20388 LOSS: 40.98247413971499\n",
      "EPOCH: 20389 LOSS: 40.98247223657595\n",
      "EPOCH: 20390 LOSS: 40.98247033359462\n",
      "EPOCH: 20391 LOSS: 40.98246843077095\n",
      "EPOCH: 20392 LOSS: 40.98246652810492\n",
      "EPOCH: 20393 LOSS: 40.982464625596535\n",
      "EPOCH: 20394 LOSS: 40.982462723245746\n",
      "EPOCH: 20395 LOSS: 40.98246082105251\n",
      "EPOCH: 20396 LOSS: 40.98245891901685\n",
      "EPOCH: 20397 LOSS: 40.98245701713872\n",
      "EPOCH: 20398 LOSS: 40.98245511541809\n",
      "EPOCH: 20399 LOSS: 40.98245321385495\n",
      "EPOCH: 20400 LOSS: 40.982451312449285\n",
      "EPOCH: 20401 LOSS: 40.982449411201074\n",
      "EPOCH: 20402 LOSS: 40.982447510110276\n",
      "EPOCH: 20403 LOSS: 40.98244560917688\n",
      "EPOCH: 20404 LOSS: 40.98244370840085\n",
      "EPOCH: 20405 LOSS: 40.98244180778217\n",
      "EPOCH: 20406 LOSS: 40.98243990732084\n",
      "EPOCH: 20407 LOSS: 40.98243800701681\n",
      "EPOCH: 20408 LOSS: 40.982436106870054\n",
      "EPOCH: 20409 LOSS: 40.98243420688056\n",
      "EPOCH: 20410 LOSS: 40.98243230704833\n",
      "EPOCH: 20411 LOSS: 40.982430407373315\n",
      "EPOCH: 20412 LOSS: 40.98242850785549\n",
      "EPOCH: 20413 LOSS: 40.98242660849483\n",
      "EPOCH: 20414 LOSS: 40.98242470929133\n",
      "EPOCH: 20415 LOSS: 40.98242281024496\n",
      "EPOCH: 20416 LOSS: 40.9824209113557\n",
      "EPOCH: 20417 LOSS: 40.98241901262353\n",
      "EPOCH: 20418 LOSS: 40.982417114048424\n",
      "EPOCH: 20419 LOSS: 40.98241521563036\n",
      "EPOCH: 20420 LOSS: 40.9824133173693\n",
      "EPOCH: 20421 LOSS: 40.98241141926523\n",
      "EPOCH: 20422 LOSS: 40.982409521318154\n",
      "EPOCH: 20423 LOSS: 40.98240762352802\n",
      "EPOCH: 20424 LOSS: 40.982405725894814\n",
      "EPOCH: 20425 LOSS: 40.982403828418526\n",
      "EPOCH: 20426 LOSS: 40.98240193109911\n",
      "EPOCH: 20427 LOSS: 40.98240003393654\n",
      "EPOCH: 20428 LOSS: 40.982398136930826\n",
      "EPOCH: 20429 LOSS: 40.98239624008193\n",
      "EPOCH: 20430 LOSS: 40.98239434338982\n",
      "EPOCH: 20431 LOSS: 40.9823924468545\n",
      "EPOCH: 20432 LOSS: 40.98239055047591\n",
      "EPOCH: 20433 LOSS: 40.98238865425406\n",
      "EPOCH: 20434 LOSS: 40.98238675818892\n",
      "EPOCH: 20435 LOSS: 40.98238486228044\n",
      "EPOCH: 20436 LOSS: 40.98238296652865\n",
      "EPOCH: 20437 LOSS: 40.982381070933485\n",
      "EPOCH: 20438 LOSS: 40.982379175494934\n",
      "EPOCH: 20439 LOSS: 40.98237728021297\n",
      "EPOCH: 20440 LOSS: 40.98237538508758\n",
      "EPOCH: 20441 LOSS: 40.982373490118746\n",
      "EPOCH: 20442 LOSS: 40.98237159530643\n",
      "EPOCH: 20443 LOSS: 40.982369700650636\n",
      "EPOCH: 20444 LOSS: 40.9823678061513\n",
      "EPOCH: 20445 LOSS: 40.98236591180846\n",
      "EPOCH: 20446 LOSS: 40.982364017622025\n",
      "EPOCH: 20447 LOSS: 40.98236212359201\n",
      "EPOCH: 20448 LOSS: 40.982360229718395\n",
      "EPOCH: 20449 LOSS: 40.982358336001155\n",
      "EPOCH: 20450 LOSS: 40.982356442440256\n",
      "EPOCH: 20451 LOSS: 40.98235454903569\n",
      "EPOCH: 20452 LOSS: 40.98235265578743\n",
      "EPOCH: 20453 LOSS: 40.98235076269544\n",
      "EPOCH: 20454 LOSS: 40.98234886975972\n",
      "EPOCH: 20455 LOSS: 40.98234697698023\n",
      "EPOCH: 20456 LOSS: 40.982345084356965\n",
      "EPOCH: 20457 LOSS: 40.98234319188988\n",
      "EPOCH: 20458 LOSS: 40.98234129957898\n",
      "EPOCH: 20459 LOSS: 40.98233940742422\n",
      "EPOCH: 20460 LOSS: 40.98233751542559\n",
      "EPOCH: 20461 LOSS: 40.982335623583054\n",
      "EPOCH: 20462 LOSS: 40.98233373189662\n",
      "EPOCH: 20463 LOSS: 40.98233184036623\n",
      "EPOCH: 20464 LOSS: 40.98232994899189\n",
      "EPOCH: 20465 LOSS: 40.98232805777356\n",
      "EPOCH: 20466 LOSS: 40.98232616671123\n",
      "EPOCH: 20467 LOSS: 40.98232427580486\n",
      "EPOCH: 20468 LOSS: 40.982322385054445\n",
      "EPOCH: 20469 LOSS: 40.982320494459955\n",
      "EPOCH: 20470 LOSS: 40.98231860402137\n",
      "EPOCH: 20471 LOSS: 40.98231671373866\n",
      "EPOCH: 20472 LOSS: 40.98231482361182\n",
      "EPOCH: 20473 LOSS: 40.98231293364082\n",
      "EPOCH: 20474 LOSS: 40.98231104382563\n",
      "EPOCH: 20475 LOSS: 40.982309154166224\n",
      "EPOCH: 20476 LOSS: 40.98230726466262\n",
      "EPOCH: 20477 LOSS: 40.98230537531474\n",
      "EPOCH: 20478 LOSS: 40.98230348612259\n",
      "EPOCH: 20479 LOSS: 40.98230159708615\n",
      "EPOCH: 20480 LOSS: 40.9822997082054\n",
      "EPOCH: 20481 LOSS: 40.982297819480294\n",
      "EPOCH: 20482 LOSS: 40.98229593091085\n",
      "EPOCH: 20483 LOSS: 40.982294042496996\n",
      "EPOCH: 20484 LOSS: 40.98229215423875\n",
      "EPOCH: 20485 LOSS: 40.982290266136076\n",
      "EPOCH: 20486 LOSS: 40.98228837818897\n",
      "EPOCH: 20487 LOSS: 40.98228649039737\n",
      "EPOCH: 20488 LOSS: 40.98228460276129\n",
      "EPOCH: 20489 LOSS: 40.982282715280675\n",
      "EPOCH: 20490 LOSS: 40.982280827955535\n",
      "EPOCH: 20491 LOSS: 40.98227894078584\n",
      "EPOCH: 20492 LOSS: 40.982277053771554\n",
      "EPOCH: 20493 LOSS: 40.98227516691267\n",
      "EPOCH: 20494 LOSS: 40.982273280209164\n",
      "EPOCH: 20495 LOSS: 40.982271393660994\n",
      "EPOCH: 20496 LOSS: 40.98226950726816\n",
      "EPOCH: 20497 LOSS: 40.98226762103063\n",
      "EPOCH: 20498 LOSS: 40.9822657349484\n",
      "EPOCH: 20499 LOSS: 40.98226384902142\n",
      "EPOCH: 20500 LOSS: 40.982261963249684\n",
      "EPOCH: 20501 LOSS: 40.98226007763317\n",
      "EPOCH: 20502 LOSS: 40.98225819217187\n",
      "EPOCH: 20503 LOSS: 40.98225630686571\n",
      "EPOCH: 20504 LOSS: 40.982254421714714\n",
      "EPOCH: 20505 LOSS: 40.98225253671886\n",
      "EPOCH: 20506 LOSS: 40.98225065187812\n",
      "EPOCH: 20507 LOSS: 40.98224876719246\n",
      "EPOCH: 20508 LOSS: 40.98224688266186\n",
      "EPOCH: 20509 LOSS: 40.98224499828631\n",
      "EPOCH: 20510 LOSS: 40.98224311406578\n",
      "EPOCH: 20511 LOSS: 40.98224123000024\n",
      "EPOCH: 20512 LOSS: 40.98223934608968\n",
      "EPOCH: 20513 LOSS: 40.98223746233408\n",
      "EPOCH: 20514 LOSS: 40.98223557873342\n",
      "EPOCH: 20515 LOSS: 40.98223369528767\n",
      "EPOCH: 20516 LOSS: 40.9822318119968\n",
      "EPOCH: 20517 LOSS: 40.98222992886079\n",
      "EPOCH: 20518 LOSS: 40.98222804587964\n",
      "EPOCH: 20519 LOSS: 40.98222616305331\n",
      "EPOCH: 20520 LOSS: 40.98222428038178\n",
      "EPOCH: 20521 LOSS: 40.98222239786502\n",
      "EPOCH: 20522 LOSS: 40.98222051550303\n",
      "EPOCH: 20523 LOSS: 40.98221863329577\n",
      "EPOCH: 20524 LOSS: 40.98221675124322\n",
      "EPOCH: 20525 LOSS: 40.98221486934537\n",
      "EPOCH: 20526 LOSS: 40.98221298760219\n",
      "EPOCH: 20527 LOSS: 40.982211106013665\n",
      "EPOCH: 20528 LOSS: 40.98220922457974\n",
      "EPOCH: 20529 LOSS: 40.982207343300416\n",
      "EPOCH: 20530 LOSS: 40.98220546217571\n",
      "EPOCH: 20531 LOSS: 40.98220358120554\n",
      "EPOCH: 20532 LOSS: 40.98220170038991\n",
      "EPOCH: 20533 LOSS: 40.98219981972879\n",
      "EPOCH: 20534 LOSS: 40.982197939222175\n",
      "EPOCH: 20535 LOSS: 40.98219605887003\n",
      "EPOCH: 20536 LOSS: 40.98219417867233\n",
      "EPOCH: 20537 LOSS: 40.98219229862906\n",
      "EPOCH: 20538 LOSS: 40.9821904187402\n",
      "EPOCH: 20539 LOSS: 40.98218853900572\n",
      "EPOCH: 20540 LOSS: 40.98218665942561\n",
      "EPOCH: 20541 LOSS: 40.98218477999983\n",
      "EPOCH: 20542 LOSS: 40.98218290072836\n",
      "EPOCH: 20543 LOSS: 40.98218102161121\n",
      "EPOCH: 20544 LOSS: 40.98217914264832\n",
      "EPOCH: 20545 LOSS: 40.98217726383969\n",
      "EPOCH: 20546 LOSS: 40.9821753851853\n",
      "EPOCH: 20547 LOSS: 40.98217350668509\n",
      "EPOCH: 20548 LOSS: 40.98217162833909\n",
      "EPOCH: 20549 LOSS: 40.982169750147264\n",
      "EPOCH: 20550 LOSS: 40.98216787210957\n",
      "EPOCH: 20551 LOSS: 40.982165994225994\n",
      "EPOCH: 20552 LOSS: 40.98216411649651\n",
      "EPOCH: 20553 LOSS: 40.98216223892112\n",
      "EPOCH: 20554 LOSS: 40.98216036149978\n",
      "EPOCH: 20555 LOSS: 40.98215848423247\n",
      "EPOCH: 20556 LOSS: 40.982156607119194\n",
      "EPOCH: 20557 LOSS: 40.98215473015988\n",
      "EPOCH: 20558 LOSS: 40.98215285335455\n",
      "EPOCH: 20559 LOSS: 40.98215097670316\n",
      "EPOCH: 20560 LOSS: 40.9821491002057\n",
      "EPOCH: 20561 LOSS: 40.98214722386216\n",
      "EPOCH: 20562 LOSS: 40.98214534767247\n",
      "EPOCH: 20563 LOSS: 40.98214347163667\n",
      "EPOCH: 20564 LOSS: 40.98214159575469\n",
      "EPOCH: 20565 LOSS: 40.98213972002652\n",
      "EPOCH: 20566 LOSS: 40.982137844452154\n",
      "EPOCH: 20567 LOSS: 40.98213596903156\n",
      "EPOCH: 20568 LOSS: 40.98213409376473\n",
      "EPOCH: 20569 LOSS: 40.9821322186516\n",
      "EPOCH: 20570 LOSS: 40.982130343692205\n",
      "EPOCH: 20571 LOSS: 40.982128468886486\n",
      "EPOCH: 20572 LOSS: 40.98212659423443\n",
      "EPOCH: 20573 LOSS: 40.98212471973602\n",
      "EPOCH: 20574 LOSS: 40.98212284539121\n",
      "EPOCH: 20575 LOSS: 40.98212097120001\n",
      "EPOCH: 20576 LOSS: 40.9821190971624\n",
      "EPOCH: 20577 LOSS: 40.98211722327832\n",
      "EPOCH: 20578 LOSS: 40.98211534954781\n",
      "EPOCH: 20579 LOSS: 40.98211347597078\n",
      "EPOCH: 20580 LOSS: 40.98211160254724\n",
      "EPOCH: 20581 LOSS: 40.9821097292772\n",
      "EPOCH: 20582 LOSS: 40.982107856160574\n",
      "EPOCH: 20583 LOSS: 40.98210598319738\n",
      "EPOCH: 20584 LOSS: 40.982104110387596\n",
      "EPOCH: 20585 LOSS: 40.98210223773118\n",
      "EPOCH: 20586 LOSS: 40.982100365228135\n",
      "EPOCH: 20587 LOSS: 40.98209849287842\n",
      "EPOCH: 20588 LOSS: 40.982096620682036\n",
      "EPOCH: 20589 LOSS: 40.98209474863893\n",
      "EPOCH: 20590 LOSS: 40.982092876749086\n",
      "EPOCH: 20591 LOSS: 40.98209100501252\n",
      "EPOCH: 20592 LOSS: 40.98208913342917\n",
      "EPOCH: 20593 LOSS: 40.98208726199903\n",
      "EPOCH: 20594 LOSS: 40.98208539072207\n",
      "EPOCH: 20595 LOSS: 40.98208351959828\n",
      "EPOCH: 20596 LOSS: 40.98208164862763\n",
      "EPOCH: 20597 LOSS: 40.9820797778101\n",
      "EPOCH: 20598 LOSS: 40.982077907145666\n",
      "EPOCH: 20599 LOSS: 40.982076036634304\n",
      "EPOCH: 20600 LOSS: 40.982074166276014\n",
      "EPOCH: 20601 LOSS: 40.982072296070754\n",
      "EPOCH: 20602 LOSS: 40.982070426018495\n",
      "EPOCH: 20603 LOSS: 40.98206855611922\n",
      "EPOCH: 20604 LOSS: 40.982066686372946\n",
      "EPOCH: 20605 LOSS: 40.9820648167796\n",
      "EPOCH: 20606 LOSS: 40.98206294733919\n",
      "EPOCH: 20607 LOSS: 40.98206107805166\n",
      "EPOCH: 20608 LOSS: 40.98205920891703\n",
      "EPOCH: 20609 LOSS: 40.98205733993525\n",
      "EPOCH: 20610 LOSS: 40.98205547110632\n",
      "EPOCH: 20611 LOSS: 40.98205360243021\n",
      "EPOCH: 20612 LOSS: 40.982051733906886\n",
      "EPOCH: 20613 LOSS: 40.98204986553634\n",
      "EPOCH: 20614 LOSS: 40.982047997318546\n",
      "EPOCH: 20615 LOSS: 40.98204612925349\n",
      "EPOCH: 20616 LOSS: 40.98204426134113\n",
      "EPOCH: 20617 LOSS: 40.982042393581466\n",
      "EPOCH: 20618 LOSS: 40.982040525974455\n",
      "EPOCH: 20619 LOSS: 40.9820386585201\n",
      "EPOCH: 20620 LOSS: 40.98203679121838\n",
      "EPOCH: 20621 LOSS: 40.982034924069254\n",
      "EPOCH: 20622 LOSS: 40.982033057072684\n",
      "EPOCH: 20623 LOSS: 40.982031190228696\n",
      "EPOCH: 20624 LOSS: 40.98202932353723\n",
      "EPOCH: 20625 LOSS: 40.982027456998296\n",
      "EPOCH: 20626 LOSS: 40.982025590611855\n",
      "EPOCH: 20627 LOSS: 40.98202372437788\n",
      "EPOCH: 20628 LOSS: 40.98202185829635\n",
      "EPOCH: 20629 LOSS: 40.98201999236724\n",
      "EPOCH: 20630 LOSS: 40.98201812659055\n",
      "EPOCH: 20631 LOSS: 40.98201626096627\n",
      "EPOCH: 20632 LOSS: 40.982014395494325\n",
      "EPOCH: 20633 LOSS: 40.98201253017473\n",
      "EPOCH: 20634 LOSS: 40.982010665007444\n",
      "EPOCH: 20635 LOSS: 40.98200879999246\n",
      "EPOCH: 20636 LOSS: 40.98200693512977\n",
      "EPOCH: 20637 LOSS: 40.982005070419326\n",
      "EPOCH: 20638 LOSS: 40.98200320586112\n",
      "EPOCH: 20639 LOSS: 40.98200134145513\n",
      "EPOCH: 20640 LOSS: 40.98199947720133\n",
      "EPOCH: 20641 LOSS: 40.981997613099686\n",
      "EPOCH: 20642 LOSS: 40.98199574915021\n",
      "EPOCH: 20643 LOSS: 40.98199388535286\n",
      "EPOCH: 20644 LOSS: 40.9819920217076\n",
      "EPOCH: 20645 LOSS: 40.981990158214444\n",
      "EPOCH: 20646 LOSS: 40.981988294873325\n",
      "EPOCH: 20647 LOSS: 40.98198643168428\n",
      "EPOCH: 20648 LOSS: 40.98198456864722\n",
      "EPOCH: 20649 LOSS: 40.98198270576219\n",
      "EPOCH: 20650 LOSS: 40.981980843029135\n",
      "EPOCH: 20651 LOSS: 40.981978980448005\n",
      "EPOCH: 20652 LOSS: 40.98197711801882\n",
      "EPOCH: 20653 LOSS: 40.98197525574156\n",
      "EPOCH: 20654 LOSS: 40.98197339361619\n",
      "EPOCH: 20655 LOSS: 40.9819715316427\n",
      "EPOCH: 20656 LOSS: 40.98196966982103\n",
      "EPOCH: 20657 LOSS: 40.98196780815121\n",
      "EPOCH: 20658 LOSS: 40.98196594663318\n",
      "EPOCH: 20659 LOSS: 40.98196408526694\n",
      "EPOCH: 20660 LOSS: 40.98196222405247\n",
      "EPOCH: 20661 LOSS: 40.98196036298974\n",
      "EPOCH: 20662 LOSS: 40.9819585020787\n",
      "EPOCH: 20663 LOSS: 40.981956641319385\n",
      "EPOCH: 20664 LOSS: 40.98195478071173\n",
      "EPOCH: 20665 LOSS: 40.98195292025575\n",
      "EPOCH: 20666 LOSS: 40.9819510599514\n",
      "EPOCH: 20667 LOSS: 40.98194919979864\n",
      "EPOCH: 20668 LOSS: 40.98194733979751\n",
      "EPOCH: 20669 LOSS: 40.981945479947925\n",
      "EPOCH: 20670 LOSS: 40.981943620249886\n",
      "EPOCH: 20671 LOSS: 40.98194176070337\n",
      "EPOCH: 20672 LOSS: 40.98193990130838\n",
      "EPOCH: 20673 LOSS: 40.98193804206486\n",
      "EPOCH: 20674 LOSS: 40.9819361829728\n",
      "EPOCH: 20675 LOSS: 40.98193432403218\n",
      "EPOCH: 20676 LOSS: 40.981932465243\n",
      "EPOCH: 20677 LOSS: 40.9819306066052\n",
      "EPOCH: 20678 LOSS: 40.98192874811877\n",
      "EPOCH: 20679 LOSS: 40.9819268897837\n",
      "EPOCH: 20680 LOSS: 40.9819250316\n",
      "EPOCH: 20681 LOSS: 40.98192317356756\n",
      "EPOCH: 20682 LOSS: 40.98192131568645\n",
      "EPOCH: 20683 LOSS: 40.98191945795658\n",
      "EPOCH: 20684 LOSS: 40.981917600377976\n",
      "EPOCH: 20685 LOSS: 40.981915742950605\n",
      "EPOCH: 20686 LOSS: 40.981913885674416\n",
      "EPOCH: 20687 LOSS: 40.981912028549424\n",
      "EPOCH: 20688 LOSS: 40.98191017157562\n",
      "EPOCH: 20689 LOSS: 40.981908314752914\n",
      "EPOCH: 20690 LOSS: 40.98190645808137\n",
      "EPOCH: 20691 LOSS: 40.98190460156089\n",
      "EPOCH: 20692 LOSS: 40.981902745191505\n",
      "EPOCH: 20693 LOSS: 40.98190088897319\n",
      "EPOCH: 20694 LOSS: 40.981899032905886\n",
      "EPOCH: 20695 LOSS: 40.981897176989605\n",
      "EPOCH: 20696 LOSS: 40.98189532122433\n",
      "EPOCH: 20697 LOSS: 40.98189346561\n",
      "EPOCH: 20698 LOSS: 40.98189161014664\n",
      "EPOCH: 20699 LOSS: 40.98188975483421\n",
      "EPOCH: 20700 LOSS: 40.981887899672685\n",
      "EPOCH: 20701 LOSS: 40.98188604466205\n",
      "EPOCH: 20702 LOSS: 40.98188418980226\n",
      "EPOCH: 20703 LOSS: 40.981882335093324\n",
      "EPOCH: 20704 LOSS: 40.981880480535224\n",
      "EPOCH: 20705 LOSS: 40.98187862612792\n",
      "EPOCH: 20706 LOSS: 40.981876771871384\n",
      "EPOCH: 20707 LOSS: 40.98187491776562\n",
      "EPOCH: 20708 LOSS: 40.98187306381058\n",
      "EPOCH: 20709 LOSS: 40.98187121000626\n",
      "EPOCH: 20710 LOSS: 40.98186935635265\n",
      "EPOCH: 20711 LOSS: 40.981867502849695\n",
      "EPOCH: 20712 LOSS: 40.9818656494974\n",
      "EPOCH: 20713 LOSS: 40.98186379629573\n",
      "EPOCH: 20714 LOSS: 40.981861943244674\n",
      "EPOCH: 20715 LOSS: 40.9818600903442\n",
      "EPOCH: 20716 LOSS: 40.98185823759431\n",
      "EPOCH: 20717 LOSS: 40.98185638499494\n",
      "EPOCH: 20718 LOSS: 40.98185453254612\n",
      "EPOCH: 20719 LOSS: 40.98185268024782\n",
      "EPOCH: 20720 LOSS: 40.98185082809996\n",
      "EPOCH: 20721 LOSS: 40.98184897610257\n",
      "EPOCH: 20722 LOSS: 40.981847124255644\n",
      "EPOCH: 20723 LOSS: 40.98184527255913\n",
      "EPOCH: 20724 LOSS: 40.981843421013004\n",
      "EPOCH: 20725 LOSS: 40.98184156961726\n",
      "EPOCH: 20726 LOSS: 40.98183971837185\n",
      "EPOCH: 20727 LOSS: 40.98183786727681\n",
      "EPOCH: 20728 LOSS: 40.98183601633207\n",
      "EPOCH: 20729 LOSS: 40.98183416553759\n",
      "EPOCH: 20730 LOSS: 40.981832314893424\n",
      "EPOCH: 20731 LOSS: 40.981830464399486\n",
      "EPOCH: 20732 LOSS: 40.98182861405578\n",
      "EPOCH: 20733 LOSS: 40.98182676386229\n",
      "EPOCH: 20734 LOSS: 40.98182491381897\n",
      "EPOCH: 20735 LOSS: 40.98182306392582\n",
      "EPOCH: 20736 LOSS: 40.98182121418282\n",
      "EPOCH: 20737 LOSS: 40.98181936458994\n",
      "EPOCH: 20738 LOSS: 40.98181751514716\n",
      "EPOCH: 20739 LOSS: 40.981815665854455\n",
      "EPOCH: 20740 LOSS: 40.98181381671182\n",
      "EPOCH: 20741 LOSS: 40.9818119677192\n",
      "EPOCH: 20742 LOSS: 40.98181011887663\n",
      "EPOCH: 20743 LOSS: 40.98180827018403\n",
      "EPOCH: 20744 LOSS: 40.98180642164142\n",
      "EPOCH: 20745 LOSS: 40.98180457324876\n",
      "EPOCH: 20746 LOSS: 40.981802725006034\n",
      "EPOCH: 20747 LOSS: 40.9818008769132\n",
      "EPOCH: 20748 LOSS: 40.981799028970265\n",
      "EPOCH: 20749 LOSS: 40.9817971811772\n",
      "EPOCH: 20750 LOSS: 40.98179533353398\n",
      "EPOCH: 20751 LOSS: 40.9817934860406\n",
      "EPOCH: 20752 LOSS: 40.98179163869702\n",
      "EPOCH: 20753 LOSS: 40.98178979150323\n",
      "EPOCH: 20754 LOSS: 40.981787944459185\n",
      "EPOCH: 20755 LOSS: 40.9817860975649\n",
      "EPOCH: 20756 LOSS: 40.981784250820326\n",
      "EPOCH: 20757 LOSS: 40.981782404225456\n",
      "EPOCH: 20758 LOSS: 40.98178055778027\n",
      "EPOCH: 20759 LOSS: 40.98177871148473\n",
      "EPOCH: 20760 LOSS: 40.98177686533882\n",
      "EPOCH: 20761 LOSS: 40.98177501934255\n",
      "EPOCH: 20762 LOSS: 40.98177317349587\n",
      "EPOCH: 20763 LOSS: 40.981771327798754\n",
      "EPOCH: 20764 LOSS: 40.98176948225119\n",
      "EPOCH: 20765 LOSS: 40.981767636853164\n",
      "EPOCH: 20766 LOSS: 40.98176579160464\n",
      "EPOCH: 20767 LOSS: 40.981763946505595\n",
      "EPOCH: 20768 LOSS: 40.98176210155605\n",
      "EPOCH: 20769 LOSS: 40.981760256755926\n",
      "EPOCH: 20770 LOSS: 40.981758412105236\n",
      "EPOCH: 20771 LOSS: 40.98175656760396\n",
      "EPOCH: 20772 LOSS: 40.98175472325206\n",
      "EPOCH: 20773 LOSS: 40.98175287904952\n",
      "EPOCH: 20774 LOSS: 40.98175103499632\n",
      "EPOCH: 20775 LOSS: 40.98174919109246\n",
      "EPOCH: 20776 LOSS: 40.9817473473379\n",
      "EPOCH: 20777 LOSS: 40.9817455037326\n",
      "EPOCH: 20778 LOSS: 40.98174366027655\n",
      "EPOCH: 20779 LOSS: 40.98174181696977\n",
      "EPOCH: 20780 LOSS: 40.98173997381219\n",
      "EPOCH: 20781 LOSS: 40.981738130803784\n",
      "EPOCH: 20782 LOSS: 40.981736287944585\n",
      "EPOCH: 20783 LOSS: 40.98173444523454\n",
      "EPOCH: 20784 LOSS: 40.98173260267359\n",
      "EPOCH: 20785 LOSS: 40.98173076026178\n",
      "EPOCH: 20786 LOSS: 40.981728917999064\n",
      "EPOCH: 20787 LOSS: 40.981727075885416\n",
      "EPOCH: 20788 LOSS: 40.9817252339208\n",
      "EPOCH: 20789 LOSS: 40.98172339210521\n",
      "EPOCH: 20790 LOSS: 40.98172155043865\n",
      "EPOCH: 20791 LOSS: 40.98171970892104\n",
      "EPOCH: 20792 LOSS: 40.98171786755244\n",
      "EPOCH: 20793 LOSS: 40.98171602633275\n",
      "EPOCH: 20794 LOSS: 40.98171418526199\n",
      "EPOCH: 20795 LOSS: 40.981712344340124\n",
      "EPOCH: 20796 LOSS: 40.98171050356716\n",
      "EPOCH: 20797 LOSS: 40.98170866294305\n",
      "EPOCH: 20798 LOSS: 40.98170682246777\n",
      "EPOCH: 20799 LOSS: 40.98170498214131\n",
      "EPOCH: 20800 LOSS: 40.98170314196364\n",
      "EPOCH: 20801 LOSS: 40.98170130193476\n",
      "EPOCH: 20802 LOSS: 40.98169946205462\n",
      "EPOCH: 20803 LOSS: 40.98169762232323\n",
      "EPOCH: 20804 LOSS: 40.98169578274056\n",
      "EPOCH: 20805 LOSS: 40.98169394330656\n",
      "EPOCH: 20806 LOSS: 40.981692104021235\n",
      "EPOCH: 20807 LOSS: 40.98169026488456\n",
      "EPOCH: 20808 LOSS: 40.98168842589652\n",
      "EPOCH: 20809 LOSS: 40.981686587057105\n",
      "EPOCH: 20810 LOSS: 40.98168474836625\n",
      "EPOCH: 20811 LOSS: 40.981682909823974\n",
      "EPOCH: 20812 LOSS: 40.98168107143026\n",
      "EPOCH: 20813 LOSS: 40.98167923318504\n",
      "EPOCH: 20814 LOSS: 40.981677395088354\n",
      "EPOCH: 20815 LOSS: 40.98167555714013\n",
      "EPOCH: 20816 LOSS: 40.981673719340364\n",
      "EPOCH: 20817 LOSS: 40.98167188168907\n",
      "EPOCH: 20818 LOSS: 40.98167004418616\n",
      "EPOCH: 20819 LOSS: 40.981668206831685\n",
      "EPOCH: 20820 LOSS: 40.98166636962557\n",
      "EPOCH: 20821 LOSS: 40.981664532567805\n",
      "EPOCH: 20822 LOSS: 40.98166269565839\n",
      "EPOCH: 20823 LOSS: 40.9816608588973\n",
      "EPOCH: 20824 LOSS: 40.98165902228449\n",
      "EPOCH: 20825 LOSS: 40.98165718581997\n",
      "EPOCH: 20826 LOSS: 40.9816553495037\n",
      "EPOCH: 20827 LOSS: 40.98165351333566\n",
      "EPOCH: 20828 LOSS: 40.981651677315824\n",
      "EPOCH: 20829 LOSS: 40.981649841444195\n",
      "EPOCH: 20830 LOSS: 40.98164800572072\n",
      "EPOCH: 20831 LOSS: 40.98164617014541\n",
      "EPOCH: 20832 LOSS: 40.981644334718226\n",
      "EPOCH: 20833 LOSS: 40.98164249943915\n",
      "EPOCH: 20834 LOSS: 40.981640664308145\n",
      "EPOCH: 20835 LOSS: 40.98163882932522\n",
      "EPOCH: 20836 LOSS: 40.98163699449036\n",
      "EPOCH: 20837 LOSS: 40.9816351598035\n",
      "EPOCH: 20838 LOSS: 40.98163332526466\n",
      "EPOCH: 20839 LOSS: 40.98163149087379\n",
      "EPOCH: 20840 LOSS: 40.9816296566309\n",
      "EPOCH: 20841 LOSS: 40.981627822535934\n",
      "EPOCH: 20842 LOSS: 40.9816259885889\n",
      "EPOCH: 20843 LOSS: 40.98162415478977\n",
      "EPOCH: 20844 LOSS: 40.98162232113851\n",
      "EPOCH: 20845 LOSS: 40.98162048763512\n",
      "EPOCH: 20846 LOSS: 40.98161865427956\n",
      "EPOCH: 20847 LOSS: 40.98161682107181\n",
      "EPOCH: 20848 LOSS: 40.98161498801187\n",
      "EPOCH: 20849 LOSS: 40.98161315509971\n",
      "EPOCH: 20850 LOSS: 40.98161132233529\n",
      "EPOCH: 20851 LOSS: 40.98160948971861\n",
      "EPOCH: 20852 LOSS: 40.98160765724965\n",
      "EPOCH: 20853 LOSS: 40.98160582492838\n",
      "EPOCH: 20854 LOSS: 40.98160399275478\n",
      "EPOCH: 20855 LOSS: 40.98160216072883\n",
      "EPOCH: 20856 LOSS: 40.98160032885051\n",
      "EPOCH: 20857 LOSS: 40.981598497119805\n",
      "EPOCH: 20858 LOSS: 40.981596665536685\n",
      "EPOCH: 20859 LOSS: 40.981594834101145\n",
      "EPOCH: 20860 LOSS: 40.98159300281315\n",
      "EPOCH: 20861 LOSS: 40.981591171672676\n",
      "EPOCH: 20862 LOSS: 40.98158934067972\n",
      "EPOCH: 20863 LOSS: 40.98158750983423\n",
      "EPOCH: 20864 LOSS: 40.98158567913622\n",
      "EPOCH: 20865 LOSS: 40.98158384858564\n",
      "EPOCH: 20866 LOSS: 40.9815820181825\n",
      "EPOCH: 20867 LOSS: 40.98158018792677\n",
      "EPOCH: 20868 LOSS: 40.981578357818414\n",
      "EPOCH: 20869 LOSS: 40.981576527857406\n",
      "EPOCH: 20870 LOSS: 40.98157469804376\n",
      "EPOCH: 20871 LOSS: 40.98157286837743\n",
      "EPOCH: 20872 LOSS: 40.98157103885839\n",
      "EPOCH: 20873 LOSS: 40.981569209486636\n",
      "EPOCH: 20874 LOSS: 40.98156738026215\n",
      "EPOCH: 20875 LOSS: 40.98156555118488\n",
      "EPOCH: 20876 LOSS: 40.98156372225483\n",
      "EPOCH: 20877 LOSS: 40.981561893472\n",
      "EPOCH: 20878 LOSS: 40.981560064836316\n",
      "EPOCH: 20879 LOSS: 40.981558236347816\n",
      "EPOCH: 20880 LOSS: 40.981556408006426\n",
      "EPOCH: 20881 LOSS: 40.98155457981217\n",
      "EPOCH: 20882 LOSS: 40.981552751765\n",
      "EPOCH: 20883 LOSS: 40.9815509238649\n",
      "EPOCH: 20884 LOSS: 40.98154909611186\n",
      "EPOCH: 20885 LOSS: 40.98154726850585\n",
      "EPOCH: 20886 LOSS: 40.98154544104684\n",
      "EPOCH: 20887 LOSS: 40.98154361373483\n",
      "EPOCH: 20888 LOSS: 40.98154178656979\n",
      "EPOCH: 20889 LOSS: 40.9815399595517\n",
      "EPOCH: 20890 LOSS: 40.98153813268054\n",
      "EPOCH: 20891 LOSS: 40.98153630595628\n",
      "EPOCH: 20892 LOSS: 40.98153447937891\n",
      "EPOCH: 20893 LOSS: 40.98153265294841\n",
      "EPOCH: 20894 LOSS: 40.98153082666475\n",
      "EPOCH: 20895 LOSS: 40.98152900052792\n",
      "EPOCH: 20896 LOSS: 40.9815271745379\n",
      "EPOCH: 20897 LOSS: 40.98152534869467\n",
      "EPOCH: 20898 LOSS: 40.98152352299818\n",
      "EPOCH: 20899 LOSS: 40.98152169744844\n",
      "EPOCH: 20900 LOSS: 40.98151987204543\n",
      "EPOCH: 20901 LOSS: 40.981518046789134\n",
      "EPOCH: 20902 LOSS: 40.9815162216795\n",
      "EPOCH: 20903 LOSS: 40.981514396716534\n",
      "EPOCH: 20904 LOSS: 40.98151257190021\n",
      "EPOCH: 20905 LOSS: 40.981510747230516\n",
      "EPOCH: 20906 LOSS: 40.98150892270741\n",
      "EPOCH: 20907 LOSS: 40.981507098330894\n",
      "EPOCH: 20908 LOSS: 40.98150527410092\n",
      "EPOCH: 20909 LOSS: 40.981503450017485\n",
      "EPOCH: 20910 LOSS: 40.981501626080586\n",
      "EPOCH: 20911 LOSS: 40.98149980229017\n",
      "EPOCH: 20912 LOSS: 40.98149797864623\n",
      "EPOCH: 20913 LOSS: 40.98149615514875\n",
      "EPOCH: 20914 LOSS: 40.981494331797705\n",
      "EPOCH: 20915 LOSS: 40.981492508593064\n",
      "EPOCH: 20916 LOSS: 40.98149068553484\n",
      "EPOCH: 20917 LOSS: 40.98148886262297\n",
      "EPOCH: 20918 LOSS: 40.981487039857456\n",
      "EPOCH: 20919 LOSS: 40.98148521723827\n",
      "EPOCH: 20920 LOSS: 40.981483394765405\n",
      "EPOCH: 20921 LOSS: 40.981481572438845\n",
      "EPOCH: 20922 LOSS: 40.98147975025855\n",
      "EPOCH: 20923 LOSS: 40.98147792822449\n",
      "EPOCH: 20924 LOSS: 40.98147610633666\n",
      "EPOCH: 20925 LOSS: 40.98147428459505\n",
      "EPOCH: 20926 LOSS: 40.98147246299964\n",
      "EPOCH: 20927 LOSS: 40.98147064155039\n",
      "EPOCH: 20928 LOSS: 40.98146882024729\n",
      "EPOCH: 20929 LOSS: 40.981466999090316\n",
      "EPOCH: 20930 LOSS: 40.98146517807944\n",
      "EPOCH: 20931 LOSS: 40.981463357214665\n",
      "EPOCH: 20932 LOSS: 40.98146153649594\n",
      "EPOCH: 20933 LOSS: 40.98145971592329\n",
      "EPOCH: 20934 LOSS: 40.981457895496646\n",
      "EPOCH: 20935 LOSS: 40.981456075216\n",
      "EPOCH: 20936 LOSS: 40.98145425508136\n",
      "EPOCH: 20937 LOSS: 40.98145243509268\n",
      "EPOCH: 20938 LOSS: 40.981450615249926\n",
      "EPOCH: 20939 LOSS: 40.98144879555312\n",
      "EPOCH: 20940 LOSS: 40.98144697600221\n",
      "EPOCH: 20941 LOSS: 40.98144515659717\n",
      "EPOCH: 20942 LOSS: 40.981443337338\n",
      "EPOCH: 20943 LOSS: 40.98144151822467\n",
      "EPOCH: 20944 LOSS: 40.981439699257166\n",
      "EPOCH: 20945 LOSS: 40.981437880435465\n",
      "EPOCH: 20946 LOSS: 40.98143606175956\n",
      "EPOCH: 20947 LOSS: 40.98143424322939\n",
      "EPOCH: 20948 LOSS: 40.981432424844954\n",
      "EPOCH: 20949 LOSS: 40.98143060660625\n",
      "EPOCH: 20950 LOSS: 40.981428788513256\n",
      "EPOCH: 20951 LOSS: 40.981426970565934\n",
      "EPOCH: 20952 LOSS: 40.98142515276427\n",
      "EPOCH: 20953 LOSS: 40.98142333510823\n",
      "EPOCH: 20954 LOSS: 40.98142151759782\n",
      "EPOCH: 20955 LOSS: 40.98141970023301\n",
      "EPOCH: 20956 LOSS: 40.981417883013776\n",
      "EPOCH: 20957 LOSS: 40.981416065940095\n",
      "EPOCH: 20958 LOSS: 40.981414249011955\n",
      "EPOCH: 20959 LOSS: 40.98141243222935\n",
      "EPOCH: 20960 LOSS: 40.9814106155922\n",
      "EPOCH: 20961 LOSS: 40.98140879910055\n",
      "EPOCH: 20962 LOSS: 40.98140698275435\n",
      "EPOCH: 20963 LOSS: 40.98140516655359\n",
      "EPOCH: 20964 LOSS: 40.98140335049824\n",
      "EPOCH: 20965 LOSS: 40.98140153458828\n",
      "EPOCH: 20966 LOSS: 40.981399718823695\n",
      "EPOCH: 20967 LOSS: 40.98139790320447\n",
      "EPOCH: 20968 LOSS: 40.98139608773058\n",
      "EPOCH: 20969 LOSS: 40.981394272401985\n",
      "EPOCH: 20970 LOSS: 40.981392457218696\n",
      "EPOCH: 20971 LOSS: 40.98139064218068\n",
      "EPOCH: 20972 LOSS: 40.9813888272879\n",
      "EPOCH: 20973 LOSS: 40.98138701254037\n",
      "EPOCH: 20974 LOSS: 40.98138519793805\n",
      "EPOCH: 20975 LOSS: 40.98138338348092\n",
      "EPOCH: 20976 LOSS: 40.98138156916896\n",
      "EPOCH: 20977 LOSS: 40.98137975500214\n",
      "EPOCH: 20978 LOSS: 40.98137794098045\n",
      "EPOCH: 20979 LOSS: 40.981376127103886\n",
      "EPOCH: 20980 LOSS: 40.9813743133724\n",
      "EPOCH: 20981 LOSS: 40.98137249978599\n",
      "EPOCH: 20982 LOSS: 40.98137068634462\n",
      "EPOCH: 20983 LOSS: 40.9813688730483\n",
      "EPOCH: 20984 LOSS: 40.981367059896954\n",
      "EPOCH: 20985 LOSS: 40.98136524689062\n",
      "EPOCH: 20986 LOSS: 40.98136343402924\n",
      "EPOCH: 20987 LOSS: 40.98136162131283\n",
      "EPOCH: 20988 LOSS: 40.98135980874133\n",
      "EPOCH: 20989 LOSS: 40.981357996314735\n",
      "EPOCH: 20990 LOSS: 40.98135618403303\n",
      "EPOCH: 20991 LOSS: 40.9813543718962\n",
      "EPOCH: 20992 LOSS: 40.98135255990422\n",
      "EPOCH: 20993 LOSS: 40.981350748057054\n",
      "EPOCH: 20994 LOSS: 40.981348936354685\n",
      "EPOCH: 20995 LOSS: 40.981347124797104\n",
      "EPOCH: 20996 LOSS: 40.98134531338432\n",
      "EPOCH: 20997 LOSS: 40.981343502116246\n",
      "EPOCH: 20998 LOSS: 40.98134169099292\n",
      "EPOCH: 20999 LOSS: 40.98133988001429\n",
      "EPOCH: 21000 LOSS: 40.98133806918034\n",
      "EPOCH: 21001 LOSS: 40.98133625849104\n",
      "EPOCH: 21002 LOSS: 40.981334447946416\n",
      "EPOCH: 21003 LOSS: 40.98133263754641\n",
      "EPOCH: 21004 LOSS: 40.981330827291\n",
      "EPOCH: 21005 LOSS: 40.98132901718017\n",
      "EPOCH: 21006 LOSS: 40.981327207213916\n",
      "EPOCH: 21007 LOSS: 40.98132539739218\n",
      "EPOCH: 21008 LOSS: 40.981323587714996\n",
      "EPOCH: 21009 LOSS: 40.9813217781823\n",
      "EPOCH: 21010 LOSS: 40.981319968794104\n",
      "EPOCH: 21011 LOSS: 40.98131815955034\n",
      "EPOCH: 21012 LOSS: 40.98131635045104\n",
      "EPOCH: 21013 LOSS: 40.98131454149615\n",
      "EPOCH: 21014 LOSS: 40.98131273268568\n",
      "EPOCH: 21015 LOSS: 40.98131092401958\n",
      "EPOCH: 21016 LOSS: 40.98130911549785\n",
      "EPOCH: 21017 LOSS: 40.98130730712045\n",
      "EPOCH: 21018 LOSS: 40.98130549888739\n",
      "EPOCH: 21019 LOSS: 40.98130369079861\n",
      "EPOCH: 21020 LOSS: 40.981301882854126\n",
      "EPOCH: 21021 LOSS: 40.981300075053895\n",
      "EPOCH: 21022 LOSS: 40.981298267397904\n",
      "EPOCH: 21023 LOSS: 40.981296459886124\n",
      "EPOCH: 21024 LOSS: 40.98129465251857\n",
      "EPOCH: 21025 LOSS: 40.98129284529519\n",
      "EPOCH: 21026 LOSS: 40.98129103821596\n",
      "EPOCH: 21027 LOSS: 40.98128923128088\n",
      "EPOCH: 21028 LOSS: 40.98128742448992\n",
      "EPOCH: 21029 LOSS: 40.98128561784305\n",
      "EPOCH: 21030 LOSS: 40.98128381134027\n",
      "EPOCH: 21031 LOSS: 40.98128200498155\n",
      "EPOCH: 21032 LOSS: 40.98128019876687\n",
      "EPOCH: 21033 LOSS: 40.981278392696204\n",
      "EPOCH: 21034 LOSS: 40.981276586769525\n",
      "EPOCH: 21035 LOSS: 40.98127478098685\n",
      "EPOCH: 21036 LOSS: 40.98127297534812\n",
      "EPOCH: 21037 LOSS: 40.98127116985334\n",
      "EPOCH: 21038 LOSS: 40.98126936450247\n",
      "EPOCH: 21039 LOSS: 40.9812675592955\n",
      "EPOCH: 21040 LOSS: 40.981265754232425\n",
      "EPOCH: 21041 LOSS: 40.9812639493132\n",
      "EPOCH: 21042 LOSS: 40.98126214453781\n",
      "EPOCH: 21043 LOSS: 40.981260339906235\n",
      "EPOCH: 21044 LOSS: 40.981258535418476\n",
      "EPOCH: 21045 LOSS: 40.98125673107449\n",
      "EPOCH: 21046 LOSS: 40.98125492687424\n",
      "EPOCH: 21047 LOSS: 40.98125312281775\n",
      "EPOCH: 21048 LOSS: 40.98125131890499\n",
      "EPOCH: 21049 LOSS: 40.9812495151359\n",
      "EPOCH: 21050 LOSS: 40.98124771151052\n",
      "EPOCH: 21051 LOSS: 40.98124590802878\n",
      "EPOCH: 21052 LOSS: 40.981244104690674\n",
      "EPOCH: 21053 LOSS: 40.981242301496195\n",
      "EPOCH: 21054 LOSS: 40.981240498445324\n",
      "EPOCH: 21055 LOSS: 40.98123869553802\n",
      "EPOCH: 21056 LOSS: 40.98123689277427\n",
      "EPOCH: 21057 LOSS: 40.98123509015407\n",
      "EPOCH: 21058 LOSS: 40.981233287677384\n",
      "EPOCH: 21059 LOSS: 40.9812314853442\n",
      "EPOCH: 21060 LOSS: 40.981229683154496\n",
      "EPOCH: 21061 LOSS: 40.98122788110824\n",
      "EPOCH: 21062 LOSS: 40.98122607920542\n",
      "EPOCH: 21063 LOSS: 40.98122427744604\n",
      "EPOCH: 21064 LOSS: 40.98122247583005\n",
      "EPOCH: 21065 LOSS: 40.98122067435744\n",
      "EPOCH: 21066 LOSS: 40.98121887302818\n",
      "EPOCH: 21067 LOSS: 40.981217071842266\n",
      "EPOCH: 21068 LOSS: 40.98121527079966\n",
      "EPOCH: 21069 LOSS: 40.98121346990038\n",
      "EPOCH: 21070 LOSS: 40.98121166914435\n",
      "EPOCH: 21071 LOSS: 40.981209868531586\n",
      "EPOCH: 21072 LOSS: 40.98120806806205\n",
      "EPOCH: 21073 LOSS: 40.981206267735764\n",
      "EPOCH: 21074 LOSS: 40.98120446755267\n",
      "EPOCH: 21075 LOSS: 40.98120266751273\n",
      "EPOCH: 21076 LOSS: 40.981200867615975\n",
      "EPOCH: 21077 LOSS: 40.98119906786234\n",
      "EPOCH: 21078 LOSS: 40.98119726825184\n",
      "EPOCH: 21079 LOSS: 40.981195468784435\n",
      "EPOCH: 21080 LOSS: 40.9811936694601\n",
      "EPOCH: 21081 LOSS: 40.98119187027884\n",
      "EPOCH: 21082 LOSS: 40.98119007124061\n",
      "EPOCH: 21083 LOSS: 40.98118827234541\n",
      "EPOCH: 21084 LOSS: 40.9811864735932\n",
      "EPOCH: 21085 LOSS: 40.98118467498397\n",
      "EPOCH: 21086 LOSS: 40.981182876517714\n",
      "EPOCH: 21087 LOSS: 40.98118107819438\n",
      "EPOCH: 21088 LOSS: 40.981179280013976\n",
      "EPOCH: 21089 LOSS: 40.981177481976474\n",
      "EPOCH: 21090 LOSS: 40.98117568408185\n",
      "EPOCH: 21091 LOSS: 40.98117388633008\n",
      "EPOCH: 21092 LOSS: 40.981172088721145\n",
      "EPOCH: 21093 LOSS: 40.98117029125505\n",
      "EPOCH: 21094 LOSS: 40.98116849393174\n",
      "EPOCH: 21095 LOSS: 40.98116669675123\n",
      "EPOCH: 21096 LOSS: 40.98116489971346\n",
      "EPOCH: 21097 LOSS: 40.98116310281844\n",
      "EPOCH: 21098 LOSS: 40.98116130606614\n",
      "EPOCH: 21099 LOSS: 40.98115950945656\n",
      "EPOCH: 21100 LOSS: 40.98115771298965\n",
      "EPOCH: 21101 LOSS: 40.98115591666539\n",
      "EPOCH: 21102 LOSS: 40.98115412048377\n",
      "EPOCH: 21103 LOSS: 40.98115232444478\n",
      "EPOCH: 21104 LOSS: 40.981150528548405\n",
      "EPOCH: 21105 LOSS: 40.9811487327946\n",
      "EPOCH: 21106 LOSS: 40.98114693718336\n",
      "EPOCH: 21107 LOSS: 40.981145141714656\n",
      "EPOCH: 21108 LOSS: 40.981143346388485\n",
      "EPOCH: 21109 LOSS: 40.98114155120483\n",
      "EPOCH: 21110 LOSS: 40.98113975616364\n",
      "EPOCH: 21111 LOSS: 40.98113796126491\n",
      "EPOCH: 21112 LOSS: 40.981136166508634\n",
      "EPOCH: 21113 LOSS: 40.98113437189477\n",
      "EPOCH: 21114 LOSS: 40.981132577423324\n",
      "EPOCH: 21115 LOSS: 40.98113078309426\n",
      "EPOCH: 21116 LOSS: 40.98112898890755\n",
      "EPOCH: 21117 LOSS: 40.98112719486319\n",
      "EPOCH: 21118 LOSS: 40.98112540096116\n",
      "EPOCH: 21119 LOSS: 40.981123607201425\n",
      "EPOCH: 21120 LOSS: 40.98112181358398\n",
      "EPOCH: 21121 LOSS: 40.981120020108804\n",
      "EPOCH: 21122 LOSS: 40.98111822677587\n",
      "EPOCH: 21123 LOSS: 40.98111643358517\n",
      "EPOCH: 21124 LOSS: 40.981114640536674\n",
      "EPOCH: 21125 LOSS: 40.98111284763037\n",
      "EPOCH: 21126 LOSS: 40.981111054866226\n",
      "EPOCH: 21127 LOSS: 40.98110926224422\n",
      "EPOCH: 21128 LOSS: 40.98110746976434\n",
      "EPOCH: 21129 LOSS: 40.98110567742658\n",
      "EPOCH: 21130 LOSS: 40.981103885230915\n",
      "EPOCH: 21131 LOSS: 40.9811020931773\n",
      "EPOCH: 21132 LOSS: 40.98110030126573\n",
      "EPOCH: 21133 LOSS: 40.98109850949621\n",
      "EPOCH: 21134 LOSS: 40.98109671786868\n",
      "EPOCH: 21135 LOSS: 40.98109492638315\n",
      "EPOCH: 21136 LOSS: 40.981093135039586\n",
      "EPOCH: 21137 LOSS: 40.981091343837974\n",
      "EPOCH: 21138 LOSS: 40.98108955277827\n",
      "EPOCH: 21139 LOSS: 40.98108776186049\n",
      "EPOCH: 21140 LOSS: 40.981085971084624\n",
      "EPOCH: 21141 LOSS: 40.981084180450594\n",
      "EPOCH: 21142 LOSS: 40.981082389958445\n",
      "EPOCH: 21143 LOSS: 40.981080599608106\n",
      "EPOCH: 21144 LOSS: 40.98107880939959\n",
      "EPOCH: 21145 LOSS: 40.98107701933286\n",
      "EPOCH: 21146 LOSS: 40.98107522940791\n",
      "EPOCH: 21147 LOSS: 40.98107343962471\n",
      "EPOCH: 21148 LOSS: 40.98107164998322\n",
      "EPOCH: 21149 LOSS: 40.98106986048348\n",
      "EPOCH: 21150 LOSS: 40.98106807112541\n",
      "EPOCH: 21151 LOSS: 40.981066281908994\n",
      "EPOCH: 21152 LOSS: 40.981064492834264\n",
      "EPOCH: 21153 LOSS: 40.98106270390116\n",
      "EPOCH: 21154 LOSS: 40.98106091510968\n",
      "EPOCH: 21155 LOSS: 40.981059126459776\n",
      "EPOCH: 21156 LOSS: 40.981057337951455\n",
      "EPOCH: 21157 LOSS: 40.9810555495847\n",
      "EPOCH: 21158 LOSS: 40.981053761359476\n",
      "EPOCH: 21159 LOSS: 40.981051973275754\n",
      "EPOCH: 21160 LOSS: 40.98105018533355\n",
      "EPOCH: 21161 LOSS: 40.98104839753282\n",
      "EPOCH: 21162 LOSS: 40.98104660987353\n",
      "EPOCH: 21163 LOSS: 40.981044822355685\n",
      "EPOCH: 21164 LOSS: 40.981043034979265\n",
      "EPOCH: 21165 LOSS: 40.981041247744244\n",
      "EPOCH: 21166 LOSS: 40.98103946065059\n",
      "EPOCH: 21167 LOSS: 40.98103767369832\n",
      "EPOCH: 21168 LOSS: 40.981035886887355\n",
      "EPOCH: 21169 LOSS: 40.98103410021773\n",
      "EPOCH: 21170 LOSS: 40.981032313689404\n",
      "EPOCH: 21171 LOSS: 40.98103052730235\n",
      "EPOCH: 21172 LOSS: 40.98102874105656\n",
      "EPOCH: 21173 LOSS: 40.98102695495203\n",
      "EPOCH: 21174 LOSS: 40.9810251689887\n",
      "EPOCH: 21175 LOSS: 40.98102338316657\n",
      "EPOCH: 21176 LOSS: 40.98102159748565\n",
      "EPOCH: 21177 LOSS: 40.98101981194586\n",
      "EPOCH: 21178 LOSS: 40.98101802654723\n",
      "EPOCH: 21179 LOSS: 40.98101624128974\n",
      "EPOCH: 21180 LOSS: 40.98101445617333\n",
      "EPOCH: 21181 LOSS: 40.981012671198016\n",
      "EPOCH: 21182 LOSS: 40.981010886363755\n",
      "EPOCH: 21183 LOSS: 40.98100910167055\n",
      "EPOCH: 21184 LOSS: 40.98100731711838\n",
      "EPOCH: 21185 LOSS: 40.981005532707215\n",
      "EPOCH: 21186 LOSS: 40.981003748437004\n",
      "EPOCH: 21187 LOSS: 40.981001964307794\n",
      "EPOCH: 21188 LOSS: 40.981000180319526\n",
      "EPOCH: 21189 LOSS: 40.980998396472174\n",
      "EPOCH: 21190 LOSS: 40.98099661276575\n",
      "EPOCH: 21191 LOSS: 40.9809948292002\n",
      "EPOCH: 21192 LOSS: 40.98099304577551\n",
      "EPOCH: 21193 LOSS: 40.980991262491685\n",
      "EPOCH: 21194 LOSS: 40.98098947934869\n",
      "EPOCH: 21195 LOSS: 40.98098769634652\n",
      "EPOCH: 21196 LOSS: 40.98098591348514\n",
      "EPOCH: 21197 LOSS: 40.98098413076451\n",
      "EPOCH: 21198 LOSS: 40.98098234818463\n",
      "EPOCH: 21199 LOSS: 40.98098056574551\n",
      "EPOCH: 21200 LOSS: 40.98097878344707\n",
      "EPOCH: 21201 LOSS: 40.98097700128936\n",
      "EPOCH: 21202 LOSS: 40.98097521927231\n",
      "EPOCH: 21203 LOSS: 40.98097343739591\n",
      "EPOCH: 21204 LOSS: 40.98097165566015\n",
      "EPOCH: 21205 LOSS: 40.98096987406499\n",
      "EPOCH: 21206 LOSS: 40.98096809261045\n",
      "EPOCH: 21207 LOSS: 40.98096631129647\n",
      "EPOCH: 21208 LOSS: 40.98096453012305\n",
      "EPOCH: 21209 LOSS: 40.98096274909018\n",
      "EPOCH: 21210 LOSS: 40.98096096819782\n",
      "EPOCH: 21211 LOSS: 40.98095918744596\n",
      "EPOCH: 21212 LOSS: 40.980957406834584\n",
      "EPOCH: 21213 LOSS: 40.98095562636365\n",
      "EPOCH: 21214 LOSS: 40.98095384603318\n",
      "EPOCH: 21215 LOSS: 40.98095206584312\n",
      "EPOCH: 21216 LOSS: 40.980950285793455\n",
      "EPOCH: 21217 LOSS: 40.98094850588417\n",
      "EPOCH: 21218 LOSS: 40.98094672611528\n",
      "EPOCH: 21219 LOSS: 40.98094494648671\n",
      "EPOCH: 21220 LOSS: 40.980943166998465\n",
      "EPOCH: 21221 LOSS: 40.98094138765052\n",
      "EPOCH: 21222 LOSS: 40.98093960844287\n",
      "EPOCH: 21223 LOSS: 40.98093782937547\n",
      "EPOCH: 21224 LOSS: 40.980936050448335\n",
      "EPOCH: 21225 LOSS: 40.98093427166142\n",
      "EPOCH: 21226 LOSS: 40.98093249301471\n",
      "EPOCH: 21227 LOSS: 40.980930714508204\n",
      "EPOCH: 21228 LOSS: 40.98092893614184\n",
      "EPOCH: 21229 LOSS: 40.98092715791563\n",
      "EPOCH: 21230 LOSS: 40.980925379829564\n",
      "EPOCH: 21231 LOSS: 40.980923601883596\n",
      "EPOCH: 21232 LOSS: 40.98092182407771\n",
      "EPOCH: 21233 LOSS: 40.980920046411924\n",
      "EPOCH: 21234 LOSS: 40.98091826888617\n",
      "EPOCH: 21235 LOSS: 40.98091649150045\n",
      "EPOCH: 21236 LOSS: 40.98091471425474\n",
      "EPOCH: 21237 LOSS: 40.98091293714904\n",
      "EPOCH: 21238 LOSS: 40.9809111601833\n",
      "EPOCH: 21239 LOSS: 40.98090938335753\n",
      "EPOCH: 21240 LOSS: 40.98090760667168\n",
      "EPOCH: 21241 LOSS: 40.98090583012574\n",
      "EPOCH: 21242 LOSS: 40.98090405371971\n",
      "EPOCH: 21243 LOSS: 40.98090227745355\n",
      "EPOCH: 21244 LOSS: 40.98090050132727\n",
      "EPOCH: 21245 LOSS: 40.98089872534079\n",
      "EPOCH: 21246 LOSS: 40.98089694949416\n",
      "EPOCH: 21247 LOSS: 40.980895173787324\n",
      "EPOCH: 21248 LOSS: 40.98089339822029\n",
      "EPOCH: 21249 LOSS: 40.98089162279297\n",
      "EPOCH: 21250 LOSS: 40.98088984750542\n",
      "EPOCH: 21251 LOSS: 40.98088807235761\n",
      "EPOCH: 21252 LOSS: 40.98088629734947\n",
      "EPOCH: 21253 LOSS: 40.98088452248103\n",
      "EPOCH: 21254 LOSS: 40.98088274775225\n",
      "EPOCH: 21255 LOSS: 40.98088097316311\n",
      "EPOCH: 21256 LOSS: 40.98087919871361\n",
      "EPOCH: 21257 LOSS: 40.9808774244037\n",
      "EPOCH: 21258 LOSS: 40.98087565023339\n",
      "EPOCH: 21259 LOSS: 40.980873876202644\n",
      "EPOCH: 21260 LOSS: 40.98087210231146\n",
      "EPOCH: 21261 LOSS: 40.98087032855978\n",
      "EPOCH: 21262 LOSS: 40.98086855494763\n",
      "EPOCH: 21263 LOSS: 40.98086678147497\n",
      "EPOCH: 21264 LOSS: 40.98086500814178\n",
      "EPOCH: 21265 LOSS: 40.98086323494803\n",
      "EPOCH: 21266 LOSS: 40.980861461893724\n",
      "EPOCH: 21267 LOSS: 40.98085968897883\n",
      "EPOCH: 21268 LOSS: 40.98085791620333\n",
      "EPOCH: 21269 LOSS: 40.980856143567195\n",
      "EPOCH: 21270 LOSS: 40.980854371070436\n",
      "EPOCH: 21271 LOSS: 40.98085259871299\n",
      "EPOCH: 21272 LOSS: 40.98085082649488\n",
      "EPOCH: 21273 LOSS: 40.98084905441607\n",
      "EPOCH: 21274 LOSS: 40.98084728247653\n",
      "EPOCH: 21275 LOSS: 40.98084551067625\n",
      "EPOCH: 21276 LOSS: 40.980843739015214\n",
      "EPOCH: 21277 LOSS: 40.98084196749339\n",
      "EPOCH: 21278 LOSS: 40.980840196110776\n",
      "EPOCH: 21279 LOSS: 40.98083842486734\n",
      "EPOCH: 21280 LOSS: 40.98083665376308\n",
      "EPOCH: 21281 LOSS: 40.980834882797936\n",
      "EPOCH: 21282 LOSS: 40.98083311197195\n",
      "EPOCH: 21283 LOSS: 40.98083134128506\n",
      "EPOCH: 21284 LOSS: 40.98082957073725\n",
      "EPOCH: 21285 LOSS: 40.98082780032851\n",
      "EPOCH: 21286 LOSS: 40.980826030058815\n",
      "EPOCH: 21287 LOSS: 40.98082425992814\n",
      "EPOCH: 21288 LOSS: 40.980822489936486\n",
      "EPOCH: 21289 LOSS: 40.98082072008383\n",
      "EPOCH: 21290 LOSS: 40.98081895037012\n",
      "EPOCH: 21291 LOSS: 40.9808171807954\n",
      "EPOCH: 21292 LOSS: 40.980815411359565\n",
      "EPOCH: 21293 LOSS: 40.98081364206268\n",
      "EPOCH: 21294 LOSS: 40.98081187290469\n",
      "EPOCH: 21295 LOSS: 40.98081010388555\n",
      "EPOCH: 21296 LOSS: 40.98080833500528\n",
      "EPOCH: 21297 LOSS: 40.98080656626384\n",
      "EPOCH: 21298 LOSS: 40.98080479766121\n",
      "EPOCH: 21299 LOSS: 40.980803029197396\n",
      "EPOCH: 21300 LOSS: 40.98080126087237\n",
      "EPOCH: 21301 LOSS: 40.98079949268608\n",
      "EPOCH: 21302 LOSS: 40.98079772463854\n",
      "EPOCH: 21303 LOSS: 40.98079595672972\n",
      "EPOCH: 21304 LOSS: 40.98079418895962\n",
      "EPOCH: 21305 LOSS: 40.98079242132818\n",
      "EPOCH: 21306 LOSS: 40.9807906538354\n",
      "EPOCH: 21307 LOSS: 40.98078888648129\n",
      "EPOCH: 21308 LOSS: 40.980787119265784\n",
      "EPOCH: 21309 LOSS: 40.98078535218892\n",
      "EPOCH: 21310 LOSS: 40.9807835852506\n",
      "EPOCH: 21311 LOSS: 40.980781818450865\n",
      "EPOCH: 21312 LOSS: 40.98078005178968\n",
      "EPOCH: 21313 LOSS: 40.98077828526702\n",
      "EPOCH: 21314 LOSS: 40.98077651888288\n",
      "EPOCH: 21315 LOSS: 40.980774752637224\n",
      "EPOCH: 21316 LOSS: 40.98077298653005\n",
      "EPOCH: 21317 LOSS: 40.98077122056133\n",
      "EPOCH: 21318 LOSS: 40.98076945473102\n",
      "EPOCH: 21319 LOSS: 40.980767689039155\n",
      "EPOCH: 21320 LOSS: 40.98076592348566\n",
      "EPOCH: 21321 LOSS: 40.98076415807057\n",
      "EPOCH: 21322 LOSS: 40.98076239279383\n",
      "EPOCH: 21323 LOSS: 40.980760627655414\n",
      "EPOCH: 21324 LOSS: 40.980758862655335\n",
      "EPOCH: 21325 LOSS: 40.98075709779356\n",
      "EPOCH: 21326 LOSS: 40.98075533307006\n",
      "EPOCH: 21327 LOSS: 40.980753568484815\n",
      "EPOCH: 21328 LOSS: 40.98075180403781\n",
      "EPOCH: 21329 LOSS: 40.98075003972903\n",
      "EPOCH: 21330 LOSS: 40.98074827555847\n",
      "EPOCH: 21331 LOSS: 40.98074651152609\n",
      "EPOCH: 21332 LOSS: 40.980744747631874\n",
      "EPOCH: 21333 LOSS: 40.980742983875814\n",
      "EPOCH: 21334 LOSS: 40.98074122025787\n",
      "EPOCH: 21335 LOSS: 40.98073945677804\n",
      "EPOCH: 21336 LOSS: 40.98073769343632\n",
      "EPOCH: 21337 LOSS: 40.98073593023263\n",
      "EPOCH: 21338 LOSS: 40.98073416716703\n",
      "EPOCH: 21339 LOSS: 40.98073240423946\n",
      "EPOCH: 21340 LOSS: 40.980730641449895\n",
      "EPOCH: 21341 LOSS: 40.98072887879832\n",
      "EPOCH: 21342 LOSS: 40.98072711628474\n",
      "EPOCH: 21343 LOSS: 40.98072535390911\n",
      "EPOCH: 21344 LOSS: 40.980723591671406\n",
      "EPOCH: 21345 LOSS: 40.980721829571635\n",
      "EPOCH: 21346 LOSS: 40.98072006760975\n",
      "EPOCH: 21347 LOSS: 40.98071830578576\n",
      "EPOCH: 21348 LOSS: 40.980716544099636\n",
      "EPOCH: 21349 LOSS: 40.980714782551345\n",
      "EPOCH: 21350 LOSS: 40.980713021140886\n",
      "EPOCH: 21351 LOSS: 40.98071125986823\n",
      "EPOCH: 21352 LOSS: 40.980709498733354\n",
      "EPOCH: 21353 LOSS: 40.980707737736246\n",
      "EPOCH: 21354 LOSS: 40.980705976876905\n",
      "EPOCH: 21355 LOSS: 40.980704216155274\n",
      "EPOCH: 21356 LOSS: 40.980702455571375\n",
      "EPOCH: 21357 LOSS: 40.98070069512514\n",
      "EPOCH: 21358 LOSS: 40.980698934816594\n",
      "EPOCH: 21359 LOSS: 40.98069717464569\n",
      "EPOCH: 21360 LOSS: 40.98069541461243\n",
      "EPOCH: 21361 LOSS: 40.9806936547168\n",
      "EPOCH: 21362 LOSS: 40.980691894958724\n",
      "EPOCH: 21363 LOSS: 40.980690135338264\n",
      "EPOCH: 21364 LOSS: 40.980688375855344\n",
      "EPOCH: 21365 LOSS: 40.98068661650997\n",
      "EPOCH: 21366 LOSS: 40.98068485730212\n",
      "EPOCH: 21367 LOSS: 40.980683098231765\n",
      "EPOCH: 21368 LOSS: 40.9806813392989\n",
      "EPOCH: 21369 LOSS: 40.98067958050349\n",
      "EPOCH: 21370 LOSS: 40.980677821845546\n",
      "EPOCH: 21371 LOSS: 40.98067606332499\n",
      "EPOCH: 21372 LOSS: 40.98067430494187\n",
      "EPOCH: 21373 LOSS: 40.98067254669614\n",
      "EPOCH: 21374 LOSS: 40.98067078858775\n",
      "EPOCH: 21375 LOSS: 40.98066903061674\n",
      "EPOCH: 21376 LOSS: 40.980667272783066\n",
      "EPOCH: 21377 LOSS: 40.98066551508669\n",
      "EPOCH: 21378 LOSS: 40.9806637575276\n",
      "EPOCH: 21379 LOSS: 40.980662000105795\n",
      "EPOCH: 21380 LOSS: 40.98066024282125\n",
      "EPOCH: 21381 LOSS: 40.98065848567392\n",
      "EPOCH: 21382 LOSS: 40.98065672866383\n",
      "EPOCH: 21383 LOSS: 40.980654971790926\n",
      "EPOCH: 21384 LOSS: 40.98065321505521\n",
      "EPOCH: 21385 LOSS: 40.98065145845665\n",
      "EPOCH: 21386 LOSS: 40.98064970199525\n",
      "EPOCH: 21387 LOSS: 40.98064794567095\n",
      "EPOCH: 21388 LOSS: 40.980646189483764\n",
      "EPOCH: 21389 LOSS: 40.980644433433646\n",
      "EPOCH: 21390 LOSS: 40.980642677520635\n",
      "EPOCH: 21391 LOSS: 40.98064092174464\n",
      "EPOCH: 21392 LOSS: 40.980639166105675\n",
      "EPOCH: 21393 LOSS: 40.98063741060373\n",
      "EPOCH: 21394 LOSS: 40.98063565523877\n",
      "EPOCH: 21395 LOSS: 40.98063390001079\n",
      "EPOCH: 21396 LOSS: 40.98063214491977\n",
      "EPOCH: 21397 LOSS: 40.98063038996567\n",
      "EPOCH: 21398 LOSS: 40.98062863514848\n",
      "EPOCH: 21399 LOSS: 40.98062688046821\n",
      "EPOCH: 21400 LOSS: 40.980625125924796\n",
      "EPOCH: 21401 LOSS: 40.98062337151824\n",
      "EPOCH: 21402 LOSS: 40.980621617248545\n",
      "EPOCH: 21403 LOSS: 40.98061986311567\n",
      "EPOCH: 21404 LOSS: 40.98061810911956\n",
      "EPOCH: 21405 LOSS: 40.98061635526029\n",
      "EPOCH: 21406 LOSS: 40.98061460153774\n",
      "EPOCH: 21407 LOSS: 40.98061284795198\n",
      "EPOCH: 21408 LOSS: 40.980611094502905\n",
      "EPOCH: 21409 LOSS: 40.98060934119056\n",
      "EPOCH: 21410 LOSS: 40.980607588014905\n",
      "EPOCH: 21411 LOSS: 40.980605834975904\n",
      "EPOCH: 21412 LOSS: 40.98060408207357\n",
      "EPOCH: 21413 LOSS: 40.98060232930787\n",
      "EPOCH: 21414 LOSS: 40.980600576678775\n",
      "EPOCH: 21415 LOSS: 40.98059882418629\n",
      "EPOCH: 21416 LOSS: 40.98059707183036\n",
      "EPOCH: 21417 LOSS: 40.980595319611005\n",
      "EPOCH: 21418 LOSS: 40.980593567528196\n",
      "EPOCH: 21419 LOSS: 40.98059181558189\n",
      "EPOCH: 21420 LOSS: 40.9805900637721\n",
      "EPOCH: 21421 LOSS: 40.980588312098774\n",
      "EPOCH: 21422 LOSS: 40.98058656056193\n",
      "EPOCH: 21423 LOSS: 40.980584809161535\n",
      "EPOCH: 21424 LOSS: 40.98058305789757\n",
      "EPOCH: 21425 LOSS: 40.98058130676999\n",
      "EPOCH: 21426 LOSS: 40.9805795557788\n",
      "EPOCH: 21427 LOSS: 40.980577804924\n",
      "EPOCH: 21428 LOSS: 40.980576054205535\n",
      "EPOCH: 21429 LOSS: 40.98057430362342\n",
      "EPOCH: 21430 LOSS: 40.98057255317761\n",
      "EPOCH: 21431 LOSS: 40.98057080286809\n",
      "EPOCH: 21432 LOSS: 40.98056905269486\n",
      "EPOCH: 21433 LOSS: 40.98056730265789\n",
      "EPOCH: 21434 LOSS: 40.980565552757135\n",
      "EPOCH: 21435 LOSS: 40.98056380299262\n",
      "EPOCH: 21436 LOSS: 40.9805620533643\n",
      "EPOCH: 21437 LOSS: 40.98056030387217\n",
      "EPOCH: 21438 LOSS: 40.98055855451619\n",
      "EPOCH: 21439 LOSS: 40.98055680529637\n",
      "EPOCH: 21440 LOSS: 40.98055505621267\n",
      "EPOCH: 21441 LOSS: 40.980553307265076\n",
      "EPOCH: 21442 LOSS: 40.980551558453584\n",
      "EPOCH: 21443 LOSS: 40.980549809778154\n",
      "EPOCH: 21444 LOSS: 40.98054806123878\n",
      "EPOCH: 21445 LOSS: 40.98054631283542\n",
      "EPOCH: 21446 LOSS: 40.980544564568106\n",
      "EPOCH: 21447 LOSS: 40.98054281643677\n",
      "EPOCH: 21448 LOSS: 40.98054106844141\n",
      "EPOCH: 21449 LOSS: 40.98053932058201\n",
      "EPOCH: 21450 LOSS: 40.98053757285855\n",
      "EPOCH: 21451 LOSS: 40.98053582527102\n",
      "EPOCH: 21452 LOSS: 40.980534077819385\n",
      "EPOCH: 21453 LOSS: 40.980532330503635\n",
      "EPOCH: 21454 LOSS: 40.980530583323734\n",
      "EPOCH: 21455 LOSS: 40.98052883627972\n",
      "EPOCH: 21456 LOSS: 40.980527089371506\n",
      "EPOCH: 21457 LOSS: 40.98052534259911\n",
      "EPOCH: 21458 LOSS: 40.980523595962495\n",
      "EPOCH: 21459 LOSS: 40.98052184946164\n",
      "EPOCH: 21460 LOSS: 40.98052010309656\n",
      "EPOCH: 21461 LOSS: 40.980518356867215\n",
      "EPOCH: 21462 LOSS: 40.98051661077357\n",
      "EPOCH: 21463 LOSS: 40.98051486481563\n",
      "EPOCH: 21464 LOSS: 40.980513118993386\n",
      "EPOCH: 21465 LOSS: 40.98051137330677\n",
      "EPOCH: 21466 LOSS: 40.98050962775582\n",
      "EPOCH: 21467 LOSS: 40.98050788234048\n",
      "EPOCH: 21468 LOSS: 40.98050613706074\n",
      "EPOCH: 21469 LOSS: 40.980504391916604\n",
      "EPOCH: 21470 LOSS: 40.980502646908036\n",
      "EPOCH: 21471 LOSS: 40.98050090203499\n",
      "EPOCH: 21472 LOSS: 40.980499157297494\n",
      "EPOCH: 21473 LOSS: 40.98049741269551\n",
      "EPOCH: 21474 LOSS: 40.98049566822901\n",
      "EPOCH: 21475 LOSS: 40.98049392389799\n",
      "EPOCH: 21476 LOSS: 40.980492179702416\n",
      "EPOCH: 21477 LOSS: 40.98049043564229\n",
      "EPOCH: 21478 LOSS: 40.98048869171758\n",
      "EPOCH: 21479 LOSS: 40.98048694792826\n",
      "EPOCH: 21480 LOSS: 40.98048520427434\n",
      "EPOCH: 21481 LOSS: 40.98048346075576\n",
      "EPOCH: 21482 LOSS: 40.980481717372534\n",
      "EPOCH: 21483 LOSS: 40.98047997412464\n",
      "EPOCH: 21484 LOSS: 40.98047823101204\n",
      "EPOCH: 21485 LOSS: 40.98047648803471\n",
      "EPOCH: 21486 LOSS: 40.98047474519269\n",
      "EPOCH: 21487 LOSS: 40.980473002485894\n",
      "EPOCH: 21488 LOSS: 40.980471259914346\n",
      "EPOCH: 21489 LOSS: 40.98046951747802\n",
      "EPOCH: 21490 LOSS: 40.980467775176855\n",
      "EPOCH: 21491 LOSS: 40.98046603301089\n",
      "EPOCH: 21492 LOSS: 40.980464290980095\n",
      "EPOCH: 21493 LOSS: 40.98046254908441\n",
      "EPOCH: 21494 LOSS: 40.980460807323865\n",
      "EPOCH: 21495 LOSS: 40.98045906569841\n",
      "EPOCH: 21496 LOSS: 40.980457324208054\n",
      "EPOCH: 21497 LOSS: 40.98045558285274\n",
      "EPOCH: 21498 LOSS: 40.9804538416325\n",
      "EPOCH: 21499 LOSS: 40.98045210054728\n",
      "EPOCH: 21500 LOSS: 40.980450359597064\n",
      "EPOCH: 21501 LOSS: 40.98044861878184\n",
      "EPOCH: 21502 LOSS: 40.98044687810159\n",
      "EPOCH: 21503 LOSS: 40.9804451375563\n",
      "EPOCH: 21504 LOSS: 40.98044339714595\n",
      "EPOCH: 21505 LOSS: 40.980441656870504\n",
      "EPOCH: 21506 LOSS: 40.980439916729964\n",
      "EPOCH: 21507 LOSS: 40.98043817672429\n",
      "EPOCH: 21508 LOSS: 40.98043643685349\n",
      "EPOCH: 21509 LOSS: 40.98043469711754\n",
      "EPOCH: 21510 LOSS: 40.9804329575164\n",
      "EPOCH: 21511 LOSS: 40.980431218050065\n",
      "EPOCH: 21512 LOSS: 40.98042947871853\n",
      "EPOCH: 21513 LOSS: 40.98042773952176\n",
      "EPOCH: 21514 LOSS: 40.980426000459744\n",
      "EPOCH: 21515 LOSS: 40.98042426153245\n",
      "EPOCH: 21516 LOSS: 40.980422522739886\n",
      "EPOCH: 21517 LOSS: 40.980420784082014\n",
      "EPOCH: 21518 LOSS: 40.9804190455588\n",
      "EPOCH: 21519 LOSS: 40.98041730717026\n",
      "EPOCH: 21520 LOSS: 40.980415568916364\n",
      "EPOCH: 21521 LOSS: 40.98041383079709\n",
      "EPOCH: 21522 LOSS: 40.9804120928124\n",
      "EPOCH: 21523 LOSS: 40.98041035496231\n",
      "EPOCH: 21524 LOSS: 40.980408617246795\n",
      "EPOCH: 21525 LOSS: 40.98040687966581\n",
      "EPOCH: 21526 LOSS: 40.980405142219354\n",
      "EPOCH: 21527 LOSS: 40.98040340490743\n",
      "EPOCH: 21528 LOSS: 40.98040166772997\n",
      "EPOCH: 21529 LOSS: 40.98039993068701\n",
      "EPOCH: 21530 LOSS: 40.98039819377849\n",
      "EPOCH: 21531 LOSS: 40.9803964570044\n",
      "EPOCH: 21532 LOSS: 40.98039472036476\n",
      "EPOCH: 21533 LOSS: 40.980392983859474\n",
      "EPOCH: 21534 LOSS: 40.98039124748862\n",
      "EPOCH: 21535 LOSS: 40.980389511252085\n",
      "EPOCH: 21536 LOSS: 40.98038777514993\n",
      "EPOCH: 21537 LOSS: 40.98038603918208\n",
      "EPOCH: 21538 LOSS: 40.98038430334854\n",
      "EPOCH: 21539 LOSS: 40.980382567649315\n",
      "EPOCH: 21540 LOSS: 40.980380832084336\n",
      "EPOCH: 21541 LOSS: 40.98037909665361\n",
      "EPOCH: 21542 LOSS: 40.98037736135714\n",
      "EPOCH: 21543 LOSS: 40.98037562619486\n",
      "EPOCH: 21544 LOSS: 40.980373891166806\n",
      "EPOCH: 21545 LOSS: 40.9803721562729\n",
      "EPOCH: 21546 LOSS: 40.98037042151318\n",
      "EPOCH: 21547 LOSS: 40.980368686887594\n",
      "EPOCH: 21548 LOSS: 40.980366952396125\n",
      "EPOCH: 21549 LOSS: 40.98036521803876\n",
      "EPOCH: 21550 LOSS: 40.98036348381551\n",
      "EPOCH: 21551 LOSS: 40.9803617497263\n",
      "EPOCH: 21552 LOSS: 40.98036001577116\n",
      "EPOCH: 21553 LOSS: 40.980358281950046\n",
      "EPOCH: 21554 LOSS: 40.98035654826295\n",
      "EPOCH: 21555 LOSS: 40.980354814709834\n",
      "EPOCH: 21556 LOSS: 40.98035308129071\n",
      "EPOCH: 21557 LOSS: 40.98035134800554\n",
      "EPOCH: 21558 LOSS: 40.980349614854305\n",
      "EPOCH: 21559 LOSS: 40.98034788183701\n",
      "EPOCH: 21560 LOSS: 40.98034614895361\n",
      "EPOCH: 21561 LOSS: 40.980344416204105\n",
      "EPOCH: 21562 LOSS: 40.980342683588454\n",
      "EPOCH: 21563 LOSS: 40.98034095110666\n",
      "EPOCH: 21564 LOSS: 40.98033921875869\n",
      "EPOCH: 21565 LOSS: 40.98033748654454\n",
      "EPOCH: 21566 LOSS: 40.98033575446419\n",
      "EPOCH: 21567 LOSS: 40.98033402251758\n",
      "EPOCH: 21568 LOSS: 40.98033229070477\n",
      "EPOCH: 21569 LOSS: 40.98033055902569\n",
      "EPOCH: 21570 LOSS: 40.980328827480335\n",
      "EPOCH: 21571 LOSS: 40.98032709606866\n",
      "EPOCH: 21572 LOSS: 40.98032536479069\n",
      "EPOCH: 21573 LOSS: 40.98032363364637\n",
      "EPOCH: 21574 LOSS: 40.98032190263571\n",
      "EPOCH: 21575 LOSS: 40.98032017175868\n",
      "EPOCH: 21576 LOSS: 40.980318441015264\n",
      "EPOCH: 21577 LOSS: 40.98031671040545\n",
      "EPOCH: 21578 LOSS: 40.980314979929176\n",
      "EPOCH: 21579 LOSS: 40.98031324958648\n",
      "EPOCH: 21580 LOSS: 40.980311519377324\n",
      "EPOCH: 21581 LOSS: 40.980309789301685\n",
      "EPOCH: 21582 LOSS: 40.98030805935956\n",
      "EPOCH: 21583 LOSS: 40.98030632955091\n",
      "EPOCH: 21584 LOSS: 40.98030459987571\n",
      "EPOCH: 21585 LOSS: 40.98030287033398\n",
      "EPOCH: 21586 LOSS: 40.980301140925654\n",
      "EPOCH: 21587 LOSS: 40.98029941165076\n",
      "EPOCH: 21588 LOSS: 40.98029768250926\n",
      "EPOCH: 21589 LOSS: 40.98029595350111\n",
      "EPOCH: 21590 LOSS: 40.980294224626334\n",
      "EPOCH: 21591 LOSS: 40.980292495884896\n",
      "EPOCH: 21592 LOSS: 40.980290767276784\n",
      "EPOCH: 21593 LOSS: 40.980289038801956\n",
      "EPOCH: 21594 LOSS: 40.98028731046042\n",
      "EPOCH: 21595 LOSS: 40.980285582252144\n",
      "EPOCH: 21596 LOSS: 40.98028385417712\n",
      "EPOCH: 21597 LOSS: 40.98028212623532\n",
      "EPOCH: 21598 LOSS: 40.98028039842674\n",
      "EPOCH: 21599 LOSS: 40.980278670751346\n",
      "EPOCH: 21600 LOSS: 40.98027694320912\n",
      "EPOCH: 21601 LOSS: 40.980275215800056\n",
      "EPOCH: 21602 LOSS: 40.98027348852412\n",
      "EPOCH: 21603 LOSS: 40.98027176138131\n",
      "EPOCH: 21604 LOSS: 40.98027003437161\n",
      "EPOCH: 21605 LOSS: 40.980268307494974\n",
      "EPOCH: 21606 LOSS: 40.98026658075142\n",
      "EPOCH: 21607 LOSS: 40.9802648541409\n",
      "EPOCH: 21608 LOSS: 40.980263127663406\n",
      "EPOCH: 21609 LOSS: 40.98026140131894\n",
      "EPOCH: 21610 LOSS: 40.98025967510745\n",
      "EPOCH: 21611 LOSS: 40.98025794902894\n",
      "EPOCH: 21612 LOSS: 40.98025622308338\n",
      "EPOCH: 21613 LOSS: 40.98025449727075\n",
      "EPOCH: 21614 LOSS: 40.980252771591054\n",
      "EPOCH: 21615 LOSS: 40.98025104604425\n",
      "EPOCH: 21616 LOSS: 40.98024932063035\n",
      "EPOCH: 21617 LOSS: 40.9802475953493\n",
      "EPOCH: 21618 LOSS: 40.98024587020109\n",
      "EPOCH: 21619 LOSS: 40.98024414518571\n",
      "EPOCH: 21620 LOSS: 40.98024242030315\n",
      "EPOCH: 21621 LOSS: 40.98024069555337\n",
      "EPOCH: 21622 LOSS: 40.98023897093638\n",
      "EPOCH: 21623 LOSS: 40.98023724645212\n",
      "EPOCH: 21624 LOSS: 40.98023552210062\n",
      "EPOCH: 21625 LOSS: 40.98023379788183\n",
      "EPOCH: 21626 LOSS: 40.98023207379575\n",
      "EPOCH: 21627 LOSS: 40.980230349842344\n",
      "EPOCH: 21628 LOSS: 40.9802286260216\n",
      "EPOCH: 21629 LOSS: 40.9802269023335\n",
      "EPOCH: 21630 LOSS: 40.98022517877804\n",
      "EPOCH: 21631 LOSS: 40.9802234553552\n",
      "EPOCH: 21632 LOSS: 40.98022173206494\n",
      "EPOCH: 21633 LOSS: 40.98022000890725\n",
      "EPOCH: 21634 LOSS: 40.98021828588213\n",
      "EPOCH: 21635 LOSS: 40.98021656298955\n",
      "EPOCH: 21636 LOSS: 40.98021484022948\n",
      "EPOCH: 21637 LOSS: 40.9802131176019\n",
      "EPOCH: 21638 LOSS: 40.98021139510683\n",
      "EPOCH: 21639 LOSS: 40.98020967274421\n",
      "EPOCH: 21640 LOSS: 40.98020795051404\n",
      "EPOCH: 21641 LOSS: 40.98020622841632\n",
      "EPOCH: 21642 LOSS: 40.98020450645099\n",
      "EPOCH: 21643 LOSS: 40.98020278461806\n",
      "EPOCH: 21644 LOSS: 40.9802010629175\n",
      "EPOCH: 21645 LOSS: 40.980199341349305\n",
      "EPOCH: 21646 LOSS: 40.98019761991345\n",
      "EPOCH: 21647 LOSS: 40.980195898609914\n",
      "EPOCH: 21648 LOSS: 40.98019417743866\n",
      "EPOCH: 21649 LOSS: 40.980192456399735\n",
      "EPOCH: 21650 LOSS: 40.98019073549305\n",
      "EPOCH: 21651 LOSS: 40.98018901471862\n",
      "EPOCH: 21652 LOSS: 40.98018729407642\n",
      "EPOCH: 21653 LOSS: 40.98018557356643\n",
      "EPOCH: 21654 LOSS: 40.98018385318865\n",
      "EPOCH: 21655 LOSS: 40.980182132943035\n",
      "EPOCH: 21656 LOSS: 40.98018041282957\n",
      "EPOCH: 21657 LOSS: 40.98017869284826\n",
      "EPOCH: 21658 LOSS: 40.980176972999075\n",
      "EPOCH: 21659 LOSS: 40.98017525328199\n",
      "EPOCH: 21660 LOSS: 40.980173533697\n",
      "EPOCH: 21661 LOSS: 40.98017181424407\n",
      "EPOCH: 21662 LOSS: 40.980170094923196\n",
      "EPOCH: 21663 LOSS: 40.98016837573435\n",
      "EPOCH: 21664 LOSS: 40.98016665667753\n",
      "EPOCH: 21665 LOSS: 40.98016493775269\n",
      "EPOCH: 21666 LOSS: 40.980163218959845\n",
      "EPOCH: 21667 LOSS: 40.98016150029895\n",
      "EPOCH: 21668 LOSS: 40.980159781770006\n",
      "EPOCH: 21669 LOSS: 40.98015806337296\n",
      "EPOCH: 21670 LOSS: 40.980156345107865\n",
      "EPOCH: 21671 LOSS: 40.98015462697464\n",
      "EPOCH: 21672 LOSS: 40.98015290897327\n",
      "EPOCH: 21673 LOSS: 40.98015119110377\n",
      "EPOCH: 21674 LOSS: 40.9801494733661\n",
      "EPOCH: 21675 LOSS: 40.98014775576027\n",
      "EPOCH: 21676 LOSS: 40.98014603828621\n",
      "EPOCH: 21677 LOSS: 40.98014432094393\n",
      "EPOCH: 21678 LOSS: 40.98014260373343\n",
      "EPOCH: 21679 LOSS: 40.98014088665468\n",
      "EPOCH: 21680 LOSS: 40.98013916970765\n",
      "EPOCH: 21681 LOSS: 40.980137452892315\n",
      "EPOCH: 21682 LOSS: 40.98013573620869\n",
      "EPOCH: 21683 LOSS: 40.98013401965673\n",
      "EPOCH: 21684 LOSS: 40.98013230323643\n",
      "EPOCH: 21685 LOSS: 40.980130586947766\n",
      "EPOCH: 21686 LOSS: 40.98012887079072\n",
      "EPOCH: 21687 LOSS: 40.98012715476527\n",
      "EPOCH: 21688 LOSS: 40.98012543887142\n",
      "EPOCH: 21689 LOSS: 40.980123723109145\n",
      "EPOCH: 21690 LOSS: 40.98012200747837\n",
      "EPOCH: 21691 LOSS: 40.98012029197917\n",
      "EPOCH: 21692 LOSS: 40.980118576611474\n",
      "EPOCH: 21693 LOSS: 40.980116861375265\n",
      "EPOCH: 21694 LOSS: 40.980115146270535\n",
      "EPOCH: 21695 LOSS: 40.98011343129727\n",
      "EPOCH: 21696 LOSS: 40.980111716455426\n",
      "EPOCH: 21697 LOSS: 40.980110001745004\n",
      "EPOCH: 21698 LOSS: 40.980108287166026\n",
      "EPOCH: 21699 LOSS: 40.9801065727184\n",
      "EPOCH: 21700 LOSS: 40.98010485840216\n",
      "EPOCH: 21701 LOSS: 40.98010314421725\n",
      "EPOCH: 21702 LOSS: 40.980101430163685\n",
      "EPOCH: 21703 LOSS: 40.980099716241455\n",
      "EPOCH: 21704 LOSS: 40.9800980024505\n",
      "EPOCH: 21705 LOSS: 40.980096288790826\n",
      "EPOCH: 21706 LOSS: 40.98009457526241\n",
      "EPOCH: 21707 LOSS: 40.980092861865245\n",
      "EPOCH: 21708 LOSS: 40.9800911485993\n",
      "EPOCH: 21709 LOSS: 40.98008943546457\n",
      "EPOCH: 21710 LOSS: 40.980087722461036\n",
      "EPOCH: 21711 LOSS: 40.980086009588675\n",
      "EPOCH: 21712 LOSS: 40.98008429684745\n",
      "EPOCH: 21713 LOSS: 40.980082584237365\n",
      "EPOCH: 21714 LOSS: 40.98008087175842\n",
      "EPOCH: 21715 LOSS: 40.980079159410565\n",
      "EPOCH: 21716 LOSS: 40.980077447193786\n",
      "EPOCH: 21717 LOSS: 40.98007573510807\n",
      "EPOCH: 21718 LOSS: 40.98007402315342\n",
      "EPOCH: 21719 LOSS: 40.98007231132978\n",
      "EPOCH: 21720 LOSS: 40.98007059963717\n",
      "EPOCH: 21721 LOSS: 40.980068888075536\n",
      "EPOCH: 21722 LOSS: 40.980067176644894\n",
      "EPOCH: 21723 LOSS: 40.9800654653452\n",
      "EPOCH: 21724 LOSS: 40.98006375417645\n",
      "EPOCH: 21725 LOSS: 40.98006204313863\n",
      "EPOCH: 21726 LOSS: 40.9800603322317\n",
      "EPOCH: 21727 LOSS: 40.98005862145567\n",
      "EPOCH: 21728 LOSS: 40.980056910810504\n",
      "EPOCH: 21729 LOSS: 40.98005520029618\n",
      "EPOCH: 21730 LOSS: 40.980053489912706\n",
      "EPOCH: 21731 LOSS: 40.980051779660045\n",
      "EPOCH: 21732 LOSS: 40.980050069538166\n",
      "EPOCH: 21733 LOSS: 40.98004835954709\n",
      "EPOCH: 21734 LOSS: 40.98004664968677\n",
      "EPOCH: 21735 LOSS: 40.98004493995718\n",
      "EPOCH: 21736 LOSS: 40.98004323035833\n",
      "EPOCH: 21737 LOSS: 40.98004152089019\n",
      "EPOCH: 21738 LOSS: 40.98003981155273\n",
      "EPOCH: 21739 LOSS: 40.98003810234597\n",
      "EPOCH: 21740 LOSS: 40.98003639326984\n",
      "EPOCH: 21741 LOSS: 40.980034684324366\n",
      "EPOCH: 21742 LOSS: 40.98003297550949\n",
      "EPOCH: 21743 LOSS: 40.98003126682524\n",
      "EPOCH: 21744 LOSS: 40.98002955827155\n",
      "EPOCH: 21745 LOSS: 40.98002784984845\n",
      "EPOCH: 21746 LOSS: 40.98002614155588\n",
      "EPOCH: 21747 LOSS: 40.98002443339387\n",
      "EPOCH: 21748 LOSS: 40.98002272536235\n",
      "EPOCH: 21749 LOSS: 40.98002101746134\n",
      "EPOCH: 21750 LOSS: 40.98001930969079\n",
      "EPOCH: 21751 LOSS: 40.98001760205072\n",
      "EPOCH: 21752 LOSS: 40.98001589454107\n",
      "EPOCH: 21753 LOSS: 40.980014187161885\n",
      "EPOCH: 21754 LOSS: 40.980012479913064\n",
      "EPOCH: 21755 LOSS: 40.98001077279467\n",
      "EPOCH: 21756 LOSS: 40.98000906580663\n",
      "EPOCH: 21757 LOSS: 40.98000735894894\n",
      "EPOCH: 21758 LOSS: 40.98000565222158\n",
      "EPOCH: 21759 LOSS: 40.980003945624546\n",
      "EPOCH: 21760 LOSS: 40.98000223915782\n",
      "EPOCH: 21761 LOSS: 40.98000053282138\n",
      "EPOCH: 21762 LOSS: 40.979998826615194\n",
      "EPOCH: 21763 LOSS: 40.97999712053927\n",
      "EPOCH: 21764 LOSS: 40.97999541459356\n",
      "EPOCH: 21765 LOSS: 40.97999370877807\n",
      "EPOCH: 21766 LOSS: 40.97999200309278\n",
      "EPOCH: 21767 LOSS: 40.979990297537654\n",
      "EPOCH: 21768 LOSS: 40.9799885921127\n",
      "EPOCH: 21769 LOSS: 40.97998688681788\n",
      "EPOCH: 21770 LOSS: 40.9799851816532\n",
      "EPOCH: 21771 LOSS: 40.97998347661861\n",
      "EPOCH: 21772 LOSS: 40.97998177171412\n",
      "EPOCH: 21773 LOSS: 40.979980066939696\n",
      "EPOCH: 21774 LOSS: 40.979978362295334\n",
      "EPOCH: 21775 LOSS: 40.97997665778099\n",
      "EPOCH: 21776 LOSS: 40.97997495339666\n",
      "EPOCH: 21777 LOSS: 40.97997324914235\n",
      "EPOCH: 21778 LOSS: 40.97997154501803\n",
      "EPOCH: 21779 LOSS: 40.97996984102365\n",
      "EPOCH: 21780 LOSS: 40.97996813715925\n",
      "EPOCH: 21781 LOSS: 40.979966433424735\n",
      "EPOCH: 21782 LOSS: 40.97996472982017\n",
      "EPOCH: 21783 LOSS: 40.97996302634549\n",
      "EPOCH: 21784 LOSS: 40.97996132300068\n",
      "EPOCH: 21785 LOSS: 40.97995961978574\n",
      "EPOCH: 21786 LOSS: 40.97995791670064\n",
      "EPOCH: 21787 LOSS: 40.97995621374537\n",
      "EPOCH: 21788 LOSS: 40.97995451091988\n",
      "EPOCH: 21789 LOSS: 40.97995280822418\n",
      "EPOCH: 21790 LOSS: 40.97995110565828\n",
      "EPOCH: 21791 LOSS: 40.97994940322212\n",
      "EPOCH: 21792 LOSS: 40.9799477009157\n",
      "EPOCH: 21793 LOSS: 40.979945998739005\n",
      "EPOCH: 21794 LOSS: 40.979944296692004\n",
      "EPOCH: 21795 LOSS: 40.979942594774684\n",
      "EPOCH: 21796 LOSS: 40.97994089298702\n",
      "EPOCH: 21797 LOSS: 40.97993919132901\n",
      "EPOCH: 21798 LOSS: 40.97993748980065\n",
      "EPOCH: 21799 LOSS: 40.979935788401875\n",
      "EPOCH: 21800 LOSS: 40.97993408713272\n",
      "EPOCH: 21801 LOSS: 40.97993238599313\n",
      "EPOCH: 21802 LOSS: 40.97993068498311\n",
      "EPOCH: 21803 LOSS: 40.9799289841026\n",
      "EPOCH: 21804 LOSS: 40.97992728335164\n",
      "EPOCH: 21805 LOSS: 40.97992558273019\n",
      "EPOCH: 21806 LOSS: 40.97992388223823\n",
      "EPOCH: 21807 LOSS: 40.97992218187574\n",
      "EPOCH: 21808 LOSS: 40.9799204816427\n",
      "EPOCH: 21809 LOSS: 40.979918781539105\n",
      "EPOCH: 21810 LOSS: 40.97991708156493\n",
      "EPOCH: 21811 LOSS: 40.97991538172015\n",
      "EPOCH: 21812 LOSS: 40.97991368200475\n",
      "EPOCH: 21813 LOSS: 40.97991198241874\n",
      "EPOCH: 21814 LOSS: 40.97991028296206\n",
      "EPOCH: 21815 LOSS: 40.97990858363471\n",
      "EPOCH: 21816 LOSS: 40.97990688443669\n",
      "EPOCH: 21817 LOSS: 40.97990518536796\n",
      "EPOCH: 21818 LOSS: 40.97990348642851\n",
      "EPOCH: 21819 LOSS: 40.9799017876183\n",
      "EPOCH: 21820 LOSS: 40.979900088937356\n",
      "EPOCH: 21821 LOSS: 40.97989839038564\n",
      "EPOCH: 21822 LOSS: 40.979896691963134\n",
      "EPOCH: 21823 LOSS: 40.97989499366982\n",
      "EPOCH: 21824 LOSS: 40.979893295505654\n",
      "EPOCH: 21825 LOSS: 40.97989159747068\n",
      "EPOCH: 21826 LOSS: 40.979889899564824\n",
      "EPOCH: 21827 LOSS: 40.97988820178811\n",
      "EPOCH: 21828 LOSS: 40.97988650414048\n",
      "EPOCH: 21829 LOSS: 40.979884806621946\n",
      "EPOCH: 21830 LOSS: 40.97988310923249\n",
      "EPOCH: 21831 LOSS: 40.97988141197207\n",
      "EPOCH: 21832 LOSS: 40.97987971484069\n",
      "EPOCH: 21833 LOSS: 40.979878017838324\n",
      "EPOCH: 21834 LOSS: 40.97987632096496\n",
      "EPOCH: 21835 LOSS: 40.979874624220585\n",
      "EPOCH: 21836 LOSS: 40.97987292760517\n",
      "EPOCH: 21837 LOSS: 40.97987123111869\n",
      "EPOCH: 21838 LOSS: 40.97986953476115\n",
      "EPOCH: 21839 LOSS: 40.97986783853252\n",
      "EPOCH: 21840 LOSS: 40.97986614243278\n",
      "EPOCH: 21841 LOSS: 40.97986444646193\n",
      "EPOCH: 21842 LOSS: 40.97986275061993\n",
      "EPOCH: 21843 LOSS: 40.97986105490678\n",
      "EPOCH: 21844 LOSS: 40.97985935932245\n",
      "EPOCH: 21845 LOSS: 40.97985766386693\n",
      "EPOCH: 21846 LOSS: 40.97985596854018\n",
      "EPOCH: 21847 LOSS: 40.97985427334222\n",
      "EPOCH: 21848 LOSS: 40.97985257827302\n",
      "EPOCH: 21849 LOSS: 40.979850883332546\n",
      "EPOCH: 21850 LOSS: 40.97984918852079\n",
      "EPOCH: 21851 LOSS: 40.97984749383774\n",
      "EPOCH: 21852 LOSS: 40.979845799283375\n",
      "EPOCH: 21853 LOSS: 40.97984410485768\n",
      "EPOCH: 21854 LOSS: 40.979842410560636\n",
      "EPOCH: 21855 LOSS: 40.97984071639223\n",
      "EPOCH: 21856 LOSS: 40.979839022352444\n",
      "EPOCH: 21857 LOSS: 40.979837328441235\n",
      "EPOCH: 21858 LOSS: 40.97983563465863\n",
      "EPOCH: 21859 LOSS: 40.97983394100457\n",
      "EPOCH: 21860 LOSS: 40.97983224747907\n",
      "EPOCH: 21861 LOSS: 40.97983055408209\n",
      "EPOCH: 21862 LOSS: 40.97982886081362\n",
      "EPOCH: 21863 LOSS: 40.97982716767363\n",
      "EPOCH: 21864 LOSS: 40.979825474662135\n",
      "EPOCH: 21865 LOSS: 40.97982378177909\n",
      "EPOCH: 21866 LOSS: 40.97982208902451\n",
      "EPOCH: 21867 LOSS: 40.979820396398324\n",
      "EPOCH: 21868 LOSS: 40.97981870390056\n",
      "EPOCH: 21869 LOSS: 40.97981701153119\n",
      "EPOCH: 21870 LOSS: 40.97981531929018\n",
      "EPOCH: 21871 LOSS: 40.97981362717752\n",
      "EPOCH: 21872 LOSS: 40.979811935193204\n",
      "EPOCH: 21873 LOSS: 40.979810243337226\n",
      "EPOCH: 21874 LOSS: 40.97980855160953\n",
      "EPOCH: 21875 LOSS: 40.97980686001011\n",
      "EPOCH: 21876 LOSS: 40.97980516853898\n",
      "EPOCH: 21877 LOSS: 40.97980347719609\n",
      "EPOCH: 21878 LOSS: 40.97980178598145\n",
      "EPOCH: 21879 LOSS: 40.979800094895\n",
      "EPOCH: 21880 LOSS: 40.97979840393676\n",
      "EPOCH: 21881 LOSS: 40.979796713106694\n",
      "EPOCH: 21882 LOSS: 40.9797950224048\n",
      "EPOCH: 21883 LOSS: 40.97979333183105\n",
      "EPOCH: 21884 LOSS: 40.97979164138542\n",
      "EPOCH: 21885 LOSS: 40.979789951067936\n",
      "EPOCH: 21886 LOSS: 40.9797882608785\n",
      "EPOCH: 21887 LOSS: 40.97978657081717\n",
      "EPOCH: 21888 LOSS: 40.979784880883884\n",
      "EPOCH: 21889 LOSS: 40.97978319107865\n",
      "EPOCH: 21890 LOSS: 40.97978150140144\n",
      "EPOCH: 21891 LOSS: 40.97977981185224\n",
      "EPOCH: 21892 LOSS: 40.97977812243104\n",
      "EPOCH: 21893 LOSS: 40.97977643313778\n",
      "EPOCH: 21894 LOSS: 40.979774743972506\n",
      "EPOCH: 21895 LOSS: 40.979773054935166\n",
      "EPOCH: 21896 LOSS: 40.979771366025744\n",
      "EPOCH: 21897 LOSS: 40.979769677244235\n",
      "EPOCH: 21898 LOSS: 40.97976798859058\n",
      "EPOCH: 21899 LOSS: 40.979766300064824\n",
      "EPOCH: 21900 LOSS: 40.97976461166692\n",
      "EPOCH: 21901 LOSS: 40.97976292339685\n",
      "EPOCH: 21902 LOSS: 40.979761235254585\n",
      "EPOCH: 21903 LOSS: 40.97975954724013\n",
      "EPOCH: 21904 LOSS: 40.979757859353455\n",
      "EPOCH: 21905 LOSS: 40.979756171594545\n",
      "EPOCH: 21906 LOSS: 40.97975448396338\n",
      "EPOCH: 21907 LOSS: 40.97975279645996\n",
      "EPOCH: 21908 LOSS: 40.97975110908425\n",
      "EPOCH: 21909 LOSS: 40.97974942183622\n",
      "EPOCH: 21910 LOSS: 40.97974773471587\n",
      "EPOCH: 21911 LOSS: 40.979746047723204\n",
      "EPOCH: 21912 LOSS: 40.97974436085817\n",
      "EPOCH: 21913 LOSS: 40.97974267412077\n",
      "EPOCH: 21914 LOSS: 40.979740987510965\n",
      "EPOCH: 21915 LOSS: 40.979739301028786\n",
      "EPOCH: 21916 LOSS: 40.979737614674136\n",
      "EPOCH: 21917 LOSS: 40.979735928447084\n",
      "EPOCH: 21918 LOSS: 40.97973424234756\n",
      "EPOCH: 21919 LOSS: 40.97973255637556\n",
      "EPOCH: 21920 LOSS: 40.97973087053107\n",
      "EPOCH: 21921 LOSS: 40.97972918481407\n",
      "EPOCH: 21922 LOSS: 40.97972749922453\n",
      "EPOCH: 21923 LOSS: 40.97972581376246\n",
      "EPOCH: 21924 LOSS: 40.97972412842782\n",
      "EPOCH: 21925 LOSS: 40.9797224432206\n",
      "EPOCH: 21926 LOSS: 40.9797207581408\n",
      "EPOCH: 21927 LOSS: 40.97971907318838\n",
      "EPOCH: 21928 LOSS: 40.97971738836331\n",
      "EPOCH: 21929 LOSS: 40.97971570366561\n",
      "EPOCH: 21930 LOSS: 40.979714019095255\n",
      "EPOCH: 21931 LOSS: 40.979712334652206\n",
      "EPOCH: 21932 LOSS: 40.97971065033646\n",
      "EPOCH: 21933 LOSS: 40.979708966147975\n",
      "EPOCH: 21934 LOSS: 40.97970728208679\n",
      "EPOCH: 21935 LOSS: 40.979705598152826\n",
      "EPOCH: 21936 LOSS: 40.97970391434612\n",
      "EPOCH: 21937 LOSS: 40.97970223066662\n",
      "EPOCH: 21938 LOSS: 40.9797005471143\n",
      "EPOCH: 21939 LOSS: 40.97969886368918\n",
      "EPOCH: 21940 LOSS: 40.97969718039123\n",
      "EPOCH: 21941 LOSS: 40.9796954972204\n",
      "EPOCH: 21942 LOSS: 40.979693814176706\n",
      "EPOCH: 21943 LOSS: 40.97969213126014\n",
      "EPOCH: 21944 LOSS: 40.97969044847066\n",
      "EPOCH: 21945 LOSS: 40.97968876580825\n",
      "EPOCH: 21946 LOSS: 40.97968708327292\n",
      "EPOCH: 21947 LOSS: 40.97968540086462\n",
      "EPOCH: 21948 LOSS: 40.979683718583324\n",
      "EPOCH: 21949 LOSS: 40.97968203642907\n",
      "EPOCH: 21950 LOSS: 40.97968035440179\n",
      "EPOCH: 21951 LOSS: 40.97967867250149\n",
      "EPOCH: 21952 LOSS: 40.97967699072815\n",
      "EPOCH: 21953 LOSS: 40.97967530908174\n",
      "EPOCH: 21954 LOSS: 40.97967362756227\n",
      "EPOCH: 21955 LOSS: 40.97967194616971\n",
      "EPOCH: 21956 LOSS: 40.979670264904016\n",
      "EPOCH: 21957 LOSS: 40.97966858376521\n",
      "EPOCH: 21958 LOSS: 40.97966690275324\n",
      "EPOCH: 21959 LOSS: 40.97966522186812\n",
      "EPOCH: 21960 LOSS: 40.979663541109836\n",
      "EPOCH: 21961 LOSS: 40.97966186047833\n",
      "EPOCH: 21962 LOSS: 40.97966017997362\n",
      "EPOCH: 21963 LOSS: 40.97965849959569\n",
      "EPOCH: 21964 LOSS: 40.97965681934452\n",
      "EPOCH: 21965 LOSS: 40.97965513922005\n",
      "EPOCH: 21966 LOSS: 40.97965345922233\n",
      "EPOCH: 21967 LOSS: 40.97965177935129\n",
      "EPOCH: 21968 LOSS: 40.97965009960693\n",
      "EPOCH: 21969 LOSS: 40.97964841998926\n",
      "EPOCH: 21970 LOSS: 40.97964674049822\n",
      "EPOCH: 21971 LOSS: 40.979645061133816\n",
      "EPOCH: 21972 LOSS: 40.979643381896025\n",
      "EPOCH: 21973 LOSS: 40.97964170278485\n",
      "EPOCH: 21974 LOSS: 40.97964002380025\n",
      "EPOCH: 21975 LOSS: 40.97963834494221\n",
      "EPOCH: 21976 LOSS: 40.97963666621072\n",
      "EPOCH: 21977 LOSS: 40.979634987605756\n",
      "EPOCH: 21978 LOSS: 40.97963330912731\n",
      "EPOCH: 21979 LOSS: 40.97963163077535\n",
      "EPOCH: 21980 LOSS: 40.97962995254988\n",
      "EPOCH: 21981 LOSS: 40.97962827445085\n",
      "EPOCH: 21982 LOSS: 40.9796265964783\n",
      "EPOCH: 21983 LOSS: 40.97962491863217\n",
      "EPOCH: 21984 LOSS: 40.97962324091241\n",
      "EPOCH: 21985 LOSS: 40.97962156331909\n",
      "EPOCH: 21986 LOSS: 40.97961988585213\n",
      "EPOCH: 21987 LOSS: 40.979618208511546\n",
      "EPOCH: 21988 LOSS: 40.97961653129728\n",
      "EPOCH: 21989 LOSS: 40.97961485420935\n",
      "EPOCH: 21990 LOSS: 40.97961317724773\n",
      "EPOCH: 21991 LOSS: 40.9796115004124\n",
      "EPOCH: 21992 LOSS: 40.97960982370335\n",
      "EPOCH: 21993 LOSS: 40.979608147120544\n",
      "EPOCH: 21994 LOSS: 40.979606470663995\n",
      "EPOCH: 21995 LOSS: 40.97960479433365\n",
      "EPOCH: 21996 LOSS: 40.97960311812953\n",
      "EPOCH: 21997 LOSS: 40.979601442051596\n",
      "EPOCH: 21998 LOSS: 40.979599766099824\n",
      "EPOCH: 21999 LOSS: 40.97959809027423\n",
      "EPOCH: 22000 LOSS: 40.97959641457476\n",
      "EPOCH: 22001 LOSS: 40.97959473900141\n",
      "EPOCH: 22002 LOSS: 40.97959306355416\n",
      "EPOCH: 22003 LOSS: 40.97959138823302\n",
      "EPOCH: 22004 LOSS: 40.97958971303793\n",
      "EPOCH: 22005 LOSS: 40.97958803796891\n",
      "EPOCH: 22006 LOSS: 40.9795863630259\n",
      "EPOCH: 22007 LOSS: 40.97958468820893\n",
      "EPOCH: 22008 LOSS: 40.97958301351797\n",
      "EPOCH: 22009 LOSS: 40.97958133895298\n",
      "EPOCH: 22010 LOSS: 40.97957966451397\n",
      "EPOCH: 22011 LOSS: 40.979577990200895\n",
      "EPOCH: 22012 LOSS: 40.97957631601378\n",
      "EPOCH: 22013 LOSS: 40.97957464195256\n",
      "EPOCH: 22014 LOSS: 40.979572968017266\n",
      "EPOCH: 22015 LOSS: 40.97957129420783\n",
      "EPOCH: 22016 LOSS: 40.97956962052427\n",
      "EPOCH: 22017 LOSS: 40.97956794696657\n",
      "EPOCH: 22018 LOSS: 40.97956627353471\n",
      "EPOCH: 22019 LOSS: 40.97956460022865\n",
      "EPOCH: 22020 LOSS: 40.979562927048384\n",
      "EPOCH: 22021 LOSS: 40.97956125399391\n",
      "EPOCH: 22022 LOSS: 40.97955958106519\n",
      "EPOCH: 22023 LOSS: 40.97955790826224\n",
      "EPOCH: 22024 LOSS: 40.97955623558501\n",
      "EPOCH: 22025 LOSS: 40.9795545630335\n",
      "EPOCH: 22026 LOSS: 40.979552890607685\n",
      "EPOCH: 22027 LOSS: 40.97955121830755\n",
      "EPOCH: 22028 LOSS: 40.97954954613308\n",
      "EPOCH: 22029 LOSS: 40.979547874084254\n",
      "EPOCH: 22030 LOSS: 40.97954620216107\n",
      "EPOCH: 22031 LOSS: 40.97954453036348\n",
      "EPOCH: 22032 LOSS: 40.97954285869152\n",
      "EPOCH: 22033 LOSS: 40.97954118714512\n",
      "EPOCH: 22034 LOSS: 40.97953951572426\n",
      "EPOCH: 22035 LOSS: 40.979537844428975\n",
      "EPOCH: 22036 LOSS: 40.97953617325921\n",
      "EPOCH: 22037 LOSS: 40.97953450221496\n",
      "EPOCH: 22038 LOSS: 40.97953283129621\n",
      "EPOCH: 22039 LOSS: 40.97953116050293\n",
      "EPOCH: 22040 LOSS: 40.979529489835116\n",
      "EPOCH: 22041 LOSS: 40.97952781929275\n",
      "EPOCH: 22042 LOSS: 40.979526148875806\n",
      "EPOCH: 22043 LOSS: 40.97952447858427\n",
      "EPOCH: 22044 LOSS: 40.979522808418125\n",
      "EPOCH: 22045 LOSS: 40.97952113837736\n",
      "EPOCH: 22046 LOSS: 40.97951946846197\n",
      "EPOCH: 22047 LOSS: 40.97951779867192\n",
      "EPOCH: 22048 LOSS: 40.97951612900718\n",
      "EPOCH: 22049 LOSS: 40.97951445946775\n",
      "EPOCH: 22050 LOSS: 40.97951279005363\n",
      "EPOCH: 22051 LOSS: 40.979511120764776\n",
      "EPOCH: 22052 LOSS: 40.97950945160118\n",
      "EPOCH: 22053 LOSS: 40.97950778256284\n",
      "EPOCH: 22054 LOSS: 40.979506113649705\n",
      "EPOCH: 22055 LOSS: 40.9795044448618\n",
      "EPOCH: 22056 LOSS: 40.979502776199084\n",
      "EPOCH: 22057 LOSS: 40.97950110766154\n",
      "EPOCH: 22058 LOSS: 40.979499439249146\n",
      "EPOCH: 22059 LOSS: 40.97949777096189\n",
      "EPOCH: 22060 LOSS: 40.97949610279977\n",
      "EPOCH: 22061 LOSS: 40.97949443476275\n",
      "EPOCH: 22062 LOSS: 40.97949276685083\n",
      "EPOCH: 22063 LOSS: 40.97949109906399\n",
      "EPOCH: 22064 LOSS: 40.979489431402186\n",
      "EPOCH: 22065 LOSS: 40.97948776386545\n",
      "EPOCH: 22066 LOSS: 40.97948609645371\n",
      "EPOCH: 22067 LOSS: 40.979484429167\n",
      "EPOCH: 22068 LOSS: 40.97948276200527\n",
      "EPOCH: 22069 LOSS: 40.97948109496852\n",
      "EPOCH: 22070 LOSS: 40.97947942805672\n",
      "EPOCH: 22071 LOSS: 40.979477761269855\n",
      "EPOCH: 22072 LOSS: 40.97947609460793\n",
      "EPOCH: 22073 LOSS: 40.979474428070894\n",
      "EPOCH: 22074 LOSS: 40.979472761658755\n",
      "EPOCH: 22075 LOSS: 40.979471095371494\n",
      "EPOCH: 22076 LOSS: 40.979469429209075\n",
      "EPOCH: 22077 LOSS: 40.979467763171506\n",
      "EPOCH: 22078 LOSS: 40.97946609725876\n",
      "EPOCH: 22079 LOSS: 40.97946443147082\n",
      "EPOCH: 22080 LOSS: 40.979462765807654\n",
      "EPOCH: 22081 LOSS: 40.979461100269276\n",
      "EPOCH: 22082 LOSS: 40.979459434855656\n",
      "EPOCH: 22083 LOSS: 40.97945776956675\n",
      "EPOCH: 22084 LOSS: 40.9794561044026\n",
      "EPOCH: 22085 LOSS: 40.979454439363145\n",
      "EPOCH: 22086 LOSS: 40.979452774448376\n",
      "EPOCH: 22087 LOSS: 40.97945110965828\n",
      "EPOCH: 22088 LOSS: 40.97944944499284\n",
      "EPOCH: 22089 LOSS: 40.97944778045202\n",
      "EPOCH: 22090 LOSS: 40.979446116035845\n",
      "EPOCH: 22091 LOSS: 40.97944445174426\n",
      "EPOCH: 22092 LOSS: 40.97944278757729\n",
      "EPOCH: 22093 LOSS: 40.979441123534855\n",
      "EPOCH: 22094 LOSS: 40.979439459617\n",
      "EPOCH: 22095 LOSS: 40.97943779582367\n",
      "EPOCH: 22096 LOSS: 40.979436132154845\n",
      "EPOCH: 22097 LOSS: 40.97943446861057\n",
      "EPOCH: 22098 LOSS: 40.97943280519075\n",
      "EPOCH: 22099 LOSS: 40.97943114189542\n",
      "EPOCH: 22100 LOSS: 40.97942947872454\n",
      "EPOCH: 22101 LOSS: 40.97942781567808\n",
      "EPOCH: 22102 LOSS: 40.97942615275606\n",
      "EPOCH: 22103 LOSS: 40.97942448995845\n",
      "EPOCH: 22104 LOSS: 40.979422827285205\n",
      "EPOCH: 22105 LOSS: 40.97942116473634\n",
      "EPOCH: 22106 LOSS: 40.97941950231183\n",
      "EPOCH: 22107 LOSS: 40.979417840011656\n",
      "EPOCH: 22108 LOSS: 40.979416177835816\n",
      "EPOCH: 22109 LOSS: 40.97941451578426\n",
      "EPOCH: 22110 LOSS: 40.979412853857006\n",
      "EPOCH: 22111 LOSS: 40.97941119205403\n",
      "EPOCH: 22112 LOSS: 40.97940953037529\n",
      "EPOCH: 22113 LOSS: 40.97940786882079\n",
      "EPOCH: 22114 LOSS: 40.979406207390525\n",
      "EPOCH: 22115 LOSS: 40.97940454608446\n",
      "EPOCH: 22116 LOSS: 40.97940288490257\n",
      "EPOCH: 22117 LOSS: 40.97940122384487\n",
      "EPOCH: 22118 LOSS: 40.97939956291131\n",
      "EPOCH: 22119 LOSS: 40.979397902101894\n",
      "EPOCH: 22120 LOSS: 40.97939624141661\n",
      "EPOCH: 22121 LOSS: 40.97939458085541\n",
      "EPOCH: 22122 LOSS: 40.97939292041831\n",
      "EPOCH: 22123 LOSS: 40.97939126010528\n",
      "EPOCH: 22124 LOSS: 40.97938959991629\n",
      "EPOCH: 22125 LOSS: 40.979387939851364\n",
      "EPOCH: 22126 LOSS: 40.97938627991044\n",
      "EPOCH: 22127 LOSS: 40.97938462009353\n",
      "EPOCH: 22128 LOSS: 40.97938296040061\n",
      "EPOCH: 22129 LOSS: 40.97938130083166\n",
      "EPOCH: 22130 LOSS: 40.97937964138666\n",
      "EPOCH: 22131 LOSS: 40.9793779820656\n",
      "EPOCH: 22132 LOSS: 40.97937632286846\n",
      "EPOCH: 22133 LOSS: 40.97937466379523\n",
      "EPOCH: 22134 LOSS: 40.97937300484588\n",
      "EPOCH: 22135 LOSS: 40.979371346020415\n",
      "EPOCH: 22136 LOSS: 40.97936968731879\n",
      "EPOCH: 22137 LOSS: 40.979368028741014\n",
      "EPOCH: 22138 LOSS: 40.97936637028706\n",
      "EPOCH: 22139 LOSS: 40.97936471195692\n",
      "EPOCH: 22140 LOSS: 40.979363053750546\n",
      "EPOCH: 22141 LOSS: 40.979361395667965\n",
      "EPOCH: 22142 LOSS: 40.97935973770914\n",
      "EPOCH: 22143 LOSS: 40.979358079874046\n",
      "EPOCH: 22144 LOSS: 40.979356422162674\n",
      "EPOCH: 22145 LOSS: 40.97935476457501\n",
      "EPOCH: 22146 LOSS: 40.97935310711104\n",
      "EPOCH: 22147 LOSS: 40.97935144977073\n",
      "EPOCH: 22148 LOSS: 40.97934979255409\n",
      "EPOCH: 22149 LOSS: 40.97934813546108\n",
      "EPOCH: 22150 LOSS: 40.9793464784917\n",
      "EPOCH: 22151 LOSS: 40.97934482164594\n",
      "EPOCH: 22152 LOSS: 40.97934316492375\n",
      "EPOCH: 22153 LOSS: 40.97934150832514\n",
      "EPOCH: 22154 LOSS: 40.97933985185008\n",
      "EPOCH: 22155 LOSS: 40.97933819549857\n",
      "EPOCH: 22156 LOSS: 40.97933653927058\n",
      "EPOCH: 22157 LOSS: 40.97933488316609\n",
      "EPOCH: 22158 LOSS: 40.97933322718511\n",
      "EPOCH: 22159 LOSS: 40.97933157132759\n",
      "EPOCH: 22160 LOSS: 40.97932991559353\n",
      "EPOCH: 22161 LOSS: 40.979328259982914\n",
      "EPOCH: 22162 LOSS: 40.979326604495725\n",
      "EPOCH: 22163 LOSS: 40.97932494913192\n",
      "EPOCH: 22164 LOSS: 40.97932329389155\n",
      "EPOCH: 22165 LOSS: 40.979321638774536\n",
      "EPOCH: 22166 LOSS: 40.97931998378088\n",
      "EPOCH: 22167 LOSS: 40.97931832891056\n",
      "EPOCH: 22168 LOSS: 40.97931667416357\n",
      "EPOCH: 22169 LOSS: 40.979315019539904\n",
      "EPOCH: 22170 LOSS: 40.979313365039495\n",
      "EPOCH: 22171 LOSS: 40.97931171066239\n",
      "EPOCH: 22172 LOSS: 40.979310056408536\n",
      "EPOCH: 22173 LOSS: 40.97930840227794\n",
      "EPOCH: 22174 LOSS: 40.97930674827056\n",
      "EPOCH: 22175 LOSS: 40.97930509438638\n",
      "EPOCH: 22176 LOSS: 40.9793034406254\n",
      "EPOCH: 22177 LOSS: 40.979301786987605\n",
      "EPOCH: 22178 LOSS: 40.979300133472975\n",
      "EPOCH: 22179 LOSS: 40.979298480081475\n",
      "EPOCH: 22180 LOSS: 40.97929682681311\n",
      "EPOCH: 22181 LOSS: 40.979295173667865\n",
      "EPOCH: 22182 LOSS: 40.9792935206457\n",
      "EPOCH: 22183 LOSS: 40.979291867746625\n",
      "EPOCH: 22184 LOSS: 40.97929021497062\n",
      "EPOCH: 22185 LOSS: 40.97928856231764\n",
      "EPOCH: 22186 LOSS: 40.979286909787696\n",
      "EPOCH: 22187 LOSS: 40.97928525738076\n",
      "EPOCH: 22188 LOSS: 40.979283605096825\n",
      "EPOCH: 22189 LOSS: 40.97928195293588\n",
      "EPOCH: 22190 LOSS: 40.979280300897884\n",
      "EPOCH: 22191 LOSS: 40.979278648982834\n",
      "EPOCH: 22192 LOSS: 40.97927699719073\n",
      "EPOCH: 22193 LOSS: 40.979275345521536\n",
      "EPOCH: 22194 LOSS: 40.979273693975216\n",
      "EPOCH: 22195 LOSS: 40.97927204255181\n",
      "EPOCH: 22196 LOSS: 40.97927039125126\n",
      "EPOCH: 22197 LOSS: 40.97926874007354\n",
      "EPOCH: 22198 LOSS: 40.97926708901868\n",
      "EPOCH: 22199 LOSS: 40.97926543808662\n",
      "EPOCH: 22200 LOSS: 40.979263787277354\n",
      "EPOCH: 22201 LOSS: 40.97926213659088\n",
      "EPOCH: 22202 LOSS: 40.979260486027165\n",
      "EPOCH: 22203 LOSS: 40.97925883558622\n",
      "EPOCH: 22204 LOSS: 40.979257185267976\n",
      "EPOCH: 22205 LOSS: 40.979255535072475\n",
      "EPOCH: 22206 LOSS: 40.979253884999686\n",
      "EPOCH: 22207 LOSS: 40.979252235049536\n",
      "EPOCH: 22208 LOSS: 40.97925058522208\n",
      "EPOCH: 22209 LOSS: 40.97924893551728\n",
      "EPOCH: 22210 LOSS: 40.97924728593512\n",
      "EPOCH: 22211 LOSS: 40.979245636475575\n",
      "EPOCH: 22212 LOSS: 40.97924398713862\n",
      "EPOCH: 22213 LOSS: 40.97924233792426\n",
      "EPOCH: 22214 LOSS: 40.97924068883246\n",
      "EPOCH: 22215 LOSS: 40.97923903986323\n",
      "EPOCH: 22216 LOSS: 40.979237391016525\n",
      "EPOCH: 22217 LOSS: 40.979235742292346\n",
      "EPOCH: 22218 LOSS: 40.979234093690664\n",
      "EPOCH: 22219 LOSS: 40.97923244521149\n",
      "EPOCH: 22220 LOSS: 40.97923079685476\n",
      "EPOCH: 22221 LOSS: 40.979229148620504\n",
      "EPOCH: 22222 LOSS: 40.979227500508685\n",
      "EPOCH: 22223 LOSS: 40.979225852519285\n",
      "EPOCH: 22224 LOSS: 40.97922420465228\n",
      "EPOCH: 22225 LOSS: 40.979222556907686\n",
      "EPOCH: 22226 LOSS: 40.97922090928546\n",
      "EPOCH: 22227 LOSS: 40.97921926178557\n",
      "EPOCH: 22228 LOSS: 40.97921761440804\n",
      "EPOCH: 22229 LOSS: 40.97921596715283\n",
      "EPOCH: 22230 LOSS: 40.979214320019935\n",
      "EPOCH: 22231 LOSS: 40.97921267300933\n",
      "EPOCH: 22232 LOSS: 40.97921102612099\n",
      "EPOCH: 22233 LOSS: 40.97920937935491\n",
      "EPOCH: 22234 LOSS: 40.979207732711096\n",
      "EPOCH: 22235 LOSS: 40.979206086189485\n",
      "EPOCH: 22236 LOSS: 40.979204439790095\n",
      "EPOCH: 22237 LOSS: 40.97920279351289\n",
      "EPOCH: 22238 LOSS: 40.97920114735787\n",
      "EPOCH: 22239 LOSS: 40.979199501325\n",
      "EPOCH: 22240 LOSS: 40.979197855414284\n",
      "EPOCH: 22241 LOSS: 40.979196209625705\n",
      "EPOCH: 22242 LOSS: 40.979194563959226\n",
      "EPOCH: 22243 LOSS: 40.97919291841485\n",
      "EPOCH: 22244 LOSS: 40.979191272992544\n",
      "EPOCH: 22245 LOSS: 40.97918962769231\n",
      "EPOCH: 22246 LOSS: 40.979187982514134\n",
      "EPOCH: 22247 LOSS: 40.97918633745797\n",
      "EPOCH: 22248 LOSS: 40.979184692523816\n",
      "EPOCH: 22249 LOSS: 40.97918304771167\n",
      "EPOCH: 22250 LOSS: 40.97918140302153\n",
      "EPOCH: 22251 LOSS: 40.979179758453334\n",
      "EPOCH: 22252 LOSS: 40.97917811400707\n",
      "EPOCH: 22253 LOSS: 40.979176469682756\n",
      "EPOCH: 22254 LOSS: 40.97917482548035\n",
      "EPOCH: 22255 LOSS: 40.979173181399865\n",
      "EPOCH: 22256 LOSS: 40.97917153744126\n",
      "EPOCH: 22257 LOSS: 40.9791698936045\n",
      "EPOCH: 22258 LOSS: 40.97916824988961\n",
      "EPOCH: 22259 LOSS: 40.979166606296566\n",
      "EPOCH: 22260 LOSS: 40.97916496282534\n",
      "EPOCH: 22261 LOSS: 40.979163319475894\n",
      "EPOCH: 22262 LOSS: 40.97916167624825\n",
      "EPOCH: 22263 LOSS: 40.979160033142385\n",
      "EPOCH: 22264 LOSS: 40.97915839015826\n",
      "EPOCH: 22265 LOSS: 40.97915674729588\n",
      "EPOCH: 22266 LOSS: 40.979155104555225\n",
      "EPOCH: 22267 LOSS: 40.979153461936264\n",
      "EPOCH: 22268 LOSS: 40.97915181943901\n",
      "EPOCH: 22269 LOSS: 40.97915017706341\n",
      "EPOCH: 22270 LOSS: 40.97914853480949\n",
      "EPOCH: 22271 LOSS: 40.979146892677186\n",
      "EPOCH: 22272 LOSS: 40.979145250666534\n",
      "EPOCH: 22273 LOSS: 40.97914360877747\n",
      "EPOCH: 22274 LOSS: 40.97914196701\n",
      "EPOCH: 22275 LOSS: 40.97914032536411\n",
      "EPOCH: 22276 LOSS: 40.97913868383978\n",
      "EPOCH: 22277 LOSS: 40.97913704243701\n",
      "EPOCH: 22278 LOSS: 40.97913540115573\n",
      "EPOCH: 22279 LOSS: 40.97913375999599\n",
      "EPOCH: 22280 LOSS: 40.979132118957736\n",
      "EPOCH: 22281 LOSS: 40.97913047804097\n",
      "EPOCH: 22282 LOSS: 40.97912883724565\n",
      "EPOCH: 22283 LOSS: 40.97912719657179\n",
      "EPOCH: 22284 LOSS: 40.97912555601936\n",
      "EPOCH: 22285 LOSS: 40.97912391558835\n",
      "EPOCH: 22286 LOSS: 40.979122275278726\n",
      "EPOCH: 22287 LOSS: 40.979120635090496\n",
      "EPOCH: 22288 LOSS: 40.97911899502361\n",
      "EPOCH: 22289 LOSS: 40.9791173550781\n",
      "EPOCH: 22290 LOSS: 40.97911571525391\n",
      "EPOCH: 22291 LOSS: 40.97911407555105\n",
      "EPOCH: 22292 LOSS: 40.979112435969476\n",
      "EPOCH: 22293 LOSS: 40.97911079650919\n",
      "EPOCH: 22294 LOSS: 40.97910915717017\n",
      "EPOCH: 22295 LOSS: 40.97910751795241\n",
      "EPOCH: 22296 LOSS: 40.979105878855876\n",
      "EPOCH: 22297 LOSS: 40.97910423988057\n",
      "EPOCH: 22298 LOSS: 40.979102601026476\n",
      "EPOCH: 22299 LOSS: 40.97910096229357\n",
      "EPOCH: 22300 LOSS: 40.97909932368182\n",
      "EPOCH: 22301 LOSS: 40.97909768519123\n",
      "EPOCH: 22302 LOSS: 40.97909604682179\n",
      "EPOCH: 22303 LOSS: 40.979094408573474\n",
      "EPOCH: 22304 LOSS: 40.97909277044626\n",
      "EPOCH: 22305 LOSS: 40.97909113244013\n",
      "EPOCH: 22306 LOSS: 40.979089494555076\n",
      "EPOCH: 22307 LOSS: 40.9790878567911\n",
      "EPOCH: 22308 LOSS: 40.97908621914816\n",
      "EPOCH: 22309 LOSS: 40.979084581626225\n",
      "EPOCH: 22310 LOSS: 40.979082944225325\n",
      "EPOCH: 22311 LOSS: 40.97908130694542\n",
      "EPOCH: 22312 LOSS: 40.97907966978647\n",
      "EPOCH: 22313 LOSS: 40.97907803274851\n",
      "EPOCH: 22314 LOSS: 40.979076395831484\n",
      "EPOCH: 22315 LOSS: 40.979074759035385\n",
      "EPOCH: 22316 LOSS: 40.979073122360205\n",
      "EPOCH: 22317 LOSS: 40.97907148580592\n",
      "EPOCH: 22318 LOSS: 40.979069849372536\n",
      "EPOCH: 22319 LOSS: 40.97906821306\n",
      "EPOCH: 22320 LOSS: 40.979066576868306\n",
      "EPOCH: 22321 LOSS: 40.97906494079746\n",
      "EPOCH: 22322 LOSS: 40.97906330484743\n",
      "EPOCH: 22323 LOSS: 40.97906166901819\n",
      "EPOCH: 22324 LOSS: 40.97906003330975\n",
      "EPOCH: 22325 LOSS: 40.97905839772208\n",
      "EPOCH: 22326 LOSS: 40.979056762255155\n",
      "EPOCH: 22327 LOSS: 40.979055126908975\n",
      "EPOCH: 22328 LOSS: 40.9790534916835\n",
      "EPOCH: 22329 LOSS: 40.97905185657875\n",
      "EPOCH: 22330 LOSS: 40.97905022159469\n",
      "EPOCH: 22331 LOSS: 40.979048586731295\n",
      "EPOCH: 22332 LOSS: 40.97904695198855\n",
      "EPOCH: 22333 LOSS: 40.979045317366456\n",
      "EPOCH: 22334 LOSS: 40.97904368286498\n",
      "EPOCH: 22335 LOSS: 40.979042048484125\n",
      "EPOCH: 22336 LOSS: 40.97904041422385\n",
      "EPOCH: 22337 LOSS: 40.97903878008416\n",
      "EPOCH: 22338 LOSS: 40.97903714606504\n",
      "EPOCH: 22339 LOSS: 40.97903551216645\n",
      "EPOCH: 22340 LOSS: 40.97903387838838\n",
      "EPOCH: 22341 LOSS: 40.979032244730845\n",
      "EPOCH: 22342 LOSS: 40.97903061119381\n",
      "EPOCH: 22343 LOSS: 40.97902897777723\n",
      "EPOCH: 22344 LOSS: 40.97902734448114\n",
      "EPOCH: 22345 LOSS: 40.97902571130549\n",
      "EPOCH: 22346 LOSS: 40.97902407825026\n",
      "EPOCH: 22347 LOSS: 40.97902244531547\n",
      "EPOCH: 22348 LOSS: 40.97902081250105\n",
      "EPOCH: 22349 LOSS: 40.979019179807025\n",
      "EPOCH: 22350 LOSS: 40.9790175472334\n",
      "EPOCH: 22351 LOSS: 40.97901591478009\n",
      "EPOCH: 22352 LOSS: 40.97901428244714\n",
      "EPOCH: 22353 LOSS: 40.97901265023451\n",
      "EPOCH: 22354 LOSS: 40.979011018142174\n",
      "EPOCH: 22355 LOSS: 40.979009386170134\n",
      "EPOCH: 22356 LOSS: 40.97900775431836\n",
      "EPOCH: 22357 LOSS: 40.97900612258684\n",
      "EPOCH: 22358 LOSS: 40.97900449097557\n",
      "EPOCH: 22359 LOSS: 40.979002859484524\n",
      "EPOCH: 22360 LOSS: 40.97900122811369\n",
      "EPOCH: 22361 LOSS: 40.97899959686306\n",
      "EPOCH: 22362 LOSS: 40.97899796573259\n",
      "EPOCH: 22363 LOSS: 40.97899633472228\n",
      "EPOCH: 22364 LOSS: 40.97899470383211\n",
      "EPOCH: 22365 LOSS: 40.97899307306208\n",
      "EPOCH: 22366 LOSS: 40.97899144241216\n",
      "EPOCH: 22367 LOSS: 40.97898981188234\n",
      "EPOCH: 22368 LOSS: 40.9789881814726\n",
      "EPOCH: 22369 LOSS: 40.97898655118292\n",
      "EPOCH: 22370 LOSS: 40.97898492101329\n",
      "EPOCH: 22371 LOSS: 40.97898329096371\n",
      "EPOCH: 22372 LOSS: 40.97898166103414\n",
      "EPOCH: 22373 LOSS: 40.97898003122456\n",
      "EPOCH: 22374 LOSS: 40.97897840153498\n",
      "EPOCH: 22375 LOSS: 40.97897677196538\n",
      "EPOCH: 22376 LOSS: 40.9789751425157\n",
      "EPOCH: 22377 LOSS: 40.978973513185984\n",
      "EPOCH: 22378 LOSS: 40.978971883976186\n",
      "EPOCH: 22379 LOSS: 40.978970254886285\n",
      "EPOCH: 22380 LOSS: 40.97896862591628\n",
      "EPOCH: 22381 LOSS: 40.97896699706615\n",
      "EPOCH: 22382 LOSS: 40.97896536833588\n",
      "EPOCH: 22383 LOSS: 40.978963739725444\n",
      "EPOCH: 22384 LOSS: 40.97896211123484\n",
      "EPOCH: 22385 LOSS: 40.97896048286407\n",
      "EPOCH: 22386 LOSS: 40.978958854613055\n",
      "EPOCH: 22387 LOSS: 40.97895722648184\n",
      "EPOCH: 22388 LOSS: 40.97895559847038\n",
      "EPOCH: 22389 LOSS: 40.97895397057867\n",
      "EPOCH: 22390 LOSS: 40.9789523428067\n",
      "EPOCH: 22391 LOSS: 40.97895071515444\n",
      "EPOCH: 22392 LOSS: 40.97894908762187\n",
      "EPOCH: 22393 LOSS: 40.97894746020901\n",
      "EPOCH: 22394 LOSS: 40.978945832915784\n",
      "EPOCH: 22395 LOSS: 40.97894420574223\n",
      "EPOCH: 22396 LOSS: 40.978942578688304\n",
      "EPOCH: 22397 LOSS: 40.97894095175401\n",
      "EPOCH: 22398 LOSS: 40.97893932493931\n",
      "EPOCH: 22399 LOSS: 40.97893769824421\n",
      "EPOCH: 22400 LOSS: 40.97893607166867\n",
      "EPOCH: 22401 LOSS: 40.97893444521269\n",
      "EPOCH: 22402 LOSS: 40.978932818876245\n",
      "EPOCH: 22403 LOSS: 40.978931192659346\n",
      "EPOCH: 22404 LOSS: 40.97892956656193\n",
      "EPOCH: 22405 LOSS: 40.978927940584015\n",
      "EPOCH: 22406 LOSS: 40.978926314725584\n",
      "EPOCH: 22407 LOSS: 40.97892468898661\n",
      "EPOCH: 22408 LOSS: 40.97892306336709\n",
      "EPOCH: 22409 LOSS: 40.97892143786699\n",
      "EPOCH: 22410 LOSS: 40.97891981248631\n",
      "EPOCH: 22411 LOSS: 40.97891818722503\n",
      "EPOCH: 22412 LOSS: 40.978916562083114\n",
      "EPOCH: 22413 LOSS: 40.978914937060594\n",
      "EPOCH: 22414 LOSS: 40.97891331215741\n",
      "EPOCH: 22415 LOSS: 40.978911687373554\n",
      "EPOCH: 22416 LOSS: 40.978910062709026\n",
      "EPOCH: 22417 LOSS: 40.9789084381638\n",
      "EPOCH: 22418 LOSS: 40.978906813737865\n",
      "EPOCH: 22419 LOSS: 40.97890518943121\n",
      "EPOCH: 22420 LOSS: 40.97890356524379\n",
      "EPOCH: 22421 LOSS: 40.978901941175614\n",
      "EPOCH: 22422 LOSS: 40.97890031722666\n",
      "EPOCH: 22423 LOSS: 40.97889869339694\n",
      "EPOCH: 22424 LOSS: 40.97889706968638\n",
      "EPOCH: 22425 LOSS: 40.97889544609501\n",
      "EPOCH: 22426 LOSS: 40.97889382262282\n",
      "EPOCH: 22427 LOSS: 40.97889219926975\n",
      "EPOCH: 22428 LOSS: 40.978890576035816\n",
      "EPOCH: 22429 LOSS: 40.978888952921\n",
      "EPOCH: 22430 LOSS: 40.978887329925286\n",
      "EPOCH: 22431 LOSS: 40.97888570704864\n",
      "EPOCH: 22432 LOSS: 40.978884084291074\n",
      "EPOCH: 22433 LOSS: 40.97888246165256\n",
      "EPOCH: 22434 LOSS: 40.97888083913307\n",
      "EPOCH: 22435 LOSS: 40.97887921673261\n",
      "EPOCH: 22436 LOSS: 40.97887759445114\n",
      "EPOCH: 22437 LOSS: 40.97887597228868\n",
      "EPOCH: 22438 LOSS: 40.978874350245164\n",
      "EPOCH: 22439 LOSS: 40.978872728320624\n",
      "EPOCH: 22440 LOSS: 40.978871106515015\n",
      "EPOCH: 22441 LOSS: 40.97886948482834\n",
      "EPOCH: 22442 LOSS: 40.978867863260575\n",
      "EPOCH: 22443 LOSS: 40.978866241811694\n",
      "EPOCH: 22444 LOSS: 40.97886462048169\n",
      "EPOCH: 22445 LOSS: 40.97886299927054\n",
      "EPOCH: 22446 LOSS: 40.97886137817826\n",
      "EPOCH: 22447 LOSS: 40.97885975720479\n",
      "EPOCH: 22448 LOSS: 40.97885813635015\n",
      "EPOCH: 22449 LOSS: 40.9788565156143\n",
      "EPOCH: 22450 LOSS: 40.97885489499722\n",
      "EPOCH: 22451 LOSS: 40.97885327449893\n",
      "EPOCH: 22452 LOSS: 40.978851654119374\n",
      "EPOCH: 22453 LOSS: 40.97885003385856\n",
      "EPOCH: 22454 LOSS: 40.97884841371648\n",
      "EPOCH: 22455 LOSS: 40.97884679369308\n",
      "EPOCH: 22456 LOSS: 40.978845173788386\n",
      "EPOCH: 22457 LOSS: 40.97884355400237\n",
      "EPOCH: 22458 LOSS: 40.978841934334994\n",
      "EPOCH: 22459 LOSS: 40.978840314786275\n",
      "EPOCH: 22460 LOSS: 40.978838695356174\n",
      "EPOCH: 22461 LOSS: 40.978837076044684\n",
      "EPOCH: 22462 LOSS: 40.9788354568518\n",
      "EPOCH: 22463 LOSS: 40.97883383777747\n",
      "EPOCH: 22464 LOSS: 40.97883221882172\n",
      "EPOCH: 22465 LOSS: 40.97883059998452\n",
      "EPOCH: 22466 LOSS: 40.97882898126585\n",
      "EPOCH: 22467 LOSS: 40.97882736266568\n",
      "EPOCH: 22468 LOSS: 40.978825744184036\n",
      "EPOCH: 22469 LOSS: 40.978824125820864\n",
      "EPOCH: 22470 LOSS: 40.978822507576155\n",
      "EPOCH: 22471 LOSS: 40.978820889449906\n",
      "EPOCH: 22472 LOSS: 40.97881927144209\n",
      "EPOCH: 22473 LOSS: 40.9788176535527\n",
      "EPOCH: 22474 LOSS: 40.97881603578173\n",
      "EPOCH: 22475 LOSS: 40.97881441812913\n",
      "EPOCH: 22476 LOSS: 40.97881280059492\n",
      "EPOCH: 22477 LOSS: 40.97881118317906\n",
      "EPOCH: 22478 LOSS: 40.97880956588155\n",
      "EPOCH: 22479 LOSS: 40.978807948702354\n",
      "EPOCH: 22480 LOSS: 40.97880633164149\n",
      "EPOCH: 22481 LOSS: 40.97880471469892\n",
      "EPOCH: 22482 LOSS: 40.97880309787463\n",
      "EPOCH: 22483 LOSS: 40.978801481168595\n",
      "EPOCH: 22484 LOSS: 40.97879986458082\n",
      "EPOCH: 22485 LOSS: 40.978798248111275\n",
      "EPOCH: 22486 LOSS: 40.97879663175995\n",
      "EPOCH: 22487 LOSS: 40.97879501552683\n",
      "EPOCH: 22488 LOSS: 40.978793399411906\n",
      "EPOCH: 22489 LOSS: 40.97879178341513\n",
      "EPOCH: 22490 LOSS: 40.97879016753653\n",
      "EPOCH: 22491 LOSS: 40.97878855177607\n",
      "EPOCH: 22492 LOSS: 40.97878693613373\n",
      "EPOCH: 22493 LOSS: 40.978785320609504\n",
      "EPOCH: 22494 LOSS: 40.97878370520337\n",
      "EPOCH: 22495 LOSS: 40.97878208991529\n",
      "EPOCH: 22496 LOSS: 40.97878047474531\n",
      "EPOCH: 22497 LOSS: 40.97877885969338\n",
      "EPOCH: 22498 LOSS: 40.978777244759456\n",
      "EPOCH: 22499 LOSS: 40.978775629943556\n",
      "EPOCH: 22500 LOSS: 40.97877401524565\n",
      "EPOCH: 22501 LOSS: 40.97877240066574\n",
      "EPOCH: 22502 LOSS: 40.978770786203796\n",
      "EPOCH: 22503 LOSS: 40.978769171859796\n",
      "EPOCH: 22504 LOSS: 40.97876755763373\n",
      "EPOCH: 22505 LOSS: 40.9787659435256\n",
      "EPOCH: 22506 LOSS: 40.97876432953538\n",
      "EPOCH: 22507 LOSS: 40.978762715663066\n",
      "EPOCH: 22508 LOSS: 40.97876110190858\n",
      "EPOCH: 22509 LOSS: 40.978759488272004\n",
      "EPOCH: 22510 LOSS: 40.97875787475324\n",
      "EPOCH: 22511 LOSS: 40.978756261352316\n",
      "EPOCH: 22512 LOSS: 40.97875464806921\n",
      "EPOCH: 22513 LOSS: 40.97875303490389\n",
      "EPOCH: 22514 LOSS: 40.97875142185637\n",
      "EPOCH: 22515 LOSS: 40.97874980892662\n",
      "EPOCH: 22516 LOSS: 40.97874819611458\n",
      "EPOCH: 22517 LOSS: 40.97874658342031\n",
      "EPOCH: 22518 LOSS: 40.97874497084375\n",
      "EPOCH: 22519 LOSS: 40.978743358384904\n",
      "EPOCH: 22520 LOSS: 40.97874174604374\n",
      "EPOCH: 22521 LOSS: 40.978740133820246\n",
      "EPOCH: 22522 LOSS: 40.978738521714426\n",
      "EPOCH: 22523 LOSS: 40.97873690972623\n",
      "EPOCH: 22524 LOSS: 40.978735297855664\n",
      "EPOCH: 22525 LOSS: 40.978733686102714\n",
      "EPOCH: 22526 LOSS: 40.978732074467366\n",
      "EPOCH: 22527 LOSS: 40.9787304629496\n",
      "EPOCH: 22528 LOSS: 40.97872885154939\n",
      "EPOCH: 22529 LOSS: 40.97872724026672\n",
      "EPOCH: 22530 LOSS: 40.97872562910161\n",
      "EPOCH: 22531 LOSS: 40.978724018054\n",
      "EPOCH: 22532 LOSS: 40.97872240712389\n",
      "EPOCH: 22533 LOSS: 40.97872079631128\n",
      "EPOCH: 22534 LOSS: 40.97871918561613\n",
      "EPOCH: 22535 LOSS: 40.97871757503844\n",
      "EPOCH: 22536 LOSS: 40.978715964578186\n",
      "EPOCH: 22537 LOSS: 40.97871435423537\n",
      "EPOCH: 22538 LOSS: 40.97871274400996\n",
      "EPOCH: 22539 LOSS: 40.978711133901946\n",
      "EPOCH: 22540 LOSS: 40.97870952391129\n",
      "EPOCH: 22541 LOSS: 40.97870791403801\n",
      "EPOCH: 22542 LOSS: 40.97870630428209\n",
      "EPOCH: 22543 LOSS: 40.97870469464351\n",
      "EPOCH: 22544 LOSS: 40.97870308512222\n",
      "EPOCH: 22545 LOSS: 40.97870147571825\n",
      "EPOCH: 22546 LOSS: 40.978699866431555\n",
      "EPOCH: 22547 LOSS: 40.97869825726214\n",
      "EPOCH: 22548 LOSS: 40.978696648209976\n",
      "EPOCH: 22549 LOSS: 40.97869503927505\n",
      "EPOCH: 22550 LOSS: 40.978693430457355\n",
      "EPOCH: 22551 LOSS: 40.978691821756854\n",
      "EPOCH: 22552 LOSS: 40.97869021317356\n",
      "EPOCH: 22553 LOSS: 40.97868860470744\n",
      "EPOCH: 22554 LOSS: 40.978686996358476\n",
      "EPOCH: 22555 LOSS: 40.97868538812667\n",
      "EPOCH: 22556 LOSS: 40.978683780012\n",
      "EPOCH: 22557 LOSS: 40.97868217201443\n",
      "EPOCH: 22558 LOSS: 40.97868056413397\n",
      "EPOCH: 22559 LOSS: 40.97867895637059\n",
      "EPOCH: 22560 LOSS: 40.978677348724275\n",
      "EPOCH: 22561 LOSS: 40.97867574119502\n",
      "EPOCH: 22562 LOSS: 40.97867413378281\n",
      "EPOCH: 22563 LOSS: 40.978672526487614\n",
      "EPOCH: 22564 LOSS: 40.97867091930945\n",
      "EPOCH: 22565 LOSS: 40.97866931224824\n",
      "EPOCH: 22566 LOSS: 40.97866770530405\n",
      "EPOCH: 22567 LOSS: 40.97866609847679\n",
      "EPOCH: 22568 LOSS: 40.97866449176647\n",
      "EPOCH: 22569 LOSS: 40.97866288517312\n",
      "EPOCH: 22570 LOSS: 40.978661278696656\n",
      "EPOCH: 22571 LOSS: 40.9786596723371\n",
      "EPOCH: 22572 LOSS: 40.978658066094425\n",
      "EPOCH: 22573 LOSS: 40.978656459968626\n",
      "EPOCH: 22574 LOSS: 40.978654853959675\n",
      "EPOCH: 22575 LOSS: 40.978653248067566\n",
      "EPOCH: 22576 LOSS: 40.97865164229228\n",
      "EPOCH: 22577 LOSS: 40.97865003663381\n",
      "EPOCH: 22578 LOSS: 40.97864843109211\n",
      "EPOCH: 22579 LOSS: 40.978646825667205\n",
      "EPOCH: 22580 LOSS: 40.97864522035906\n",
      "EPOCH: 22581 LOSS: 40.97864361516765\n",
      "EPOCH: 22582 LOSS: 40.97864201009298\n",
      "EPOCH: 22583 LOSS: 40.978640405135025\n",
      "EPOCH: 22584 LOSS: 40.978638800293766\n",
      "EPOCH: 22585 LOSS: 40.97863719556922\n",
      "EPOCH: 22586 LOSS: 40.978635590961304\n",
      "EPOCH: 22587 LOSS: 40.978633986470065\n",
      "EPOCH: 22588 LOSS: 40.978632382095455\n",
      "EPOCH: 22589 LOSS: 40.97863077783748\n",
      "EPOCH: 22590 LOSS: 40.978629173696106\n",
      "EPOCH: 22591 LOSS: 40.97862756967132\n",
      "EPOCH: 22592 LOSS: 40.978625965763115\n",
      "EPOCH: 22593 LOSS: 40.978624361971484\n",
      "EPOCH: 22594 LOSS: 40.97862275829638\n",
      "EPOCH: 22595 LOSS: 40.978621154737816\n",
      "EPOCH: 22596 LOSS: 40.978619551295765\n",
      "EPOCH: 22597 LOSS: 40.97861794797022\n",
      "EPOCH: 22598 LOSS: 40.97861634476116\n",
      "EPOCH: 22599 LOSS: 40.97861474166857\n",
      "EPOCH: 22600 LOSS: 40.978613138692424\n",
      "EPOCH: 22601 LOSS: 40.97861153583273\n",
      "EPOCH: 22602 LOSS: 40.97860993308946\n",
      "EPOCH: 22603 LOSS: 40.97860833046259\n",
      "EPOCH: 22604 LOSS: 40.97860672795212\n",
      "EPOCH: 22605 LOSS: 40.97860512555803\n",
      "EPOCH: 22606 LOSS: 40.9786035232803\n",
      "EPOCH: 22607 LOSS: 40.97860192111892\n",
      "EPOCH: 22608 LOSS: 40.97860031907387\n",
      "EPOCH: 22609 LOSS: 40.97859871714515\n",
      "EPOCH: 22610 LOSS: 40.978597115332704\n",
      "EPOCH: 22611 LOSS: 40.97859551363655\n",
      "EPOCH: 22612 LOSS: 40.97859391205669\n",
      "EPOCH: 22613 LOSS: 40.978592310593065\n",
      "EPOCH: 22614 LOSS: 40.978590709245694\n",
      "EPOCH: 22615 LOSS: 40.97858910801453\n",
      "EPOCH: 22616 LOSS: 40.97858750689959\n",
      "EPOCH: 22617 LOSS: 40.97858590590084\n",
      "EPOCH: 22618 LOSS: 40.97858430501828\n",
      "EPOCH: 22619 LOSS: 40.97858270425187\n",
      "EPOCH: 22620 LOSS: 40.97858110360162\n",
      "EPOCH: 22621 LOSS: 40.97857950306749\n",
      "EPOCH: 22622 LOSS: 40.9785779026495\n",
      "EPOCH: 22623 LOSS: 40.97857630234759\n",
      "EPOCH: 22624 LOSS: 40.978574702161765\n",
      "EPOCH: 22625 LOSS: 40.978573102092035\n",
      "EPOCH: 22626 LOSS: 40.97857150213835\n",
      "EPOCH: 22627 LOSS: 40.97856990230072\n",
      "EPOCH: 22628 LOSS: 40.9785683025791\n",
      "EPOCH: 22629 LOSS: 40.9785667029735\n",
      "EPOCH: 22630 LOSS: 40.97856510348389\n",
      "EPOCH: 22631 LOSS: 40.97856350411026\n",
      "EPOCH: 22632 LOSS: 40.97856190485261\n",
      "EPOCH: 22633 LOSS: 40.97856030571089\n",
      "EPOCH: 22634 LOSS: 40.97855870668512\n",
      "EPOCH: 22635 LOSS: 40.978557107775266\n",
      "EPOCH: 22636 LOSS: 40.97855550898131\n",
      "EPOCH: 22637 LOSS: 40.97855391030326\n",
      "EPOCH: 22638 LOSS: 40.97855231174107\n",
      "EPOCH: 22639 LOSS: 40.97855071329474\n",
      "EPOCH: 22640 LOSS: 40.97854911496427\n",
      "EPOCH: 22641 LOSS: 40.97854751674961\n",
      "EPOCH: 22642 LOSS: 40.97854591865076\n",
      "EPOCH: 22643 LOSS: 40.97854432066772\n",
      "EPOCH: 22644 LOSS: 40.97854272280046\n",
      "EPOCH: 22645 LOSS: 40.978541125048984\n",
      "EPOCH: 22646 LOSS: 40.97853952741323\n",
      "EPOCH: 22647 LOSS: 40.978537929893236\n",
      "EPOCH: 22648 LOSS: 40.978536332488964\n",
      "EPOCH: 22649 LOSS: 40.97853473520039\n",
      "EPOCH: 22650 LOSS: 40.978533138027515\n",
      "EPOCH: 22651 LOSS: 40.97853154097031\n",
      "EPOCH: 22652 LOSS: 40.978529944028764\n",
      "EPOCH: 22653 LOSS: 40.97852834720287\n",
      "EPOCH: 22654 LOSS: 40.97852675049259\n",
      "EPOCH: 22655 LOSS: 40.97852515389796\n",
      "EPOCH: 22656 LOSS: 40.97852355741891\n",
      "EPOCH: 22657 LOSS: 40.97852196105545\n",
      "EPOCH: 22658 LOSS: 40.97852036480755\n",
      "EPOCH: 22659 LOSS: 40.97851876867521\n",
      "EPOCH: 22660 LOSS: 40.97851717265842\n",
      "EPOCH: 22661 LOSS: 40.97851557675715\n",
      "EPOCH: 22662 LOSS: 40.97851398097139\n",
      "EPOCH: 22663 LOSS: 40.97851238530113\n",
      "EPOCH: 22664 LOSS: 40.97851078974633\n",
      "EPOCH: 22665 LOSS: 40.97850919430701\n",
      "EPOCH: 22666 LOSS: 40.978507598983136\n",
      "EPOCH: 22667 LOSS: 40.97850600377469\n",
      "EPOCH: 22668 LOSS: 40.97850440868167\n",
      "EPOCH: 22669 LOSS: 40.97850281370406\n",
      "EPOCH: 22670 LOSS: 40.97850121884183\n",
      "EPOCH: 22671 LOSS: 40.978499624094965\n",
      "EPOCH: 22672 LOSS: 40.97849802946348\n",
      "EPOCH: 22673 LOSS: 40.97849643494732\n",
      "EPOCH: 22674 LOSS: 40.97849484054649\n",
      "EPOCH: 22675 LOSS: 40.97849324626097\n",
      "EPOCH: 22676 LOSS: 40.97849165209075\n",
      "EPOCH: 22677 LOSS: 40.97849005803583\n",
      "EPOCH: 22678 LOSS: 40.97848846409616\n",
      "EPOCH: 22679 LOSS: 40.97848687027174\n",
      "EPOCH: 22680 LOSS: 40.97848527656258\n",
      "EPOCH: 22681 LOSS: 40.978483682968616\n",
      "EPOCH: 22682 LOSS: 40.978482089489866\n",
      "EPOCH: 22683 LOSS: 40.97848049612631\n",
      "EPOCH: 22684 LOSS: 40.97847890287794\n",
      "EPOCH: 22685 LOSS: 40.97847730974471\n",
      "EPOCH: 22686 LOSS: 40.978475716726635\n",
      "EPOCH: 22687 LOSS: 40.9784741238237\n",
      "EPOCH: 22688 LOSS: 40.97847253103589\n",
      "EPOCH: 22689 LOSS: 40.97847093836316\n",
      "EPOCH: 22690 LOSS: 40.97846934580552\n",
      "EPOCH: 22691 LOSS: 40.97846775336295\n",
      "EPOCH: 22692 LOSS: 40.978466161035456\n",
      "EPOCH: 22693 LOSS: 40.978464568822986\n",
      "EPOCH: 22694 LOSS: 40.97846297672554\n",
      "EPOCH: 22695 LOSS: 40.9784613847431\n",
      "EPOCH: 22696 LOSS: 40.97845979287568\n",
      "EPOCH: 22697 LOSS: 40.97845820112322\n",
      "EPOCH: 22698 LOSS: 40.978456609485725\n",
      "EPOCH: 22699 LOSS: 40.97845501796321\n",
      "EPOCH: 22700 LOSS: 40.9784534265556\n",
      "EPOCH: 22701 LOSS: 40.97845183526291\n",
      "EPOCH: 22702 LOSS: 40.97845024408513\n",
      "EPOCH: 22703 LOSS: 40.97844865302224\n",
      "EPOCH: 22704 LOSS: 40.978447062074224\n",
      "EPOCH: 22705 LOSS: 40.97844547124109\n",
      "EPOCH: 22706 LOSS: 40.97844388052277\n",
      "EPOCH: 22707 LOSS: 40.9784422899193\n",
      "EPOCH: 22708 LOSS: 40.97844069943064\n",
      "EPOCH: 22709 LOSS: 40.97843910905678\n",
      "EPOCH: 22710 LOSS: 40.9784375187977\n",
      "EPOCH: 22711 LOSS: 40.97843592865339\n",
      "EPOCH: 22712 LOSS: 40.978434338623835\n",
      "EPOCH: 22713 LOSS: 40.97843274870902\n",
      "EPOCH: 22714 LOSS: 40.97843115890895\n",
      "EPOCH: 22715 LOSS: 40.978429569223564\n",
      "EPOCH: 22716 LOSS: 40.97842797965288\n",
      "EPOCH: 22717 LOSS: 40.97842639019687\n",
      "EPOCH: 22718 LOSS: 40.978424800855535\n",
      "EPOCH: 22719 LOSS: 40.97842321162885\n",
      "EPOCH: 22720 LOSS: 40.97842162251679\n",
      "EPOCH: 22721 LOSS: 40.97842003351935\n",
      "EPOCH: 22722 LOSS: 40.97841844463652\n",
      "EPOCH: 22723 LOSS: 40.97841685586829\n",
      "EPOCH: 22724 LOSS: 40.97841526721463\n",
      "EPOCH: 22725 LOSS: 40.978413678675516\n",
      "EPOCH: 22726 LOSS: 40.978412090250956\n",
      "EPOCH: 22727 LOSS: 40.978410501940914\n",
      "EPOCH: 22728 LOSS: 40.978408913745405\n",
      "EPOCH: 22729 LOSS: 40.978407325664385\n",
      "EPOCH: 22730 LOSS: 40.978405737697834\n",
      "EPOCH: 22731 LOSS: 40.97840414984579\n",
      "EPOCH: 22732 LOSS: 40.97840256210817\n",
      "EPOCH: 22733 LOSS: 40.97840097448502\n",
      "EPOCH: 22734 LOSS: 40.978399386976264\n",
      "EPOCH: 22735 LOSS: 40.97839779958193\n",
      "EPOCH: 22736 LOSS: 40.978396212301995\n",
      "EPOCH: 22737 LOSS: 40.97839462513643\n",
      "EPOCH: 22738 LOSS: 40.97839303808524\n",
      "EPOCH: 22739 LOSS: 40.97839145114839\n",
      "EPOCH: 22740 LOSS: 40.978389864325884\n",
      "EPOCH: 22741 LOSS: 40.9783882776177\n",
      "EPOCH: 22742 LOSS: 40.978386691023815\n",
      "EPOCH: 22743 LOSS: 40.9783851045442\n",
      "EPOCH: 22744 LOSS: 40.97838351817889\n",
      "EPOCH: 22745 LOSS: 40.97838193192782\n",
      "EPOCH: 22746 LOSS: 40.978380345791\n",
      "EPOCH: 22747 LOSS: 40.978378759768425\n",
      "EPOCH: 22748 LOSS: 40.97837717386005\n",
      "EPOCH: 22749 LOSS: 40.978375588065894\n",
      "EPOCH: 22750 LOSS: 40.978374002385905\n",
      "EPOCH: 22751 LOSS: 40.97837241682009\n",
      "EPOCH: 22752 LOSS: 40.97837083136844\n",
      "EPOCH: 22753 LOSS: 40.978369246030915\n",
      "EPOCH: 22754 LOSS: 40.97836766080752\n",
      "EPOCH: 22755 LOSS: 40.97836607569824\n",
      "EPOCH: 22756 LOSS: 40.978364490703065\n",
      "EPOCH: 22757 LOSS: 40.97836290582196\n",
      "EPOCH: 22758 LOSS: 40.978361321054905\n",
      "EPOCH: 22759 LOSS: 40.978359736401934\n",
      "EPOCH: 22760 LOSS: 40.97835815186298\n",
      "EPOCH: 22761 LOSS: 40.978356567438055\n",
      "EPOCH: 22762 LOSS: 40.97835498312713\n",
      "EPOCH: 22763 LOSS: 40.978353398930196\n",
      "EPOCH: 22764 LOSS: 40.978351814847244\n",
      "EPOCH: 22765 LOSS: 40.978350230878256\n",
      "EPOCH: 22766 LOSS: 40.9783486470232\n",
      "EPOCH: 22767 LOSS: 40.97834706328209\n",
      "EPOCH: 22768 LOSS: 40.97834547965489\n",
      "EPOCH: 22769 LOSS: 40.978343896141595\n",
      "EPOCH: 22770 LOSS: 40.9783423127422\n",
      "EPOCH: 22771 LOSS: 40.97834072945666\n",
      "EPOCH: 22772 LOSS: 40.978339146284966\n",
      "EPOCH: 22773 LOSS: 40.978337563227136\n",
      "EPOCH: 22774 LOSS: 40.97833598028312\n",
      "EPOCH: 22775 LOSS: 40.97833439745294\n",
      "EPOCH: 22776 LOSS: 40.97833281473653\n",
      "EPOCH: 22777 LOSS: 40.97833123213392\n",
      "EPOCH: 22778 LOSS: 40.978329649645076\n",
      "EPOCH: 22779 LOSS: 40.978328067269985\n",
      "EPOCH: 22780 LOSS: 40.97832648500862\n",
      "EPOCH: 22781 LOSS: 40.97832490286099\n",
      "EPOCH: 22782 LOSS: 40.978323320827066\n",
      "EPOCH: 22783 LOSS: 40.97832173890684\n",
      "EPOCH: 22784 LOSS: 40.9783201571003\n",
      "EPOCH: 22785 LOSS: 40.978318575407414\n",
      "EPOCH: 22786 LOSS: 40.97831699382817\n",
      "EPOCH: 22787 LOSS: 40.97831541236256\n",
      "EPOCH: 22788 LOSS: 40.97831383101059\n",
      "EPOCH: 22789 LOSS: 40.978312249772216\n",
      "EPOCH: 22790 LOSS: 40.978310668647424\n",
      "EPOCH: 22791 LOSS: 40.978309087636205\n",
      "EPOCH: 22792 LOSS: 40.97830750673857\n",
      "EPOCH: 22793 LOSS: 40.97830592595446\n",
      "EPOCH: 22794 LOSS: 40.978304345283895\n",
      "EPOCH: 22795 LOSS: 40.97830276472683\n",
      "EPOCH: 22796 LOSS: 40.978301184283275\n",
      "EPOCH: 22797 LOSS: 40.978299603953204\n",
      "EPOCH: 22798 LOSS: 40.9782980237366\n",
      "EPOCH: 22799 LOSS: 40.978296443633454\n",
      "EPOCH: 22800 LOSS: 40.97829486364376\n",
      "EPOCH: 22801 LOSS: 40.97829328376747\n",
      "EPOCH: 22802 LOSS: 40.97829170400462\n",
      "EPOCH: 22803 LOSS: 40.978290124355155\n",
      "EPOCH: 22804 LOSS: 40.97828854481907\n",
      "EPOCH: 22805 LOSS: 40.97828696539635\n",
      "EPOCH: 22806 LOSS: 40.97828538608698\n",
      "EPOCH: 22807 LOSS: 40.97828380689097\n",
      "EPOCH: 22808 LOSS: 40.978282227808265\n",
      "EPOCH: 22809 LOSS: 40.97828064883886\n",
      "EPOCH: 22810 LOSS: 40.978279069982776\n",
      "EPOCH: 22811 LOSS: 40.978277491239965\n",
      "EPOCH: 22812 LOSS: 40.9782759126104\n",
      "EPOCH: 22813 LOSS: 40.978274334094095\n",
      "EPOCH: 22814 LOSS: 40.97827275569102\n",
      "EPOCH: 22815 LOSS: 40.97827117740117\n",
      "EPOCH: 22816 LOSS: 40.978269599224525\n",
      "EPOCH: 22817 LOSS: 40.97826802116107\n",
      "EPOCH: 22818 LOSS: 40.97826644321079\n",
      "EPOCH: 22819 LOSS: 40.978264865373674\n",
      "EPOCH: 22820 LOSS: 40.978263287649696\n",
      "EPOCH: 22821 LOSS: 40.97826171003886\n",
      "EPOCH: 22822 LOSS: 40.97826013254112\n",
      "EPOCH: 22823 LOSS: 40.97825855515652\n",
      "EPOCH: 22824 LOSS: 40.97825697788498\n",
      "EPOCH: 22825 LOSS: 40.97825540072652\n",
      "EPOCH: 22826 LOSS: 40.97825382368111\n",
      "EPOCH: 22827 LOSS: 40.978252246748745\n",
      "EPOCH: 22828 LOSS: 40.97825066992941\n",
      "EPOCH: 22829 LOSS: 40.978249093223084\n",
      "EPOCH: 22830 LOSS: 40.978247516629764\n",
      "EPOCH: 22831 LOSS: 40.97824594014943\n",
      "EPOCH: 22832 LOSS: 40.97824436378205\n",
      "EPOCH: 22833 LOSS: 40.97824278752764\n",
      "EPOCH: 22834 LOSS: 40.97824121138618\n",
      "EPOCH: 22835 LOSS: 40.97823963535763\n",
      "EPOCH: 22836 LOSS: 40.97823805944199\n",
      "EPOCH: 22837 LOSS: 40.978236483639236\n",
      "EPOCH: 22838 LOSS: 40.97823490794937\n",
      "EPOCH: 22839 LOSS: 40.97823333237236\n",
      "EPOCH: 22840 LOSS: 40.97823175690823\n",
      "EPOCH: 22841 LOSS: 40.978230181556924\n",
      "EPOCH: 22842 LOSS: 40.97822860631843\n",
      "EPOCH: 22843 LOSS: 40.97822703119276\n",
      "EPOCH: 22844 LOSS: 40.97822545617987\n",
      "EPOCH: 22845 LOSS: 40.97822388127976\n",
      "EPOCH: 22846 LOSS: 40.97822230649239\n",
      "EPOCH: 22847 LOSS: 40.978220731817814\n",
      "EPOCH: 22848 LOSS: 40.978219157255936\n",
      "EPOCH: 22849 LOSS: 40.97821758280681\n",
      "EPOCH: 22850 LOSS: 40.97821600847037\n",
      "EPOCH: 22851 LOSS: 40.97821443424661\n",
      "EPOCH: 22852 LOSS: 40.97821286013553\n",
      "EPOCH: 22853 LOSS: 40.978211286137125\n",
      "EPOCH: 22854 LOSS: 40.97820971225134\n",
      "EPOCH: 22855 LOSS: 40.97820813847821\n",
      "EPOCH: 22856 LOSS: 40.9782065648177\n",
      "EPOCH: 22857 LOSS: 40.97820499126976\n",
      "EPOCH: 22858 LOSS: 40.978203417834436\n",
      "EPOCH: 22859 LOSS: 40.97820184451168\n",
      "EPOCH: 22860 LOSS: 40.978200271301475\n",
      "EPOCH: 22861 LOSS: 40.97819869820382\n",
      "EPOCH: 22862 LOSS: 40.97819712521868\n",
      "EPOCH: 22863 LOSS: 40.97819555234607\n",
      "EPOCH: 22864 LOSS: 40.97819397958594\n",
      "EPOCH: 22865 LOSS: 40.97819240693831\n",
      "EPOCH: 22866 LOSS: 40.97819083440315\n",
      "EPOCH: 22867 LOSS: 40.97818926198045\n",
      "EPOCH: 22868 LOSS: 40.97818768967018\n",
      "EPOCH: 22869 LOSS: 40.97818611747235\n",
      "EPOCH: 22870 LOSS: 40.978184545386895\n",
      "EPOCH: 22871 LOSS: 40.97818297341387\n",
      "EPOCH: 22872 LOSS: 40.978181401553215\n",
      "EPOCH: 22873 LOSS: 40.97817982980493\n",
      "EPOCH: 22874 LOSS: 40.978178258168995\n",
      "EPOCH: 22875 LOSS: 40.9781766866454\n",
      "EPOCH: 22876 LOSS: 40.97817511523414\n",
      "EPOCH: 22877 LOSS: 40.97817354393518\n",
      "EPOCH: 22878 LOSS: 40.978171972748505\n",
      "EPOCH: 22879 LOSS: 40.97817040167411\n",
      "EPOCH: 22880 LOSS: 40.978168830711994\n",
      "EPOCH: 22881 LOSS: 40.97816725986212\n",
      "EPOCH: 22882 LOSS: 40.978165689124495\n",
      "EPOCH: 22883 LOSS: 40.978164118499066\n",
      "EPOCH: 22884 LOSS: 40.97816254798586\n",
      "EPOCH: 22885 LOSS: 40.97816097758484\n",
      "EPOCH: 22886 LOSS: 40.978159407296005\n",
      "EPOCH: 22887 LOSS: 40.978157837119326\n",
      "EPOCH: 22888 LOSS: 40.978156267054814\n",
      "EPOCH: 22889 LOSS: 40.97815469710241\n",
      "EPOCH: 22890 LOSS: 40.97815312726214\n",
      "EPOCH: 22891 LOSS: 40.97815155753396\n",
      "EPOCH: 22892 LOSS: 40.978149987917874\n",
      "EPOCH: 22893 LOSS: 40.97814841841389\n",
      "EPOCH: 22894 LOSS: 40.97814684902194\n",
      "EPOCH: 22895 LOSS: 40.97814527974205\n",
      "EPOCH: 22896 LOSS: 40.97814371057417\n",
      "EPOCH: 22897 LOSS: 40.97814214151833\n",
      "EPOCH: 22898 LOSS: 40.97814057257448\n",
      "EPOCH: 22899 LOSS: 40.978139003742626\n",
      "EPOCH: 22900 LOSS: 40.97813743502273\n",
      "EPOCH: 22901 LOSS: 40.97813586641481\n",
      "EPOCH: 22902 LOSS: 40.97813429791883\n",
      "EPOCH: 22903 LOSS: 40.97813272953478\n",
      "EPOCH: 22904 LOSS: 40.97813116126265\n",
      "EPOCH: 22905 LOSS: 40.978129593102416\n",
      "EPOCH: 22906 LOSS: 40.97812802505405\n",
      "EPOCH: 22907 LOSS: 40.97812645711757\n",
      "EPOCH: 22908 LOSS: 40.97812488929296\n",
      "EPOCH: 22909 LOSS: 40.97812332158017\n",
      "EPOCH: 22910 LOSS: 40.978121753979224\n",
      "EPOCH: 22911 LOSS: 40.97812018649008\n",
      "EPOCH: 22912 LOSS: 40.978118619112735\n",
      "EPOCH: 22913 LOSS: 40.978117051847185\n",
      "EPOCH: 22914 LOSS: 40.978115484693404\n",
      "EPOCH: 22915 LOSS: 40.978113917651385\n",
      "EPOCH: 22916 LOSS: 40.97811235072109\n",
      "EPOCH: 22917 LOSS: 40.97811078390252\n",
      "EPOCH: 22918 LOSS: 40.97810921719569\n",
      "EPOCH: 22919 LOSS: 40.978107650600535\n",
      "EPOCH: 22920 LOSS: 40.978106084117044\n",
      "EPOCH: 22921 LOSS: 40.978104517745244\n",
      "EPOCH: 22922 LOSS: 40.9781029514851\n",
      "EPOCH: 22923 LOSS: 40.97810138533659\n",
      "EPOCH: 22924 LOSS: 40.97809981929971\n",
      "EPOCH: 22925 LOSS: 40.97809825337444\n",
      "EPOCH: 22926 LOSS: 40.97809668756076\n",
      "EPOCH: 22927 LOSS: 40.97809512185865\n",
      "EPOCH: 22928 LOSS: 40.97809355626812\n",
      "EPOCH: 22929 LOSS: 40.97809199078914\n",
      "EPOCH: 22930 LOSS: 40.978090425421705\n",
      "EPOCH: 22931 LOSS: 40.978088860165784\n",
      "EPOCH: 22932 LOSS: 40.97808729502138\n",
      "EPOCH: 22933 LOSS: 40.978085729988464\n",
      "EPOCH: 22934 LOSS: 40.978084165067024\n",
      "EPOCH: 22935 LOSS: 40.97808260025707\n",
      "EPOCH: 22936 LOSS: 40.978081035558546\n",
      "EPOCH: 22937 LOSS: 40.97807947097147\n",
      "EPOCH: 22938 LOSS: 40.97807790649581\n",
      "EPOCH: 22939 LOSS: 40.97807634213156\n",
      "EPOCH: 22940 LOSS: 40.978074777878696\n",
      "EPOCH: 22941 LOSS: 40.978073213737204\n",
      "EPOCH: 22942 LOSS: 40.978071649707104\n",
      "EPOCH: 22943 LOSS: 40.97807008578833\n",
      "EPOCH: 22944 LOSS: 40.9780685219809\n",
      "EPOCH: 22945 LOSS: 40.97806695828478\n",
      "EPOCH: 22946 LOSS: 40.97806539469998\n",
      "EPOCH: 22947 LOSS: 40.97806383122647\n",
      "EPOCH: 22948 LOSS: 40.97806226786422\n",
      "EPOCH: 22949 LOSS: 40.978060704613256\n",
      "EPOCH: 22950 LOSS: 40.97805914147354\n",
      "EPOCH: 22951 LOSS: 40.97805757844504\n",
      "EPOCH: 22952 LOSS: 40.97805601552777\n",
      "EPOCH: 22953 LOSS: 40.978054452721715\n",
      "EPOCH: 22954 LOSS: 40.97805289002683\n",
      "EPOCH: 22955 LOSS: 40.97805132744313\n",
      "EPOCH: 22956 LOSS: 40.9780497649706\n",
      "EPOCH: 22957 LOSS: 40.978048202609216\n",
      "EPOCH: 22958 LOSS: 40.978046640358954\n",
      "EPOCH: 22959 LOSS: 40.978045078219814\n",
      "EPOCH: 22960 LOSS: 40.97804351619179\n",
      "EPOCH: 22961 LOSS: 40.97804195427484\n",
      "EPOCH: 22962 LOSS: 40.97804039246898\n",
      "EPOCH: 22963 LOSS: 40.978038830774175\n",
      "EPOCH: 22964 LOSS: 40.97803726919041\n",
      "EPOCH: 22965 LOSS: 40.97803570771768\n",
      "EPOCH: 22966 LOSS: 40.978034146355974\n",
      "EPOCH: 22967 LOSS: 40.978032585105275\n",
      "EPOCH: 22968 LOSS: 40.978031023965556\n",
      "EPOCH: 22969 LOSS: 40.97802946293682\n",
      "EPOCH: 22970 LOSS: 40.978027902019036\n",
      "EPOCH: 22971 LOSS: 40.97802634121221\n",
      "EPOCH: 22972 LOSS: 40.97802478051629\n",
      "EPOCH: 22973 LOSS: 40.9780232199313\n",
      "EPOCH: 22974 LOSS: 40.97802165945722\n",
      "EPOCH: 22975 LOSS: 40.978020099094024\n",
      "EPOCH: 22976 LOSS: 40.9780185388417\n",
      "EPOCH: 22977 LOSS: 40.97801697870024\n",
      "EPOCH: 22978 LOSS: 40.97801541866963\n",
      "EPOCH: 22979 LOSS: 40.97801385874983\n",
      "EPOCH: 22980 LOSS: 40.97801229894087\n",
      "EPOCH: 22981 LOSS: 40.97801073924271\n",
      "EPOCH: 22982 LOSS: 40.97800917965533\n",
      "EPOCH: 22983 LOSS: 40.97800762017872\n",
      "EPOCH: 22984 LOSS: 40.97800606081287\n",
      "EPOCH: 22985 LOSS: 40.978004501557784\n",
      "EPOCH: 22986 LOSS: 40.978002942413404\n",
      "EPOCH: 22987 LOSS: 40.978001383379755\n",
      "EPOCH: 22988 LOSS: 40.9779998244568\n",
      "EPOCH: 22989 LOSS: 40.97799826564453\n",
      "EPOCH: 22990 LOSS: 40.97799670694294\n",
      "EPOCH: 22991 LOSS: 40.977995148351994\n",
      "EPOCH: 22992 LOSS: 40.97799358987171\n",
      "EPOCH: 22993 LOSS: 40.977992031502055\n",
      "EPOCH: 22994 LOSS: 40.97799047324301\n",
      "EPOCH: 22995 LOSS: 40.977988915094556\n",
      "EPOCH: 22996 LOSS: 40.97798735705671\n",
      "EPOCH: 22997 LOSS: 40.97798579912943\n",
      "EPOCH: 22998 LOSS: 40.9779842413127\n",
      "EPOCH: 22999 LOSS: 40.97798268360652\n",
      "EPOCH: 23000 LOSS: 40.977981126010874\n",
      "EPOCH: 23001 LOSS: 40.97797956852574\n",
      "EPOCH: 23002 LOSS: 40.97797801115111\n",
      "EPOCH: 23003 LOSS: 40.97797645388696\n",
      "EPOCH: 23004 LOSS: 40.977974896733286\n",
      "EPOCH: 23005 LOSS: 40.97797333969007\n",
      "EPOCH: 23006 LOSS: 40.97797178275731\n",
      "EPOCH: 23007 LOSS: 40.97797022593496\n",
      "EPOCH: 23008 LOSS: 40.977968669223024\n",
      "EPOCH: 23009 LOSS: 40.97796711262151\n",
      "EPOCH: 23010 LOSS: 40.97796555613037\n",
      "EPOCH: 23011 LOSS: 40.97796399974961\n",
      "EPOCH: 23012 LOSS: 40.9779624434792\n",
      "EPOCH: 23013 LOSS: 40.97796088731913\n",
      "EPOCH: 23014 LOSS: 40.97795933126939\n",
      "EPOCH: 23015 LOSS: 40.97795777532997\n",
      "EPOCH: 23016 LOSS: 40.97795621950087\n",
      "EPOCH: 23017 LOSS: 40.97795466378204\n",
      "EPOCH: 23018 LOSS: 40.977953108173466\n",
      "EPOCH: 23019 LOSS: 40.97795155267518\n",
      "EPOCH: 23020 LOSS: 40.977949997287126\n",
      "EPOCH: 23021 LOSS: 40.977948442009286\n",
      "EPOCH: 23022 LOSS: 40.97794688684168\n",
      "EPOCH: 23023 LOSS: 40.97794533178427\n",
      "EPOCH: 23024 LOSS: 40.97794377683705\n",
      "EPOCH: 23025 LOSS: 40.977942222\n",
      "EPOCH: 23026 LOSS: 40.97794066727311\n",
      "EPOCH: 23027 LOSS: 40.97793911265637\n",
      "EPOCH: 23028 LOSS: 40.977937558149755\n",
      "EPOCH: 23029 LOSS: 40.97793600375325\n",
      "EPOCH: 23030 LOSS: 40.977934449466844\n",
      "EPOCH: 23031 LOSS: 40.97793289529052\n",
      "EPOCH: 23032 LOSS: 40.97793134122429\n",
      "EPOCH: 23033 LOSS: 40.97792978726812\n",
      "EPOCH: 23034 LOSS: 40.97792823342198\n",
      "EPOCH: 23035 LOSS: 40.977926679685865\n",
      "EPOCH: 23036 LOSS: 40.97792512605977\n",
      "EPOCH: 23037 LOSS: 40.97792357254368\n",
      "EPOCH: 23038 LOSS: 40.977922019137594\n",
      "EPOCH: 23039 LOSS: 40.97792046584148\n",
      "EPOCH: 23040 LOSS: 40.977918912655305\n",
      "EPOCH: 23041 LOSS: 40.97791735957909\n",
      "EPOCH: 23042 LOSS: 40.97791580661279\n",
      "EPOCH: 23043 LOSS: 40.97791425375642\n",
      "EPOCH: 23044 LOSS: 40.97791270100994\n",
      "EPOCH: 23045 LOSS: 40.97791114837335\n",
      "EPOCH: 23046 LOSS: 40.97790959584665\n",
      "EPOCH: 23047 LOSS: 40.97790804342979\n",
      "EPOCH: 23048 LOSS: 40.977906491122795\n",
      "EPOCH: 23049 LOSS: 40.977904938925604\n",
      "EPOCH: 23050 LOSS: 40.977903386838264\n",
      "EPOCH: 23051 LOSS: 40.9779018348607\n",
      "EPOCH: 23052 LOSS: 40.977900282992934\n",
      "EPOCH: 23053 LOSS: 40.97789873123495\n",
      "EPOCH: 23054 LOSS: 40.97789717958671\n",
      "EPOCH: 23055 LOSS: 40.97789562804824\n",
      "EPOCH: 23056 LOSS: 40.97789407661948\n",
      "EPOCH: 23057 LOSS: 40.97789252530045\n",
      "EPOCH: 23058 LOSS: 40.977890974091125\n",
      "EPOCH: 23059 LOSS: 40.97788942299148\n",
      "EPOCH: 23060 LOSS: 40.97788787200151\n",
      "EPOCH: 23061 LOSS: 40.977886321121204\n",
      "EPOCH: 23062 LOSS: 40.97788477035055\n",
      "EPOCH: 23063 LOSS: 40.97788321968953\n",
      "EPOCH: 23064 LOSS: 40.977881669138135\n",
      "EPOCH: 23065 LOSS: 40.97788011869633\n",
      "EPOCH: 23066 LOSS: 40.97787856836412\n",
      "EPOCH: 23067 LOSS: 40.977877018141484\n",
      "EPOCH: 23068 LOSS: 40.97787546802842\n",
      "EPOCH: 23069 LOSS: 40.9778739180249\n",
      "EPOCH: 23070 LOSS: 40.97787236813091\n",
      "EPOCH: 23071 LOSS: 40.977870818346425\n",
      "EPOCH: 23072 LOSS: 40.977869268671455\n",
      "EPOCH: 23073 LOSS: 40.97786771910599\n",
      "EPOCH: 23074 LOSS: 40.977866169649985\n",
      "EPOCH: 23075 LOSS: 40.977864620303464\n",
      "EPOCH: 23076 LOSS: 40.97786307106638\n",
      "EPOCH: 23077 LOSS: 40.977861521938735\n",
      "EPOCH: 23078 LOSS: 40.97785997292051\n",
      "EPOCH: 23079 LOSS: 40.97785842401167\n",
      "EPOCH: 23080 LOSS: 40.977856875212254\n",
      "EPOCH: 23081 LOSS: 40.97785532652219\n",
      "EPOCH: 23082 LOSS: 40.977853777941526\n",
      "EPOCH: 23083 LOSS: 40.97785222947017\n",
      "EPOCH: 23084 LOSS: 40.97785068110818\n",
      "EPOCH: 23085 LOSS: 40.977849132855496\n",
      "EPOCH: 23086 LOSS: 40.97784758471212\n",
      "EPOCH: 23087 LOSS: 40.977846036678045\n",
      "EPOCH: 23088 LOSS: 40.97784448875325\n",
      "EPOCH: 23089 LOSS: 40.97784294093772\n",
      "EPOCH: 23090 LOSS: 40.977841393231444\n",
      "EPOCH: 23091 LOSS: 40.97783984563439\n",
      "EPOCH: 23092 LOSS: 40.97783829814658\n",
      "EPOCH: 23093 LOSS: 40.97783675076797\n",
      "EPOCH: 23094 LOSS: 40.97783520349855\n",
      "EPOCH: 23095 LOSS: 40.97783365633831\n",
      "EPOCH: 23096 LOSS: 40.97783210928724\n",
      "EPOCH: 23097 LOSS: 40.97783056234533\n",
      "EPOCH: 23098 LOSS: 40.97782901551254\n",
      "EPOCH: 23099 LOSS: 40.977827468788895\n",
      "EPOCH: 23100 LOSS: 40.977825922174354\n",
      "EPOCH: 23101 LOSS: 40.977824375668916\n",
      "EPOCH: 23102 LOSS: 40.977822829272554\n",
      "EPOCH: 23103 LOSS: 40.977821282985246\n",
      "EPOCH: 23104 LOSS: 40.97781973680702\n",
      "EPOCH: 23105 LOSS: 40.97781819073782\n",
      "EPOCH: 23106 LOSS: 40.97781664477765\n",
      "EPOCH: 23107 LOSS: 40.9778150989265\n",
      "EPOCH: 23108 LOSS: 40.977813553184326\n",
      "EPOCH: 23109 LOSS: 40.977812007551144\n",
      "EPOCH: 23110 LOSS: 40.97781046202692\n",
      "EPOCH: 23111 LOSS: 40.97780891661169\n",
      "EPOCH: 23112 LOSS: 40.97780737130539\n",
      "EPOCH: 23113 LOSS: 40.977805826108\n",
      "EPOCH: 23114 LOSS: 40.977804281019516\n",
      "EPOCH: 23115 LOSS: 40.97780273603994\n",
      "EPOCH: 23116 LOSS: 40.97780119116926\n",
      "EPOCH: 23117 LOSS: 40.97779964640746\n",
      "EPOCH: 23118 LOSS: 40.9777981017545\n",
      "EPOCH: 23119 LOSS: 40.97779655721038\n",
      "EPOCH: 23120 LOSS: 40.97779501277512\n",
      "EPOCH: 23121 LOSS: 40.97779346844865\n",
      "EPOCH: 23122 LOSS: 40.97779192423097\n",
      "EPOCH: 23123 LOSS: 40.977790380122094\n",
      "EPOCH: 23124 LOSS: 40.977788836122\n",
      "EPOCH: 23125 LOSS: 40.97778729223065\n",
      "EPOCH: 23126 LOSS: 40.97778574844804\n",
      "EPOCH: 23127 LOSS: 40.97778420477419\n",
      "EPOCH: 23128 LOSS: 40.977782661209034\n",
      "EPOCH: 23129 LOSS: 40.9777811177526\n",
      "EPOCH: 23130 LOSS: 40.97777957440484\n",
      "EPOCH: 23131 LOSS: 40.97777803116576\n",
      "EPOCH: 23132 LOSS: 40.97777648803534\n",
      "EPOCH: 23133 LOSS: 40.97777494501355\n",
      "EPOCH: 23134 LOSS: 40.97777340210042\n",
      "EPOCH: 23135 LOSS: 40.97777185929591\n",
      "EPOCH: 23136 LOSS: 40.977770316599994\n",
      "EPOCH: 23137 LOSS: 40.97776877401267\n",
      "EPOCH: 23138 LOSS: 40.97776723153393\n",
      "EPOCH: 23139 LOSS: 40.97776568916374\n",
      "EPOCH: 23140 LOSS: 40.97776414690211\n",
      "EPOCH: 23141 LOSS: 40.97776260474902\n",
      "EPOCH: 23142 LOSS: 40.977761062704445\n",
      "EPOCH: 23143 LOSS: 40.97775952076838\n",
      "EPOCH: 23144 LOSS: 40.977757978940794\n",
      "EPOCH: 23145 LOSS: 40.97775643722171\n",
      "EPOCH: 23146 LOSS: 40.977754895611085\n",
      "EPOCH: 23147 LOSS: 40.977753354108906\n",
      "EPOCH: 23148 LOSS: 40.97775181271517\n",
      "EPOCH: 23149 LOSS: 40.977750271429855\n",
      "EPOCH: 23150 LOSS: 40.977748730252955\n",
      "EPOCH: 23151 LOSS: 40.977747189184456\n",
      "EPOCH: 23152 LOSS: 40.97774564822433\n",
      "EPOCH: 23153 LOSS: 40.977744107372565\n",
      "EPOCH: 23154 LOSS: 40.97774256662916\n",
      "EPOCH: 23155 LOSS: 40.97774102599409\n",
      "EPOCH: 23156 LOSS: 40.97773948546737\n",
      "EPOCH: 23157 LOSS: 40.977737945048936\n",
      "EPOCH: 23158 LOSS: 40.977736404738806\n",
      "EPOCH: 23159 LOSS: 40.977734864536956\n",
      "EPOCH: 23160 LOSS: 40.97773332444339\n",
      "EPOCH: 23161 LOSS: 40.97773178445807\n",
      "EPOCH: 23162 LOSS: 40.977730244581\n",
      "EPOCH: 23163 LOSS: 40.977728704812165\n",
      "EPOCH: 23164 LOSS: 40.97772716515152\n",
      "EPOCH: 23165 LOSS: 40.9777256255991\n",
      "EPOCH: 23166 LOSS: 40.977724086154865\n",
      "EPOCH: 23167 LOSS: 40.977722546818796\n",
      "EPOCH: 23168 LOSS: 40.97772100759089\n",
      "EPOCH: 23169 LOSS: 40.97771946847113\n",
      "EPOCH: 23170 LOSS: 40.97771792945949\n",
      "EPOCH: 23171 LOSS: 40.97771639055598\n",
      "EPOCH: 23172 LOSS: 40.97771485176056\n",
      "EPOCH: 23173 LOSS: 40.97771331307325\n",
      "EPOCH: 23174 LOSS: 40.97771177449399\n",
      "EPOCH: 23175 LOSS: 40.9777102360228\n",
      "EPOCH: 23176 LOSS: 40.97770869765968\n",
      "EPOCH: 23177 LOSS: 40.97770715940456\n",
      "EPOCH: 23178 LOSS: 40.977705621257506\n",
      "EPOCH: 23179 LOSS: 40.97770408321842\n",
      "EPOCH: 23180 LOSS: 40.97770254528733\n",
      "EPOCH: 23181 LOSS: 40.97770100746424\n",
      "EPOCH: 23182 LOSS: 40.97769946974908\n",
      "EPOCH: 23183 LOSS: 40.97769793214189\n",
      "EPOCH: 23184 LOSS: 40.97769639464265\n",
      "EPOCH: 23185 LOSS: 40.97769485725133\n",
      "EPOCH: 23186 LOSS: 40.9776933199679\n",
      "EPOCH: 23187 LOSS: 40.97769178279237\n",
      "EPOCH: 23188 LOSS: 40.97769024572473\n",
      "EPOCH: 23189 LOSS: 40.97768870876496\n",
      "EPOCH: 23190 LOSS: 40.97768717191303\n",
      "EPOCH: 23191 LOSS: 40.97768563516895\n",
      "EPOCH: 23192 LOSS: 40.977684098532684\n",
      "EPOCH: 23193 LOSS: 40.97768256200425\n",
      "EPOCH: 23194 LOSS: 40.97768102558359\n",
      "EPOCH: 23195 LOSS: 40.977679489270734\n",
      "EPOCH: 23196 LOSS: 40.97767795306565\n",
      "EPOCH: 23197 LOSS: 40.97767641696831\n",
      "EPOCH: 23198 LOSS: 40.97767488097872\n",
      "EPOCH: 23199 LOSS: 40.977673345096846\n",
      "EPOCH: 23200 LOSS: 40.977671809322715\n",
      "EPOCH: 23201 LOSS: 40.97767027365626\n",
      "EPOCH: 23202 LOSS: 40.977668738097506\n",
      "EPOCH: 23203 LOSS: 40.977667202646415\n",
      "EPOCH: 23204 LOSS: 40.97766566730299\n",
      "EPOCH: 23205 LOSS: 40.977664132067225\n",
      "EPOCH: 23206 LOSS: 40.97766259693906\n",
      "EPOCH: 23207 LOSS: 40.97766106191854\n",
      "EPOCH: 23208 LOSS: 40.97765952700561\n",
      "EPOCH: 23209 LOSS: 40.97765799220029\n",
      "EPOCH: 23210 LOSS: 40.977656457502526\n",
      "EPOCH: 23211 LOSS: 40.97765492291233\n",
      "EPOCH: 23212 LOSS: 40.977653388429694\n",
      "EPOCH: 23213 LOSS: 40.97765185405458\n",
      "EPOCH: 23214 LOSS: 40.977650319787\n",
      "EPOCH: 23215 LOSS: 40.97764878562691\n",
      "EPOCH: 23216 LOSS: 40.97764725157433\n",
      "EPOCH: 23217 LOSS: 40.97764571762923\n",
      "EPOCH: 23218 LOSS: 40.9776441837916\n",
      "EPOCH: 23219 LOSS: 40.97764265006141\n",
      "EPOCH: 23220 LOSS: 40.97764111643866\n",
      "EPOCH: 23221 LOSS: 40.97763958292334\n",
      "EPOCH: 23222 LOSS: 40.977638049515434\n",
      "EPOCH: 23223 LOSS: 40.977636516214915\n",
      "EPOCH: 23224 LOSS: 40.9776349830218\n",
      "EPOCH: 23225 LOSS: 40.977633449936036\n",
      "EPOCH: 23226 LOSS: 40.97763191695765\n",
      "EPOCH: 23227 LOSS: 40.97763038408658\n",
      "EPOCH: 23228 LOSS: 40.97762885132285\n",
      "EPOCH: 23229 LOSS: 40.97762731866644\n",
      "EPOCH: 23230 LOSS: 40.97762578611732\n",
      "EPOCH: 23231 LOSS: 40.97762425367549\n",
      "EPOCH: 23232 LOSS: 40.97762272134094\n",
      "EPOCH: 23233 LOSS: 40.97762118911365\n",
      "EPOCH: 23234 LOSS: 40.977619656993596\n",
      "EPOCH: 23235 LOSS: 40.97761812498079\n",
      "EPOCH: 23236 LOSS: 40.9776165930752\n",
      "EPOCH: 23237 LOSS: 40.97761506127679\n",
      "EPOCH: 23238 LOSS: 40.97761352958561\n",
      "EPOCH: 23239 LOSS: 40.97761199800157\n",
      "EPOCH: 23240 LOSS: 40.97761046652473\n",
      "EPOCH: 23241 LOSS: 40.97760893515502\n",
      "EPOCH: 23242 LOSS: 40.977607403892435\n",
      "EPOCH: 23243 LOSS: 40.97760587273697\n",
      "EPOCH: 23244 LOSS: 40.97760434168865\n",
      "EPOCH: 23245 LOSS: 40.9776028107474\n",
      "EPOCH: 23246 LOSS: 40.977601279913245\n",
      "EPOCH: 23247 LOSS: 40.977599749186126\n",
      "EPOCH: 23248 LOSS: 40.97759821856609\n",
      "EPOCH: 23249 LOSS: 40.97759668805309\n",
      "EPOCH: 23250 LOSS: 40.977595157647116\n",
      "EPOCH: 23251 LOSS: 40.97759362734814\n",
      "EPOCH: 23252 LOSS: 40.97759209715617\n",
      "EPOCH: 23253 LOSS: 40.97759056707118\n",
      "EPOCH: 23254 LOSS: 40.977589037093196\n",
      "EPOCH: 23255 LOSS: 40.97758750722214\n",
      "EPOCH: 23256 LOSS: 40.97758597745803\n",
      "EPOCH: 23257 LOSS: 40.97758444780085\n",
      "EPOCH: 23258 LOSS: 40.977582918250604\n",
      "EPOCH: 23259 LOSS: 40.97758138880724\n",
      "EPOCH: 23260 LOSS: 40.977579859470765\n",
      "EPOCH: 23261 LOSS: 40.97757833024118\n",
      "EPOCH: 23262 LOSS: 40.977576801118445\n",
      "EPOCH: 23263 LOSS: 40.97757527210257\n",
      "EPOCH: 23264 LOSS: 40.97757374319351\n",
      "EPOCH: 23265 LOSS: 40.97757221439129\n",
      "EPOCH: 23266 LOSS: 40.977570685695866\n",
      "EPOCH: 23267 LOSS: 40.97756915710724\n",
      "EPOCH: 23268 LOSS: 40.977567628625394\n",
      "EPOCH: 23269 LOSS: 40.977566100250314\n",
      "EPOCH: 23270 LOSS: 40.977564571981986\n",
      "EPOCH: 23271 LOSS: 40.977563043820396\n",
      "EPOCH: 23272 LOSS: 40.97756151576554\n",
      "EPOCH: 23273 LOSS: 40.97755998781737\n",
      "EPOCH: 23274 LOSS: 40.97755845997592\n",
      "EPOCH: 23275 LOSS: 40.97755693224115\n",
      "EPOCH: 23276 LOSS: 40.97755540461304\n",
      "EPOCH: 23277 LOSS: 40.97755387709161\n",
      "EPOCH: 23278 LOSS: 40.9775523496768\n",
      "EPOCH: 23279 LOSS: 40.97755082236863\n",
      "EPOCH: 23280 LOSS: 40.97754929516708\n",
      "EPOCH: 23281 LOSS: 40.97754776807212\n",
      "EPOCH: 23282 LOSS: 40.97754624108376\n",
      "EPOCH: 23283 LOSS: 40.97754471420197\n",
      "EPOCH: 23284 LOSS: 40.97754318742674\n",
      "EPOCH: 23285 LOSS: 40.977541660758064\n",
      "EPOCH: 23286 LOSS: 40.97754013419592\n",
      "EPOCH: 23287 LOSS: 40.97753860774027\n",
      "EPOCH: 23288 LOSS: 40.97753708139117\n",
      "EPOCH: 23289 LOSS: 40.97753555514854\n",
      "EPOCH: 23290 LOSS: 40.97753402901239\n",
      "EPOCH: 23291 LOSS: 40.97753250298271\n",
      "EPOCH: 23292 LOSS: 40.97753097705948\n",
      "EPOCH: 23293 LOSS: 40.97752945124269\n",
      "EPOCH: 23294 LOSS: 40.97752792553233\n",
      "EPOCH: 23295 LOSS: 40.97752639992837\n",
      "EPOCH: 23296 LOSS: 40.97752487443081\n",
      "EPOCH: 23297 LOSS: 40.97752334903964\n",
      "EPOCH: 23298 LOSS: 40.977521823754834\n",
      "EPOCH: 23299 LOSS: 40.97752029857638\n",
      "EPOCH: 23300 LOSS: 40.97751877350428\n",
      "EPOCH: 23301 LOSS: 40.97751724853852\n",
      "EPOCH: 23302 LOSS: 40.97751572367905\n",
      "EPOCH: 23303 LOSS: 40.9775141989259\n",
      "EPOCH: 23304 LOSS: 40.97751267427905\n",
      "EPOCH: 23305 LOSS: 40.977511149738454\n",
      "EPOCH: 23306 LOSS: 40.97750962530412\n",
      "EPOCH: 23307 LOSS: 40.977508100976046\n",
      "EPOCH: 23308 LOSS: 40.977506576754195\n",
      "EPOCH: 23309 LOSS: 40.97750505263857\n",
      "EPOCH: 23310 LOSS: 40.97750352862915\n",
      "EPOCH: 23311 LOSS: 40.97750200472594\n",
      "EPOCH: 23312 LOSS: 40.977500480928896\n",
      "EPOCH: 23313 LOSS: 40.977498957238005\n",
      "EPOCH: 23314 LOSS: 40.977497433653284\n",
      "EPOCH: 23315 LOSS: 40.97749591017471\n",
      "EPOCH: 23316 LOSS: 40.97749438680225\n",
      "EPOCH: 23317 LOSS: 40.977492863535915\n",
      "EPOCH: 23318 LOSS: 40.977491340375664\n",
      "EPOCH: 23319 LOSS: 40.97748981732149\n",
      "EPOCH: 23320 LOSS: 40.9774882943734\n",
      "EPOCH: 23321 LOSS: 40.977486771531375\n",
      "EPOCH: 23322 LOSS: 40.977485248795375\n",
      "EPOCH: 23323 LOSS: 40.97748372616543\n",
      "EPOCH: 23324 LOSS: 40.977482203641486\n",
      "EPOCH: 23325 LOSS: 40.977480681223554\n",
      "EPOCH: 23326 LOSS: 40.977479158911606\n",
      "EPOCH: 23327 LOSS: 40.97747763670564\n",
      "EPOCH: 23328 LOSS: 40.977476114605636\n",
      "EPOCH: 23329 LOSS: 40.977474592611586\n",
      "EPOCH: 23330 LOSS: 40.97747307072346\n",
      "EPOCH: 23331 LOSS: 40.97747154894128\n",
      "EPOCH: 23332 LOSS: 40.977470027264985\n",
      "EPOCH: 23333 LOSS: 40.9774685056946\n",
      "EPOCH: 23334 LOSS: 40.97746698423009\n",
      "EPOCH: 23335 LOSS: 40.977465462871436\n",
      "EPOCH: 23336 LOSS: 40.977463941618666\n",
      "EPOCH: 23337 LOSS: 40.97746242047171\n",
      "EPOCH: 23338 LOSS: 40.97746089943059\n",
      "EPOCH: 23339 LOSS: 40.977459378495304\n",
      "EPOCH: 23340 LOSS: 40.977457857665804\n",
      "EPOCH: 23341 LOSS: 40.97745633694208\n",
      "EPOCH: 23342 LOSS: 40.97745481632415\n",
      "EPOCH: 23343 LOSS: 40.977453295811955\n",
      "EPOCH: 23344 LOSS: 40.97745177540554\n",
      "EPOCH: 23345 LOSS: 40.97745025510484\n",
      "EPOCH: 23346 LOSS: 40.97744873490986\n",
      "EPOCH: 23347 LOSS: 40.9774472148206\n",
      "EPOCH: 23348 LOSS: 40.97744569483702\n",
      "EPOCH: 23349 LOSS: 40.97744417495912\n",
      "EPOCH: 23350 LOSS: 40.97744265518688\n",
      "EPOCH: 23351 LOSS: 40.9774411355203\n",
      "EPOCH: 23352 LOSS: 40.97743961595937\n",
      "EPOCH: 23353 LOSS: 40.97743809650406\n",
      "EPOCH: 23354 LOSS: 40.97743657715434\n",
      "EPOCH: 23355 LOSS: 40.97743505791024\n",
      "EPOCH: 23356 LOSS: 40.97743353877172\n",
      "EPOCH: 23357 LOSS: 40.97743201973877\n",
      "EPOCH: 23358 LOSS: 40.97743050081139\n",
      "EPOCH: 23359 LOSS: 40.97742898198953\n",
      "EPOCH: 23360 LOSS: 40.97742746327323\n",
      "EPOCH: 23361 LOSS: 40.97742594466243\n",
      "EPOCH: 23362 LOSS: 40.97742442615713\n",
      "EPOCH: 23363 LOSS: 40.97742290775734\n",
      "EPOCH: 23364 LOSS: 40.97742138946302\n",
      "EPOCH: 23365 LOSS: 40.97741987127415\n",
      "EPOCH: 23366 LOSS: 40.97741835319075\n",
      "EPOCH: 23367 LOSS: 40.97741683521277\n",
      "EPOCH: 23368 LOSS: 40.977415317340224\n",
      "EPOCH: 23369 LOSS: 40.97741379957307\n",
      "EPOCH: 23370 LOSS: 40.97741228191134\n",
      "EPOCH: 23371 LOSS: 40.977410764354985\n",
      "EPOCH: 23372 LOSS: 40.977409246903996\n",
      "EPOCH: 23373 LOSS: 40.97740772955835\n",
      "EPOCH: 23374 LOSS: 40.97740621231807\n",
      "EPOCH: 23375 LOSS: 40.977404695183125\n",
      "EPOCH: 23376 LOSS: 40.977403178153466\n",
      "EPOCH: 23377 LOSS: 40.97740166122912\n",
      "EPOCH: 23378 LOSS: 40.97740014441007\n",
      "EPOCH: 23379 LOSS: 40.9773986276963\n",
      "EPOCH: 23380 LOSS: 40.977397111087775\n",
      "EPOCH: 23381 LOSS: 40.97739559458451\n",
      "EPOCH: 23382 LOSS: 40.97739407818648\n",
      "EPOCH: 23383 LOSS: 40.977392561893666\n",
      "EPOCH: 23384 LOSS: 40.97739104570608\n",
      "EPOCH: 23385 LOSS: 40.977389529623665\n",
      "EPOCH: 23386 LOSS: 40.97738801364646\n",
      "EPOCH: 23387 LOSS: 40.9773864977744\n",
      "EPOCH: 23388 LOSS: 40.97738498200749\n",
      "EPOCH: 23389 LOSS: 40.97738346634574\n",
      "EPOCH: 23390 LOSS: 40.977381950789116\n",
      "EPOCH: 23391 LOSS: 40.97738043533761\n",
      "EPOCH: 23392 LOSS: 40.977378919991196\n",
      "EPOCH: 23393 LOSS: 40.97737740474986\n",
      "EPOCH: 23394 LOSS: 40.97737588961362\n",
      "EPOCH: 23395 LOSS: 40.97737437458243\n",
      "EPOCH: 23396 LOSS: 40.97737285965628\n",
      "EPOCH: 23397 LOSS: 40.97737134483519\n",
      "EPOCH: 23398 LOSS: 40.977369830119095\n",
      "EPOCH: 23399 LOSS: 40.97736831550802\n",
      "EPOCH: 23400 LOSS: 40.97736680100194\n",
      "EPOCH: 23401 LOSS: 40.97736528660084\n",
      "EPOCH: 23402 LOSS: 40.97736377230472\n",
      "EPOCH: 23403 LOSS: 40.97736225811353\n",
      "EPOCH: 23404 LOSS: 40.97736074402728\n",
      "EPOCH: 23405 LOSS: 40.97735923004598\n",
      "EPOCH: 23406 LOSS: 40.97735771616958\n",
      "EPOCH: 23407 LOSS: 40.9773562023981\n",
      "EPOCH: 23408 LOSS: 40.97735468873149\n",
      "EPOCH: 23409 LOSS: 40.97735317516974\n",
      "EPOCH: 23410 LOSS: 40.977351661712866\n",
      "EPOCH: 23411 LOSS: 40.977350148360856\n",
      "EPOCH: 23412 LOSS: 40.97734863511366\n",
      "EPOCH: 23413 LOSS: 40.97734712197127\n",
      "EPOCH: 23414 LOSS: 40.97734560893372\n",
      "EPOCH: 23415 LOSS: 40.977344096000955\n",
      "EPOCH: 23416 LOSS: 40.97734258317297\n",
      "EPOCH: 23417 LOSS: 40.97734107044975\n",
      "EPOCH: 23418 LOSS: 40.977339557831286\n",
      "EPOCH: 23419 LOSS: 40.97733804531754\n",
      "EPOCH: 23420 LOSS: 40.97733653290855\n",
      "EPOCH: 23421 LOSS: 40.97733502060426\n",
      "EPOCH: 23422 LOSS: 40.97733350840468\n",
      "EPOCH: 23423 LOSS: 40.97733199630977\n",
      "EPOCH: 23424 LOSS: 40.97733048431955\n",
      "EPOCH: 23425 LOSS: 40.977328972433995\n",
      "EPOCH: 23426 LOSS: 40.97732746065307\n",
      "EPOCH: 23427 LOSS: 40.9773259489768\n",
      "EPOCH: 23428 LOSS: 40.977324437405144\n",
      "EPOCH: 23429 LOSS: 40.977322925938076\n",
      "EPOCH: 23430 LOSS: 40.97732141457563\n",
      "EPOCH: 23431 LOSS: 40.97731990331775\n",
      "EPOCH: 23432 LOSS: 40.977318392164435\n",
      "EPOCH: 23433 LOSS: 40.977316881115684\n",
      "EPOCH: 23434 LOSS: 40.97731537017145\n",
      "EPOCH: 23435 LOSS: 40.97731385933177\n",
      "EPOCH: 23436 LOSS: 40.97731234859659\n",
      "EPOCH: 23437 LOSS: 40.97731083796593\n",
      "EPOCH: 23438 LOSS: 40.977309327439755\n",
      "EPOCH: 23439 LOSS: 40.97730781701803\n",
      "EPOCH: 23440 LOSS: 40.97730630670079\n",
      "EPOCH: 23441 LOSS: 40.977304796487985\n",
      "EPOCH: 23442 LOSS: 40.97730328637962\n",
      "EPOCH: 23443 LOSS: 40.97730177637567\n",
      "EPOCH: 23444 LOSS: 40.97730026647615\n",
      "EPOCH: 23445 LOSS: 40.97729875668099\n",
      "EPOCH: 23446 LOSS: 40.97729724699025\n",
      "EPOCH: 23447 LOSS: 40.977295737403836\n",
      "EPOCH: 23448 LOSS: 40.97729422792182\n",
      "EPOCH: 23449 LOSS: 40.97729271854411\n",
      "EPOCH: 23450 LOSS: 40.977291209270746\n",
      "EPOCH: 23451 LOSS: 40.97728970010169\n",
      "EPOCH: 23452 LOSS: 40.97728819103693\n",
      "EPOCH: 23453 LOSS: 40.97728668207648\n",
      "EPOCH: 23454 LOSS: 40.97728517322029\n",
      "EPOCH: 23455 LOSS: 40.977283664468374\n",
      "EPOCH: 23456 LOSS: 40.9772821558207\n",
      "EPOCH: 23457 LOSS: 40.97728064727726\n",
      "EPOCH: 23458 LOSS: 40.97727913883804\n",
      "EPOCH: 23459 LOSS: 40.977277630503025\n",
      "EPOCH: 23460 LOSS: 40.97727612227223\n",
      "EPOCH: 23461 LOSS: 40.97727461414559\n",
      "EPOCH: 23462 LOSS: 40.97727310612313\n",
      "EPOCH: 23463 LOSS: 40.97727159820484\n",
      "EPOCH: 23464 LOSS: 40.97727009039066\n",
      "EPOCH: 23465 LOSS: 40.97726858268065\n",
      "EPOCH: 23466 LOSS: 40.977267075074735\n",
      "EPOCH: 23467 LOSS: 40.97726556757293\n",
      "EPOCH: 23468 LOSS: 40.97726406017519\n",
      "EPOCH: 23469 LOSS: 40.977262552881555\n",
      "EPOCH: 23470 LOSS: 40.97726104569198\n",
      "EPOCH: 23471 LOSS: 40.97725953860645\n",
      "EPOCH: 23472 LOSS: 40.977258031624956\n",
      "EPOCH: 23473 LOSS: 40.977256524747474\n",
      "EPOCH: 23474 LOSS: 40.977255017974024\n",
      "EPOCH: 23475 LOSS: 40.97725351130456\n",
      "EPOCH: 23476 LOSS: 40.97725200473909\n",
      "EPOCH: 23477 LOSS: 40.977250498277584\n",
      "EPOCH: 23478 LOSS: 40.977248991920035\n",
      "EPOCH: 23479 LOSS: 40.977247485666446\n",
      "EPOCH: 23480 LOSS: 40.97724597951677\n",
      "EPOCH: 23481 LOSS: 40.977244473471025\n",
      "EPOCH: 23482 LOSS: 40.97724296752918\n",
      "EPOCH: 23483 LOSS: 40.97724146169122\n",
      "EPOCH: 23484 LOSS: 40.977239955957145\n",
      "EPOCH: 23485 LOSS: 40.97723845032692\n",
      "EPOCH: 23486 LOSS: 40.97723694480058\n",
      "EPOCH: 23487 LOSS: 40.97723543937806\n",
      "EPOCH: 23488 LOSS: 40.977233934059356\n",
      "EPOCH: 23489 LOSS: 40.97723242884449\n",
      "EPOCH: 23490 LOSS: 40.977230923733416\n",
      "EPOCH: 23491 LOSS: 40.977229418726104\n",
      "EPOCH: 23492 LOSS: 40.97722791382259\n",
      "EPOCH: 23493 LOSS: 40.97722640902282\n",
      "EPOCH: 23494 LOSS: 40.977224904326825\n",
      "EPOCH: 23495 LOSS: 40.97722339973454\n",
      "EPOCH: 23496 LOSS: 40.977221895245975\n",
      "EPOCH: 23497 LOSS: 40.97722039086115\n",
      "EPOCH: 23498 LOSS: 40.97721888657998\n",
      "EPOCH: 23499 LOSS: 40.9772173824025\n",
      "EPOCH: 23500 LOSS: 40.97721587832871\n",
      "EPOCH: 23501 LOSS: 40.97721437435855\n",
      "EPOCH: 23502 LOSS: 40.977212870492025\n",
      "EPOCH: 23503 LOSS: 40.97721136672915\n",
      "EPOCH: 23504 LOSS: 40.977209863069895\n",
      "EPOCH: 23505 LOSS: 40.97720835951423\n",
      "EPOCH: 23506 LOSS: 40.97720685606215\n",
      "EPOCH: 23507 LOSS: 40.97720535271366\n",
      "EPOCH: 23508 LOSS: 40.97720384946873\n",
      "EPOCH: 23509 LOSS: 40.977202346327346\n",
      "EPOCH: 23510 LOSS: 40.97720084328948\n",
      "EPOCH: 23511 LOSS: 40.97719934035516\n",
      "EPOCH: 23512 LOSS: 40.97719783752436\n",
      "EPOCH: 23513 LOSS: 40.97719633479703\n",
      "EPOCH: 23514 LOSS: 40.977194832173204\n",
      "EPOCH: 23515 LOSS: 40.97719332965284\n",
      "EPOCH: 23516 LOSS: 40.97719182723594\n",
      "EPOCH: 23517 LOSS: 40.977190324922475\n",
      "EPOCH: 23518 LOSS: 40.97718882271245\n",
      "EPOCH: 23519 LOSS: 40.97718732060585\n",
      "EPOCH: 23520 LOSS: 40.977185818602656\n",
      "EPOCH: 23521 LOSS: 40.97718431670283\n",
      "EPOCH: 23522 LOSS: 40.9771828149064\n",
      "EPOCH: 23523 LOSS: 40.97718131321335\n",
      "EPOCH: 23524 LOSS: 40.97717981162363\n",
      "EPOCH: 23525 LOSS: 40.977178310137255\n",
      "EPOCH: 23526 LOSS: 40.97717680875421\n",
      "EPOCH: 23527 LOSS: 40.97717530747448\n",
      "EPOCH: 23528 LOSS: 40.977173806298055\n",
      "EPOCH: 23529 LOSS: 40.97717230522492\n",
      "EPOCH: 23530 LOSS: 40.97717080425504\n",
      "EPOCH: 23531 LOSS: 40.977169303388436\n",
      "EPOCH: 23532 LOSS: 40.977167802625075\n",
      "EPOCH: 23533 LOSS: 40.97716630196496\n",
      "EPOCH: 23534 LOSS: 40.97716480140805\n",
      "EPOCH: 23535 LOSS: 40.977163300954366\n",
      "EPOCH: 23536 LOSS: 40.97716180060387\n",
      "EPOCH: 23537 LOSS: 40.97716030035655\n",
      "EPOCH: 23538 LOSS: 40.977158800212415\n",
      "EPOCH: 23539 LOSS: 40.977157300171434\n",
      "EPOCH: 23540 LOSS: 40.97715580023359\n",
      "EPOCH: 23541 LOSS: 40.97715430039888\n",
      "EPOCH: 23542 LOSS: 40.977152800667284\n",
      "EPOCH: 23543 LOSS: 40.9771513010388\n",
      "EPOCH: 23544 LOSS: 40.9771498015134\n",
      "EPOCH: 23545 LOSS: 40.97714830209108\n",
      "EPOCH: 23546 LOSS: 40.97714680277183\n",
      "EPOCH: 23547 LOSS: 40.97714530355562\n",
      "EPOCH: 23548 LOSS: 40.97714380444246\n",
      "EPOCH: 23549 LOSS: 40.97714230543234\n",
      "EPOCH: 23550 LOSS: 40.977140806525206\n",
      "EPOCH: 23551 LOSS: 40.97713930772109\n",
      "EPOCH: 23552 LOSS: 40.977137809019965\n",
      "EPOCH: 23553 LOSS: 40.97713631042181\n",
      "EPOCH: 23554 LOSS: 40.977134811926604\n",
      "EPOCH: 23555 LOSS: 40.97713331353434\n",
      "EPOCH: 23556 LOSS: 40.977131815245045\n",
      "EPOCH: 23557 LOSS: 40.97713031705864\n",
      "EPOCH: 23558 LOSS: 40.97712881897516\n",
      "EPOCH: 23559 LOSS: 40.977127320994555\n",
      "EPOCH: 23560 LOSS: 40.97712582311687\n",
      "EPOCH: 23561 LOSS: 40.97712432534202\n",
      "EPOCH: 23562 LOSS: 40.97712282767006\n",
      "EPOCH: 23563 LOSS: 40.977121330100914\n",
      "EPOCH: 23564 LOSS: 40.977119832634614\n",
      "EPOCH: 23565 LOSS: 40.97711833527114\n",
      "EPOCH: 23566 LOSS: 40.97711683801045\n",
      "EPOCH: 23567 LOSS: 40.97711534085256\n",
      "EPOCH: 23568 LOSS: 40.977113843797454\n",
      "EPOCH: 23569 LOSS: 40.97711234684511\n",
      "EPOCH: 23570 LOSS: 40.977110849995526\n",
      "EPOCH: 23571 LOSS: 40.97710935324867\n",
      "EPOCH: 23572 LOSS: 40.97710785660455\n",
      "EPOCH: 23573 LOSS: 40.97710636006313\n",
      "EPOCH: 23574 LOSS: 40.97710486362442\n",
      "EPOCH: 23575 LOSS: 40.97710336728842\n",
      "EPOCH: 23576 LOSS: 40.977101871055055\n",
      "EPOCH: 23577 LOSS: 40.977100374924376\n",
      "EPOCH: 23578 LOSS: 40.97709887889635\n",
      "EPOCH: 23579 LOSS: 40.97709738297095\n",
      "EPOCH: 23580 LOSS: 40.97709588714817\n",
      "EPOCH: 23581 LOSS: 40.97709439142801\n",
      "EPOCH: 23582 LOSS: 40.977092895810436\n",
      "EPOCH: 23583 LOSS: 40.97709140029545\n",
      "EPOCH: 23584 LOSS: 40.97708990488305\n",
      "EPOCH: 23585 LOSS: 40.97708840957318\n",
      "EPOCH: 23586 LOSS: 40.97708691436587\n",
      "EPOCH: 23587 LOSS: 40.9770854192611\n",
      "EPOCH: 23588 LOSS: 40.977083924258835\n",
      "EPOCH: 23589 LOSS: 40.97708242935909\n",
      "EPOCH: 23590 LOSS: 40.97708093456184\n",
      "EPOCH: 23591 LOSS: 40.977079439867055\n",
      "EPOCH: 23592 LOSS: 40.97707794527473\n",
      "EPOCH: 23593 LOSS: 40.97707645078489\n",
      "EPOCH: 23594 LOSS: 40.97707495639747\n",
      "EPOCH: 23595 LOSS: 40.977073462112486\n",
      "EPOCH: 23596 LOSS: 40.977071967929916\n",
      "EPOCH: 23597 LOSS: 40.97707047384976\n",
      "EPOCH: 23598 LOSS: 40.97706897987198\n",
      "EPOCH: 23599 LOSS: 40.97706748599657\n",
      "EPOCH: 23600 LOSS: 40.97706599222354\n",
      "EPOCH: 23601 LOSS: 40.97706449855286\n",
      "EPOCH: 23602 LOSS: 40.977063004984515\n",
      "EPOCH: 23603 LOSS: 40.97706151151849\n",
      "EPOCH: 23604 LOSS: 40.97706001815477\n",
      "EPOCH: 23605 LOSS: 40.97705852489338\n",
      "EPOCH: 23606 LOSS: 40.97705703173423\n",
      "EPOCH: 23607 LOSS: 40.9770555386774\n",
      "EPOCH: 23608 LOSS: 40.97705404572281\n",
      "EPOCH: 23609 LOSS: 40.97705255287047\n",
      "EPOCH: 23610 LOSS: 40.977051060120374\n",
      "EPOCH: 23611 LOSS: 40.97704956747249\n",
      "EPOCH: 23612 LOSS: 40.9770480749268\n",
      "EPOCH: 23613 LOSS: 40.977046582483325\n",
      "EPOCH: 23614 LOSS: 40.97704509014203\n",
      "EPOCH: 23615 LOSS: 40.977043597902906\n",
      "EPOCH: 23616 LOSS: 40.97704210576594\n",
      "EPOCH: 23617 LOSS: 40.977040613731106\n",
      "EPOCH: 23618 LOSS: 40.97703912179841\n",
      "EPOCH: 23619 LOSS: 40.97703762996783\n",
      "EPOCH: 23620 LOSS: 40.97703613823938\n",
      "EPOCH: 23621 LOSS: 40.977034646613\n",
      "EPOCH: 23622 LOSS: 40.97703315508871\n",
      "EPOCH: 23623 LOSS: 40.97703166366648\n",
      "EPOCH: 23624 LOSS: 40.9770301723463\n",
      "EPOCH: 23625 LOSS: 40.977028681128175\n",
      "EPOCH: 23626 LOSS: 40.97702719001207\n",
      "EPOCH: 23627 LOSS: 40.97702569899799\n",
      "EPOCH: 23628 LOSS: 40.9770242080859\n",
      "EPOCH: 23629 LOSS: 40.9770227172758\n",
      "EPOCH: 23630 LOSS: 40.97702122656768\n",
      "EPOCH: 23631 LOSS: 40.977019735961534\n",
      "EPOCH: 23632 LOSS: 40.977018245457316\n",
      "EPOCH: 23633 LOSS: 40.977016755055054\n",
      "EPOCH: 23634 LOSS: 40.97701526475471\n",
      "EPOCH: 23635 LOSS: 40.9770137745563\n",
      "EPOCH: 23636 LOSS: 40.97701228445976\n",
      "EPOCH: 23637 LOSS: 40.97701079446513\n",
      "EPOCH: 23638 LOSS: 40.97700930457236\n",
      "EPOCH: 23639 LOSS: 40.97700781478146\n",
      "EPOCH: 23640 LOSS: 40.977006325092404\n",
      "EPOCH: 23641 LOSS: 40.977004835505184\n",
      "EPOCH: 23642 LOSS: 40.97700334601977\n",
      "EPOCH: 23643 LOSS: 40.97700185663619\n",
      "EPOCH: 23644 LOSS: 40.97700036735442\n",
      "EPOCH: 23645 LOSS: 40.97699887817441\n",
      "EPOCH: 23646 LOSS: 40.97699738909617\n",
      "EPOCH: 23647 LOSS: 40.9769959001197\n",
      "EPOCH: 23648 LOSS: 40.976994411244966\n",
      "EPOCH: 23649 LOSS: 40.97699292247198\n",
      "EPOCH: 23650 LOSS: 40.976991433800706\n",
      "EPOCH: 23651 LOSS: 40.97698994523113\n",
      "EPOCH: 23652 LOSS: 40.97698845676324\n",
      "EPOCH: 23653 LOSS: 40.97698696839705\n",
      "EPOCH: 23654 LOSS: 40.97698548013253\n",
      "EPOCH: 23655 LOSS: 40.97698399196966\n",
      "EPOCH: 23656 LOSS: 40.976982503908445\n",
      "EPOCH: 23657 LOSS: 40.97698101594885\n",
      "EPOCH: 23658 LOSS: 40.976979528090865\n",
      "EPOCH: 23659 LOSS: 40.9769780403345\n",
      "EPOCH: 23660 LOSS: 40.97697655267971\n",
      "EPOCH: 23661 LOSS: 40.97697506512652\n",
      "EPOCH: 23662 LOSS: 40.97697357767488\n",
      "EPOCH: 23663 LOSS: 40.9769720903248\n",
      "EPOCH: 23664 LOSS: 40.97697060307626\n",
      "EPOCH: 23665 LOSS: 40.97696911592925\n",
      "EPOCH: 23666 LOSS: 40.976967628883756\n",
      "EPOCH: 23667 LOSS: 40.97696614193977\n",
      "EPOCH: 23668 LOSS: 40.976964655097255\n",
      "EPOCH: 23669 LOSS: 40.97696316835623\n",
      "EPOCH: 23670 LOSS: 40.97696168171666\n",
      "EPOCH: 23671 LOSS: 40.97696019517855\n",
      "EPOCH: 23672 LOSS: 40.97695870874188\n",
      "EPOCH: 23673 LOSS: 40.97695722240663\n",
      "EPOCH: 23674 LOSS: 40.9769557361728\n",
      "EPOCH: 23675 LOSS: 40.97695425004036\n",
      "EPOCH: 23676 LOSS: 40.97695276400931\n",
      "EPOCH: 23677 LOSS: 40.976951278079646\n",
      "EPOCH: 23678 LOSS: 40.97694979225133\n",
      "EPOCH: 23679 LOSS: 40.97694830652438\n",
      "EPOCH: 23680 LOSS: 40.976946820898746\n",
      "EPOCH: 23681 LOSS: 40.97694533537445\n",
      "EPOCH: 23682 LOSS: 40.976943849951454\n",
      "EPOCH: 23683 LOSS: 40.97694236462977\n",
      "EPOCH: 23684 LOSS: 40.976940879409355\n",
      "EPOCH: 23685 LOSS: 40.97693939429023\n",
      "EPOCH: 23686 LOSS: 40.97693790927235\n",
      "EPOCH: 23687 LOSS: 40.97693642435571\n",
      "EPOCH: 23688 LOSS: 40.97693493954034\n",
      "EPOCH: 23689 LOSS: 40.97693345482616\n",
      "EPOCH: 23690 LOSS: 40.9769319702132\n",
      "EPOCH: 23691 LOSS: 40.97693048570143\n",
      "EPOCH: 23692 LOSS: 40.976929001290856\n",
      "EPOCH: 23693 LOSS: 40.97692751698145\n",
      "EPOCH: 23694 LOSS: 40.97692603277318\n",
      "EPOCH: 23695 LOSS: 40.97692454866608\n",
      "EPOCH: 23696 LOSS: 40.976923064660106\n",
      "EPOCH: 23697 LOSS: 40.976921580755246\n",
      "EPOCH: 23698 LOSS: 40.9769200969515\n",
      "EPOCH: 23699 LOSS: 40.97691861324884\n",
      "EPOCH: 23700 LOSS: 40.97691712964729\n",
      "EPOCH: 23701 LOSS: 40.97691564614678\n",
      "EPOCH: 23702 LOSS: 40.97691416274731\n",
      "EPOCH: 23703 LOSS: 40.976912679448915\n",
      "EPOCH: 23704 LOSS: 40.97691119625155\n",
      "EPOCH: 23705 LOSS: 40.976909713155194\n",
      "EPOCH: 23706 LOSS: 40.97690823015983\n",
      "EPOCH: 23707 LOSS: 40.97690674726549\n",
      "EPOCH: 23708 LOSS: 40.976905264472094\n",
      "EPOCH: 23709 LOSS: 40.9769037817797\n",
      "EPOCH: 23710 LOSS: 40.976902299188254\n",
      "EPOCH: 23711 LOSS: 40.97690081669772\n",
      "EPOCH: 23712 LOSS: 40.97689933430815\n",
      "EPOCH: 23713 LOSS: 40.976897852019476\n",
      "EPOCH: 23714 LOSS: 40.97689636983173\n",
      "EPOCH: 23715 LOSS: 40.97689488774485\n",
      "EPOCH: 23716 LOSS: 40.976893405758844\n",
      "EPOCH: 23717 LOSS: 40.97689192387372\n",
      "EPOCH: 23718 LOSS: 40.97689044208945\n",
      "EPOCH: 23719 LOSS: 40.97688896040601\n",
      "EPOCH: 23720 LOSS: 40.9768874788234\n",
      "EPOCH: 23721 LOSS: 40.97688599734161\n",
      "EPOCH: 23722 LOSS: 40.976884515960634\n",
      "EPOCH: 23723 LOSS: 40.97688303468043\n",
      "EPOCH: 23724 LOSS: 40.97688155350101\n",
      "EPOCH: 23725 LOSS: 40.97688007242235\n",
      "EPOCH: 23726 LOSS: 40.97687859144444\n",
      "EPOCH: 23727 LOSS: 40.97687711056727\n",
      "EPOCH: 23728 LOSS: 40.97687562979085\n",
      "EPOCH: 23729 LOSS: 40.976874149115105\n",
      "EPOCH: 23730 LOSS: 40.97687266854009\n",
      "EPOCH: 23731 LOSS: 40.97687118806576\n",
      "EPOCH: 23732 LOSS: 40.976869707692096\n",
      "EPOCH: 23733 LOSS: 40.97686822741909\n",
      "EPOCH: 23734 LOSS: 40.976866747246746\n",
      "EPOCH: 23735 LOSS: 40.97686526717504\n",
      "EPOCH: 23736 LOSS: 40.97686378720395\n",
      "EPOCH: 23737 LOSS: 40.97686230733349\n",
      "EPOCH: 23738 LOSS: 40.97686082756361\n",
      "EPOCH: 23739 LOSS: 40.97685934789433\n",
      "EPOCH: 23740 LOSS: 40.976857868325624\n",
      "EPOCH: 23741 LOSS: 40.97685638885747\n",
      "EPOCH: 23742 LOSS: 40.97685490948989\n",
      "EPOCH: 23743 LOSS: 40.976853430222825\n",
      "EPOCH: 23744 LOSS: 40.976851951056275\n",
      "EPOCH: 23745 LOSS: 40.97685047199026\n",
      "EPOCH: 23746 LOSS: 40.97684899302473\n",
      "EPOCH: 23747 LOSS: 40.97684751415969\n",
      "EPOCH: 23748 LOSS: 40.97684603539513\n",
      "EPOCH: 23749 LOSS: 40.976844556731024\n",
      "EPOCH: 23750 LOSS: 40.97684307816736\n",
      "EPOCH: 23751 LOSS: 40.97684159970415\n",
      "EPOCH: 23752 LOSS: 40.976840121341354\n",
      "EPOCH: 23753 LOSS: 40.97683864307896\n",
      "EPOCH: 23754 LOSS: 40.97683716491699\n",
      "EPOCH: 23755 LOSS: 40.97683568685538\n",
      "EPOCH: 23756 LOSS: 40.976834208894154\n",
      "EPOCH: 23757 LOSS: 40.97683273103328\n",
      "EPOCH: 23758 LOSS: 40.976831253272756\n",
      "EPOCH: 23759 LOSS: 40.976829775612586\n",
      "EPOCH: 23760 LOSS: 40.97682829805271\n",
      "EPOCH: 23761 LOSS: 40.97682682059315\n",
      "EPOCH: 23762 LOSS: 40.976825343233905\n",
      "EPOCH: 23763 LOSS: 40.976823865974936\n",
      "EPOCH: 23764 LOSS: 40.97682238881623\n",
      "EPOCH: 23765 LOSS: 40.976820911757784\n",
      "EPOCH: 23766 LOSS: 40.9768194347996\n",
      "EPOCH: 23767 LOSS: 40.976817957941634\n",
      "EPOCH: 23768 LOSS: 40.976816481183924\n",
      "EPOCH: 23769 LOSS: 40.97681500452638\n",
      "EPOCH: 23770 LOSS: 40.97681352796906\n",
      "EPOCH: 23771 LOSS: 40.97681205151191\n",
      "EPOCH: 23772 LOSS: 40.97681057515494\n",
      "EPOCH: 23773 LOSS: 40.97680909889813\n",
      "EPOCH: 23774 LOSS: 40.97680762274146\n",
      "EPOCH: 23775 LOSS: 40.976806146684915\n",
      "EPOCH: 23776 LOSS: 40.976804670728505\n",
      "EPOCH: 23777 LOSS: 40.976803194872204\n",
      "EPOCH: 23778 LOSS: 40.976801719116\n",
      "EPOCH: 23779 LOSS: 40.97680024345987\n",
      "EPOCH: 23780 LOSS: 40.97679876790383\n",
      "EPOCH: 23781 LOSS: 40.97679729244784\n",
      "EPOCH: 23782 LOSS: 40.976795817091876\n",
      "EPOCH: 23783 LOSS: 40.97679434183597\n",
      "EPOCH: 23784 LOSS: 40.97679286668007\n",
      "EPOCH: 23785 LOSS: 40.97679139162418\n",
      "EPOCH: 23786 LOSS: 40.97678991666831\n",
      "EPOCH: 23787 LOSS: 40.9767884418124\n",
      "EPOCH: 23788 LOSS: 40.97678696705647\n",
      "EPOCH: 23789 LOSS: 40.97678549240049\n",
      "EPOCH: 23790 LOSS: 40.97678401784445\n",
      "EPOCH: 23791 LOSS: 40.97678254338835\n",
      "EPOCH: 23792 LOSS: 40.976781069032185\n",
      "EPOCH: 23793 LOSS: 40.97677959477592\n",
      "EPOCH: 23794 LOSS: 40.97677812061955\n",
      "EPOCH: 23795 LOSS: 40.97677664656307\n",
      "EPOCH: 23796 LOSS: 40.97677517260646\n",
      "EPOCH: 23797 LOSS: 40.97677369874969\n",
      "EPOCH: 23798 LOSS: 40.976772224992786\n",
      "EPOCH: 23799 LOSS: 40.9767707513357\n",
      "EPOCH: 23800 LOSS: 40.97676927777843\n",
      "EPOCH: 23801 LOSS: 40.976767804320986\n",
      "EPOCH: 23802 LOSS: 40.976766330963336\n",
      "EPOCH: 23803 LOSS: 40.97676485770546\n",
      "EPOCH: 23804 LOSS: 40.97676338454737\n",
      "EPOCH: 23805 LOSS: 40.97676191148901\n",
      "EPOCH: 23806 LOSS: 40.97676043853043\n",
      "EPOCH: 23807 LOSS: 40.976758965671564\n",
      "EPOCH: 23808 LOSS: 40.97675749291241\n",
      "EPOCH: 23809 LOSS: 40.97675602025298\n",
      "EPOCH: 23810 LOSS: 40.97675454769323\n",
      "EPOCH: 23811 LOSS: 40.97675307523318\n",
      "EPOCH: 23812 LOSS: 40.976751602872795\n",
      "EPOCH: 23813 LOSS: 40.976750130612075\n",
      "EPOCH: 23814 LOSS: 40.976748658450994\n",
      "EPOCH: 23815 LOSS: 40.97674718638954\n",
      "EPOCH: 23816 LOSS: 40.9767457144277\n",
      "EPOCH: 23817 LOSS: 40.9767442425655\n",
      "EPOCH: 23818 LOSS: 40.97674277080286\n",
      "EPOCH: 23819 LOSS: 40.97674129913983\n",
      "EPOCH: 23820 LOSS: 40.976739827576374\n",
      "EPOCH: 23821 LOSS: 40.97673835611246\n",
      "EPOCH: 23822 LOSS: 40.97673688474809\n",
      "EPOCH: 23823 LOSS: 40.976735413483254\n",
      "EPOCH: 23824 LOSS: 40.97673394231795\n",
      "EPOCH: 23825 LOSS: 40.97673247125216\n",
      "EPOCH: 23826 LOSS: 40.97673100028586\n",
      "EPOCH: 23827 LOSS: 40.976729529419046\n",
      "EPOCH: 23828 LOSS: 40.97672805865169\n",
      "EPOCH: 23829 LOSS: 40.976726587983805\n",
      "EPOCH: 23830 LOSS: 40.97672511741536\n",
      "EPOCH: 23831 LOSS: 40.976723646946354\n",
      "EPOCH: 23832 LOSS: 40.97672217657677\n",
      "EPOCH: 23833 LOSS: 40.97672070630659\n",
      "EPOCH: 23834 LOSS: 40.976719236135814\n",
      "EPOCH: 23835 LOSS: 40.976717766064425\n",
      "EPOCH: 23836 LOSS: 40.97671629609239\n",
      "EPOCH: 23837 LOSS: 40.976714826219734\n",
      "EPOCH: 23838 LOSS: 40.97671335644641\n",
      "EPOCH: 23839 LOSS: 40.976711886772435\n",
      "EPOCH: 23840 LOSS: 40.97671041719778\n",
      "EPOCH: 23841 LOSS: 40.976708947722415\n",
      "EPOCH: 23842 LOSS: 40.97670747834637\n",
      "EPOCH: 23843 LOSS: 40.9767060090696\n",
      "EPOCH: 23844 LOSS: 40.97670453989209\n",
      "EPOCH: 23845 LOSS: 40.97670307081387\n",
      "EPOCH: 23846 LOSS: 40.976701601834876\n",
      "EPOCH: 23847 LOSS: 40.97670013295513\n",
      "EPOCH: 23848 LOSS: 40.97669866417459\n",
      "EPOCH: 23849 LOSS: 40.97669719549328\n",
      "EPOCH: 23850 LOSS: 40.97669572691115\n",
      "EPOCH: 23851 LOSS: 40.976694258428225\n",
      "EPOCH: 23852 LOSS: 40.97669279004445\n",
      "EPOCH: 23853 LOSS: 40.976691321759866\n",
      "EPOCH: 23854 LOSS: 40.976689853574406\n",
      "EPOCH: 23855 LOSS: 40.9766883854881\n",
      "EPOCH: 23856 LOSS: 40.97668691750092\n",
      "EPOCH: 23857 LOSS: 40.97668544961283\n",
      "EPOCH: 23858 LOSS: 40.97668398182384\n",
      "EPOCH: 23859 LOSS: 40.97668251413395\n",
      "EPOCH: 23860 LOSS: 40.976681046543135\n",
      "EPOCH: 23861 LOSS: 40.97667957905138\n",
      "EPOCH: 23862 LOSS: 40.97667811165867\n",
      "EPOCH: 23863 LOSS: 40.97667664436499\n",
      "EPOCH: 23864 LOSS: 40.97667517717034\n",
      "EPOCH: 23865 LOSS: 40.97667371007471\n",
      "EPOCH: 23866 LOSS: 40.97667224307808\n",
      "EPOCH: 23867 LOSS: 40.97667077618043\n",
      "EPOCH: 23868 LOSS: 40.976669309381755\n",
      "EPOCH: 23869 LOSS: 40.97666784268204\n",
      "EPOCH: 23870 LOSS: 40.97666637608128\n",
      "EPOCH: 23871 LOSS: 40.97666490957947\n",
      "EPOCH: 23872 LOSS: 40.976663443176584\n",
      "EPOCH: 23873 LOSS: 40.9766619768726\n",
      "EPOCH: 23874 LOSS: 40.976660510667514\n",
      "EPOCH: 23875 LOSS: 40.976659044561316\n",
      "EPOCH: 23876 LOSS: 40.97665757855401\n",
      "EPOCH: 23877 LOSS: 40.97665611264556\n",
      "EPOCH: 23878 LOSS: 40.976654646835954\n",
      "EPOCH: 23879 LOSS: 40.976653181125194\n",
      "EPOCH: 23880 LOSS: 40.97665171551328\n",
      "EPOCH: 23881 LOSS: 40.97665025000016\n",
      "EPOCH: 23882 LOSS: 40.97664878458584\n",
      "EPOCH: 23883 LOSS: 40.97664731927031\n",
      "EPOCH: 23884 LOSS: 40.97664585405357\n",
      "EPOCH: 23885 LOSS: 40.9766443889356\n",
      "EPOCH: 23886 LOSS: 40.97664292391636\n",
      "EPOCH: 23887 LOSS: 40.97664145899587\n",
      "EPOCH: 23888 LOSS: 40.97663999417412\n",
      "EPOCH: 23889 LOSS: 40.976638529451066\n",
      "EPOCH: 23890 LOSS: 40.97663706482673\n",
      "EPOCH: 23891 LOSS: 40.97663560030108\n",
      "EPOCH: 23892 LOSS: 40.97663413587412\n",
      "EPOCH: 23893 LOSS: 40.976632671545815\n",
      "EPOCH: 23894 LOSS: 40.976631207316174\n",
      "EPOCH: 23895 LOSS: 40.97662974318517\n",
      "EPOCH: 23896 LOSS: 40.976628279152784\n",
      "EPOCH: 23897 LOSS: 40.976626815219035\n",
      "EPOCH: 23898 LOSS: 40.97662535138389\n",
      "EPOCH: 23899 LOSS: 40.97662388764732\n",
      "EPOCH: 23900 LOSS: 40.976622424009356\n",
      "EPOCH: 23901 LOSS: 40.976620960469944\n",
      "EPOCH: 23902 LOSS: 40.97661949702909\n",
      "EPOCH: 23903 LOSS: 40.97661803368678\n",
      "EPOCH: 23904 LOSS: 40.976616570443\n",
      "EPOCH: 23905 LOSS: 40.97661510729775\n",
      "EPOCH: 23906 LOSS: 40.97661364425099\n",
      "EPOCH: 23907 LOSS: 40.97661218130274\n",
      "EPOCH: 23908 LOSS: 40.97661071845296\n",
      "EPOCH: 23909 LOSS: 40.976609255701675\n",
      "EPOCH: 23910 LOSS: 40.976607793048814\n",
      "EPOCH: 23911 LOSS: 40.97660633049441\n",
      "EPOCH: 23912 LOSS: 40.97660486803845\n",
      "EPOCH: 23913 LOSS: 40.97660340568089\n",
      "EPOCH: 23914 LOSS: 40.976601943421755\n",
      "EPOCH: 23915 LOSS: 40.976600481261016\n",
      "EPOCH: 23916 LOSS: 40.97659901919867\n",
      "EPOCH: 23917 LOSS: 40.97659755723468\n",
      "EPOCH: 23918 LOSS: 40.97659609536905\n",
      "EPOCH: 23919 LOSS: 40.97659463360178\n",
      "EPOCH: 23920 LOSS: 40.97659317193285\n",
      "EPOCH: 23921 LOSS: 40.97659171036223\n",
      "EPOCH: 23922 LOSS: 40.97659024888992\n",
      "EPOCH: 23923 LOSS: 40.97658878751591\n",
      "EPOCH: 23924 LOSS: 40.976587326240185\n",
      "EPOCH: 23925 LOSS: 40.976585865062745\n",
      "EPOCH: 23926 LOSS: 40.976584403983566\n",
      "EPOCH: 23927 LOSS: 40.97658294300261\n",
      "EPOCH: 23928 LOSS: 40.97658148211991\n",
      "EPOCH: 23929 LOSS: 40.97658002133544\n",
      "EPOCH: 23930 LOSS: 40.97657856064917\n",
      "EPOCH: 23931 LOSS: 40.97657710006111\n",
      "EPOCH: 23932 LOSS: 40.976575639571244\n",
      "EPOCH: 23933 LOSS: 40.97657417917954\n",
      "EPOCH: 23934 LOSS: 40.97657271888602\n",
      "EPOCH: 23935 LOSS: 40.976571258690626\n",
      "EPOCH: 23936 LOSS: 40.97656979859338\n",
      "EPOCH: 23937 LOSS: 40.97656833859427\n",
      "EPOCH: 23938 LOSS: 40.976566878693276\n",
      "EPOCH: 23939 LOSS: 40.97656541889036\n",
      "EPOCH: 23940 LOSS: 40.97656395918557\n",
      "EPOCH: 23941 LOSS: 40.97656249957884\n",
      "EPOCH: 23942 LOSS: 40.976561040070166\n",
      "EPOCH: 23943 LOSS: 40.97655958065957\n",
      "EPOCH: 23944 LOSS: 40.976558121347\n",
      "EPOCH: 23945 LOSS: 40.97655666213247\n",
      "EPOCH: 23946 LOSS: 40.976555203015934\n",
      "EPOCH: 23947 LOSS: 40.97655374399743\n",
      "EPOCH: 23948 LOSS: 40.97655228507692\n",
      "EPOCH: 23949 LOSS: 40.976550826254375\n",
      "EPOCH: 23950 LOSS: 40.97654936752979\n",
      "EPOCH: 23951 LOSS: 40.97654790890318\n",
      "EPOCH: 23952 LOSS: 40.976546450374514\n",
      "EPOCH: 23953 LOSS: 40.97654499194377\n",
      "EPOCH: 23954 LOSS: 40.97654353361094\n",
      "EPOCH: 23955 LOSS: 40.97654207537604\n",
      "EPOCH: 23956 LOSS: 40.976540617239024\n",
      "EPOCH: 23957 LOSS: 40.97653915919988\n",
      "EPOCH: 23958 LOSS: 40.976537701258636\n",
      "EPOCH: 23959 LOSS: 40.976536243415225\n",
      "EPOCH: 23960 LOSS: 40.97653478566966\n",
      "EPOCH: 23961 LOSS: 40.976533328021944\n",
      "EPOCH: 23962 LOSS: 40.97653187047204\n",
      "EPOCH: 23963 LOSS: 40.976530413019944\n",
      "EPOCH: 23964 LOSS: 40.97652895566566\n",
      "EPOCH: 23965 LOSS: 40.976527498409155\n",
      "EPOCH: 23966 LOSS: 40.97652604125042\n",
      "EPOCH: 23967 LOSS: 40.97652458418945\n",
      "EPOCH: 23968 LOSS: 40.97652312722623\n",
      "EPOCH: 23969 LOSS: 40.976521670360746\n",
      "EPOCH: 23970 LOSS: 40.97652021359298\n",
      "EPOCH: 23971 LOSS: 40.97651875692293\n",
      "EPOCH: 23972 LOSS: 40.97651730035061\n",
      "EPOCH: 23973 LOSS: 40.97651584387593\n",
      "EPOCH: 23974 LOSS: 40.976514387498966\n",
      "EPOCH: 23975 LOSS: 40.976512931219645\n",
      "EPOCH: 23976 LOSS: 40.97651147503798\n",
      "EPOCH: 23977 LOSS: 40.976510018953945\n",
      "EPOCH: 23978 LOSS: 40.97650856296756\n",
      "EPOCH: 23979 LOSS: 40.97650710707877\n",
      "EPOCH: 23980 LOSS: 40.976505651287596\n",
      "EPOCH: 23981 LOSS: 40.97650419559402\n",
      "EPOCH: 23982 LOSS: 40.97650273999801\n",
      "EPOCH: 23983 LOSS: 40.97650128449956\n",
      "EPOCH: 23984 LOSS: 40.97649982909869\n",
      "EPOCH: 23985 LOSS: 40.976498373795344\n",
      "EPOCH: 23986 LOSS: 40.97649691858953\n",
      "EPOCH: 23987 LOSS: 40.97649546348124\n",
      "EPOCH: 23988 LOSS: 40.97649400847047\n",
      "EPOCH: 23989 LOSS: 40.97649255355718\n",
      "EPOCH: 23990 LOSS: 40.97649109874138\n",
      "EPOCH: 23991 LOSS: 40.97648964402304\n",
      "EPOCH: 23992 LOSS: 40.976488189402154\n",
      "EPOCH: 23993 LOSS: 40.97648673487872\n",
      "EPOCH: 23994 LOSS: 40.976485280452735\n",
      "EPOCH: 23995 LOSS: 40.976483826124145\n",
      "EPOCH: 23996 LOSS: 40.976482371892985\n",
      "EPOCH: 23997 LOSS: 40.97648091775921\n",
      "EPOCH: 23998 LOSS: 40.976479463722825\n",
      "EPOCH: 23999 LOSS: 40.97647800978382\n",
      "EPOCH: 24000 LOSS: 40.976476555942185\n",
      "EPOCH: 24001 LOSS: 40.97647510219787\n",
      "EPOCH: 24002 LOSS: 40.976473648550915\n",
      "EPOCH: 24003 LOSS: 40.97647219500128\n",
      "EPOCH: 24004 LOSS: 40.97647074154895\n",
      "EPOCH: 24005 LOSS: 40.97646928819393\n",
      "EPOCH: 24006 LOSS: 40.9764678349362\n",
      "EPOCH: 24007 LOSS: 40.97646638177575\n",
      "EPOCH: 24008 LOSS: 40.97646492871256\n",
      "EPOCH: 24009 LOSS: 40.976463475746606\n",
      "EPOCH: 24010 LOSS: 40.976462022877925\n",
      "EPOCH: 24011 LOSS: 40.97646057010644\n",
      "EPOCH: 24012 LOSS: 40.9764591174322\n",
      "EPOCH: 24013 LOSS: 40.97645766485514\n",
      "EPOCH: 24014 LOSS: 40.976456212375275\n",
      "EPOCH: 24015 LOSS: 40.976454759992606\n",
      "EPOCH: 24016 LOSS: 40.97645330770711\n",
      "EPOCH: 24017 LOSS: 40.97645185551874\n",
      "EPOCH: 24018 LOSS: 40.97645040342755\n",
      "EPOCH: 24019 LOSS: 40.97644895143347\n",
      "EPOCH: 24020 LOSS: 40.9764474995365\n",
      "EPOCH: 24021 LOSS: 40.97644604773666\n",
      "EPOCH: 24022 LOSS: 40.976444596033886\n",
      "EPOCH: 24023 LOSS: 40.97644314442823\n",
      "EPOCH: 24024 LOSS: 40.97644169291965\n",
      "EPOCH: 24025 LOSS: 40.97644024150809\n",
      "EPOCH: 24026 LOSS: 40.97643879019361\n",
      "EPOCH: 24027 LOSS: 40.97643733897616\n",
      "EPOCH: 24028 LOSS: 40.97643588785573\n",
      "EPOCH: 24029 LOSS: 40.97643443683232\n",
      "EPOCH: 24030 LOSS: 40.97643298590589\n",
      "EPOCH: 24031 LOSS: 40.97643153507646\n",
      "EPOCH: 24032 LOSS: 40.976430084344\n",
      "EPOCH: 24033 LOSS: 40.97642863370851\n",
      "EPOCH: 24034 LOSS: 40.976427183169974\n",
      "EPOCH: 24035 LOSS: 40.97642573272837\n",
      "EPOCH: 24036 LOSS: 40.976424282383704\n",
      "EPOCH: 24037 LOSS: 40.97642283213594\n",
      "EPOCH: 24038 LOSS: 40.97642138198507\n",
      "EPOCH: 24039 LOSS: 40.97641993193111\n",
      "EPOCH: 24040 LOSS: 40.976418481974015\n",
      "EPOCH: 24041 LOSS: 40.976417032113815\n",
      "EPOCH: 24042 LOSS: 40.976415582350455\n",
      "EPOCH: 24043 LOSS: 40.976414132683914\n",
      "EPOCH: 24044 LOSS: 40.97641268311425\n",
      "EPOCH: 24045 LOSS: 40.976411233641386\n",
      "EPOCH: 24046 LOSS: 40.976409784265314\n",
      "EPOCH: 24047 LOSS: 40.97640833498606\n",
      "EPOCH: 24048 LOSS: 40.97640688580357\n",
      "EPOCH: 24049 LOSS: 40.97640543671786\n",
      "EPOCH: 24050 LOSS: 40.976403987728915\n",
      "EPOCH: 24051 LOSS: 40.976402538836695\n",
      "EPOCH: 24052 LOSS: 40.976401090041236\n",
      "EPOCH: 24053 LOSS: 40.97639964134248\n",
      "EPOCH: 24054 LOSS: 40.97639819274046\n",
      "EPOCH: 24055 LOSS: 40.97639674423512\n",
      "EPOCH: 24056 LOSS: 40.97639529582648\n",
      "EPOCH: 24057 LOSS: 40.9763938475145\n",
      "EPOCH: 24058 LOSS: 40.9763923992992\n",
      "EPOCH: 24059 LOSS: 40.976390951180534\n",
      "EPOCH: 24060 LOSS: 40.97638950315852\n",
      "EPOCH: 24061 LOSS: 40.97638805523314\n",
      "EPOCH: 24062 LOSS: 40.97638660740438\n",
      "EPOCH: 24063 LOSS: 40.976385159672205\n",
      "EPOCH: 24064 LOSS: 40.97638371203661\n",
      "EPOCH: 24065 LOSS: 40.97638226449761\n",
      "EPOCH: 24066 LOSS: 40.97638081705519\n",
      "EPOCH: 24067 LOSS: 40.976379369709306\n",
      "EPOCH: 24068 LOSS: 40.976377922459974\n",
      "EPOCH: 24069 LOSS: 40.97637647530718\n",
      "EPOCH: 24070 LOSS: 40.97637502825091\n",
      "EPOCH: 24071 LOSS: 40.97637358129113\n",
      "EPOCH: 24072 LOSS: 40.97637213442785\n",
      "EPOCH: 24073 LOSS: 40.97637068766107\n",
      "EPOCH: 24074 LOSS: 40.976369240990735\n",
      "EPOCH: 24075 LOSS: 40.97636779441689\n",
      "EPOCH: 24076 LOSS: 40.976366347939475\n",
      "EPOCH: 24077 LOSS: 40.9763649015585\n",
      "EPOCH: 24078 LOSS: 40.97636345527394\n",
      "EPOCH: 24079 LOSS: 40.976362009085804\n",
      "EPOCH: 24080 LOSS: 40.976360562994074\n",
      "EPOCH: 24081 LOSS: 40.97635911699872\n",
      "EPOCH: 24082 LOSS: 40.97635767109975\n",
      "EPOCH: 24083 LOSS: 40.976356225297145\n",
      "EPOCH: 24084 LOSS: 40.97635477959089\n",
      "EPOCH: 24085 LOSS: 40.97635333398098\n",
      "EPOCH: 24086 LOSS: 40.9763518884674\n",
      "EPOCH: 24087 LOSS: 40.97635044305011\n",
      "EPOCH: 24088 LOSS: 40.97634899772916\n",
      "EPOCH: 24089 LOSS: 40.9763475525045\n",
      "EPOCH: 24090 LOSS: 40.97634610737611\n",
      "EPOCH: 24091 LOSS: 40.976344662343976\n",
      "EPOCH: 24092 LOSS: 40.97634321740813\n",
      "EPOCH: 24093 LOSS: 40.97634177256852\n",
      "EPOCH: 24094 LOSS: 40.97634032782513\n",
      "EPOCH: 24095 LOSS: 40.97633888317796\n",
      "EPOCH: 24096 LOSS: 40.97633743862701\n",
      "EPOCH: 24097 LOSS: 40.976335994172274\n",
      "EPOCH: 24098 LOSS: 40.976334549813686\n",
      "EPOCH: 24099 LOSS: 40.976333105551305\n",
      "EPOCH: 24100 LOSS: 40.976331661385075\n",
      "EPOCH: 24101 LOSS: 40.97633021731501\n",
      "EPOCH: 24102 LOSS: 40.97632877334105\n",
      "EPOCH: 24103 LOSS: 40.97632732946323\n",
      "EPOCH: 24104 LOSS: 40.97632588568155\n",
      "EPOCH: 24105 LOSS: 40.976324441995935\n",
      "EPOCH: 24106 LOSS: 40.97632299840643\n",
      "EPOCH: 24107 LOSS: 40.97632155491301\n",
      "EPOCH: 24108 LOSS: 40.97632011151565\n",
      "EPOCH: 24109 LOSS: 40.97631866821434\n",
      "EPOCH: 24110 LOSS: 40.9763172250091\n",
      "EPOCH: 24111 LOSS: 40.976315781899864\n",
      "EPOCH: 24112 LOSS: 40.97631433888665\n",
      "EPOCH: 24113 LOSS: 40.97631289596944\n",
      "EPOCH: 24114 LOSS: 40.97631145314824\n",
      "EPOCH: 24115 LOSS: 40.97631001042302\n",
      "EPOCH: 24116 LOSS: 40.97630856779377\n",
      "EPOCH: 24117 LOSS: 40.97630712526048\n",
      "EPOCH: 24118 LOSS: 40.97630568282314\n",
      "EPOCH: 24119 LOSS: 40.97630424048174\n",
      "EPOCH: 24120 LOSS: 40.976302798236254\n",
      "EPOCH: 24121 LOSS: 40.9763013560867\n",
      "EPOCH: 24122 LOSS: 40.97629991403303\n",
      "EPOCH: 24123 LOSS: 40.97629847207526\n",
      "EPOCH: 24124 LOSS: 40.97629703021337\n",
      "EPOCH: 24125 LOSS: 40.97629558844733\n",
      "EPOCH: 24126 LOSS: 40.97629414677715\n",
      "EPOCH: 24127 LOSS: 40.976292705202816\n",
      "EPOCH: 24128 LOSS: 40.97629126372432\n",
      "EPOCH: 24129 LOSS: 40.97628982234161\n",
      "EPOCH: 24130 LOSS: 40.97628838105473\n",
      "EPOCH: 24131 LOSS: 40.97628693986364\n",
      "EPOCH: 24132 LOSS: 40.97628549876835\n",
      "EPOCH: 24133 LOSS: 40.97628405776882\n",
      "EPOCH: 24134 LOSS: 40.976282616865035\n",
      "EPOCH: 24135 LOSS: 40.97628117605702\n",
      "EPOCH: 24136 LOSS: 40.97627973534473\n",
      "EPOCH: 24137 LOSS: 40.97627829472816\n",
      "EPOCH: 24138 LOSS: 40.9762768542073\n",
      "EPOCH: 24139 LOSS: 40.97627541378216\n",
      "EPOCH: 24140 LOSS: 40.97627397345267\n",
      "EPOCH: 24141 LOSS: 40.97627253321888\n",
      "EPOCH: 24142 LOSS: 40.97627109308075\n",
      "EPOCH: 24143 LOSS: 40.97626965303828\n",
      "EPOCH: 24144 LOSS: 40.976268213091444\n",
      "EPOCH: 24145 LOSS: 40.97626677324025\n",
      "EPOCH: 24146 LOSS: 40.97626533348466\n",
      "EPOCH: 24147 LOSS: 40.97626389382467\n",
      "EPOCH: 24148 LOSS: 40.97626245426029\n",
      "EPOCH: 24149 LOSS: 40.97626101479148\n",
      "EPOCH: 24150 LOSS: 40.97625957541824\n",
      "EPOCH: 24151 LOSS: 40.97625813614058\n",
      "EPOCH: 24152 LOSS: 40.976256696958444\n",
      "EPOCH: 24153 LOSS: 40.976255257871856\n",
      "EPOCH: 24154 LOSS: 40.97625381888078\n",
      "EPOCH: 24155 LOSS: 40.97625237998521\n",
      "EPOCH: 24156 LOSS: 40.97625094118516\n",
      "EPOCH: 24157 LOSS: 40.976249502480584\n",
      "EPOCH: 24158 LOSS: 40.976248063871495\n",
      "EPOCH: 24159 LOSS: 40.97624662535786\n",
      "EPOCH: 24160 LOSS: 40.97624518693968\n",
      "EPOCH: 24161 LOSS: 40.97624374861694\n",
      "EPOCH: 24162 LOSS: 40.97624231038962\n",
      "EPOCH: 24163 LOSS: 40.97624087225773\n",
      "EPOCH: 24164 LOSS: 40.97623943422124\n",
      "EPOCH: 24165 LOSS: 40.97623799628013\n",
      "EPOCH: 24166 LOSS: 40.97623655843443\n",
      "EPOCH: 24167 LOSS: 40.97623512068409\n",
      "EPOCH: 24168 LOSS: 40.97623368302909\n",
      "EPOCH: 24169 LOSS: 40.97623224546946\n",
      "EPOCH: 24170 LOSS: 40.976230808005155\n",
      "EPOCH: 24171 LOSS: 40.976229370636176\n",
      "EPOCH: 24172 LOSS: 40.976227933362495\n",
      "EPOCH: 24173 LOSS: 40.976226496184125\n",
      "EPOCH: 24174 LOSS: 40.97622505910105\n",
      "EPOCH: 24175 LOSS: 40.97622362211324\n",
      "EPOCH: 24176 LOSS: 40.97622218522072\n",
      "EPOCH: 24177 LOSS: 40.97622074842341\n",
      "EPOCH: 24178 LOSS: 40.97621931172136\n",
      "EPOCH: 24179 LOSS: 40.97621787511453\n",
      "EPOCH: 24180 LOSS: 40.97621643860293\n",
      "EPOCH: 24181 LOSS: 40.976215002186535\n",
      "EPOCH: 24182 LOSS: 40.97621356586533\n",
      "EPOCH: 24183 LOSS: 40.976212129639315\n",
      "EPOCH: 24184 LOSS: 40.97621069350846\n",
      "EPOCH: 24185 LOSS: 40.97620925747276\n",
      "EPOCH: 24186 LOSS: 40.97620782153221\n",
      "EPOCH: 24187 LOSS: 40.97620638568681\n",
      "EPOCH: 24188 LOSS: 40.97620494993653\n",
      "EPOCH: 24189 LOSS: 40.976203514281345\n",
      "EPOCH: 24190 LOSS: 40.97620207872128\n",
      "EPOCH: 24191 LOSS: 40.97620064325629\n",
      "EPOCH: 24192 LOSS: 40.97619920788638\n",
      "EPOCH: 24193 LOSS: 40.97619777261153\n",
      "EPOCH: 24194 LOSS: 40.97619633743174\n",
      "EPOCH: 24195 LOSS: 40.97619490234698\n",
      "EPOCH: 24196 LOSS: 40.97619346735727\n",
      "EPOCH: 24197 LOSS: 40.97619203246256\n",
      "EPOCH: 24198 LOSS: 40.976190597662864\n",
      "EPOCH: 24199 LOSS: 40.976189162958164\n",
      "EPOCH: 24200 LOSS: 40.97618772834844\n",
      "EPOCH: 24201 LOSS: 40.9761862938337\n",
      "EPOCH: 24202 LOSS: 40.97618485941392\n",
      "EPOCH: 24203 LOSS: 40.976183425089076\n",
      "EPOCH: 24204 LOSS: 40.97618199085916\n",
      "EPOCH: 24205 LOSS: 40.976180556724174\n",
      "EPOCH: 24206 LOSS: 40.976179122684115\n",
      "EPOCH: 24207 LOSS: 40.97617768873897\n",
      "EPOCH: 24208 LOSS: 40.97617625488867\n",
      "EPOCH: 24209 LOSS: 40.97617482113328\n",
      "EPOCH: 24210 LOSS: 40.97617338747275\n",
      "EPOCH: 24211 LOSS: 40.976171953907084\n",
      "EPOCH: 24212 LOSS: 40.97617052043624\n",
      "EPOCH: 24213 LOSS: 40.97616908706024\n",
      "EPOCH: 24214 LOSS: 40.97616765377906\n",
      "EPOCH: 24215 LOSS: 40.97616622059269\n",
      "EPOCH: 24216 LOSS: 40.976164787501105\n",
      "EPOCH: 24217 LOSS: 40.9761633545043\n",
      "EPOCH: 24218 LOSS: 40.97616192160229\n",
      "EPOCH: 24219 LOSS: 40.97616048879502\n",
      "EPOCH: 24220 LOSS: 40.97615905608251\n",
      "EPOCH: 24221 LOSS: 40.976157623464736\n",
      "EPOCH: 24222 LOSS: 40.97615619094169\n",
      "EPOCH: 24223 LOSS: 40.976154758513346\n",
      "EPOCH: 24224 LOSS: 40.97615332617972\n",
      "EPOCH: 24225 LOSS: 40.976151893940795\n",
      "EPOCH: 24226 LOSS: 40.976150461796536\n",
      "EPOCH: 24227 LOSS: 40.976149029746935\n",
      "EPOCH: 24228 LOSS: 40.97614759779199\n",
      "EPOCH: 24229 LOSS: 40.976146165931716\n",
      "EPOCH: 24230 LOSS: 40.976144734166056\n",
      "EPOCH: 24231 LOSS: 40.97614330249501\n",
      "EPOCH: 24232 LOSS: 40.97614187091859\n",
      "EPOCH: 24233 LOSS: 40.976140439436776\n",
      "EPOCH: 24234 LOSS: 40.97613900804953\n",
      "EPOCH: 24235 LOSS: 40.97613757675687\n",
      "EPOCH: 24236 LOSS: 40.976136145558755\n",
      "EPOCH: 24237 LOSS: 40.976134714455206\n",
      "EPOCH: 24238 LOSS: 40.97613328344619\n",
      "EPOCH: 24239 LOSS: 40.9761318525317\n",
      "EPOCH: 24240 LOSS: 40.97613042171174\n",
      "EPOCH: 24241 LOSS: 40.97612899098628\n",
      "EPOCH: 24242 LOSS: 40.976127560355295\n",
      "EPOCH: 24243 LOSS: 40.97612612981883\n",
      "EPOCH: 24244 LOSS: 40.97612469937681\n",
      "EPOCH: 24245 LOSS: 40.97612326902927\n",
      "EPOCH: 24246 LOSS: 40.97612183877614\n",
      "EPOCH: 24247 LOSS: 40.97612040861746\n",
      "EPOCH: 24248 LOSS: 40.976118978553224\n",
      "EPOCH: 24249 LOSS: 40.97611754858338\n",
      "EPOCH: 24250 LOSS: 40.976116118707935\n",
      "EPOCH: 24251 LOSS: 40.9761146889269\n",
      "EPOCH: 24252 LOSS: 40.97611325924022\n",
      "EPOCH: 24253 LOSS: 40.97611182964792\n",
      "EPOCH: 24254 LOSS: 40.97611040014996\n",
      "EPOCH: 24255 LOSS: 40.97610897074637\n",
      "EPOCH: 24256 LOSS: 40.976107541437074\n",
      "EPOCH: 24257 LOSS: 40.97610611222213\n",
      "EPOCH: 24258 LOSS: 40.97610468310148\n",
      "EPOCH: 24259 LOSS: 40.97610325407513\n",
      "EPOCH: 24260 LOSS: 40.97610182514306\n",
      "EPOCH: 24261 LOSS: 40.97610039630527\n",
      "EPOCH: 24262 LOSS: 40.97609896756174\n",
      "EPOCH: 24263 LOSS: 40.97609753891246\n",
      "EPOCH: 24264 LOSS: 40.97609611035741\n",
      "EPOCH: 24265 LOSS: 40.97609468189658\n",
      "EPOCH: 24266 LOSS: 40.976093253529996\n",
      "EPOCH: 24267 LOSS: 40.9760918252576\n",
      "EPOCH: 24268 LOSS: 40.97609039707939\n",
      "EPOCH: 24269 LOSS: 40.97608896899535\n",
      "EPOCH: 24270 LOSS: 40.9760875410055\n",
      "EPOCH: 24271 LOSS: 40.9760861131098\n",
      "EPOCH: 24272 LOSS: 40.97608468530826\n",
      "EPOCH: 24273 LOSS: 40.976083257600834\n",
      "EPOCH: 24274 LOSS: 40.976081829987535\n",
      "EPOCH: 24275 LOSS: 40.976080402468355\n",
      "EPOCH: 24276 LOSS: 40.97607897504326\n",
      "EPOCH: 24277 LOSS: 40.97607754771228\n",
      "EPOCH: 24278 LOSS: 40.976076120475355\n",
      "EPOCH: 24279 LOSS: 40.97607469333251\n",
      "EPOCH: 24280 LOSS: 40.97607326628371\n",
      "EPOCH: 24281 LOSS: 40.97607183932895\n",
      "EPOCH: 24282 LOSS: 40.97607041246822\n",
      "EPOCH: 24283 LOSS: 40.97606898570152\n",
      "EPOCH: 24284 LOSS: 40.976067559028806\n",
      "EPOCH: 24285 LOSS: 40.97606613245011\n",
      "EPOCH: 24286 LOSS: 40.9760647059654\n",
      "EPOCH: 24287 LOSS: 40.97606327957463\n",
      "EPOCH: 24288 LOSS: 40.97606185327786\n",
      "EPOCH: 24289 LOSS: 40.97606042707501\n",
      "EPOCH: 24290 LOSS: 40.97605900096613\n",
      "EPOCH: 24291 LOSS: 40.976057574951156\n",
      "EPOCH: 24292 LOSS: 40.9760561490301\n",
      "EPOCH: 24293 LOSS: 40.97605472320294\n",
      "EPOCH: 24294 LOSS: 40.976053297469676\n",
      "EPOCH: 24295 LOSS: 40.97605187183031\n",
      "EPOCH: 24296 LOSS: 40.97605044628479\n",
      "EPOCH: 24297 LOSS: 40.976049020833145\n",
      "EPOCH: 24298 LOSS: 40.97604759547534\n",
      "EPOCH: 24299 LOSS: 40.97604617021137\n",
      "EPOCH: 24300 LOSS: 40.97604474504121\n",
      "EPOCH: 24301 LOSS: 40.97604331996487\n",
      "EPOCH: 24302 LOSS: 40.97604189498235\n",
      "EPOCH: 24303 LOSS: 40.976040470093594\n",
      "EPOCH: 24304 LOSS: 40.976039045298634\n",
      "EPOCH: 24305 LOSS: 40.97603762059743\n",
      "EPOCH: 24306 LOSS: 40.97603619598999\n",
      "EPOCH: 24307 LOSS: 40.976034771476264\n",
      "EPOCH: 24308 LOSS: 40.97603334705629\n",
      "EPOCH: 24309 LOSS: 40.976031922730044\n",
      "EPOCH: 24310 LOSS: 40.97603049849749\n",
      "EPOCH: 24311 LOSS: 40.97602907435864\n",
      "EPOCH: 24312 LOSS: 40.976027650313476\n",
      "EPOCH: 24313 LOSS: 40.97602622636198\n",
      "EPOCH: 24314 LOSS: 40.97602480250414\n",
      "EPOCH: 24315 LOSS: 40.97602337873998\n",
      "EPOCH: 24316 LOSS: 40.97602195506944\n",
      "EPOCH: 24317 LOSS: 40.97602053149252\n",
      "EPOCH: 24318 LOSS: 40.976019108009226\n",
      "EPOCH: 24319 LOSS: 40.976017684619535\n",
      "EPOCH: 24320 LOSS: 40.97601626132345\n",
      "EPOCH: 24321 LOSS: 40.97601483812094\n",
      "EPOCH: 24322 LOSS: 40.97601341501199\n",
      "EPOCH: 24323 LOSS: 40.976011991996614\n",
      "EPOCH: 24324 LOSS: 40.976010569074774\n",
      "EPOCH: 24325 LOSS: 40.976009146246476\n",
      "EPOCH: 24326 LOSS: 40.97600772351169\n",
      "EPOCH: 24327 LOSS: 40.97600630087043\n",
      "EPOCH: 24328 LOSS: 40.97600487832267\n",
      "EPOCH: 24329 LOSS: 40.9760034558684\n",
      "EPOCH: 24330 LOSS: 40.976002033507626\n",
      "EPOCH: 24331 LOSS: 40.976000611240295\n",
      "EPOCH: 24332 LOSS: 40.97599918906642\n",
      "EPOCH: 24333 LOSS: 40.97599776698601\n",
      "EPOCH: 24334 LOSS: 40.975996344999025\n",
      "EPOCH: 24335 LOSS: 40.975994923105446\n",
      "EPOCH: 24336 LOSS: 40.97599350130531\n",
      "EPOCH: 24337 LOSS: 40.97599207959854\n",
      "EPOCH: 24338 LOSS: 40.97599065798517\n",
      "EPOCH: 24339 LOSS: 40.97598923646518\n",
      "EPOCH: 24340 LOSS: 40.97598781503855\n",
      "EPOCH: 24341 LOSS: 40.975986393705284\n",
      "EPOCH: 24342 LOSS: 40.97598497246534\n",
      "EPOCH: 24343 LOSS: 40.97598355131874\n",
      "EPOCH: 24344 LOSS: 40.97598213026545\n",
      "EPOCH: 24345 LOSS: 40.97598070930549\n",
      "EPOCH: 24346 LOSS: 40.975979288438786\n",
      "EPOCH: 24347 LOSS: 40.97597786766539\n",
      "EPOCH: 24348 LOSS: 40.975976446985285\n",
      "EPOCH: 24349 LOSS: 40.97597502639842\n",
      "EPOCH: 24350 LOSS: 40.97597360590481\n",
      "EPOCH: 24351 LOSS: 40.97597218550444\n",
      "EPOCH: 24352 LOSS: 40.9759707651973\n",
      "EPOCH: 24353 LOSS: 40.97596934498338\n",
      "EPOCH: 24354 LOSS: 40.97596792486266\n",
      "EPOCH: 24355 LOSS: 40.97596650483513\n",
      "EPOCH: 24356 LOSS: 40.97596508490078\n",
      "EPOCH: 24357 LOSS: 40.9759636650596\n",
      "EPOCH: 24358 LOSS: 40.97596224531159\n",
      "EPOCH: 24359 LOSS: 40.97596082565673\n",
      "EPOCH: 24360 LOSS: 40.97595940609497\n",
      "EPOCH: 24361 LOSS: 40.97595798662638\n",
      "EPOCH: 24362 LOSS: 40.97595656725089\n",
      "EPOCH: 24363 LOSS: 40.9759551479685\n",
      "EPOCH: 24364 LOSS: 40.9759537287792\n",
      "EPOCH: 24365 LOSS: 40.97595230968299\n",
      "EPOCH: 24366 LOSS: 40.97595089067984\n",
      "EPOCH: 24367 LOSS: 40.97594947176973\n",
      "EPOCH: 24368 LOSS: 40.97594805295269\n",
      "EPOCH: 24369 LOSS: 40.97594663422868\n",
      "EPOCH: 24370 LOSS: 40.97594521559768\n",
      "EPOCH: 24371 LOSS: 40.9759437970597\n",
      "EPOCH: 24372 LOSS: 40.97594237861472\n",
      "EPOCH: 24373 LOSS: 40.97594096026273\n",
      "EPOCH: 24374 LOSS: 40.975939542003715\n",
      "EPOCH: 24375 LOSS: 40.975938123837665\n",
      "EPOCH: 24376 LOSS: 40.975936705764575\n",
      "EPOCH: 24377 LOSS: 40.975935287784424\n",
      "EPOCH: 24378 LOSS: 40.975933869897204\n",
      "EPOCH: 24379 LOSS: 40.97593245210291\n",
      "EPOCH: 24380 LOSS: 40.975931034401526\n",
      "EPOCH: 24381 LOSS: 40.975929616793024\n",
      "EPOCH: 24382 LOSS: 40.97592819927742\n",
      "EPOCH: 24383 LOSS: 40.975926781854696\n",
      "EPOCH: 24384 LOSS: 40.975925364524834\n",
      "EPOCH: 24385 LOSS: 40.975923947287825\n",
      "EPOCH: 24386 LOSS: 40.97592253014365\n",
      "EPOCH: 24387 LOSS: 40.97592111309231\n",
      "EPOCH: 24388 LOSS: 40.97591969613378\n",
      "EPOCH: 24389 LOSS: 40.975918279268065\n",
      "EPOCH: 24390 LOSS: 40.97591686249514\n",
      "EPOCH: 24391 LOSS: 40.975915445815005\n",
      "EPOCH: 24392 LOSS: 40.97591402922764\n",
      "EPOCH: 24393 LOSS: 40.97591261273305\n",
      "EPOCH: 24394 LOSS: 40.9759111963312\n",
      "EPOCH: 24395 LOSS: 40.9759097800221\n",
      "EPOCH: 24396 LOSS: 40.9759083638057\n",
      "EPOCH: 24397 LOSS: 40.97590694768204\n",
      "EPOCH: 24398 LOSS: 40.97590553165108\n",
      "EPOCH: 24399 LOSS: 40.97590411571281\n",
      "EPOCH: 24400 LOSS: 40.975902699867234\n",
      "EPOCH: 24401 LOSS: 40.97590128411431\n",
      "EPOCH: 24402 LOSS: 40.97589986845404\n",
      "EPOCH: 24403 LOSS: 40.97589845288645\n",
      "EPOCH: 24404 LOSS: 40.97589703741148\n",
      "EPOCH: 24405 LOSS: 40.97589562202914\n",
      "EPOCH: 24406 LOSS: 40.97589420673941\n",
      "EPOCH: 24407 LOSS: 40.975892791542286\n",
      "EPOCH: 24408 LOSS: 40.97589137643775\n",
      "EPOCH: 24409 LOSS: 40.9758899614258\n",
      "EPOCH: 24410 LOSS: 40.97588854650642\n",
      "EPOCH: 24411 LOSS: 40.975887131679606\n",
      "EPOCH: 24412 LOSS: 40.97588571694533\n",
      "EPOCH: 24413 LOSS: 40.97588430230359\n",
      "EPOCH: 24414 LOSS: 40.975882887754366\n",
      "EPOCH: 24415 LOSS: 40.97588147329766\n",
      "EPOCH: 24416 LOSS: 40.97588005893347\n",
      "EPOCH: 24417 LOSS: 40.97587864466175\n",
      "EPOCH: 24418 LOSS: 40.97587723048253\n",
      "EPOCH: 24419 LOSS: 40.97587581639576\n",
      "EPOCH: 24420 LOSS: 40.97587440240146\n",
      "EPOCH: 24421 LOSS: 40.97587298849959\n",
      "EPOCH: 24422 LOSS: 40.97587157469017\n",
      "EPOCH: 24423 LOSS: 40.97587016097317\n",
      "EPOCH: 24424 LOSS: 40.975868747348564\n",
      "EPOCH: 24425 LOSS: 40.97586733381639\n",
      "EPOCH: 24426 LOSS: 40.97586592037656\n",
      "EPOCH: 24427 LOSS: 40.97586450702916\n",
      "EPOCH: 24428 LOSS: 40.975863093774095\n",
      "EPOCH: 24429 LOSS: 40.97586168061139\n",
      "EPOCH: 24430 LOSS: 40.97586026754103\n",
      "EPOCH: 24431 LOSS: 40.975858854563\n",
      "EPOCH: 24432 LOSS: 40.97585744167731\n",
      "EPOCH: 24433 LOSS: 40.97585602888391\n",
      "EPOCH: 24434 LOSS: 40.97585461618281\n",
      "EPOCH: 24435 LOSS: 40.975853203574\n",
      "EPOCH: 24436 LOSS: 40.975851791057465\n",
      "EPOCH: 24437 LOSS: 40.97585037863321\n",
      "EPOCH: 24438 LOSS: 40.9758489663012\n",
      "EPOCH: 24439 LOSS: 40.975847554061446\n",
      "EPOCH: 24440 LOSS: 40.97584614191389\n",
      "EPOCH: 24441 LOSS: 40.97584472985858\n",
      "EPOCH: 24442 LOSS: 40.975843317895475\n",
      "EPOCH: 24443 LOSS: 40.975841906024556\n",
      "EPOCH: 24444 LOSS: 40.97584049424583\n",
      "EPOCH: 24445 LOSS: 40.97583908255929\n",
      "EPOCH: 24446 LOSS: 40.9758376709649\n",
      "EPOCH: 24447 LOSS: 40.975836259462675\n",
      "EPOCH: 24448 LOSS: 40.97583484805258\n",
      "EPOCH: 24449 LOSS: 40.97583343673463\n",
      "EPOCH: 24450 LOSS: 40.975832025508794\n",
      "EPOCH: 24451 LOSS: 40.975830614375056\n",
      "EPOCH: 24452 LOSS: 40.97582920333343\n",
      "EPOCH: 24453 LOSS: 40.97582779238388\n",
      "EPOCH: 24454 LOSS: 40.9758263815264\n",
      "EPOCH: 24455 LOSS: 40.97582497076099\n",
      "EPOCH: 24456 LOSS: 40.97582356008764\n",
      "EPOCH: 24457 LOSS: 40.97582214950633\n",
      "EPOCH: 24458 LOSS: 40.97582073901703\n",
      "EPOCH: 24459 LOSS: 40.975819328619764\n",
      "EPOCH: 24460 LOSS: 40.975817918314505\n",
      "EPOCH: 24461 LOSS: 40.975816508101246\n",
      "EPOCH: 24462 LOSS: 40.975815097979954\n",
      "EPOCH: 24463 LOSS: 40.975813687950655\n",
      "EPOCH: 24464 LOSS: 40.975812278013315\n",
      "EPOCH: 24465 LOSS: 40.97581086816791\n",
      "EPOCH: 24466 LOSS: 40.97580945841446\n",
      "EPOCH: 24467 LOSS: 40.975808048752924\n",
      "EPOCH: 24468 LOSS: 40.975806639183325\n",
      "EPOCH: 24469 LOSS: 40.97580522970564\n",
      "EPOCH: 24470 LOSS: 40.975803820319825\n",
      "EPOCH: 24471 LOSS: 40.9758024110259\n",
      "EPOCH: 24472 LOSS: 40.97580100182384\n",
      "EPOCH: 24473 LOSS: 40.97579959271367\n",
      "EPOCH: 24474 LOSS: 40.97579818369533\n",
      "EPOCH: 24475 LOSS: 40.97579677476883\n",
      "EPOCH: 24476 LOSS: 40.97579536593417\n",
      "EPOCH: 24477 LOSS: 40.9757939571913\n",
      "EPOCH: 24478 LOSS: 40.97579254854026\n",
      "EPOCH: 24479 LOSS: 40.975791139981034\n",
      "EPOCH: 24480 LOSS: 40.97578973151355\n",
      "EPOCH: 24481 LOSS: 40.97578832313786\n",
      "EPOCH: 24482 LOSS: 40.975786914853934\n",
      "EPOCH: 24483 LOSS: 40.975785506661744\n",
      "EPOCH: 24484 LOSS: 40.9757840985613\n",
      "EPOCH: 24485 LOSS: 40.97578269055259\n",
      "EPOCH: 24486 LOSS: 40.975781282635594\n",
      "EPOCH: 24487 LOSS: 40.9757798748103\n",
      "EPOCH: 24488 LOSS: 40.97577846707669\n",
      "EPOCH: 24489 LOSS: 40.97577705943478\n",
      "EPOCH: 24490 LOSS: 40.97577565188454\n",
      "EPOCH: 24491 LOSS: 40.97577424442594\n",
      "EPOCH: 24492 LOSS: 40.975772837059026\n",
      "EPOCH: 24493 LOSS: 40.97577142978372\n",
      "EPOCH: 24494 LOSS: 40.97577002260006\n",
      "EPOCH: 24495 LOSS: 40.97576861550801\n",
      "EPOCH: 24496 LOSS: 40.97576720850756\n",
      "EPOCH: 24497 LOSS: 40.97576580159871\n",
      "EPOCH: 24498 LOSS: 40.97576439478145\n",
      "EPOCH: 24499 LOSS: 40.97576298805575\n",
      "EPOCH: 24500 LOSS: 40.97576158142161\n",
      "EPOCH: 24501 LOSS: 40.97576017487902\n",
      "EPOCH: 24502 LOSS: 40.975758768427966\n",
      "EPOCH: 24503 LOSS: 40.97575736206845\n",
      "EPOCH: 24504 LOSS: 40.97575595580045\n",
      "EPOCH: 24505 LOSS: 40.97575454962396\n",
      "EPOCH: 24506 LOSS: 40.97575314353895\n",
      "EPOCH: 24507 LOSS: 40.97575173754542\n",
      "EPOCH: 24508 LOSS: 40.975750331643376\n",
      "EPOCH: 24509 LOSS: 40.97574892583278\n",
      "EPOCH: 24510 LOSS: 40.97574752011365\n",
      "EPOCH: 24511 LOSS: 40.97574611448596\n",
      "EPOCH: 24512 LOSS: 40.97574470894966\n",
      "EPOCH: 24513 LOSS: 40.975743303504814\n",
      "EPOCH: 24514 LOSS: 40.97574189815136\n",
      "EPOCH: 24515 LOSS: 40.975740492889315\n",
      "EPOCH: 24516 LOSS: 40.97573908771864\n",
      "EPOCH: 24517 LOSS: 40.97573768263933\n",
      "EPOCH: 24518 LOSS: 40.97573627765137\n",
      "EPOCH: 24519 LOSS: 40.975734872754785\n",
      "EPOCH: 24520 LOSS: 40.97573346794953\n",
      "EPOCH: 24521 LOSS: 40.97573206323561\n",
      "EPOCH: 24522 LOSS: 40.975730658613\n",
      "EPOCH: 24523 LOSS: 40.9757292540817\n",
      "EPOCH: 24524 LOSS: 40.975727849641686\n",
      "EPOCH: 24525 LOSS: 40.97572644529294\n",
      "EPOCH: 24526 LOSS: 40.975725041035496\n",
      "EPOCH: 24527 LOSS: 40.9757236368693\n",
      "EPOCH: 24528 LOSS: 40.975722232794354\n",
      "EPOCH: 24529 LOSS: 40.975720828810644\n",
      "EPOCH: 24530 LOSS: 40.97571942491817\n",
      "EPOCH: 24531 LOSS: 40.975718021116904\n",
      "EPOCH: 24532 LOSS: 40.975716617406846\n",
      "EPOCH: 24533 LOSS: 40.97571521378798\n",
      "EPOCH: 24534 LOSS: 40.97571381026031\n",
      "EPOCH: 24535 LOSS: 40.9757124068238\n",
      "EPOCH: 24536 LOSS: 40.97571100347845\n",
      "EPOCH: 24537 LOSS: 40.97570960022426\n",
      "EPOCH: 24538 LOSS: 40.975708197061216\n",
      "EPOCH: 24539 LOSS: 40.975706793989275\n",
      "EPOCH: 24540 LOSS: 40.97570539100848\n",
      "EPOCH: 24541 LOSS: 40.97570398811878\n",
      "EPOCH: 24542 LOSS: 40.97570258532017\n",
      "EPOCH: 24543 LOSS: 40.975701182612646\n",
      "EPOCH: 24544 LOSS: 40.975699779996184\n",
      "EPOCH: 24545 LOSS: 40.9756983774708\n",
      "EPOCH: 24546 LOSS: 40.975696975036456\n",
      "EPOCH: 24547 LOSS: 40.97569557269317\n",
      "EPOCH: 24548 LOSS: 40.97569417044089\n",
      "EPOCH: 24549 LOSS: 40.97569276827963\n",
      "EPOCH: 24550 LOSS: 40.9756913662094\n",
      "EPOCH: 24551 LOSS: 40.975689964230156\n",
      "EPOCH: 24552 LOSS: 40.97568856234187\n",
      "EPOCH: 24553 LOSS: 40.975687160544595\n",
      "EPOCH: 24554 LOSS: 40.97568575883827\n",
      "EPOCH: 24555 LOSS: 40.97568435722289\n",
      "EPOCH: 24556 LOSS: 40.97568295569845\n",
      "EPOCH: 24557 LOSS: 40.97568155426494\n",
      "EPOCH: 24558 LOSS: 40.97568015292235\n",
      "EPOCH: 24559 LOSS: 40.97567875167067\n",
      "EPOCH: 24560 LOSS: 40.97567735050988\n",
      "EPOCH: 24561 LOSS: 40.97567594943999\n",
      "EPOCH: 24562 LOSS: 40.97567454846097\n",
      "EPOCH: 24563 LOSS: 40.975673147572806\n",
      "EPOCH: 24564 LOSS: 40.9756717467755\n",
      "EPOCH: 24565 LOSS: 40.97567034606904\n",
      "EPOCH: 24566 LOSS: 40.97566894545339\n",
      "EPOCH: 24567 LOSS: 40.97566754492857\n",
      "EPOCH: 24568 LOSS: 40.975666144494575\n",
      "EPOCH: 24569 LOSS: 40.975664744151345\n",
      "EPOCH: 24570 LOSS: 40.97566334389894\n",
      "EPOCH: 24571 LOSS: 40.97566194373728\n",
      "EPOCH: 24572 LOSS: 40.97566054366639\n",
      "EPOCH: 24573 LOSS: 40.975659143686265\n",
      "EPOCH: 24574 LOSS: 40.97565774379688\n",
      "EPOCH: 24575 LOSS: 40.97565634399821\n",
      "EPOCH: 24576 LOSS: 40.97565494429027\n",
      "EPOCH: 24577 LOSS: 40.97565354467305\n",
      "EPOCH: 24578 LOSS: 40.97565214514652\n",
      "EPOCH: 24579 LOSS: 40.975650745710674\n",
      "EPOCH: 24580 LOSS: 40.975649346365515\n",
      "EPOCH: 24581 LOSS: 40.97564794711103\n",
      "EPOCH: 24582 LOSS: 40.97564654794718\n",
      "EPOCH: 24583 LOSS: 40.975645148873966\n",
      "EPOCH: 24584 LOSS: 40.9756437498914\n",
      "EPOCH: 24585 LOSS: 40.975642350999436\n",
      "EPOCH: 24586 LOSS: 40.975640952198106\n",
      "EPOCH: 24587 LOSS: 40.97563955348738\n",
      "EPOCH: 24588 LOSS: 40.97563815486723\n",
      "EPOCH: 24589 LOSS: 40.975636756337664\n",
      "EPOCH: 24590 LOSS: 40.97563535789867\n",
      "EPOCH: 24591 LOSS: 40.975633959550194\n",
      "EPOCH: 24592 LOSS: 40.97563256129231\n",
      "EPOCH: 24593 LOSS: 40.975631163124945\n",
      "EPOCH: 24594 LOSS: 40.975629765048105\n",
      "EPOCH: 24595 LOSS: 40.975628367061766\n",
      "EPOCH: 24596 LOSS: 40.97562696916593\n",
      "EPOCH: 24597 LOSS: 40.97562557136058\n",
      "EPOCH: 24598 LOSS: 40.97562417364573\n",
      "EPOCH: 24599 LOSS: 40.975622776021325\n",
      "EPOCH: 24600 LOSS: 40.97562137848739\n",
      "EPOCH: 24601 LOSS: 40.97561998104389\n",
      "EPOCH: 24602 LOSS: 40.975618583690824\n",
      "EPOCH: 24603 LOSS: 40.97561718642822\n",
      "EPOCH: 24604 LOSS: 40.975615789256\n",
      "EPOCH: 24605 LOSS: 40.97561439217419\n",
      "EPOCH: 24606 LOSS: 40.97561299518276\n",
      "EPOCH: 24607 LOSS: 40.97561159828171\n",
      "EPOCH: 24608 LOSS: 40.975610201471035\n",
      "EPOCH: 24609 LOSS: 40.975608804750735\n",
      "EPOCH: 24610 LOSS: 40.97560740812076\n",
      "EPOCH: 24611 LOSS: 40.97560601158112\n",
      "EPOCH: 24612 LOSS: 40.97560461513182\n",
      "EPOCH: 24613 LOSS: 40.97560321877283\n",
      "EPOCH: 24614 LOSS: 40.97560182250416\n",
      "EPOCH: 24615 LOSS: 40.97560042632576\n",
      "EPOCH: 24616 LOSS: 40.97559903023766\n",
      "EPOCH: 24617 LOSS: 40.975597634239826\n",
      "EPOCH: 24618 LOSS: 40.97559623833225\n",
      "EPOCH: 24619 LOSS: 40.97559484251492\n",
      "EPOCH: 24620 LOSS: 40.97559344678784\n",
      "EPOCH: 24621 LOSS: 40.97559205115098\n",
      "EPOCH: 24622 LOSS: 40.97559065560433\n",
      "EPOCH: 24623 LOSS: 40.975589260147906\n",
      "EPOCH: 24624 LOSS: 40.97558786478166\n",
      "EPOCH: 24625 LOSS: 40.975586469505586\n",
      "EPOCH: 24626 LOSS: 40.975585074319724\n",
      "EPOCH: 24627 LOSS: 40.975583679224\n",
      "EPOCH: 24628 LOSS: 40.97558228421843\n",
      "EPOCH: 24629 LOSS: 40.975580889303\n",
      "EPOCH: 24630 LOSS: 40.97557949447771\n",
      "EPOCH: 24631 LOSS: 40.97557809974252\n",
      "EPOCH: 24632 LOSS: 40.97557670509746\n",
      "EPOCH: 24633 LOSS: 40.97557531054247\n",
      "EPOCH: 24634 LOSS: 40.97557391607759\n",
      "EPOCH: 24635 LOSS: 40.97557252170277\n",
      "EPOCH: 24636 LOSS: 40.97557112741802\n",
      "EPOCH: 24637 LOSS: 40.97556973322334\n",
      "EPOCH: 24638 LOSS: 40.975568339118695\n",
      "EPOCH: 24639 LOSS: 40.97556694510406\n",
      "EPOCH: 24640 LOSS: 40.97556555117947\n",
      "EPOCH: 24641 LOSS: 40.97556415734488\n",
      "EPOCH: 24642 LOSS: 40.97556276360028\n",
      "EPOCH: 24643 LOSS: 40.97556136994569\n",
      "EPOCH: 24644 LOSS: 40.975559976381064\n",
      "EPOCH: 24645 LOSS: 40.97555858290641\n",
      "EPOCH: 24646 LOSS: 40.975557189521716\n",
      "EPOCH: 24647 LOSS: 40.97555579622695\n",
      "EPOCH: 24648 LOSS: 40.97555440302212\n",
      "EPOCH: 24649 LOSS: 40.97555300990724\n",
      "EPOCH: 24650 LOSS: 40.97555161688225\n",
      "EPOCH: 24651 LOSS: 40.97555022394717\n",
      "EPOCH: 24652 LOSS: 40.975548831101975\n",
      "EPOCH: 24653 LOSS: 40.97554743834665\n",
      "EPOCH: 24654 LOSS: 40.97554604568121\n",
      "EPOCH: 24655 LOSS: 40.97554465310563\n",
      "EPOCH: 24656 LOSS: 40.975543260619894\n",
      "EPOCH: 24657 LOSS: 40.97554186822398\n",
      "EPOCH: 24658 LOSS: 40.97554047591791\n",
      "EPOCH: 24659 LOSS: 40.975539083701634\n",
      "EPOCH: 24660 LOSS: 40.97553769157519\n",
      "EPOCH: 24661 LOSS: 40.975536299538525\n",
      "EPOCH: 24662 LOSS: 40.97553490759163\n",
      "EPOCH: 24663 LOSS: 40.97553351573452\n",
      "EPOCH: 24664 LOSS: 40.97553212396717\n",
      "EPOCH: 24665 LOSS: 40.97553073228958\n",
      "EPOCH: 24666 LOSS: 40.97552934070171\n",
      "EPOCH: 24667 LOSS: 40.97552794920358\n",
      "EPOCH: 24668 LOSS: 40.97552655779516\n",
      "EPOCH: 24669 LOSS: 40.97552516647646\n",
      "EPOCH: 24670 LOSS: 40.97552377524745\n",
      "EPOCH: 24671 LOSS: 40.97552238410813\n",
      "EPOCH: 24672 LOSS: 40.97552099305845\n",
      "EPOCH: 24673 LOSS: 40.975519602098466\n",
      "EPOCH: 24674 LOSS: 40.97551821122813\n",
      "EPOCH: 24675 LOSS: 40.97551682044743\n",
      "EPOCH: 24676 LOSS: 40.975515429756356\n",
      "EPOCH: 24677 LOSS: 40.97551403915492\n",
      "EPOCH: 24678 LOSS: 40.97551264864308\n",
      "EPOCH: 24679 LOSS: 40.975511258220834\n",
      "EPOCH: 24680 LOSS: 40.97550986788818\n",
      "EPOCH: 24681 LOSS: 40.975508477645114\n",
      "EPOCH: 24682 LOSS: 40.97550708749161\n",
      "EPOCH: 24683 LOSS: 40.97550569742765\n",
      "EPOCH: 24684 LOSS: 40.975504307453235\n",
      "EPOCH: 24685 LOSS: 40.97550291756838\n",
      "EPOCH: 24686 LOSS: 40.97550152777302\n",
      "EPOCH: 24687 LOSS: 40.97550013806718\n",
      "EPOCH: 24688 LOSS: 40.97549874845083\n",
      "EPOCH: 24689 LOSS: 40.975497358923995\n",
      "EPOCH: 24690 LOSS: 40.97549596948662\n",
      "EPOCH: 24691 LOSS: 40.97549458013872\n",
      "EPOCH: 24692 LOSS: 40.975493190880286\n",
      "EPOCH: 24693 LOSS: 40.9754918017113\n",
      "EPOCH: 24694 LOSS: 40.97549041263173\n",
      "EPOCH: 24695 LOSS: 40.9754890236416\n",
      "EPOCH: 24696 LOSS: 40.97548763474089\n",
      "EPOCH: 24697 LOSS: 40.975486245929574\n",
      "EPOCH: 24698 LOSS: 40.97548485720765\n",
      "EPOCH: 24699 LOSS: 40.97548346857511\n",
      "EPOCH: 24700 LOSS: 40.97548208003194\n",
      "EPOCH: 24701 LOSS: 40.97548069157814\n",
      "EPOCH: 24702 LOSS: 40.97547930321369\n",
      "EPOCH: 24703 LOSS: 40.97547791493858\n",
      "EPOCH: 24704 LOSS: 40.975476526752786\n",
      "EPOCH: 24705 LOSS: 40.97547513865633\n",
      "EPOCH: 24706 LOSS: 40.975473750649165\n",
      "EPOCH: 24707 LOSS: 40.975472362731296\n",
      "EPOCH: 24708 LOSS: 40.97547097490272\n",
      "EPOCH: 24709 LOSS: 40.975469587163424\n",
      "EPOCH: 24710 LOSS: 40.9754681995134\n",
      "EPOCH: 24711 LOSS: 40.975466811952614\n",
      "EPOCH: 24712 LOSS: 40.97546542448108\n",
      "EPOCH: 24713 LOSS: 40.975464037098774\n",
      "EPOCH: 24714 LOSS: 40.975462649805685\n",
      "EPOCH: 24715 LOSS: 40.97546126260181\n",
      "EPOCH: 24716 LOSS: 40.97545987548713\n",
      "EPOCH: 24717 LOSS: 40.97545848846166\n",
      "EPOCH: 24718 LOSS: 40.97545710152535\n",
      "EPOCH: 24719 LOSS: 40.97545571467822\n",
      "EPOCH: 24720 LOSS: 40.97545432792023\n",
      "EPOCH: 24721 LOSS: 40.97545294125139\n",
      "EPOCH: 24722 LOSS: 40.97545155467169\n",
      "EPOCH: 24723 LOSS: 40.97545016818111\n",
      "EPOCH: 24724 LOSS: 40.97544878177966\n",
      "EPOCH: 24725 LOSS: 40.97544739546729\n",
      "EPOCH: 24726 LOSS: 40.97544600924404\n",
      "EPOCH: 24727 LOSS: 40.97544462310984\n",
      "EPOCH: 24728 LOSS: 40.97544323706474\n",
      "EPOCH: 24729 LOSS: 40.9754418511087\n",
      "EPOCH: 24730 LOSS: 40.97544046524168\n",
      "EPOCH: 24731 LOSS: 40.97543907946373\n",
      "EPOCH: 24732 LOSS: 40.97543769377479\n",
      "EPOCH: 24733 LOSS: 40.97543630817488\n",
      "EPOCH: 24734 LOSS: 40.97543492266395\n",
      "EPOCH: 24735 LOSS: 40.975433537242054\n",
      "EPOCH: 24736 LOSS: 40.975432151909125\n",
      "EPOCH: 24737 LOSS: 40.975430766665184\n",
      "EPOCH: 24738 LOSS: 40.97542938151019\n",
      "EPOCH: 24739 LOSS: 40.97542799644416\n",
      "EPOCH: 24740 LOSS: 40.975426611467064\n",
      "EPOCH: 24741 LOSS: 40.97542522657891\n",
      "EPOCH: 24742 LOSS: 40.97542384177968\n",
      "EPOCH: 24743 LOSS: 40.97542245706935\n",
      "EPOCH: 24744 LOSS: 40.97542107244793\n",
      "EPOCH: 24745 LOSS: 40.97541968791539\n",
      "EPOCH: 24746 LOSS: 40.97541830347173\n",
      "EPOCH: 24747 LOSS: 40.97541691911694\n",
      "EPOCH: 24748 LOSS: 40.97541553485101\n",
      "EPOCH: 24749 LOSS: 40.97541415067393\n",
      "EPOCH: 24750 LOSS: 40.97541276658567\n",
      "EPOCH: 24751 LOSS: 40.975411382586245\n",
      "EPOCH: 24752 LOSS: 40.975409998675644\n",
      "EPOCH: 24753 LOSS: 40.975408614853826\n",
      "EPOCH: 24754 LOSS: 40.97540723112082\n",
      "EPOCH: 24755 LOSS: 40.975405847476594\n",
      "EPOCH: 24756 LOSS: 40.97540446392114\n",
      "EPOCH: 24757 LOSS: 40.97540308045443\n",
      "EPOCH: 24758 LOSS: 40.97540169707649\n",
      "EPOCH: 24759 LOSS: 40.975400313787276\n",
      "EPOCH: 24760 LOSS: 40.97539893058681\n",
      "EPOCH: 24761 LOSS: 40.97539754747505\n",
      "EPOCH: 24762 LOSS: 40.97539616445201\n",
      "EPOCH: 24763 LOSS: 40.97539478151765\n",
      "EPOCH: 24764 LOSS: 40.97539339867199\n",
      "EPOCH: 24765 LOSS: 40.975392015915\n",
      "EPOCH: 24766 LOSS: 40.97539063324668\n",
      "EPOCH: 24767 LOSS: 40.97538925066702\n",
      "EPOCH: 24768 LOSS: 40.97538786817598\n",
      "EPOCH: 24769 LOSS: 40.97538648577358\n",
      "EPOCH: 24770 LOSS: 40.97538510345982\n",
      "EPOCH: 24771 LOSS: 40.97538372123466\n",
      "EPOCH: 24772 LOSS: 40.97538233909812\n",
      "EPOCH: 24773 LOSS: 40.975380957050156\n",
      "EPOCH: 24774 LOSS: 40.97537957509077\n",
      "EPOCH: 24775 LOSS: 40.97537819321995\n",
      "EPOCH: 24776 LOSS: 40.9753768114377\n",
      "EPOCH: 24777 LOSS: 40.975375429744\n",
      "EPOCH: 24778 LOSS: 40.97537404813883\n",
      "EPOCH: 24779 LOSS: 40.97537266662219\n",
      "EPOCH: 24780 LOSS: 40.97537128519404\n",
      "EPOCH: 24781 LOSS: 40.97536990385445\n",
      "EPOCH: 24782 LOSS: 40.975368522603326\n",
      "EPOCH: 24783 LOSS: 40.975367141440685\n",
      "EPOCH: 24784 LOSS: 40.97536576036653\n",
      "EPOCH: 24785 LOSS: 40.97536437938083\n",
      "EPOCH: 24786 LOSS: 40.97536299848357\n",
      "EPOCH: 24787 LOSS: 40.975361617674764\n",
      "EPOCH: 24788 LOSS: 40.97536023695439\n",
      "EPOCH: 24789 LOSS: 40.975358856322444\n",
      "EPOCH: 24790 LOSS: 40.97535747577889\n",
      "EPOCH: 24791 LOSS: 40.975356095323754\n",
      "EPOCH: 24792 LOSS: 40.97535471495701\n",
      "EPOCH: 24793 LOSS: 40.975353334678616\n",
      "EPOCH: 24794 LOSS: 40.97535195448863\n",
      "EPOCH: 24795 LOSS: 40.975350574386965\n",
      "EPOCH: 24796 LOSS: 40.97534919437366\n",
      "EPOCH: 24797 LOSS: 40.975347814448696\n",
      "EPOCH: 24798 LOSS: 40.975346434612064\n",
      "EPOCH: 24799 LOSS: 40.97534505486374\n",
      "EPOCH: 24800 LOSS: 40.97534367520372\n",
      "EPOCH: 24801 LOSS: 40.97534229563199\n",
      "EPOCH: 24802 LOSS: 40.97534091614855\n",
      "EPOCH: 24803 LOSS: 40.97533953675337\n",
      "EPOCH: 24804 LOSS: 40.975338157446465\n",
      "EPOCH: 24805 LOSS: 40.97533677822782\n",
      "EPOCH: 24806 LOSS: 40.97533539909739\n",
      "EPOCH: 24807 LOSS: 40.97533402005521\n",
      "EPOCH: 24808 LOSS: 40.97533264110125\n",
      "EPOCH: 24809 LOSS: 40.97533126223547\n",
      "EPOCH: 24810 LOSS: 40.975329883457924\n",
      "EPOCH: 24811 LOSS: 40.975328504768555\n",
      "EPOCH: 24812 LOSS: 40.975327126167365\n",
      "EPOCH: 24813 LOSS: 40.97532574765433\n",
      "EPOCH: 24814 LOSS: 40.97532436922946\n",
      "EPOCH: 24815 LOSS: 40.97532299089275\n",
      "EPOCH: 24816 LOSS: 40.97532161264415\n",
      "EPOCH: 24817 LOSS: 40.97532023448369\n",
      "EPOCH: 24818 LOSS: 40.975318856411334\n",
      "EPOCH: 24819 LOSS: 40.975317478427094\n",
      "EPOCH: 24820 LOSS: 40.97531610053095\n",
      "EPOCH: 24821 LOSS: 40.975314722722885\n",
      "EPOCH: 24822 LOSS: 40.97531334500286\n",
      "EPOCH: 24823 LOSS: 40.97531196737094\n",
      "EPOCH: 24824 LOSS: 40.97531058982706\n",
      "EPOCH: 24825 LOSS: 40.975309212371215\n",
      "EPOCH: 24826 LOSS: 40.975307835003385\n",
      "EPOCH: 24827 LOSS: 40.975306457723605\n",
      "EPOCH: 24828 LOSS: 40.97530508053181\n",
      "EPOCH: 24829 LOSS: 40.97530370342802\n",
      "EPOCH: 24830 LOSS: 40.97530232641222\n",
      "EPOCH: 24831 LOSS: 40.97530094948439\n",
      "EPOCH: 24832 LOSS: 40.975299572644545\n",
      "EPOCH: 24833 LOSS: 40.97529819589265\n",
      "EPOCH: 24834 LOSS: 40.975296819228674\n",
      "EPOCH: 24835 LOSS: 40.97529544265265\n",
      "EPOCH: 24836 LOSS: 40.97529406616455\n",
      "EPOCH: 24837 LOSS: 40.975292689764366\n",
      "EPOCH: 24838 LOSS: 40.9752913134521\n",
      "EPOCH: 24839 LOSS: 40.9752899372277\n",
      "EPOCH: 24840 LOSS: 40.975288561091205\n",
      "EPOCH: 24841 LOSS: 40.975287185042575\n",
      "EPOCH: 24842 LOSS: 40.9752858090818\n",
      "EPOCH: 24843 LOSS: 40.975284433208884\n",
      "EPOCH: 24844 LOSS: 40.975283057423795\n",
      "EPOCH: 24845 LOSS: 40.97528168172655\n",
      "EPOCH: 24846 LOSS: 40.975280306117114\n",
      "EPOCH: 24847 LOSS: 40.97527893059549\n",
      "EPOCH: 24848 LOSS: 40.97527755516167\n",
      "EPOCH: 24849 LOSS: 40.97527617981563\n",
      "EPOCH: 24850 LOSS: 40.97527480455736\n",
      "EPOCH: 24851 LOSS: 40.975273429386874\n",
      "EPOCH: 24852 LOSS: 40.97527205430415\n",
      "EPOCH: 24853 LOSS: 40.97527067930916\n",
      "EPOCH: 24854 LOSS: 40.97526930440189\n",
      "EPOCH: 24855 LOSS: 40.97526792958238\n",
      "EPOCH: 24856 LOSS: 40.975266554850535\n",
      "EPOCH: 24857 LOSS: 40.97526518020644\n",
      "EPOCH: 24858 LOSS: 40.97526380565003\n",
      "EPOCH: 24859 LOSS: 40.97526243118131\n",
      "EPOCH: 24860 LOSS: 40.97526105680022\n",
      "EPOCH: 24861 LOSS: 40.97525968250682\n",
      "EPOCH: 24862 LOSS: 40.975258308301065\n",
      "EPOCH: 24863 LOSS: 40.97525693418296\n",
      "EPOCH: 24864 LOSS: 40.975255560152476\n",
      "EPOCH: 24865 LOSS: 40.97525418620962\n",
      "EPOCH: 24866 LOSS: 40.97525281235437\n",
      "EPOCH: 24867 LOSS: 40.97525143858671\n",
      "EPOCH: 24868 LOSS: 40.97525006490666\n",
      "EPOCH: 24869 LOSS: 40.97524869131418\n",
      "EPOCH: 24870 LOSS: 40.97524731780926\n",
      "EPOCH: 24871 LOSS: 40.9752459443919\n",
      "EPOCH: 24872 LOSS: 40.97524457106209\n",
      "EPOCH: 24873 LOSS: 40.9752431978198\n",
      "EPOCH: 24874 LOSS: 40.97524182466505\n",
      "EPOCH: 24875 LOSS: 40.97524045159783\n",
      "EPOCH: 24876 LOSS: 40.9752390786181\n",
      "EPOCH: 24877 LOSS: 40.97523770572586\n",
      "EPOCH: 24878 LOSS: 40.975236332921114\n",
      "EPOCH: 24879 LOSS: 40.975234960203814\n",
      "EPOCH: 24880 LOSS: 40.97523358757401\n",
      "EPOCH: 24881 LOSS: 40.97523221503165\n",
      "EPOCH: 24882 LOSS: 40.97523084257672\n",
      "EPOCH: 24883 LOSS: 40.97522947020924\n",
      "EPOCH: 24884 LOSS: 40.975228097929175\n",
      "EPOCH: 24885 LOSS: 40.975226725736505\n",
      "EPOCH: 24886 LOSS: 40.975225353631245\n",
      "EPOCH: 24887 LOSS: 40.97522398161338\n",
      "EPOCH: 24888 LOSS: 40.9752226096829\n",
      "EPOCH: 24889 LOSS: 40.975221237839776\n",
      "EPOCH: 24890 LOSS: 40.975219866084025\n",
      "EPOCH: 24891 LOSS: 40.97521849441561\n",
      "EPOCH: 24892 LOSS: 40.97521712283453\n",
      "EPOCH: 24893 LOSS: 40.97521575134078\n",
      "EPOCH: 24894 LOSS: 40.975214379934364\n",
      "EPOCH: 24895 LOSS: 40.975213008615235\n",
      "EPOCH: 24896 LOSS: 40.9752116373834\n",
      "EPOCH: 24897 LOSS: 40.97521026623886\n",
      "EPOCH: 24898 LOSS: 40.975208895181595\n",
      "EPOCH: 24899 LOSS: 40.9752075242116\n",
      "EPOCH: 24900 LOSS: 40.975206153328855\n",
      "EPOCH: 24901 LOSS: 40.97520478253335\n",
      "EPOCH: 24902 LOSS: 40.97520341182506\n",
      "EPOCH: 24903 LOSS: 40.975202041204035\n",
      "EPOCH: 24904 LOSS: 40.97520067067019\n",
      "EPOCH: 24905 LOSS: 40.97519930022355\n",
      "EPOCH: 24906 LOSS: 40.97519792986413\n",
      "EPOCH: 24907 LOSS: 40.97519655959187\n",
      "EPOCH: 24908 LOSS: 40.97519518940678\n",
      "EPOCH: 24909 LOSS: 40.975193819308856\n",
      "EPOCH: 24910 LOSS: 40.97519244929808\n",
      "EPOCH: 24911 LOSS: 40.97519107937445\n",
      "EPOCH: 24912 LOSS: 40.97518970953793\n",
      "EPOCH: 24913 LOSS: 40.97518833978854\n",
      "EPOCH: 24914 LOSS: 40.97518697012627\n",
      "EPOCH: 24915 LOSS: 40.975185600551086\n",
      "EPOCH: 24916 LOSS: 40.975184231063004\n",
      "EPOCH: 24917 LOSS: 40.975182861661985\n",
      "EPOCH: 24918 LOSS: 40.97518149234804\n",
      "EPOCH: 24919 LOSS: 40.97518012312115\n",
      "EPOCH: 24920 LOSS: 40.9751787539813\n",
      "EPOCH: 24921 LOSS: 40.975177384928486\n",
      "EPOCH: 24922 LOSS: 40.9751760159627\n",
      "EPOCH: 24923 LOSS: 40.975174647083946\n",
      "EPOCH: 24924 LOSS: 40.97517327829218\n",
      "EPOCH: 24925 LOSS: 40.97517190958742\n",
      "EPOCH: 24926 LOSS: 40.97517054096963\n",
      "EPOCH: 24927 LOSS: 40.975169172438825\n",
      "EPOCH: 24928 LOSS: 40.97516780399498\n",
      "EPOCH: 24929 LOSS: 40.97516643563808\n",
      "EPOCH: 24930 LOSS: 40.975165067368124\n",
      "EPOCH: 24931 LOSS: 40.97516369918512\n",
      "EPOCH: 24932 LOSS: 40.97516233108902\n",
      "EPOCH: 24933 LOSS: 40.97516096307983\n",
      "EPOCH: 24934 LOSS: 40.97515959515755\n",
      "EPOCH: 24935 LOSS: 40.975158227322154\n",
      "EPOCH: 24936 LOSS: 40.97515685957366\n",
      "EPOCH: 24937 LOSS: 40.975155491912\n",
      "EPOCH: 24938 LOSS: 40.97515412433722\n",
      "EPOCH: 24939 LOSS: 40.9751527568493\n",
      "EPOCH: 24940 LOSS: 40.9751513894482\n",
      "EPOCH: 24941 LOSS: 40.97515002213394\n",
      "EPOCH: 24942 LOSS: 40.97514865490649\n",
      "EPOCH: 24943 LOSS: 40.97514728776585\n",
      "EPOCH: 24944 LOSS: 40.97514592071201\n",
      "EPOCH: 24945 LOSS: 40.97514455374496\n",
      "EPOCH: 24946 LOSS: 40.975143186864685\n",
      "EPOCH: 24947 LOSS: 40.97514182007117\n",
      "EPOCH: 24948 LOSS: 40.975140453364425\n",
      "EPOCH: 24949 LOSS: 40.97513908674441\n",
      "EPOCH: 24950 LOSS: 40.97513772021115\n",
      "EPOCH: 24951 LOSS: 40.9751363537646\n",
      "EPOCH: 24952 LOSS: 40.97513498740477\n",
      "EPOCH: 24953 LOSS: 40.975133621131654\n",
      "EPOCH: 24954 LOSS: 40.975132254945215\n",
      "EPOCH: 24955 LOSS: 40.97513088884547\n",
      "EPOCH: 24956 LOSS: 40.975129522832404\n",
      "EPOCH: 24957 LOSS: 40.975128156905996\n",
      "EPOCH: 24958 LOSS: 40.975126791066245\n",
      "EPOCH: 24959 LOSS: 40.975125425313124\n",
      "EPOCH: 24960 LOSS: 40.97512405964664\n",
      "EPOCH: 24961 LOSS: 40.97512269406678\n",
      "EPOCH: 24962 LOSS: 40.97512132857354\n",
      "EPOCH: 24963 LOSS: 40.9751199631669\n",
      "EPOCH: 24964 LOSS: 40.97511859784685\n",
      "EPOCH: 24965 LOSS: 40.97511723261337\n",
      "EPOCH: 24966 LOSS: 40.97511586746647\n",
      "EPOCH: 24967 LOSS: 40.97511450240613\n",
      "EPOCH: 24968 LOSS: 40.975113137432345\n",
      "EPOCH: 24969 LOSS: 40.97511177254509\n",
      "EPOCH: 24970 LOSS: 40.97511040774437\n",
      "EPOCH: 24971 LOSS: 40.97510904303016\n",
      "EPOCH: 24972 LOSS: 40.975107678402466\n",
      "EPOCH: 24973 LOSS: 40.97510631386129\n",
      "EPOCH: 24974 LOSS: 40.97510494940658\n",
      "EPOCH: 24975 LOSS: 40.975103585038354\n",
      "EPOCH: 24976 LOSS: 40.97510222075659\n",
      "EPOCH: 24977 LOSS: 40.97510085656128\n",
      "EPOCH: 24978 LOSS: 40.97509949245242\n",
      "EPOCH: 24979 LOSS: 40.975098128430005\n",
      "EPOCH: 24980 LOSS: 40.97509676449402\n",
      "EPOCH: 24981 LOSS: 40.975095400644456\n",
      "EPOCH: 24982 LOSS: 40.97509403688127\n",
      "EPOCH: 24983 LOSS: 40.97509267320451\n",
      "EPOCH: 24984 LOSS: 40.97509130961412\n",
      "EPOCH: 24985 LOSS: 40.97508994611011\n",
      "EPOCH: 24986 LOSS: 40.97508858269246\n",
      "EPOCH: 24987 LOSS: 40.97508721936117\n",
      "EPOCH: 24988 LOSS: 40.975085856116216\n",
      "EPOCH: 24989 LOSS: 40.975084492957606\n",
      "EPOCH: 24990 LOSS: 40.97508312988532\n",
      "EPOCH: 24991 LOSS: 40.97508176689934\n",
      "EPOCH: 24992 LOSS: 40.97508040399967\n",
      "EPOCH: 24993 LOSS: 40.97507904118629\n",
      "EPOCH: 24994 LOSS: 40.975077678459186\n",
      "EPOCH: 24995 LOSS: 40.97507631581836\n",
      "EPOCH: 24996 LOSS: 40.9750749532638\n",
      "EPOCH: 24997 LOSS: 40.9750735907955\n",
      "EPOCH: 24998 LOSS: 40.975072228413424\n",
      "EPOCH: 24999 LOSS: 40.97507086611759\n",
      "EPOCH: 25000 LOSS: 40.975069503907974\n",
      "EPOCH: 25001 LOSS: 40.97506814178457\n",
      "EPOCH: 25002 LOSS: 40.97506677974737\n",
      "EPOCH: 25003 LOSS: 40.97506541779637\n",
      "EPOCH: 25004 LOSS: 40.97506405593154\n",
      "EPOCH: 25005 LOSS: 40.97506269415287\n",
      "EPOCH: 25006 LOSS: 40.97506133246036\n",
      "EPOCH: 25007 LOSS: 40.97505997085402\n",
      "EPOCH: 25008 LOSS: 40.9750586093338\n",
      "EPOCH: 25009 LOSS: 40.97505724789973\n",
      "EPOCH: 25010 LOSS: 40.97505588655176\n",
      "EPOCH: 25011 LOSS: 40.975054525289906\n",
      "EPOCH: 25012 LOSS: 40.97505316411416\n",
      "EPOCH: 25013 LOSS: 40.9750518030245\n",
      "EPOCH: 25014 LOSS: 40.97505044202089\n",
      "EPOCH: 25015 LOSS: 40.97504908110338\n",
      "EPOCH: 25016 LOSS: 40.97504772027192\n",
      "EPOCH: 25017 LOSS: 40.9750463595265\n",
      "EPOCH: 25018 LOSS: 40.97504499886711\n",
      "EPOCH: 25019 LOSS: 40.97504363829376\n",
      "EPOCH: 25020 LOSS: 40.97504227780644\n",
      "EPOCH: 25021 LOSS: 40.9750409174051\n",
      "EPOCH: 25022 LOSS: 40.97503955708977\n",
      "EPOCH: 25023 LOSS: 40.97503819686044\n",
      "EPOCH: 25024 LOSS: 40.97503683671707\n",
      "EPOCH: 25025 LOSS: 40.975035476659656\n",
      "EPOCH: 25026 LOSS: 40.975034116688214\n",
      "EPOCH: 25027 LOSS: 40.975032756802705\n",
      "EPOCH: 25028 LOSS: 40.97503139700314\n",
      "EPOCH: 25029 LOSS: 40.97503003728949\n",
      "EPOCH: 25030 LOSS: 40.975028677661776\n",
      "EPOCH: 25031 LOSS: 40.97502731811995\n",
      "EPOCH: 25032 LOSS: 40.97502595866402\n",
      "EPOCH: 25033 LOSS: 40.97502459929399\n",
      "EPOCH: 25034 LOSS: 40.97502324000981\n",
      "EPOCH: 25035 LOSS: 40.9750218808115\n",
      "EPOCH: 25036 LOSS: 40.97502052169905\n",
      "EPOCH: 25037 LOSS: 40.97501916267245\n",
      "EPOCH: 25038 LOSS: 40.975017803731674\n",
      "EPOCH: 25039 LOSS: 40.975016444876715\n",
      "EPOCH: 25040 LOSS: 40.975015086107575\n",
      "EPOCH: 25041 LOSS: 40.97501372742424\n",
      "EPOCH: 25042 LOSS: 40.9750123688267\n",
      "EPOCH: 25043 LOSS: 40.97501101031493\n",
      "EPOCH: 25044 LOSS: 40.97500965188895\n",
      "EPOCH: 25045 LOSS: 40.97500829354872\n",
      "EPOCH: 25046 LOSS: 40.975006935294246\n",
      "EPOCH: 25047 LOSS: 40.97500557712551\n",
      "EPOCH: 25048 LOSS: 40.97500421904252\n",
      "EPOCH: 25049 LOSS: 40.975002861045226\n",
      "EPOCH: 25050 LOSS: 40.97500150313367\n",
      "EPOCH: 25051 LOSS: 40.97500014530779\n",
      "EPOCH: 25052 LOSS: 40.97499878756763\n",
      "EPOCH: 25053 LOSS: 40.97499742991313\n",
      "EPOCH: 25054 LOSS: 40.97499607234431\n",
      "EPOCH: 25055 LOSS: 40.97499471486113\n",
      "EPOCH: 25056 LOSS: 40.97499335746362\n",
      "EPOCH: 25057 LOSS: 40.97499200015176\n",
      "EPOCH: 25058 LOSS: 40.97499064292551\n",
      "EPOCH: 25059 LOSS: 40.97498928578488\n",
      "EPOCH: 25060 LOSS: 40.974987928729874\n",
      "EPOCH: 25061 LOSS: 40.974986571760454\n",
      "EPOCH: 25062 LOSS: 40.97498521487663\n",
      "EPOCH: 25063 LOSS: 40.974983858078375\n",
      "EPOCH: 25064 LOSS: 40.9749825013657\n",
      "EPOCH: 25065 LOSS: 40.97498114473859\n",
      "EPOCH: 25066 LOSS: 40.97497978819701\n",
      "EPOCH: 25067 LOSS: 40.97497843174099\n",
      "EPOCH: 25068 LOSS: 40.97497707537048\n",
      "EPOCH: 25069 LOSS: 40.974975719085506\n",
      "EPOCH: 25070 LOSS: 40.97497436288603\n",
      "EPOCH: 25071 LOSS: 40.97497300677205\n",
      "EPOCH: 25072 LOSS: 40.974971650743576\n",
      "EPOCH: 25073 LOSS: 40.97497029480055\n",
      "EPOCH: 25074 LOSS: 40.974968938943015\n",
      "EPOCH: 25075 LOSS: 40.97496758317093\n",
      "EPOCH: 25076 LOSS: 40.97496622748429\n",
      "EPOCH: 25077 LOSS: 40.974964871883095\n",
      "EPOCH: 25078 LOSS: 40.974963516367325\n",
      "EPOCH: 25079 LOSS: 40.974962160936975\n",
      "EPOCH: 25080 LOSS: 40.97496080559203\n",
      "EPOCH: 25081 LOSS: 40.974959450332484\n",
      "EPOCH: 25082 LOSS: 40.97495809515831\n",
      "EPOCH: 25083 LOSS: 40.97495674006953\n",
      "EPOCH: 25084 LOSS: 40.9749553850661\n",
      "EPOCH: 25085 LOSS: 40.97495403014805\n",
      "EPOCH: 25086 LOSS: 40.974952675315315\n",
      "EPOCH: 25087 LOSS: 40.97495132056794\n",
      "EPOCH: 25088 LOSS: 40.97494996590589\n",
      "EPOCH: 25089 LOSS: 40.974948611329154\n",
      "EPOCH: 25090 LOSS: 40.97494725683772\n",
      "EPOCH: 25091 LOSS: 40.974945902431585\n",
      "EPOCH: 25092 LOSS: 40.97494454811075\n",
      "EPOCH: 25093 LOSS: 40.97494319387516\n",
      "EPOCH: 25094 LOSS: 40.974941839724856\n",
      "EPOCH: 25095 LOSS: 40.9749404856598\n",
      "EPOCH: 25096 LOSS: 40.97493913168\n",
      "EPOCH: 25097 LOSS: 40.974937777785435\n",
      "EPOCH: 25098 LOSS: 40.974936423976104\n",
      "EPOCH: 25099 LOSS: 40.974935070251945\n",
      "EPOCH: 25100 LOSS: 40.97493371661303\n",
      "EPOCH: 25101 LOSS: 40.97493236305931\n",
      "EPOCH: 25102 LOSS: 40.974931009590755\n",
      "EPOCH: 25103 LOSS: 40.97492965620739\n",
      "EPOCH: 25104 LOSS: 40.97492830290918\n",
      "EPOCH: 25105 LOSS: 40.97492694969615\n",
      "EPOCH: 25106 LOSS: 40.97492559656823\n",
      "EPOCH: 25107 LOSS: 40.97492424352547\n",
      "EPOCH: 25108 LOSS: 40.974922890567825\n",
      "EPOCH: 25109 LOSS: 40.97492153769531\n",
      "EPOCH: 25110 LOSS: 40.97492018490786\n",
      "EPOCH: 25111 LOSS: 40.97491883220554\n",
      "EPOCH: 25112 LOSS: 40.9749174795883\n",
      "EPOCH: 25113 LOSS: 40.97491612705612\n",
      "EPOCH: 25114 LOSS: 40.974914774609005\n",
      "EPOCH: 25115 LOSS: 40.974913422246956\n",
      "EPOCH: 25116 LOSS: 40.97491206996995\n",
      "EPOCH: 25117 LOSS: 40.97491071777798\n",
      "EPOCH: 25118 LOSS: 40.97490936567104\n",
      "EPOCH: 25119 LOSS: 40.97490801364909\n",
      "EPOCH: 25120 LOSS: 40.97490666171217\n",
      "EPOCH: 25121 LOSS: 40.97490530986023\n",
      "EPOCH: 25122 LOSS: 40.97490395809328\n",
      "EPOCH: 25123 LOSS: 40.97490260641129\n",
      "EPOCH: 25124 LOSS: 40.97490125481427\n",
      "EPOCH: 25125 LOSS: 40.9748999033022\n",
      "EPOCH: 25126 LOSS: 40.974898551875086\n",
      "EPOCH: 25127 LOSS: 40.974897200532894\n",
      "EPOCH: 25128 LOSS: 40.97489584927565\n",
      "EPOCH: 25129 LOSS: 40.974894498103296\n",
      "EPOCH: 25130 LOSS: 40.974893147015855\n",
      "EPOCH: 25131 LOSS: 40.9748917960133\n",
      "EPOCH: 25132 LOSS: 40.97489044509563\n",
      "EPOCH: 25133 LOSS: 40.974889094262835\n",
      "EPOCH: 25134 LOSS: 40.97488774351492\n",
      "EPOCH: 25135 LOSS: 40.97488639285185\n",
      "EPOCH: 25136 LOSS: 40.97488504227361\n",
      "EPOCH: 25137 LOSS: 40.97488369178022\n",
      "EPOCH: 25138 LOSS: 40.97488234137164\n",
      "EPOCH: 25139 LOSS: 40.97488099104787\n",
      "EPOCH: 25140 LOSS: 40.97487964080892\n",
      "EPOCH: 25141 LOSS: 40.97487829065476\n",
      "EPOCH: 25142 LOSS: 40.974876940585375\n",
      "EPOCH: 25143 LOSS: 40.97487559060077\n",
      "EPOCH: 25144 LOSS: 40.97487424070092\n",
      "EPOCH: 25145 LOSS: 40.974872890885834\n",
      "EPOCH: 25146 LOSS: 40.97487154115547\n",
      "EPOCH: 25147 LOSS: 40.974870191509865\n",
      "EPOCH: 25148 LOSS: 40.97486884194899\n",
      "EPOCH: 25149 LOSS: 40.97486749247281\n",
      "EPOCH: 25150 LOSS: 40.974866143081336\n",
      "EPOCH: 25151 LOSS: 40.97486479377454\n",
      "EPOCH: 25152 LOSS: 40.974863444552454\n",
      "EPOCH: 25153 LOSS: 40.974862095415034\n",
      "EPOCH: 25154 LOSS: 40.974860746362275\n",
      "EPOCH: 25155 LOSS: 40.97485939739417\n",
      "EPOCH: 25156 LOSS: 40.9748580485107\n",
      "EPOCH: 25157 LOSS: 40.97485669971188\n",
      "EPOCH: 25158 LOSS: 40.974855350997665\n",
      "EPOCH: 25159 LOSS: 40.97485400236806\n",
      "EPOCH: 25160 LOSS: 40.974852653823085\n",
      "EPOCH: 25161 LOSS: 40.9748513053627\n",
      "EPOCH: 25162 LOSS: 40.97484995698688\n",
      "EPOCH: 25163 LOSS: 40.97484860869565\n",
      "EPOCH: 25164 LOSS: 40.974847260488986\n",
      "EPOCH: 25165 LOSS: 40.97484591236685\n",
      "EPOCH: 25166 LOSS: 40.97484456432928\n",
      "EPOCH: 25167 LOSS: 40.97484321637623\n",
      "EPOCH: 25168 LOSS: 40.97484186850771\n",
      "EPOCH: 25169 LOSS: 40.97484052072372\n",
      "EPOCH: 25170 LOSS: 40.97483917302421\n",
      "EPOCH: 25171 LOSS: 40.97483782540918\n",
      "EPOCH: 25172 LOSS: 40.97483647787867\n",
      "EPOCH: 25173 LOSS: 40.97483513043262\n",
      "EPOCH: 25174 LOSS: 40.97483378307105\n",
      "EPOCH: 25175 LOSS: 40.97483243579391\n",
      "EPOCH: 25176 LOSS: 40.97483108860122\n",
      "EPOCH: 25177 LOSS: 40.97482974149297\n",
      "EPOCH: 25178 LOSS: 40.974828394469135\n",
      "EPOCH: 25179 LOSS: 40.974827047529736\n",
      "EPOCH: 25180 LOSS: 40.97482570067472\n",
      "EPOCH: 25181 LOSS: 40.9748243539041\n",
      "EPOCH: 25182 LOSS: 40.97482300721788\n",
      "EPOCH: 25183 LOSS: 40.97482166061602\n",
      "EPOCH: 25184 LOSS: 40.97482031409853\n",
      "EPOCH: 25185 LOSS: 40.974818967665385\n",
      "EPOCH: 25186 LOSS: 40.97481762131659\n",
      "EPOCH: 25187 LOSS: 40.97481627505213\n",
      "EPOCH: 25188 LOSS: 40.97481492887199\n",
      "EPOCH: 25189 LOSS: 40.97481358277619\n",
      "EPOCH: 25190 LOSS: 40.97481223676466\n",
      "EPOCH: 25191 LOSS: 40.97481089083745\n",
      "EPOCH: 25192 LOSS: 40.9748095449945\n",
      "EPOCH: 25193 LOSS: 40.97480819923585\n",
      "EPOCH: 25194 LOSS: 40.97480685356146\n",
      "EPOCH: 25195 LOSS: 40.97480550797133\n",
      "EPOCH: 25196 LOSS: 40.974804162465425\n",
      "EPOCH: 25197 LOSS: 40.97480281704377\n",
      "EPOCH: 25198 LOSS: 40.97480147170634\n",
      "EPOCH: 25199 LOSS: 40.97480012645312\n",
      "EPOCH: 25200 LOSS: 40.97479878128411\n",
      "EPOCH: 25201 LOSS: 40.97479743619931\n",
      "EPOCH: 25202 LOSS: 40.97479609119867\n",
      "EPOCH: 25203 LOSS: 40.974794746282214\n",
      "EPOCH: 25204 LOSS: 40.974793401449915\n",
      "EPOCH: 25205 LOSS: 40.97479205670179\n",
      "EPOCH: 25206 LOSS: 40.97479071203781\n",
      "EPOCH: 25207 LOSS: 40.97478936745796\n",
      "EPOCH: 25208 LOSS: 40.97478802296224\n",
      "EPOCH: 25209 LOSS: 40.974786678550636\n",
      "EPOCH: 25210 LOSS: 40.97478533422313\n",
      "EPOCH: 25211 LOSS: 40.974783989979734\n",
      "EPOCH: 25212 LOSS: 40.97478264582041\n",
      "EPOCH: 25213 LOSS: 40.97478130174518\n",
      "EPOCH: 25214 LOSS: 40.974779957754\n",
      "EPOCH: 25215 LOSS: 40.97477861384689\n",
      "EPOCH: 25216 LOSS: 40.974777270023836\n",
      "EPOCH: 25217 LOSS: 40.97477592628479\n",
      "EPOCH: 25218 LOSS: 40.974774582629784\n",
      "EPOCH: 25219 LOSS: 40.97477323905882\n",
      "EPOCH: 25220 LOSS: 40.974771895571834\n",
      "EPOCH: 25221 LOSS: 40.974770552168856\n",
      "EPOCH: 25222 LOSS: 40.974769208849864\n",
      "EPOCH: 25223 LOSS: 40.97476786561486\n",
      "EPOCH: 25224 LOSS: 40.97476652246381\n",
      "EPOCH: 25225 LOSS: 40.97476517939673\n",
      "EPOCH: 25226 LOSS: 40.97476383641358\n",
      "EPOCH: 25227 LOSS: 40.97476249351438\n",
      "EPOCH: 25228 LOSS: 40.97476115069911\n",
      "EPOCH: 25229 LOSS: 40.974759807967764\n",
      "EPOCH: 25230 LOSS: 40.97475846532031\n",
      "EPOCH: 25231 LOSS: 40.974757122756785\n",
      "EPOCH: 25232 LOSS: 40.974755780277114\n",
      "EPOCH: 25233 LOSS: 40.974754437881344\n",
      "EPOCH: 25234 LOSS: 40.97475309556943\n",
      "EPOCH: 25235 LOSS: 40.97475175334139\n",
      "EPOCH: 25236 LOSS: 40.974750411197206\n",
      "EPOCH: 25237 LOSS: 40.97474906913684\n",
      "EPOCH: 25238 LOSS: 40.97474772716033\n",
      "EPOCH: 25239 LOSS: 40.974746385267615\n",
      "EPOCH: 25240 LOSS: 40.974745043458725\n",
      "EPOCH: 25241 LOSS: 40.97474370173363\n",
      "EPOCH: 25242 LOSS: 40.974742360092314\n",
      "EPOCH: 25243 LOSS: 40.974741018534786\n",
      "EPOCH: 25244 LOSS: 40.97473967706104\n",
      "EPOCH: 25245 LOSS: 40.97473833567106\n",
      "EPOCH: 25246 LOSS: 40.974736994364804\n",
      "EPOCH: 25247 LOSS: 40.97473565314232\n",
      "EPOCH: 25248 LOSS: 40.97473431200355\n",
      "EPOCH: 25249 LOSS: 40.974732970948516\n",
      "EPOCH: 25250 LOSS: 40.97473162997716\n",
      "EPOCH: 25251 LOSS: 40.97473028908954\n",
      "EPOCH: 25252 LOSS: 40.9747289482856\n",
      "EPOCH: 25253 LOSS: 40.97472760756535\n",
      "EPOCH: 25254 LOSS: 40.97472626692876\n",
      "EPOCH: 25255 LOSS: 40.97472492637584\n",
      "EPOCH: 25256 LOSS: 40.97472358590656\n",
      "EPOCH: 25257 LOSS: 40.97472224552094\n",
      "EPOCH: 25258 LOSS: 40.974720905218945\n",
      "EPOCH: 25259 LOSS: 40.97471956500058\n",
      "EPOCH: 25260 LOSS: 40.974718224865825\n",
      "EPOCH: 25261 LOSS: 40.97471688481468\n",
      "EPOCH: 25262 LOSS: 40.97471554484713\n",
      "EPOCH: 25263 LOSS: 40.974714204963156\n",
      "EPOCH: 25264 LOSS: 40.974712865162765\n",
      "EPOCH: 25265 LOSS: 40.974711525445926\n",
      "EPOCH: 25266 LOSS: 40.97471018581264\n",
      "EPOCH: 25267 LOSS: 40.974708846262914\n",
      "EPOCH: 25268 LOSS: 40.97470750679672\n",
      "EPOCH: 25269 LOSS: 40.97470616741404\n",
      "EPOCH: 25270 LOSS: 40.974704828114895\n",
      "EPOCH: 25271 LOSS: 40.97470348889925\n",
      "EPOCH: 25272 LOSS: 40.97470214976708\n",
      "EPOCH: 25273 LOSS: 40.97470081071842\n",
      "EPOCH: 25274 LOSS: 40.974699471753226\n",
      "EPOCH: 25275 LOSS: 40.97469813287152\n",
      "EPOCH: 25276 LOSS: 40.97469679407324\n",
      "EPOCH: 25277 LOSS: 40.974695455358415\n",
      "EPOCH: 25278 LOSS: 40.97469411672703\n",
      "EPOCH: 25279 LOSS: 40.97469277817907\n",
      "EPOCH: 25280 LOSS: 40.97469143971453\n",
      "EPOCH: 25281 LOSS: 40.97469010133341\n",
      "EPOCH: 25282 LOSS: 40.974688763035665\n",
      "EPOCH: 25283 LOSS: 40.974687424821326\n",
      "EPOCH: 25284 LOSS: 40.974686086690355\n",
      "EPOCH: 25285 LOSS: 40.97468474864275\n",
      "EPOCH: 25286 LOSS: 40.974683410678516\n",
      "EPOCH: 25287 LOSS: 40.97468207279763\n",
      "EPOCH: 25288 LOSS: 40.97468073500008\n",
      "EPOCH: 25289 LOSS: 40.97467939728586\n",
      "EPOCH: 25290 LOSS: 40.97467805965497\n",
      "EPOCH: 25291 LOSS: 40.97467672210738\n",
      "EPOCH: 25292 LOSS: 40.97467538464309\n",
      "EPOCH: 25293 LOSS: 40.974674047262084\n",
      "EPOCH: 25294 LOSS: 40.974672709964366\n",
      "EPOCH: 25295 LOSS: 40.974671372749924\n",
      "EPOCH: 25296 LOSS: 40.974670035618736\n",
      "EPOCH: 25297 LOSS: 40.97466869857081\n",
      "EPOCH: 25298 LOSS: 40.97466736160611\n",
      "EPOCH: 25299 LOSS: 40.97466602472464\n",
      "EPOCH: 25300 LOSS: 40.97466468792641\n",
      "EPOCH: 25301 LOSS: 40.97466335121138\n",
      "EPOCH: 25302 LOSS: 40.974662014579565\n",
      "EPOCH: 25303 LOSS: 40.97466067803093\n",
      "EPOCH: 25304 LOSS: 40.974659341565484\n",
      "EPOCH: 25305 LOSS: 40.974658005183215\n",
      "EPOCH: 25306 LOSS: 40.97465666888411\n",
      "EPOCH: 25307 LOSS: 40.97465533266815\n",
      "EPOCH: 25308 LOSS: 40.974653996535345\n",
      "EPOCH: 25309 LOSS: 40.97465266048566\n",
      "EPOCH: 25310 LOSS: 40.974651324519115\n",
      "EPOCH: 25311 LOSS: 40.974649988635676\n",
      "EPOCH: 25312 LOSS: 40.97464865283535\n",
      "EPOCH: 25313 LOSS: 40.97464731711811\n",
      "EPOCH: 25314 LOSS: 40.97464598148396\n",
      "EPOCH: 25315 LOSS: 40.974644645932884\n",
      "EPOCH: 25316 LOSS: 40.974643310464884\n",
      "EPOCH: 25317 LOSS: 40.97464197507992\n",
      "EPOCH: 25318 LOSS: 40.974640639778016\n",
      "EPOCH: 25319 LOSS: 40.97463930455916\n",
      "EPOCH: 25320 LOSS: 40.974637969423306\n",
      "EPOCH: 25321 LOSS: 40.97463663437051\n",
      "EPOCH: 25322 LOSS: 40.97463529940069\n",
      "EPOCH: 25323 LOSS: 40.974633964513885\n",
      "EPOCH: 25324 LOSS: 40.974632629710044\n",
      "EPOCH: 25325 LOSS: 40.974631294989194\n",
      "EPOCH: 25326 LOSS: 40.97462996035132\n",
      "EPOCH: 25327 LOSS: 40.9746286257964\n",
      "EPOCH: 25328 LOSS: 40.97462729132444\n",
      "EPOCH: 25329 LOSS: 40.97462595693541\n",
      "EPOCH: 25330 LOSS: 40.97462462262931\n",
      "EPOCH: 25331 LOSS: 40.974623288406136\n",
      "EPOCH: 25332 LOSS: 40.974621954265885\n",
      "EPOCH: 25333 LOSS: 40.9746206202085\n",
      "EPOCH: 25334 LOSS: 40.97461928623403\n",
      "EPOCH: 25335 LOSS: 40.974617952342435\n",
      "EPOCH: 25336 LOSS: 40.97461661853373\n",
      "EPOCH: 25337 LOSS: 40.97461528480787\n",
      "EPOCH: 25338 LOSS: 40.97461395116486\n",
      "EPOCH: 25339 LOSS: 40.9746126176047\n",
      "EPOCH: 25340 LOSS: 40.97461128412738\n",
      "EPOCH: 25341 LOSS: 40.97460995073287\n",
      "EPOCH: 25342 LOSS: 40.97460861742117\n",
      "EPOCH: 25343 LOSS: 40.97460728419229\n",
      "EPOCH: 25344 LOSS: 40.9746059510462\n",
      "EPOCH: 25345 LOSS: 40.974604617982884\n",
      "EPOCH: 25346 LOSS: 40.97460328500237\n",
      "EPOCH: 25347 LOSS: 40.97460195210459\n",
      "EPOCH: 25348 LOSS: 40.97460061928959\n",
      "EPOCH: 25349 LOSS: 40.97459928655732\n",
      "EPOCH: 25350 LOSS: 40.9745979539078\n",
      "EPOCH: 25351 LOSS: 40.97459662134099\n",
      "EPOCH: 25352 LOSS: 40.97459528885691\n",
      "EPOCH: 25353 LOSS: 40.974593956455536\n",
      "EPOCH: 25354 LOSS: 40.97459262413686\n",
      "EPOCH: 25355 LOSS: 40.97459129190087\n",
      "EPOCH: 25356 LOSS: 40.974589959747554\n",
      "EPOCH: 25357 LOSS: 40.97458862767693\n",
      "EPOCH: 25358 LOSS: 40.974587295688934\n",
      "EPOCH: 25359 LOSS: 40.97458596378361\n",
      "EPOCH: 25360 LOSS: 40.974584631960916\n",
      "EPOCH: 25361 LOSS: 40.97458330022086\n",
      "EPOCH: 25362 LOSS: 40.97458196856341\n",
      "EPOCH: 25363 LOSS: 40.974580636988584\n",
      "EPOCH: 25364 LOSS: 40.97457930549635\n",
      "EPOCH: 25365 LOSS: 40.974577974086706\n",
      "EPOCH: 25366 LOSS: 40.97457664275966\n",
      "EPOCH: 25367 LOSS: 40.97457531151518\n",
      "EPOCH: 25368 LOSS: 40.97457398035324\n",
      "EPOCH: 25369 LOSS: 40.974572649273895\n",
      "EPOCH: 25370 LOSS: 40.97457131827706\n",
      "EPOCH: 25371 LOSS: 40.974569987362784\n",
      "EPOCH: 25372 LOSS: 40.974568656531005\n",
      "EPOCH: 25373 LOSS: 40.974567325781756\n",
      "EPOCH: 25374 LOSS: 40.974565995115\n",
      "EPOCH: 25375 LOSS: 40.97456466453076\n",
      "EPOCH: 25376 LOSS: 40.974563334028986\n",
      "EPOCH: 25377 LOSS: 40.97456200360969\n",
      "EPOCH: 25378 LOSS: 40.974560673272855\n",
      "EPOCH: 25379 LOSS: 40.9745593430185\n",
      "EPOCH: 25380 LOSS: 40.97455801284658\n",
      "EPOCH: 25381 LOSS: 40.9745566827571\n",
      "EPOCH: 25382 LOSS: 40.974555352750045\n",
      "EPOCH: 25383 LOSS: 40.974554022825416\n",
      "EPOCH: 25384 LOSS: 40.974552692983174\n",
      "EPOCH: 25385 LOSS: 40.97455136322334\n",
      "EPOCH: 25386 LOSS: 40.9745500335459\n",
      "EPOCH: 25387 LOSS: 40.97454870395083\n",
      "EPOCH: 25388 LOSS: 40.97454737443815\n",
      "EPOCH: 25389 LOSS: 40.97454604500783\n",
      "EPOCH: 25390 LOSS: 40.974544715659846\n",
      "EPOCH: 25391 LOSS: 40.9745433863942\n",
      "EPOCH: 25392 LOSS: 40.9745420572109\n",
      "EPOCH: 25393 LOSS: 40.974540728109915\n",
      "EPOCH: 25394 LOSS: 40.97453939909125\n",
      "EPOCH: 25395 LOSS: 40.974538070154864\n",
      "EPOCH: 25396 LOSS: 40.97453674130079\n",
      "EPOCH: 25397 LOSS: 40.97453541252901\n",
      "EPOCH: 25398 LOSS: 40.97453408383949\n",
      "EPOCH: 25399 LOSS: 40.97453275523223\n",
      "EPOCH: 25400 LOSS: 40.97453142670722\n",
      "EPOCH: 25401 LOSS: 40.97453009826448\n",
      "EPOCH: 25402 LOSS: 40.97452876990395\n",
      "EPOCH: 25403 LOSS: 40.97452744162566\n",
      "EPOCH: 25404 LOSS: 40.97452611342959\n",
      "EPOCH: 25405 LOSS: 40.97452478531571\n",
      "EPOCH: 25406 LOSS: 40.974523457284036\n",
      "EPOCH: 25407 LOSS: 40.97452212933456\n",
      "EPOCH: 25408 LOSS: 40.974520801467236\n",
      "EPOCH: 25409 LOSS: 40.9745194736821\n",
      "EPOCH: 25410 LOSS: 40.97451814597913\n",
      "EPOCH: 25411 LOSS: 40.974516818358296\n",
      "EPOCH: 25412 LOSS: 40.97451549081961\n",
      "EPOCH: 25413 LOSS: 40.974514163363054\n",
      "EPOCH: 25414 LOSS: 40.97451283598861\n",
      "EPOCH: 25415 LOSS: 40.97451150869628\n",
      "EPOCH: 25416 LOSS: 40.97451018148606\n",
      "EPOCH: 25417 LOSS: 40.97450885435791\n",
      "EPOCH: 25418 LOSS: 40.97450752731187\n",
      "EPOCH: 25419 LOSS: 40.97450620034789\n",
      "EPOCH: 25420 LOSS: 40.974504873465975\n",
      "EPOCH: 25421 LOSS: 40.97450354666611\n",
      "EPOCH: 25422 LOSS: 40.97450221994829\n",
      "EPOCH: 25423 LOSS: 40.974500893312495\n",
      "EPOCH: 25424 LOSS: 40.97449956675873\n",
      "EPOCH: 25425 LOSS: 40.974498240287005\n",
      "EPOCH: 25426 LOSS: 40.97449691389727\n",
      "EPOCH: 25427 LOSS: 40.9744955875895\n",
      "EPOCH: 25428 LOSS: 40.97449426136376\n",
      "EPOCH: 25429 LOSS: 40.97449293521998\n",
      "EPOCH: 25430 LOSS: 40.974491609158164\n",
      "EPOCH: 25431 LOSS: 40.974490283178326\n",
      "EPOCH: 25432 LOSS: 40.97448895728041\n",
      "EPOCH: 25433 LOSS: 40.97448763146444\n",
      "EPOCH: 25434 LOSS: 40.97448630573041\n",
      "EPOCH: 25435 LOSS: 40.97448498007829\n",
      "EPOCH: 25436 LOSS: 40.97448365450809\n",
      "EPOCH: 25437 LOSS: 40.97448232901977\n",
      "EPOCH: 25438 LOSS: 40.97448100361336\n",
      "EPOCH: 25439 LOSS: 40.974479678288844\n",
      "EPOCH: 25440 LOSS: 40.97447835304618\n",
      "EPOCH: 25441 LOSS: 40.97447702788537\n",
      "EPOCH: 25442 LOSS: 40.97447570280643\n",
      "EPOCH: 25443 LOSS: 40.97447437780933\n",
      "EPOCH: 25444 LOSS: 40.97447305289407\n",
      "EPOCH: 25445 LOSS: 40.97447172806062\n",
      "EPOCH: 25446 LOSS: 40.974470403309\n",
      "EPOCH: 25447 LOSS: 40.97446907863917\n",
      "EPOCH: 25448 LOSS: 40.97446775405115\n",
      "EPOCH: 25449 LOSS: 40.97446642954491\n",
      "EPOCH: 25450 LOSS: 40.974465105120444\n",
      "EPOCH: 25451 LOSS: 40.974463780777754\n",
      "EPOCH: 25452 LOSS: 40.974462456516804\n",
      "EPOCH: 25453 LOSS: 40.97446113233762\n",
      "EPOCH: 25454 LOSS: 40.97445980824018\n",
      "EPOCH: 25455 LOSS: 40.97445848422445\n",
      "EPOCH: 25456 LOSS: 40.974457160290456\n",
      "EPOCH: 25457 LOSS: 40.97445583643816\n",
      "EPOCH: 25458 LOSS: 40.974454512667585\n",
      "EPOCH: 25459 LOSS: 40.974453188978686\n",
      "EPOCH: 25460 LOSS: 40.974451865371464\n",
      "EPOCH: 25461 LOSS: 40.974450541845925\n",
      "EPOCH: 25462 LOSS: 40.97444921840204\n",
      "EPOCH: 25463 LOSS: 40.97444789503981\n",
      "EPOCH: 25464 LOSS: 40.97444657175922\n",
      "EPOCH: 25465 LOSS: 40.97444524856027\n",
      "EPOCH: 25466 LOSS: 40.974443925442955\n",
      "EPOCH: 25467 LOSS: 40.97444260240725\n",
      "EPOCH: 25468 LOSS: 40.97444127945313\n",
      "EPOCH: 25469 LOSS: 40.97443995658063\n",
      "EPOCH: 25470 LOSS: 40.9744386337897\n",
      "EPOCH: 25471 LOSS: 40.97443731108036\n",
      "EPOCH: 25472 LOSS: 40.97443598845258\n",
      "EPOCH: 25473 LOSS: 40.97443466590637\n",
      "EPOCH: 25474 LOSS: 40.97443334344172\n",
      "EPOCH: 25475 LOSS: 40.974432021058576\n",
      "EPOCH: 25476 LOSS: 40.974430698756976\n",
      "EPOCH: 25477 LOSS: 40.974429376536904\n",
      "EPOCH: 25478 LOSS: 40.974428054398324\n",
      "EPOCH: 25479 LOSS: 40.97442673234127\n",
      "EPOCH: 25480 LOSS: 40.9744254103657\n",
      "EPOCH: 25481 LOSS: 40.97442408847161\n",
      "EPOCH: 25482 LOSS: 40.97442276665899\n",
      "EPOCH: 25483 LOSS: 40.974421444927835\n",
      "EPOCH: 25484 LOSS: 40.974420123278136\n",
      "EPOCH: 25485 LOSS: 40.97441880170989\n",
      "EPOCH: 25486 LOSS: 40.974417480223046\n",
      "EPOCH: 25487 LOSS: 40.97441615881766\n",
      "EPOCH: 25488 LOSS: 40.97441483749369\n",
      "EPOCH: 25489 LOSS: 40.97441351625112\n",
      "EPOCH: 25490 LOSS: 40.97441219508994\n",
      "EPOCH: 25491 LOSS: 40.97441087401016\n",
      "EPOCH: 25492 LOSS: 40.97440955301175\n",
      "EPOCH: 25493 LOSS: 40.9744082320947\n",
      "EPOCH: 25494 LOSS: 40.97440691125904\n",
      "EPOCH: 25495 LOSS: 40.9744055905047\n",
      "EPOCH: 25496 LOSS: 40.97440426983171\n",
      "EPOCH: 25497 LOSS: 40.974402949240066\n",
      "EPOCH: 25498 LOSS: 40.97440162872972\n",
      "EPOCH: 25499 LOSS: 40.974400308300716\n",
      "EPOCH: 25500 LOSS: 40.97439898795299\n",
      "EPOCH: 25501 LOSS: 40.97439766768657\n",
      "EPOCH: 25502 LOSS: 40.97439634750142\n",
      "EPOCH: 25503 LOSS: 40.974395027397556\n",
      "EPOCH: 25504 LOSS: 40.97439370737496\n",
      "EPOCH: 25505 LOSS: 40.9743923874336\n",
      "EPOCH: 25506 LOSS: 40.97439106757351\n",
      "EPOCH: 25507 LOSS: 40.97438974779463\n",
      "EPOCH: 25508 LOSS: 40.97438842809701\n",
      "EPOCH: 25509 LOSS: 40.97438710848059\n",
      "EPOCH: 25510 LOSS: 40.97438578894538\n",
      "EPOCH: 25511 LOSS: 40.97438446949137\n",
      "EPOCH: 25512 LOSS: 40.97438315011854\n",
      "EPOCH: 25513 LOSS: 40.974381830826914\n",
      "EPOCH: 25514 LOSS: 40.97438051161644\n",
      "EPOCH: 25515 LOSS: 40.974379192487135\n",
      "EPOCH: 25516 LOSS: 40.97437787343897\n",
      "EPOCH: 25517 LOSS: 40.97437655447196\n",
      "EPOCH: 25518 LOSS: 40.97437523558609\n",
      "EPOCH: 25519 LOSS: 40.97437391678133\n",
      "EPOCH: 25520 LOSS: 40.97437259805768\n",
      "EPOCH: 25521 LOSS: 40.97437127941515\n",
      "EPOCH: 25522 LOSS: 40.974369960853714\n",
      "EPOCH: 25523 LOSS: 40.974368642373356\n",
      "EPOCH: 25524 LOSS: 40.97436732397407\n",
      "EPOCH: 25525 LOSS: 40.974366005655874\n",
      "EPOCH: 25526 LOSS: 40.97436468741871\n",
      "EPOCH: 25527 LOSS: 40.97436336926261\n",
      "EPOCH: 25528 LOSS: 40.97436205118755\n",
      "EPOCH: 25529 LOSS: 40.97436073319351\n",
      "EPOCH: 25530 LOSS: 40.9743594152805\n",
      "EPOCH: 25531 LOSS: 40.9743580974485\n",
      "EPOCH: 25532 LOSS: 40.97435677969749\n",
      "EPOCH: 25533 LOSS: 40.97435546202749\n",
      "EPOCH: 25534 LOSS: 40.97435414443846\n",
      "EPOCH: 25535 LOSS: 40.97435282693041\n",
      "EPOCH: 25536 LOSS: 40.97435150950331\n",
      "EPOCH: 25537 LOSS: 40.97435019215718\n",
      "EPOCH: 25538 LOSS: 40.97434887489199\n",
      "EPOCH: 25539 LOSS: 40.97434755770773\n",
      "EPOCH: 25540 LOSS: 40.97434624060441\n",
      "EPOCH: 25541 LOSS: 40.974344923582\n",
      "EPOCH: 25542 LOSS: 40.974343606640495\n",
      "EPOCH: 25543 LOSS: 40.974342289779884\n",
      "EPOCH: 25544 LOSS: 40.97434097300019\n",
      "EPOCH: 25545 LOSS: 40.974339656301325\n",
      "EPOCH: 25546 LOSS: 40.97433833968338\n",
      "EPOCH: 25547 LOSS: 40.974337023146276\n",
      "EPOCH: 25548 LOSS: 40.97433570669002\n",
      "EPOCH: 25549 LOSS: 40.97433439031461\n",
      "EPOCH: 25550 LOSS: 40.974333074020024\n",
      "EPOCH: 25551 LOSS: 40.97433175780628\n",
      "EPOCH: 25552 LOSS: 40.97433044167333\n",
      "EPOCH: 25553 LOSS: 40.974329125621196\n",
      "EPOCH: 25554 LOSS: 40.97432780964986\n",
      "EPOCH: 25555 LOSS: 40.97432649375931\n",
      "EPOCH: 25556 LOSS: 40.974325177949524\n",
      "EPOCH: 25557 LOSS: 40.974323862220515\n",
      "EPOCH: 25558 LOSS: 40.97432254657226\n",
      "EPOCH: 25559 LOSS: 40.97432123100476\n",
      "EPOCH: 25560 LOSS: 40.974319915518\n",
      "EPOCH: 25561 LOSS: 40.97431860011196\n",
      "EPOCH: 25562 LOSS: 40.974317284786636\n",
      "EPOCH: 25563 LOSS: 40.97431596954205\n",
      "EPOCH: 25564 LOSS: 40.97431465437814\n",
      "EPOCH: 25565 LOSS: 40.974313339294916\n",
      "EPOCH: 25566 LOSS: 40.9743120242924\n",
      "EPOCH: 25567 LOSS: 40.974310709370556\n",
      "EPOCH: 25568 LOSS: 40.97430939452938\n",
      "EPOCH: 25569 LOSS: 40.97430807976883\n",
      "EPOCH: 25570 LOSS: 40.97430676508894\n",
      "EPOCH: 25571 LOSS: 40.97430545048969\n",
      "EPOCH: 25572 LOSS: 40.97430413597105\n",
      "EPOCH: 25573 LOSS: 40.97430282153306\n",
      "EPOCH: 25574 LOSS: 40.97430150717565\n",
      "EPOCH: 25575 LOSS: 40.97430019289885\n",
      "EPOCH: 25576 LOSS: 40.97429887870267\n",
      "EPOCH: 25577 LOSS: 40.974297564587026\n",
      "EPOCH: 25578 LOSS: 40.97429625055197\n",
      "EPOCH: 25579 LOSS: 40.974294936597474\n",
      "EPOCH: 25580 LOSS: 40.97429362272353\n",
      "EPOCH: 25581 LOSS: 40.97429230893014\n",
      "EPOCH: 25582 LOSS: 40.974290995217274\n",
      "EPOCH: 25583 LOSS: 40.97428968158493\n",
      "EPOCH: 25584 LOSS: 40.9742883680331\n",
      "EPOCH: 25585 LOSS: 40.974287054561785\n",
      "EPOCH: 25586 LOSS: 40.97428574117096\n",
      "EPOCH: 25587 LOSS: 40.97428442786063\n",
      "EPOCH: 25588 LOSS: 40.97428311463077\n",
      "EPOCH: 25589 LOSS: 40.97428180148138\n",
      "EPOCH: 25590 LOSS: 40.974280488412454\n",
      "EPOCH: 25591 LOSS: 40.97427917542398\n",
      "EPOCH: 25592 LOSS: 40.97427786251592\n",
      "EPOCH: 25593 LOSS: 40.97427654968833\n",
      "EPOCH: 25594 LOSS: 40.97427523694114\n",
      "EPOCH: 25595 LOSS: 40.97427392427436\n",
      "EPOCH: 25596 LOSS: 40.97427261168798\n",
      "EPOCH: 25597 LOSS: 40.974271299182014\n",
      "EPOCH: 25598 LOSS: 40.974269986756426\n",
      "EPOCH: 25599 LOSS: 40.974268674411206\n",
      "EPOCH: 25600 LOSS: 40.97426736214637\n",
      "EPOCH: 25601 LOSS: 40.97426604996187\n",
      "EPOCH: 25602 LOSS: 40.97426473785773\n",
      "EPOCH: 25603 LOSS: 40.97426342583393\n",
      "EPOCH: 25604 LOSS: 40.97426211389046\n",
      "EPOCH: 25605 LOSS: 40.974260802027295\n",
      "EPOCH: 25606 LOSS: 40.974259490244464\n",
      "EPOCH: 25607 LOSS: 40.97425817854192\n",
      "EPOCH: 25608 LOSS: 40.97425686691966\n",
      "EPOCH: 25609 LOSS: 40.974255555377695\n",
      "EPOCH: 25610 LOSS: 40.974254243916\n",
      "EPOCH: 25611 LOSS: 40.97425293253457\n",
      "EPOCH: 25612 LOSS: 40.9742516212334\n",
      "EPOCH: 25613 LOSS: 40.97425031001248\n",
      "EPOCH: 25614 LOSS: 40.97424899887177\n",
      "EPOCH: 25615 LOSS: 40.9742476878113\n",
      "EPOCH: 25616 LOSS: 40.97424637683106\n",
      "EPOCH: 25617 LOSS: 40.97424506593102\n",
      "EPOCH: 25618 LOSS: 40.97424375511117\n",
      "EPOCH: 25619 LOSS: 40.97424244437153\n",
      "EPOCH: 25620 LOSS: 40.97424113371207\n",
      "EPOCH: 25621 LOSS: 40.97423982313278\n",
      "EPOCH: 25622 LOSS: 40.97423851263362\n",
      "EPOCH: 25623 LOSS: 40.97423720221465\n",
      "EPOCH: 25624 LOSS: 40.974235891875814\n",
      "EPOCH: 25625 LOSS: 40.97423458161711\n",
      "EPOCH: 25626 LOSS: 40.974233271438536\n",
      "EPOCH: 25627 LOSS: 40.97423196134008\n",
      "EPOCH: 25628 LOSS: 40.97423065132171\n",
      "EPOCH: 25629 LOSS: 40.97422934138346\n",
      "EPOCH: 25630 LOSS: 40.97422803152531\n",
      "EPOCH: 25631 LOSS: 40.974226721747215\n",
      "EPOCH: 25632 LOSS: 40.97422541204918\n",
      "EPOCH: 25633 LOSS: 40.97422410243123\n",
      "EPOCH: 25634 LOSS: 40.974222792893315\n",
      "EPOCH: 25635 LOSS: 40.97422148343546\n",
      "EPOCH: 25636 LOSS: 40.97422017405762\n",
      "EPOCH: 25637 LOSS: 40.97421886475981\n",
      "EPOCH: 25638 LOSS: 40.974217555542026\n",
      "EPOCH: 25639 LOSS: 40.97421624640424\n",
      "EPOCH: 25640 LOSS: 40.974214937346446\n",
      "EPOCH: 25641 LOSS: 40.97421362836863\n",
      "EPOCH: 25642 LOSS: 40.9742123194708\n",
      "EPOCH: 25643 LOSS: 40.974211010652944\n",
      "EPOCH: 25644 LOSS: 40.97420970191505\n",
      "EPOCH: 25645 LOSS: 40.97420839325711\n",
      "EPOCH: 25646 LOSS: 40.97420708467908\n",
      "EPOCH: 25647 LOSS: 40.97420577618101\n",
      "EPOCH: 25648 LOSS: 40.97420446776285\n",
      "EPOCH: 25649 LOSS: 40.974203159424604\n",
      "EPOCH: 25650 LOSS: 40.974201851166285\n",
      "EPOCH: 25651 LOSS: 40.974200542987816\n",
      "EPOCH: 25652 LOSS: 40.97419923488927\n",
      "EPOCH: 25653 LOSS: 40.97419792687059\n",
      "EPOCH: 25654 LOSS: 40.97419661893178\n",
      "EPOCH: 25655 LOSS: 40.974195311072805\n",
      "EPOCH: 25656 LOSS: 40.97419400329369\n",
      "EPOCH: 25657 LOSS: 40.974192695594425\n",
      "EPOCH: 25658 LOSS: 40.974191387975\n",
      "EPOCH: 25659 LOSS: 40.97419008043536\n",
      "EPOCH: 25660 LOSS: 40.974188772975566\n",
      "EPOCH: 25661 LOSS: 40.974187465595556\n",
      "EPOCH: 25662 LOSS: 40.97418615829534\n",
      "EPOCH: 25663 LOSS: 40.97418485107492\n",
      "EPOCH: 25664 LOSS: 40.97418354393427\n",
      "EPOCH: 25665 LOSS: 40.974182236873375\n",
      "EPOCH: 25666 LOSS: 40.97418092989225\n",
      "EPOCH: 25667 LOSS: 40.97417962299087\n",
      "EPOCH: 25668 LOSS: 40.974178316169215\n",
      "EPOCH: 25669 LOSS: 40.974177009427294\n",
      "EPOCH: 25670 LOSS: 40.974175702765095\n",
      "EPOCH: 25671 LOSS: 40.97417439618261\n",
      "EPOCH: 25672 LOSS: 40.97417308967984\n",
      "EPOCH: 25673 LOSS: 40.974171783256736\n",
      "EPOCH: 25674 LOSS: 40.97417047691333\n",
      "EPOCH: 25675 LOSS: 40.97416917064959\n",
      "EPOCH: 25676 LOSS: 40.97416786446553\n",
      "EPOCH: 25677 LOSS: 40.974166558361105\n",
      "EPOCH: 25678 LOSS: 40.97416525233635\n",
      "EPOCH: 25679 LOSS: 40.974163946391215\n",
      "EPOCH: 25680 LOSS: 40.97416264052572\n",
      "EPOCH: 25681 LOSS: 40.97416133473983\n",
      "EPOCH: 25682 LOSS: 40.97416002903356\n",
      "EPOCH: 25683 LOSS: 40.97415872340689\n",
      "EPOCH: 25684 LOSS: 40.9741574178598\n",
      "EPOCH: 25685 LOSS: 40.9741561123923\n",
      "EPOCH: 25686 LOSS: 40.97415480700438\n",
      "EPOCH: 25687 LOSS: 40.97415350169601\n",
      "EPOCH: 25688 LOSS: 40.9741521964672\n",
      "EPOCH: 25689 LOSS: 40.97415089131795\n",
      "EPOCH: 25690 LOSS: 40.97414958624821\n",
      "EPOCH: 25691 LOSS: 40.97414828125802\n",
      "EPOCH: 25692 LOSS: 40.97414697634734\n",
      "EPOCH: 25693 LOSS: 40.974145671516155\n",
      "EPOCH: 25694 LOSS: 40.9741443667645\n",
      "EPOCH: 25695 LOSS: 40.97414306209231\n",
      "EPOCH: 25696 LOSS: 40.97414175749961\n",
      "EPOCH: 25697 LOSS: 40.97414045298638\n",
      "EPOCH: 25698 LOSS: 40.97413914855262\n",
      "EPOCH: 25699 LOSS: 40.97413784419831\n",
      "EPOCH: 25700 LOSS: 40.974136539923435\n",
      "EPOCH: 25701 LOSS: 40.97413523572801\n",
      "EPOCH: 25702 LOSS: 40.974133931612\n",
      "EPOCH: 25703 LOSS: 40.974132627575415\n",
      "EPOCH: 25704 LOSS: 40.97413132361824\n",
      "EPOCH: 25705 LOSS: 40.974130019740464\n",
      "EPOCH: 25706 LOSS: 40.97412871594208\n",
      "EPOCH: 25707 LOSS: 40.97412741222307\n",
      "EPOCH: 25708 LOSS: 40.974126108583434\n",
      "EPOCH: 25709 LOSS: 40.974124805023166\n",
      "EPOCH: 25710 LOSS: 40.97412350154225\n",
      "EPOCH: 25711 LOSS: 40.974122198140684\n",
      "EPOCH: 25712 LOSS: 40.974120894818434\n",
      "EPOCH: 25713 LOSS: 40.974119591575516\n",
      "EPOCH: 25714 LOSS: 40.97411828841192\n",
      "EPOCH: 25715 LOSS: 40.97411698532764\n",
      "EPOCH: 25716 LOSS: 40.97411568232265\n",
      "EPOCH: 25717 LOSS: 40.97411437939695\n",
      "EPOCH: 25718 LOSS: 40.97411307655053\n",
      "EPOCH: 25719 LOSS: 40.97411177378338\n",
      "EPOCH: 25720 LOSS: 40.97411047109549\n",
      "EPOCH: 25721 LOSS: 40.97410916848689\n",
      "EPOCH: 25722 LOSS: 40.974107865957485\n",
      "EPOCH: 25723 LOSS: 40.974106563507334\n",
      "EPOCH: 25724 LOSS: 40.97410526113641\n",
      "EPOCH: 25725 LOSS: 40.974103958844694\n",
      "EPOCH: 25726 LOSS: 40.97410265663221\n",
      "EPOCH: 25727 LOSS: 40.97410135449889\n",
      "EPOCH: 25728 LOSS: 40.9741000524448\n",
      "EPOCH: 25729 LOSS: 40.974098750469864\n",
      "EPOCH: 25730 LOSS: 40.974097448574106\n",
      "EPOCH: 25731 LOSS: 40.97409614675751\n",
      "EPOCH: 25732 LOSS: 40.97409484502005\n",
      "EPOCH: 25733 LOSS: 40.97409354336176\n",
      "EPOCH: 25734 LOSS: 40.974092241782586\n",
      "EPOCH: 25735 LOSS: 40.97409094028255\n",
      "EPOCH: 25736 LOSS: 40.97408963886163\n",
      "EPOCH: 25737 LOSS: 40.9740883375198\n",
      "EPOCH: 25738 LOSS: 40.9740870362571\n",
      "EPOCH: 25739 LOSS: 40.974085735073466\n",
      "EPOCH: 25740 LOSS: 40.974084433968926\n",
      "EPOCH: 25741 LOSS: 40.97408313294345\n",
      "EPOCH: 25742 LOSS: 40.97408183199704\n",
      "EPOCH: 25743 LOSS: 40.97408053112967\n",
      "EPOCH: 25744 LOSS: 40.97407923034135\n",
      "EPOCH: 25745 LOSS: 40.97407792963208\n",
      "EPOCH: 25746 LOSS: 40.97407662900182\n",
      "EPOCH: 25747 LOSS: 40.97407532845058\n",
      "EPOCH: 25748 LOSS: 40.97407402797836\n",
      "EPOCH: 25749 LOSS: 40.974072727585124\n",
      "EPOCH: 25750 LOSS: 40.9740714272709\n",
      "EPOCH: 25751 LOSS: 40.97407012703563\n",
      "EPOCH: 25752 LOSS: 40.974068826879346\n",
      "EPOCH: 25753 LOSS: 40.97406752680202\n",
      "EPOCH: 25754 LOSS: 40.97406622680364\n",
      "EPOCH: 25755 LOSS: 40.974064926884225\n",
      "EPOCH: 25756 LOSS: 40.97406362704373\n",
      "EPOCH: 25757 LOSS: 40.974062327282155\n",
      "EPOCH: 25758 LOSS: 40.97406102759951\n",
      "EPOCH: 25759 LOSS: 40.97405972799578\n",
      "EPOCH: 25760 LOSS: 40.974058428470926\n",
      "EPOCH: 25761 LOSS: 40.974057129024985\n",
      "EPOCH: 25762 LOSS: 40.974055829657914\n",
      "EPOCH: 25763 LOSS: 40.97405453036971\n",
      "EPOCH: 25764 LOSS: 40.974053231160376\n",
      "EPOCH: 25765 LOSS: 40.974051932029894\n",
      "EPOCH: 25766 LOSS: 40.97405063297827\n",
      "EPOCH: 25767 LOSS: 40.97404933400546\n",
      "EPOCH: 25768 LOSS: 40.97404803511149\n",
      "EPOCH: 25769 LOSS: 40.97404673629634\n",
      "EPOCH: 25770 LOSS: 40.97404543755999\n",
      "EPOCH: 25771 LOSS: 40.97404413890244\n",
      "EPOCH: 25772 LOSS: 40.974042840323676\n",
      "EPOCH: 25773 LOSS: 40.9740415418237\n",
      "EPOCH: 25774 LOSS: 40.97404024340251\n",
      "EPOCH: 25775 LOSS: 40.97403894506007\n",
      "EPOCH: 25776 LOSS: 40.974037646796376\n",
      "EPOCH: 25777 LOSS: 40.974036348611456\n",
      "EPOCH: 25778 LOSS: 40.97403505050525\n",
      "EPOCH: 25779 LOSS: 40.97403375247776\n",
      "EPOCH: 25780 LOSS: 40.97403245452901\n",
      "EPOCH: 25781 LOSS: 40.97403115665896\n",
      "EPOCH: 25782 LOSS: 40.97402985886762\n",
      "EPOCH: 25783 LOSS: 40.97402856115497\n",
      "EPOCH: 25784 LOSS: 40.974027263521\n",
      "EPOCH: 25785 LOSS: 40.974025965965694\n",
      "EPOCH: 25786 LOSS: 40.97402466848906\n",
      "EPOCH: 25787 LOSS: 40.97402337109108\n",
      "EPOCH: 25788 LOSS: 40.97402207377175\n",
      "EPOCH: 25789 LOSS: 40.97402077653105\n",
      "EPOCH: 25790 LOSS: 40.97401947936899\n",
      "EPOCH: 25791 LOSS: 40.97401818228553\n",
      "EPOCH: 25792 LOSS: 40.974016885280705\n",
      "EPOCH: 25793 LOSS: 40.97401558835445\n",
      "EPOCH: 25794 LOSS: 40.97401429150682\n",
      "EPOCH: 25795 LOSS: 40.97401299473775\n",
      "EPOCH: 25796 LOSS: 40.97401169804727\n",
      "EPOCH: 25797 LOSS: 40.97401040143535\n",
      "EPOCH: 25798 LOSS: 40.97400910490197\n",
      "EPOCH: 25799 LOSS: 40.974007808447155\n",
      "EPOCH: 25800 LOSS: 40.974006512070886\n",
      "EPOCH: 25801 LOSS: 40.97400521577313\n",
      "EPOCH: 25802 LOSS: 40.97400391955391\n",
      "EPOCH: 25803 LOSS: 40.97400262341318\n",
      "EPOCH: 25804 LOSS: 40.97400132735096\n",
      "EPOCH: 25805 LOSS: 40.97400003136724\n",
      "EPOCH: 25806 LOSS: 40.973998735462004\n",
      "EPOCH: 25807 LOSS: 40.97399743963524\n",
      "EPOCH: 25808 LOSS: 40.973996143886936\n",
      "EPOCH: 25809 LOSS: 40.9739948482171\n",
      "EPOCH: 25810 LOSS: 40.973993552625714\n",
      "EPOCH: 25811 LOSS: 40.973992257112755\n",
      "EPOCH: 25812 LOSS: 40.97399096167824\n",
      "EPOCH: 25813 LOSS: 40.97398966632213\n",
      "EPOCH: 25814 LOSS: 40.973988371044456\n",
      "EPOCH: 25815 LOSS: 40.97398707584516\n",
      "EPOCH: 25816 LOSS: 40.97398578072428\n",
      "EPOCH: 25817 LOSS: 40.973984485681775\n",
      "EPOCH: 25818 LOSS: 40.97398319071765\n",
      "EPOCH: 25819 LOSS: 40.97398189583188\n",
      "EPOCH: 25820 LOSS: 40.97398060102448\n",
      "EPOCH: 25821 LOSS: 40.97397930629543\n",
      "EPOCH: 25822 LOSS: 40.97397801164472\n",
      "EPOCH: 25823 LOSS: 40.97397671707235\n",
      "EPOCH: 25824 LOSS: 40.973975422578306\n",
      "EPOCH: 25825 LOSS: 40.973974128162546\n",
      "EPOCH: 25826 LOSS: 40.973972833825115\n",
      "EPOCH: 25827 LOSS: 40.973971539565966\n",
      "EPOCH: 25828 LOSS: 40.97397024538512\n",
      "EPOCH: 25829 LOSS: 40.973968951282544\n",
      "EPOCH: 25830 LOSS: 40.97396765725822\n",
      "EPOCH: 25831 LOSS: 40.973966363312186\n",
      "EPOCH: 25832 LOSS: 40.97396506944439\n",
      "EPOCH: 25833 LOSS: 40.97396377565483\n",
      "EPOCH: 25834 LOSS: 40.973962481943516\n",
      "EPOCH: 25835 LOSS: 40.97396118831042\n",
      "EPOCH: 25836 LOSS: 40.97395989475554\n",
      "EPOCH: 25837 LOSS: 40.97395860127886\n",
      "EPOCH: 25838 LOSS: 40.9739573078804\n",
      "EPOCH: 25839 LOSS: 40.9739560145601\n",
      "EPOCH: 25840 LOSS: 40.973954721317995\n",
      "EPOCH: 25841 LOSS: 40.973953428154054\n",
      "EPOCH: 25842 LOSS: 40.973952135068274\n",
      "EPOCH: 25843 LOSS: 40.97395084206066\n",
      "EPOCH: 25844 LOSS: 40.97394954913118\n",
      "EPOCH: 25845 LOSS: 40.97394825627984\n",
      "EPOCH: 25846 LOSS: 40.97394696350662\n",
      "EPOCH: 25847 LOSS: 40.97394567081152\n",
      "EPOCH: 25848 LOSS: 40.97394437819453\n",
      "EPOCH: 25849 LOSS: 40.973943085655634\n",
      "EPOCH: 25850 LOSS: 40.97394179319484\n",
      "EPOCH: 25851 LOSS: 40.97394050081212\n",
      "EPOCH: 25852 LOSS: 40.97393920850746\n",
      "EPOCH: 25853 LOSS: 40.97393791628088\n",
      "EPOCH: 25854 LOSS: 40.97393662413234\n",
      "EPOCH: 25855 LOSS: 40.97393533206187\n",
      "EPOCH: 25856 LOSS: 40.97393404006942\n",
      "EPOCH: 25857 LOSS: 40.973932748155\n",
      "EPOCH: 25858 LOSS: 40.97393145631861\n",
      "EPOCH: 25859 LOSS: 40.973930164560215\n",
      "EPOCH: 25860 LOSS: 40.97392887287984\n",
      "EPOCH: 25861 LOSS: 40.97392758127742\n",
      "EPOCH: 25862 LOSS: 40.97392628975302\n",
      "EPOCH: 25863 LOSS: 40.97392499830657\n",
      "EPOCH: 25864 LOSS: 40.9739237069381\n",
      "EPOCH: 25865 LOSS: 40.973922415647586\n",
      "EPOCH: 25866 LOSS: 40.97392112443502\n",
      "EPOCH: 25867 LOSS: 40.97391983330039\n",
      "EPOCH: 25868 LOSS: 40.973918542243695\n",
      "EPOCH: 25869 LOSS: 40.97391725126492\n",
      "EPOCH: 25870 LOSS: 40.97391596036406\n",
      "EPOCH: 25871 LOSS: 40.9739146695411\n",
      "EPOCH: 25872 LOSS: 40.973913378796034\n",
      "EPOCH: 25873 LOSS: 40.97391208812884\n",
      "EPOCH: 25874 LOSS: 40.97391079753953\n",
      "EPOCH: 25875 LOSS: 40.9739095070281\n",
      "EPOCH: 25876 LOSS: 40.973908216594516\n",
      "EPOCH: 25877 LOSS: 40.97390692623878\n",
      "EPOCH: 25878 LOSS: 40.9739056359609\n",
      "EPOCH: 25879 LOSS: 40.97390434576084\n",
      "EPOCH: 25880 LOSS: 40.97390305563861\n",
      "EPOCH: 25881 LOSS: 40.9739017655942\n",
      "EPOCH: 25882 LOSS: 40.9739004756276\n",
      "EPOCH: 25883 LOSS: 40.973899185738766\n",
      "EPOCH: 25884 LOSS: 40.97389789592774\n",
      "EPOCH: 25885 LOSS: 40.97389660619449\n",
      "EPOCH: 25886 LOSS: 40.97389531653902\n",
      "EPOCH: 25887 LOSS: 40.97389402696132\n",
      "EPOCH: 25888 LOSS: 40.97389273746134\n",
      "EPOCH: 25889 LOSS: 40.973891448039126\n",
      "EPOCH: 25890 LOSS: 40.97389015869463\n",
      "EPOCH: 25891 LOSS: 40.97388886942788\n",
      "EPOCH: 25892 LOSS: 40.97388758023884\n",
      "EPOCH: 25893 LOSS: 40.973886291127506\n",
      "EPOCH: 25894 LOSS: 40.97388500209385\n",
      "EPOCH: 25895 LOSS: 40.973883713137916\n",
      "EPOCH: 25896 LOSS: 40.97388242425965\n",
      "EPOCH: 25897 LOSS: 40.973881135459074\n",
      "EPOCH: 25898 LOSS: 40.97387984673613\n",
      "EPOCH: 25899 LOSS: 40.97387855809087\n",
      "EPOCH: 25900 LOSS: 40.97387726952324\n",
      "EPOCH: 25901 LOSS: 40.97387598103326\n",
      "EPOCH: 25902 LOSS: 40.973874692620896\n",
      "EPOCH: 25903 LOSS: 40.973873404286145\n",
      "EPOCH: 25904 LOSS: 40.973872116029014\n",
      "EPOCH: 25905 LOSS: 40.97387082784948\n",
      "EPOCH: 25906 LOSS: 40.973869539747554\n",
      "EPOCH: 25907 LOSS: 40.9738682517232\n",
      "EPOCH: 25908 LOSS: 40.97386696377642\n",
      "EPOCH: 25909 LOSS: 40.97386567590722\n",
      "EPOCH: 25910 LOSS: 40.97386438811557\n",
      "EPOCH: 25911 LOSS: 40.973863100401466\n",
      "EPOCH: 25912 LOSS: 40.9738618127649\n",
      "EPOCH: 25913 LOSS: 40.97386052520588\n",
      "EPOCH: 25914 LOSS: 40.97385923772437\n",
      "EPOCH: 25915 LOSS: 40.973857950320365\n",
      "EPOCH: 25916 LOSS: 40.973856662993875\n",
      "EPOCH: 25917 LOSS: 40.97385537574489\n",
      "EPOCH: 25918 LOSS: 40.973854088573376\n",
      "EPOCH: 25919 LOSS: 40.97385280147935\n",
      "EPOCH: 25920 LOSS: 40.97385151446278\n",
      "EPOCH: 25921 LOSS: 40.97385022752369\n",
      "EPOCH: 25922 LOSS: 40.973848940662045\n",
      "EPOCH: 25923 LOSS: 40.97384765387784\n",
      "EPOCH: 25924 LOSS: 40.97384636717107\n",
      "EPOCH: 25925 LOSS: 40.97384508054173\n",
      "EPOCH: 25926 LOSS: 40.97384379398979\n",
      "EPOCH: 25927 LOSS: 40.97384250751527\n",
      "EPOCH: 25928 LOSS: 40.97384122111815\n",
      "EPOCH: 25929 LOSS: 40.97383993479842\n",
      "EPOCH: 25930 LOSS: 40.97383864855607\n",
      "EPOCH: 25931 LOSS: 40.973837362391095\n",
      "EPOCH: 25932 LOSS: 40.97383607630348\n",
      "EPOCH: 25933 LOSS: 40.97383479029322\n",
      "EPOCH: 25934 LOSS: 40.973833504360314\n",
      "EPOCH: 25935 LOSS: 40.973832218504725\n",
      "EPOCH: 25936 LOSS: 40.973830932726486\n",
      "EPOCH: 25937 LOSS: 40.97382964702555\n",
      "EPOCH: 25938 LOSS: 40.97382836140194\n",
      "EPOCH: 25939 LOSS: 40.973827075855624\n",
      "EPOCH: 25940 LOSS: 40.9738257903866\n",
      "EPOCH: 25941 LOSS: 40.973824504994866\n",
      "EPOCH: 25942 LOSS: 40.9738232196804\n",
      "EPOCH: 25943 LOSS: 40.97382193444321\n",
      "EPOCH: 25944 LOSS: 40.97382064928326\n",
      "EPOCH: 25945 LOSS: 40.97381936420057\n",
      "EPOCH: 25946 LOSS: 40.97381807919513\n",
      "EPOCH: 25947 LOSS: 40.97381679426691\n",
      "EPOCH: 25948 LOSS: 40.973815509415935\n",
      "EPOCH: 25949 LOSS: 40.97381422464214\n",
      "EPOCH: 25950 LOSS: 40.973812939945574\n",
      "EPOCH: 25951 LOSS: 40.9738116553262\n",
      "EPOCH: 25952 LOSS: 40.97381037078401\n",
      "EPOCH: 25953 LOSS: 40.973809086319\n",
      "EPOCH: 25954 LOSS: 40.97380780193115\n",
      "EPOCH: 25955 LOSS: 40.973806517620474\n",
      "EPOCH: 25956 LOSS: 40.97380523338696\n",
      "EPOCH: 25957 LOSS: 40.97380394923059\n",
      "EPOCH: 25958 LOSS: 40.97380266515134\n",
      "EPOCH: 25959 LOSS: 40.97380138114922\n",
      "EPOCH: 25960 LOSS: 40.97380009722421\n",
      "EPOCH: 25961 LOSS: 40.97379881337632\n",
      "EPOCH: 25962 LOSS: 40.973797529605534\n",
      "EPOCH: 25963 LOSS: 40.97379624591184\n",
      "EPOCH: 25964 LOSS: 40.973794962295216\n",
      "EPOCH: 25965 LOSS: 40.97379367875567\n",
      "EPOCH: 25966 LOSS: 40.97379239529318\n",
      "EPOCH: 25967 LOSS: 40.97379111190777\n",
      "EPOCH: 25968 LOSS: 40.97378982859939\n",
      "EPOCH: 25969 LOSS: 40.97378854536805\n",
      "EPOCH: 25970 LOSS: 40.97378726221376\n",
      "EPOCH: 25971 LOSS: 40.97378597913648\n",
      "EPOCH: 25972 LOSS: 40.97378469613619\n",
      "EPOCH: 25973 LOSS: 40.973783413212914\n",
      "EPOCH: 25974 LOSS: 40.973782130366665\n",
      "EPOCH: 25975 LOSS: 40.97378084759738\n",
      "EPOCH: 25976 LOSS: 40.97377956490506\n",
      "EPOCH: 25977 LOSS: 40.97377828228973\n",
      "EPOCH: 25978 LOSS: 40.97377699975134\n",
      "EPOCH: 25979 LOSS: 40.97377571728991\n",
      "EPOCH: 25980 LOSS: 40.97377443490542\n",
      "EPOCH: 25981 LOSS: 40.97377315259788\n",
      "EPOCH: 25982 LOSS: 40.97377187036724\n",
      "EPOCH: 25983 LOSS: 40.97377058821353\n",
      "EPOCH: 25984 LOSS: 40.97376930613674\n",
      "EPOCH: 25985 LOSS: 40.97376802413684\n",
      "EPOCH: 25986 LOSS: 40.973766742213826\n",
      "EPOCH: 25987 LOSS: 40.973765460367694\n",
      "EPOCH: 25988 LOSS: 40.97376417859844\n",
      "EPOCH: 25989 LOSS: 40.973762896906045\n",
      "EPOCH: 25990 LOSS: 40.9737616152905\n",
      "EPOCH: 25991 LOSS: 40.9737603337518\n",
      "EPOCH: 25992 LOSS: 40.973759052289935\n",
      "EPOCH: 25993 LOSS: 40.973757770904925\n",
      "EPOCH: 25994 LOSS: 40.973756489596724\n",
      "EPOCH: 25995 LOSS: 40.97375520836533\n",
      "EPOCH: 25996 LOSS: 40.97375392721074\n",
      "EPOCH: 25997 LOSS: 40.973752646132944\n",
      "EPOCH: 25998 LOSS: 40.97375136513193\n",
      "EPOCH: 25999 LOSS: 40.973750084207715\n",
      "EPOCH: 26000 LOSS: 40.97374880336024\n",
      "EPOCH: 26001 LOSS: 40.973747522589534\n",
      "EPOCH: 26002 LOSS: 40.97374624189558\n",
      "EPOCH: 26003 LOSS: 40.97374496127837\n",
      "EPOCH: 26004 LOSS: 40.97374368073789\n",
      "EPOCH: 26005 LOSS: 40.973742400274126\n",
      "EPOCH: 26006 LOSS: 40.9737411198871\n",
      "EPOCH: 26007 LOSS: 40.97373983957676\n",
      "EPOCH: 26008 LOSS: 40.97373855934312\n",
      "EPOCH: 26009 LOSS: 40.97373727918618\n",
      "EPOCH: 26010 LOSS: 40.973735999105934\n",
      "EPOCH: 26011 LOSS: 40.97373471910233\n",
      "EPOCH: 26012 LOSS: 40.973733439175405\n",
      "EPOCH: 26013 LOSS: 40.97373215932515\n",
      "EPOCH: 26014 LOSS: 40.97373087955152\n",
      "EPOCH: 26015 LOSS: 40.973729599854536\n",
      "EPOCH: 26016 LOSS: 40.97372832023418\n",
      "EPOCH: 26017 LOSS: 40.97372704069045\n",
      "EPOCH: 26018 LOSS: 40.97372576122332\n",
      "EPOCH: 26019 LOSS: 40.97372448183279\n",
      "EPOCH: 26020 LOSS: 40.973723202518876\n",
      "EPOCH: 26021 LOSS: 40.973721923281545\n",
      "EPOCH: 26022 LOSS: 40.97372064412076\n",
      "EPOCH: 26023 LOSS: 40.97371936503656\n",
      "EPOCH: 26024 LOSS: 40.97371808602894\n",
      "EPOCH: 26025 LOSS: 40.973716807097844\n",
      "EPOCH: 26026 LOSS: 40.9737155282433\n",
      "EPOCH: 26027 LOSS: 40.9737142494653\n",
      "EPOCH: 26028 LOSS: 40.97371297076381\n",
      "EPOCH: 26029 LOSS: 40.97371169213884\n",
      "EPOCH: 26030 LOSS: 40.973710413590396\n",
      "EPOCH: 26031 LOSS: 40.97370913511841\n",
      "EPOCH: 26032 LOSS: 40.97370785672295\n",
      "EPOCH: 26033 LOSS: 40.97370657840396\n",
      "EPOCH: 26034 LOSS: 40.973705300161456\n",
      "EPOCH: 26035 LOSS: 40.9737040219954\n",
      "EPOCH: 26036 LOSS: 40.97370274390579\n",
      "EPOCH: 26037 LOSS: 40.973701465892646\n",
      "EPOCH: 26038 LOSS: 40.973700187955934\n",
      "EPOCH: 26039 LOSS: 40.97369891009565\n",
      "EPOCH: 26040 LOSS: 40.9736976323118\n",
      "EPOCH: 26041 LOSS: 40.97369635460436\n",
      "EPOCH: 26042 LOSS: 40.9736950769733\n",
      "EPOCH: 26043 LOSS: 40.97369379941864\n",
      "EPOCH: 26044 LOSS: 40.97369252194038\n",
      "EPOCH: 26045 LOSS: 40.9736912445385\n",
      "EPOCH: 26046 LOSS: 40.97368996721299\n",
      "EPOCH: 26047 LOSS: 40.97368868996383\n",
      "EPOCH: 26048 LOSS: 40.97368741279102\n",
      "EPOCH: 26049 LOSS: 40.973686135694564\n",
      "EPOCH: 26050 LOSS: 40.97368485867443\n",
      "EPOCH: 26051 LOSS: 40.973683581730626\n",
      "EPOCH: 26052 LOSS: 40.97368230486316\n",
      "EPOCH: 26053 LOSS: 40.97368102807197\n",
      "EPOCH: 26054 LOSS: 40.97367975135711\n",
      "EPOCH: 26055 LOSS: 40.973678474718525\n",
      "EPOCH: 26056 LOSS: 40.973677198156224\n",
      "EPOCH: 26057 LOSS: 40.97367592167019\n",
      "EPOCH: 26058 LOSS: 40.973674645260424\n",
      "EPOCH: 26059 LOSS: 40.973673368926924\n",
      "EPOCH: 26060 LOSS: 40.97367209266967\n",
      "EPOCH: 26061 LOSS: 40.973670816488664\n",
      "EPOCH: 26062 LOSS: 40.97366954038387\n",
      "EPOCH: 26063 LOSS: 40.973668264355304\n",
      "EPOCH: 26064 LOSS: 40.97366698840295\n",
      "EPOCH: 26065 LOSS: 40.97366571252682\n",
      "EPOCH: 26066 LOSS: 40.973664436726864\n",
      "EPOCH: 26067 LOSS: 40.9736631610031\n",
      "EPOCH: 26068 LOSS: 40.97366188535553\n",
      "EPOCH: 26069 LOSS: 40.97366060978412\n",
      "EPOCH: 26070 LOSS: 40.97365933428887\n",
      "EPOCH: 26071 LOSS: 40.97365805886978\n",
      "EPOCH: 26072 LOSS: 40.97365678352683\n",
      "EPOCH: 26073 LOSS: 40.97365550826001\n",
      "EPOCH: 26074 LOSS: 40.97365423306933\n",
      "EPOCH: 26075 LOSS: 40.97365295795476\n",
      "EPOCH: 26076 LOSS: 40.97365168291631\n",
      "EPOCH: 26077 LOSS: 40.973650407953954\n",
      "EPOCH: 26078 LOSS: 40.973649133067696\n",
      "EPOCH: 26079 LOSS: 40.97364785825752\n",
      "EPOCH: 26080 LOSS: 40.97364658352341\n",
      "EPOCH: 26081 LOSS: 40.97364530886538\n",
      "EPOCH: 26082 LOSS: 40.97364403428341\n",
      "EPOCH: 26083 LOSS: 40.973642759777476\n",
      "EPOCH: 26084 LOSS: 40.9736414853476\n",
      "EPOCH: 26085 LOSS: 40.97364021099376\n",
      "EPOCH: 26086 LOSS: 40.973638936715915\n",
      "EPOCH: 26087 LOSS: 40.97363766251412\n",
      "EPOCH: 26088 LOSS: 40.97363638838832\n",
      "EPOCH: 26089 LOSS: 40.97363511433852\n",
      "EPOCH: 26090 LOSS: 40.9736338403647\n",
      "EPOCH: 26091 LOSS: 40.97363256646685\n",
      "EPOCH: 26092 LOSS: 40.973631292645024\n",
      "EPOCH: 26093 LOSS: 40.97363001889913\n",
      "EPOCH: 26094 LOSS: 40.97362874522918\n",
      "EPOCH: 26095 LOSS: 40.9736274716352\n",
      "EPOCH: 26096 LOSS: 40.97362619811713\n",
      "EPOCH: 26097 LOSS: 40.973624924675015\n",
      "EPOCH: 26098 LOSS: 40.9736236513088\n",
      "EPOCH: 26099 LOSS: 40.97362237801852\n",
      "EPOCH: 26100 LOSS: 40.97362110480414\n",
      "EPOCH: 26101 LOSS: 40.97361983166566\n",
      "EPOCH: 26102 LOSS: 40.97361855860305\n",
      "EPOCH: 26103 LOSS: 40.97361728561633\n",
      "EPOCH: 26104 LOSS: 40.973616012705484\n",
      "EPOCH: 26105 LOSS: 40.97361473987049\n",
      "EPOCH: 26106 LOSS: 40.97361346711134\n",
      "EPOCH: 26107 LOSS: 40.97361219442806\n",
      "EPOCH: 26108 LOSS: 40.97361092182059\n",
      "EPOCH: 26109 LOSS: 40.973609649288974\n",
      "EPOCH: 26110 LOSS: 40.973608376833155\n",
      "EPOCH: 26111 LOSS: 40.97360710445316\n",
      "EPOCH: 26112 LOSS: 40.97360583214895\n",
      "EPOCH: 26113 LOSS: 40.973604559920545\n",
      "EPOCH: 26114 LOSS: 40.97360328776792\n",
      "EPOCH: 26115 LOSS: 40.973602015691085\n",
      "EPOCH: 26116 LOSS: 40.97360074369\n",
      "EPOCH: 26117 LOSS: 40.97359947176468\n",
      "EPOCH: 26118 LOSS: 40.973598199915116\n",
      "EPOCH: 26119 LOSS: 40.97359692814128\n",
      "EPOCH: 26120 LOSS: 40.973595656443194\n",
      "EPOCH: 26121 LOSS: 40.97359438482081\n",
      "EPOCH: 26122 LOSS: 40.97359311327417\n",
      "EPOCH: 26123 LOSS: 40.97359184180323\n",
      "EPOCH: 26124 LOSS: 40.973590570407964\n",
      "EPOCH: 26125 LOSS: 40.97358929908841\n",
      "EPOCH: 26126 LOSS: 40.97358802784455\n",
      "EPOCH: 26127 LOSS: 40.97358675667635\n",
      "EPOCH: 26128 LOSS: 40.97358548558381\n",
      "EPOCH: 26129 LOSS: 40.97358421456693\n",
      "EPOCH: 26130 LOSS: 40.973582943625686\n",
      "EPOCH: 26131 LOSS: 40.973581672760105\n",
      "EPOCH: 26132 LOSS: 40.97358040197014\n",
      "EPOCH: 26133 LOSS: 40.9735791312558\n",
      "EPOCH: 26134 LOSS: 40.97357786061707\n",
      "EPOCH: 26135 LOSS: 40.97357659005395\n",
      "EPOCH: 26136 LOSS: 40.973575319566436\n",
      "EPOCH: 26137 LOSS: 40.9735740491545\n",
      "EPOCH: 26138 LOSS: 40.97357277881814\n",
      "EPOCH: 26139 LOSS: 40.97357150855735\n",
      "EPOCH: 26140 LOSS: 40.973570238372126\n",
      "EPOCH: 26141 LOSS: 40.97356896826247\n",
      "EPOCH: 26142 LOSS: 40.973567698228344\n",
      "EPOCH: 26143 LOSS: 40.97356642826976\n",
      "EPOCH: 26144 LOSS: 40.97356515838669\n",
      "EPOCH: 26145 LOSS: 40.97356388857916\n",
      "EPOCH: 26146 LOSS: 40.97356261884714\n",
      "EPOCH: 26147 LOSS: 40.97356134919062\n",
      "EPOCH: 26148 LOSS: 40.97356007960959\n",
      "EPOCH: 26149 LOSS: 40.973558810104045\n",
      "EPOCH: 26150 LOSS: 40.97355754067398\n",
      "EPOCH: 26151 LOSS: 40.973556271319374\n",
      "EPOCH: 26152 LOSS: 40.97355500204025\n",
      "EPOCH: 26153 LOSS: 40.97355373283657\n",
      "EPOCH: 26154 LOSS: 40.97355246370833\n",
      "EPOCH: 26155 LOSS: 40.97355119465553\n",
      "EPOCH: 26156 LOSS: 40.97354992567816\n",
      "EPOCH: 26157 LOSS: 40.973548656776195\n",
      "EPOCH: 26158 LOSS: 40.97354738794964\n",
      "EPOCH: 26159 LOSS: 40.973546119198495\n",
      "EPOCH: 26160 LOSS: 40.97354485052274\n",
      "EPOCH: 26161 LOSS: 40.973543581922364\n",
      "EPOCH: 26162 LOSS: 40.97354231339736\n",
      "EPOCH: 26163 LOSS: 40.973541044947744\n",
      "EPOCH: 26164 LOSS: 40.973539776573475\n",
      "EPOCH: 26165 LOSS: 40.97353850827456\n",
      "EPOCH: 26166 LOSS: 40.97353724005097\n",
      "EPOCH: 26167 LOSS: 40.973535971902734\n",
      "EPOCH: 26168 LOSS: 40.973534703829806\n",
      "EPOCH: 26169 LOSS: 40.97353343583221\n",
      "EPOCH: 26170 LOSS: 40.973532167909916\n",
      "EPOCH: 26171 LOSS: 40.97353090006291\n",
      "EPOCH: 26172 LOSS: 40.9735296322912\n",
      "EPOCH: 26173 LOSS: 40.97352836459478\n",
      "EPOCH: 26174 LOSS: 40.97352709697364\n",
      "EPOCH: 26175 LOSS: 40.97352582942775\n",
      "EPOCH: 26176 LOSS: 40.97352456195712\n",
      "EPOCH: 26177 LOSS: 40.973523294561744\n",
      "EPOCH: 26178 LOSS: 40.973522027241614\n",
      "EPOCH: 26179 LOSS: 40.9735207599967\n",
      "EPOCH: 26180 LOSS: 40.97351949282701\n",
      "EPOCH: 26181 LOSS: 40.97351822573255\n",
      "EPOCH: 26182 LOSS: 40.97351695871329\n",
      "EPOCH: 26183 LOSS: 40.97351569176922\n",
      "EPOCH: 26184 LOSS: 40.97351442490034\n",
      "EPOCH: 26185 LOSS: 40.97351315810665\n",
      "EPOCH: 26186 LOSS: 40.973511891388135\n",
      "EPOCH: 26187 LOSS: 40.973510624744776\n",
      "EPOCH: 26188 LOSS: 40.97350935817656\n",
      "EPOCH: 26189 LOSS: 40.97350809168351\n",
      "EPOCH: 26190 LOSS: 40.97350682526559\n",
      "EPOCH: 26191 LOSS: 40.973505558922795\n",
      "EPOCH: 26192 LOSS: 40.973504292655136\n",
      "EPOCH: 26193 LOSS: 40.97350302646257\n",
      "EPOCH: 26194 LOSS: 40.97350176034513\n",
      "EPOCH: 26195 LOSS: 40.9735004943028\n",
      "EPOCH: 26196 LOSS: 40.97349922833551\n",
      "EPOCH: 26197 LOSS: 40.97349796244333\n",
      "EPOCH: 26198 LOSS: 40.97349669662621\n",
      "EPOCH: 26199 LOSS: 40.973495430884185\n",
      "EPOCH: 26200 LOSS: 40.973494165217176\n",
      "EPOCH: 26201 LOSS: 40.97349289962523\n",
      "EPOCH: 26202 LOSS: 40.97349163410831\n",
      "EPOCH: 26203 LOSS: 40.973490368666425\n",
      "EPOCH: 26204 LOSS: 40.97348910329957\n",
      "EPOCH: 26205 LOSS: 40.97348783800771\n",
      "EPOCH: 26206 LOSS: 40.97348657279086\n",
      "EPOCH: 26207 LOSS: 40.973485307649014\n",
      "EPOCH: 26208 LOSS: 40.97348404258216\n",
      "EPOCH: 26209 LOSS: 40.97348277759028\n",
      "EPOCH: 26210 LOSS: 40.973481512673345\n",
      "EPOCH: 26211 LOSS: 40.97348024783138\n",
      "EPOCH: 26212 LOSS: 40.97347898306439\n",
      "EPOCH: 26213 LOSS: 40.97347771837234\n",
      "EPOCH: 26214 LOSS: 40.9734764537552\n",
      "EPOCH: 26215 LOSS: 40.97347518921301\n",
      "EPOCH: 26216 LOSS: 40.97347392474573\n",
      "EPOCH: 26217 LOSS: 40.973472660353366\n",
      "EPOCH: 26218 LOSS: 40.97347139603592\n",
      "EPOCH: 26219 LOSS: 40.97347013179334\n",
      "EPOCH: 26220 LOSS: 40.973468867625655\n",
      "EPOCH: 26221 LOSS: 40.97346760353285\n",
      "EPOCH: 26222 LOSS: 40.97346633951493\n",
      "EPOCH: 26223 LOSS: 40.973465075571845\n",
      "EPOCH: 26224 LOSS: 40.973463811703624\n",
      "EPOCH: 26225 LOSS: 40.973462547910245\n",
      "EPOCH: 26226 LOSS: 40.9734612841917\n",
      "EPOCH: 26227 LOSS: 40.973460020547975\n",
      "EPOCH: 26228 LOSS: 40.973458756979085\n",
      "EPOCH: 26229 LOSS: 40.973457493485014\n",
      "EPOCH: 26230 LOSS: 40.97345623006572\n",
      "EPOCH: 26231 LOSS: 40.97345496672122\n",
      "EPOCH: 26232 LOSS: 40.97345370345151\n",
      "EPOCH: 26233 LOSS: 40.973452440256594\n",
      "EPOCH: 26234 LOSS: 40.973451177136425\n",
      "EPOCH: 26235 LOSS: 40.97344991409102\n",
      "EPOCH: 26236 LOSS: 40.97344865112039\n",
      "EPOCH: 26237 LOSS: 40.97344738822445\n",
      "EPOCH: 26238 LOSS: 40.973446125403285\n",
      "EPOCH: 26239 LOSS: 40.97344486265685\n",
      "EPOCH: 26240 LOSS: 40.97344359998511\n",
      "EPOCH: 26241 LOSS: 40.973442337388086\n",
      "EPOCH: 26242 LOSS: 40.973441074865775\n",
      "EPOCH: 26243 LOSS: 40.97343981241814\n",
      "EPOCH: 26244 LOSS: 40.9734385500452\n",
      "EPOCH: 26245 LOSS: 40.97343728774694\n",
      "EPOCH: 26246 LOSS: 40.97343602552335\n",
      "EPOCH: 26247 LOSS: 40.97343476337441\n",
      "EPOCH: 26248 LOSS: 40.97343350130012\n",
      "EPOCH: 26249 LOSS: 40.973432239300465\n",
      "EPOCH: 26250 LOSS: 40.97343097737546\n",
      "EPOCH: 26251 LOSS: 40.97342971552507\n",
      "EPOCH: 26252 LOSS: 40.97342845374931\n",
      "EPOCH: 26253 LOSS: 40.973427192048156\n",
      "EPOCH: 26254 LOSS: 40.973425930421584\n",
      "EPOCH: 26255 LOSS: 40.97342466886963\n",
      "EPOCH: 26256 LOSS: 40.97342340739225\n",
      "EPOCH: 26257 LOSS: 40.97342214598944\n",
      "EPOCH: 26258 LOSS: 40.9734208846612\n",
      "EPOCH: 26259 LOSS: 40.97341962340753\n",
      "EPOCH: 26260 LOSS: 40.9734183622284\n",
      "EPOCH: 26261 LOSS: 40.973417101123815\n",
      "EPOCH: 26262 LOSS: 40.97341584009375\n",
      "EPOCH: 26263 LOSS: 40.973414579138236\n",
      "EPOCH: 26264 LOSS: 40.973413318257215\n",
      "EPOCH: 26265 LOSS: 40.97341205745072\n",
      "EPOCH: 26266 LOSS: 40.97341079671871\n",
      "EPOCH: 26267 LOSS: 40.97340953606121\n",
      "EPOCH: 26268 LOSS: 40.97340827547818\n",
      "EPOCH: 26269 LOSS: 40.973407014969645\n",
      "EPOCH: 26270 LOSS: 40.97340575453555\n",
      "EPOCH: 26271 LOSS: 40.97340449417593\n",
      "EPOCH: 26272 LOSS: 40.97340323389076\n",
      "EPOCH: 26273 LOSS: 40.973401973680026\n",
      "EPOCH: 26274 LOSS: 40.97340071354373\n",
      "EPOCH: 26275 LOSS: 40.97339945348186\n",
      "EPOCH: 26276 LOSS: 40.973398193494404\n",
      "EPOCH: 26277 LOSS: 40.973396933581355\n",
      "EPOCH: 26278 LOSS: 40.973395673742715\n",
      "EPOCH: 26279 LOSS: 40.97339441397847\n",
      "EPOCH: 26280 LOSS: 40.97339315428861\n",
      "EPOCH: 26281 LOSS: 40.9733918946731\n",
      "EPOCH: 26282 LOSS: 40.97339063513197\n",
      "EPOCH: 26283 LOSS: 40.97338937566519\n",
      "EPOCH: 26284 LOSS: 40.97338811627278\n",
      "EPOCH: 26285 LOSS: 40.97338685695471\n",
      "EPOCH: 26286 LOSS: 40.973385597710966\n",
      "EPOCH: 26287 LOSS: 40.97338433854156\n",
      "EPOCH: 26288 LOSS: 40.97338307944645\n",
      "EPOCH: 26289 LOSS: 40.97338182042566\n",
      "EPOCH: 26290 LOSS: 40.97338056147919\n",
      "EPOCH: 26291 LOSS: 40.97337930260698\n",
      "EPOCH: 26292 LOSS: 40.97337804380908\n",
      "EPOCH: 26293 LOSS: 40.973376785085435\n",
      "EPOCH: 26294 LOSS: 40.97337552643607\n",
      "EPOCH: 26295 LOSS: 40.97337426786095\n",
      "EPOCH: 26296 LOSS: 40.973373009360095\n",
      "EPOCH: 26297 LOSS: 40.973371750933474\n",
      "EPOCH: 26298 LOSS: 40.9733704925811\n",
      "EPOCH: 26299 LOSS: 40.973369234302936\n",
      "EPOCH: 26300 LOSS: 40.973367976099\n",
      "EPOCH: 26301 LOSS: 40.97336671796926\n",
      "EPOCH: 26302 LOSS: 40.97336545991372\n",
      "EPOCH: 26303 LOSS: 40.9733642019324\n",
      "EPOCH: 26304 LOSS: 40.97336294402525\n",
      "EPOCH: 26305 LOSS: 40.97336168619226\n",
      "EPOCH: 26306 LOSS: 40.973360428433466\n",
      "EPOCH: 26307 LOSS: 40.97335917074881\n",
      "EPOCH: 26308 LOSS: 40.973357913138315\n",
      "EPOCH: 26309 LOSS: 40.97335665560196\n",
      "EPOCH: 26310 LOSS: 40.97335539813973\n",
      "EPOCH: 26311 LOSS: 40.97335414075163\n",
      "EPOCH: 26312 LOSS: 40.973352883437656\n",
      "EPOCH: 26313 LOSS: 40.97335162619779\n",
      "EPOCH: 26314 LOSS: 40.97335036903202\n",
      "EPOCH: 26315 LOSS: 40.97334911194035\n",
      "EPOCH: 26316 LOSS: 40.973347854922764\n",
      "EPOCH: 26317 LOSS: 40.97334659797927\n",
      "EPOCH: 26318 LOSS: 40.97334534110981\n",
      "EPOCH: 26319 LOSS: 40.97334408431444\n",
      "EPOCH: 26320 LOSS: 40.97334282759309\n",
      "EPOCH: 26321 LOSS: 40.97334157094582\n",
      "EPOCH: 26322 LOSS: 40.97334031437257\n",
      "EPOCH: 26323 LOSS: 40.973339057873346\n",
      "EPOCH: 26324 LOSS: 40.973337801448125\n",
      "EPOCH: 26325 LOSS: 40.97333654509694\n",
      "EPOCH: 26326 LOSS: 40.97333528881974\n",
      "EPOCH: 26327 LOSS: 40.97333403261654\n",
      "EPOCH: 26328 LOSS: 40.97333277648734\n",
      "EPOCH: 26329 LOSS: 40.97333152043209\n",
      "EPOCH: 26330 LOSS: 40.97333026445082\n",
      "EPOCH: 26331 LOSS: 40.97332900854353\n",
      "EPOCH: 26332 LOSS: 40.97332775271016\n",
      "EPOCH: 26333 LOSS: 40.97332649695076\n",
      "EPOCH: 26334 LOSS: 40.973325241265286\n",
      "EPOCH: 26335 LOSS: 40.973323985653735\n",
      "EPOCH: 26336 LOSS: 40.973322730116124\n",
      "EPOCH: 26337 LOSS: 40.97332147465241\n",
      "EPOCH: 26338 LOSS: 40.97332021926258\n",
      "EPOCH: 26339 LOSS: 40.97331896394667\n",
      "EPOCH: 26340 LOSS: 40.973317708704634\n",
      "EPOCH: 26341 LOSS: 40.9733164535365\n",
      "EPOCH: 26342 LOSS: 40.97331519844221\n",
      "EPOCH: 26343 LOSS: 40.973313943421786\n",
      "EPOCH: 26344 LOSS: 40.97331268847522\n",
      "EPOCH: 26345 LOSS: 40.97331143360249\n",
      "EPOCH: 26346 LOSS: 40.97331017880363\n",
      "EPOCH: 26347 LOSS: 40.97330892407855\n",
      "EPOCH: 26348 LOSS: 40.97330766942733\n",
      "EPOCH: 26349 LOSS: 40.9733064148499\n",
      "EPOCH: 26350 LOSS: 40.973305160346285\n",
      "EPOCH: 26351 LOSS: 40.97330390591646\n",
      "EPOCH: 26352 LOSS: 40.97330265156043\n",
      "EPOCH: 26353 LOSS: 40.97330139727818\n",
      "EPOCH: 26354 LOSS: 40.973300143069686\n",
      "EPOCH: 26355 LOSS: 40.97329888893497\n",
      "EPOCH: 26356 LOSS: 40.97329763487401\n",
      "EPOCH: 26357 LOSS: 40.9732963808868\n",
      "EPOCH: 26358 LOSS: 40.97329512697331\n",
      "EPOCH: 26359 LOSS: 40.97329387313356\n",
      "EPOCH: 26360 LOSS: 40.97329261936754\n",
      "EPOCH: 26361 LOSS: 40.97329136567521\n",
      "EPOCH: 26362 LOSS: 40.9732901120566\n",
      "EPOCH: 26363 LOSS: 40.973288858511694\n",
      "EPOCH: 26364 LOSS: 40.97328760504047\n",
      "EPOCH: 26365 LOSS: 40.97328635164294\n",
      "EPOCH: 26366 LOSS: 40.97328509831907\n",
      "EPOCH: 26367 LOSS: 40.97328384506886\n",
      "EPOCH: 26368 LOSS: 40.97328259189231\n",
      "EPOCH: 26369 LOSS: 40.97328133878941\n",
      "EPOCH: 26370 LOSS: 40.97328008576014\n",
      "EPOCH: 26371 LOSS: 40.973278832804525\n",
      "EPOCH: 26372 LOSS: 40.97327757992252\n",
      "EPOCH: 26373 LOSS: 40.97327632711412\n",
      "EPOCH: 26374 LOSS: 40.97327507437933\n",
      "EPOCH: 26375 LOSS: 40.97327382171815\n",
      "EPOCH: 26376 LOSS: 40.97327256913056\n",
      "EPOCH: 26377 LOSS: 40.97327131661653\n",
      "EPOCH: 26378 LOSS: 40.973270064176106\n",
      "EPOCH: 26379 LOSS: 40.973268811809234\n",
      "EPOCH: 26380 LOSS: 40.97326755951592\n",
      "EPOCH: 26381 LOSS: 40.97326630729615\n",
      "EPOCH: 26382 LOSS: 40.97326505514994\n",
      "EPOCH: 26383 LOSS: 40.973263803077245\n",
      "EPOCH: 26384 LOSS: 40.97326255107808\n",
      "EPOCH: 26385 LOSS: 40.973261299152426\n",
      "EPOCH: 26386 LOSS: 40.973260047300286\n",
      "EPOCH: 26387 LOSS: 40.97325879552164\n",
      "EPOCH: 26388 LOSS: 40.97325754381649\n",
      "EPOCH: 26389 LOSS: 40.97325629218484\n",
      "EPOCH: 26390 LOSS: 40.973255040626654\n",
      "EPOCH: 26391 LOSS: 40.973253789141935\n",
      "EPOCH: 26392 LOSS: 40.973252537730666\n",
      "EPOCH: 26393 LOSS: 40.97325128639285\n",
      "EPOCH: 26394 LOSS: 40.9732500351285\n",
      "EPOCH: 26395 LOSS: 40.97324878393756\n",
      "EPOCH: 26396 LOSS: 40.97324753282006\n",
      "EPOCH: 26397 LOSS: 40.97324628177597\n",
      "EPOCH: 26398 LOSS: 40.9732450308053\n",
      "EPOCH: 26399 LOSS: 40.97324377990802\n",
      "EPOCH: 26400 LOSS: 40.97324252908415\n",
      "EPOCH: 26401 LOSS: 40.97324127833367\n",
      "EPOCH: 26402 LOSS: 40.97324002765653\n",
      "EPOCH: 26403 LOSS: 40.97323877705279\n",
      "EPOCH: 26404 LOSS: 40.97323752652241\n",
      "EPOCH: 26405 LOSS: 40.97323627606538\n",
      "EPOCH: 26406 LOSS: 40.97323502568169\n",
      "EPOCH: 26407 LOSS: 40.97323377537134\n",
      "EPOCH: 26408 LOSS: 40.97323252513432\n",
      "EPOCH: 26409 LOSS: 40.973231274970615\n",
      "EPOCH: 26410 LOSS: 40.97323002488024\n",
      "EPOCH: 26411 LOSS: 40.97322877486317\n",
      "EPOCH: 26412 LOSS: 40.97322752491938\n",
      "EPOCH: 26413 LOSS: 40.97322627504888\n",
      "EPOCH: 26414 LOSS: 40.97322502525166\n",
      "EPOCH: 26415 LOSS: 40.97322377552773\n",
      "EPOCH: 26416 LOSS: 40.973222525877034\n",
      "EPOCH: 26417 LOSS: 40.97322127629961\n",
      "EPOCH: 26418 LOSS: 40.97322002679542\n",
      "EPOCH: 26419 LOSS: 40.97321877736449\n",
      "EPOCH: 26420 LOSS: 40.973217528006764\n",
      "EPOCH: 26421 LOSS: 40.97321627872228\n",
      "EPOCH: 26422 LOSS: 40.973215029511024\n",
      "EPOCH: 26423 LOSS: 40.97321378037295\n",
      "EPOCH: 26424 LOSS: 40.973212531308086\n",
      "EPOCH: 26425 LOSS: 40.97321128231639\n",
      "EPOCH: 26426 LOSS: 40.97321003339792\n",
      "EPOCH: 26427 LOSS: 40.97320878455258\n",
      "EPOCH: 26428 LOSS: 40.97320753578043\n",
      "EPOCH: 26429 LOSS: 40.973206287081446\n",
      "EPOCH: 26430 LOSS: 40.97320503845558\n",
      "EPOCH: 26431 LOSS: 40.97320378990289\n",
      "EPOCH: 26432 LOSS: 40.97320254142332\n",
      "EPOCH: 26433 LOSS: 40.97320129301687\n",
      "EPOCH: 26434 LOSS: 40.973200044683544\n",
      "EPOCH: 26435 LOSS: 40.97319879642331\n",
      "EPOCH: 26436 LOSS: 40.9731975482362\n",
      "EPOCH: 26437 LOSS: 40.973196300122176\n",
      "EPOCH: 26438 LOSS: 40.97319505208122\n",
      "EPOCH: 26439 LOSS: 40.97319380411336\n",
      "EPOCH: 26440 LOSS: 40.973192556218564\n",
      "EPOCH: 26441 LOSS: 40.97319130839683\n",
      "EPOCH: 26442 LOSS: 40.97319006064814\n",
      "EPOCH: 26443 LOSS: 40.97318881297251\n",
      "EPOCH: 26444 LOSS: 40.97318756536989\n",
      "EPOCH: 26445 LOSS: 40.97318631784032\n",
      "EPOCH: 26446 LOSS: 40.97318507038376\n",
      "EPOCH: 26447 LOSS: 40.97318382300021\n",
      "EPOCH: 26448 LOSS: 40.97318257568968\n",
      "EPOCH: 26449 LOSS: 40.97318132845213\n",
      "EPOCH: 26450 LOSS: 40.973180081287566\n",
      "EPOCH: 26451 LOSS: 40.97317883419599\n",
      "EPOCH: 26452 LOSS: 40.97317758717739\n",
      "EPOCH: 26453 LOSS: 40.97317634023174\n",
      "EPOCH: 26454 LOSS: 40.97317509335903\n",
      "EPOCH: 26455 LOSS: 40.97317384655929\n",
      "EPOCH: 26456 LOSS: 40.973172599832495\n",
      "EPOCH: 26457 LOSS: 40.973171353178614\n",
      "EPOCH: 26458 LOSS: 40.973170106597664\n",
      "EPOCH: 26459 LOSS: 40.97316886008963\n",
      "EPOCH: 26460 LOSS: 40.97316761365449\n",
      "EPOCH: 26461 LOSS: 40.97316636729225\n",
      "EPOCH: 26462 LOSS: 40.97316512100291\n",
      "EPOCH: 26463 LOSS: 40.97316387478645\n",
      "EPOCH: 26464 LOSS: 40.97316262864288\n",
      "EPOCH: 26465 LOSS: 40.97316138257216\n",
      "EPOCH: 26466 LOSS: 40.97316013657428\n",
      "EPOCH: 26467 LOSS: 40.97315889064927\n",
      "EPOCH: 26468 LOSS: 40.9731576447971\n",
      "EPOCH: 26469 LOSS: 40.97315639901776\n",
      "EPOCH: 26470 LOSS: 40.97315515331125\n",
      "EPOCH: 26471 LOSS: 40.97315390767754\n",
      "EPOCH: 26472 LOSS: 40.97315266211666\n",
      "EPOCH: 26473 LOSS: 40.97315141662858\n",
      "EPOCH: 26474 LOSS: 40.973150171213284\n",
      "EPOCH: 26475 LOSS: 40.973148925870774\n",
      "EPOCH: 26476 LOSS: 40.97314768060106\n",
      "EPOCH: 26477 LOSS: 40.97314643540409\n",
      "EPOCH: 26478 LOSS: 40.97314519027989\n",
      "EPOCH: 26479 LOSS: 40.973143945228436\n",
      "EPOCH: 26480 LOSS: 40.973142700249745\n",
      "EPOCH: 26481 LOSS: 40.973141455343765\n",
      "EPOCH: 26482 LOSS: 40.973140210510536\n",
      "EPOCH: 26483 LOSS: 40.97313896575001\n",
      "EPOCH: 26484 LOSS: 40.973137721062216\n",
      "EPOCH: 26485 LOSS: 40.973136476447124\n",
      "EPOCH: 26486 LOSS: 40.97313523190471\n",
      "EPOCH: 26487 LOSS: 40.973133987435006\n",
      "EPOCH: 26488 LOSS: 40.973132743037965\n",
      "EPOCH: 26489 LOSS: 40.97313149871361\n",
      "EPOCH: 26490 LOSS: 40.9731302544619\n",
      "EPOCH: 26491 LOSS: 40.97312901028286\n",
      "EPOCH: 26492 LOSS: 40.97312776617647\n",
      "EPOCH: 26493 LOSS: 40.97312652214272\n",
      "EPOCH: 26494 LOSS: 40.97312527818159\n",
      "EPOCH: 26495 LOSS: 40.97312403429309\n",
      "EPOCH: 26496 LOSS: 40.97312279047721\n",
      "EPOCH: 26497 LOSS: 40.97312154673395\n",
      "EPOCH: 26498 LOSS: 40.97312030306327\n",
      "EPOCH: 26499 LOSS: 40.9731190594652\n",
      "EPOCH: 26500 LOSS: 40.973117815939695\n",
      "EPOCH: 26501 LOSS: 40.97311657248676\n",
      "EPOCH: 26502 LOSS: 40.973115329106406\n",
      "EPOCH: 26503 LOSS: 40.97311408579863\n",
      "EPOCH: 26504 LOSS: 40.97311284256338\n",
      "EPOCH: 26505 LOSS: 40.97311159940067\n",
      "EPOCH: 26506 LOSS: 40.9731103563105\n",
      "EPOCH: 26507 LOSS: 40.97310911329288\n",
      "EPOCH: 26508 LOSS: 40.97310787034775\n",
      "EPOCH: 26509 LOSS: 40.97310662747515\n",
      "EPOCH: 26510 LOSS: 40.97310538467505\n",
      "EPOCH: 26511 LOSS: 40.97310414194742\n",
      "EPOCH: 26512 LOSS: 40.97310289929231\n",
      "EPOCH: 26513 LOSS: 40.97310165670967\n",
      "EPOCH: 26514 LOSS: 40.97310041419951\n",
      "EPOCH: 26515 LOSS: 40.973099171761795\n",
      "EPOCH: 26516 LOSS: 40.97309792939654\n",
      "EPOCH: 26517 LOSS: 40.97309668710374\n",
      "EPOCH: 26518 LOSS: 40.97309544488337\n",
      "EPOCH: 26519 LOSS: 40.973094202735446\n",
      "EPOCH: 26520 LOSS: 40.973092960659926\n",
      "EPOCH: 26521 LOSS: 40.97309171865683\n",
      "EPOCH: 26522 LOSS: 40.973090476726135\n",
      "EPOCH: 26523 LOSS: 40.97308923486786\n",
      "EPOCH: 26524 LOSS: 40.97308799308195\n",
      "EPOCH: 26525 LOSS: 40.973086751368434\n",
      "EPOCH: 26526 LOSS: 40.97308550972731\n",
      "EPOCH: 26527 LOSS: 40.973084268158516\n",
      "EPOCH: 26528 LOSS: 40.97308302666212\n",
      "EPOCH: 26529 LOSS: 40.97308178523805\n",
      "EPOCH: 26530 LOSS: 40.97308054388633\n",
      "EPOCH: 26531 LOSS: 40.973079302606955\n",
      "EPOCH: 26532 LOSS: 40.9730780613999\n",
      "EPOCH: 26533 LOSS: 40.97307682026515\n",
      "EPOCH: 26534 LOSS: 40.973075579202714\n",
      "EPOCH: 26535 LOSS: 40.973074338212605\n",
      "EPOCH: 26536 LOSS: 40.97307309729478\n",
      "EPOCH: 26537 LOSS: 40.97307185644923\n",
      "EPOCH: 26538 LOSS: 40.97307061567597\n",
      "EPOCH: 26539 LOSS: 40.973069374974976\n",
      "EPOCH: 26540 LOSS: 40.97306813434625\n",
      "EPOCH: 26541 LOSS: 40.973066893789785\n",
      "EPOCH: 26542 LOSS: 40.973065653305554\n",
      "EPOCH: 26543 LOSS: 40.973064412893564\n",
      "EPOCH: 26544 LOSS: 40.97306317255381\n",
      "EPOCH: 26545 LOSS: 40.973061932286285\n",
      "EPOCH: 26546 LOSS: 40.973060692090954\n",
      "EPOCH: 26547 LOSS: 40.97305945196785\n",
      "EPOCH: 26548 LOSS: 40.97305821191694\n",
      "EPOCH: 26549 LOSS: 40.973056971938234\n",
      "EPOCH: 26550 LOSS: 40.973055732031696\n",
      "EPOCH: 26551 LOSS: 40.97305449219732\n",
      "EPOCH: 26552 LOSS: 40.973053252435136\n",
      "EPOCH: 26553 LOSS: 40.9730520127451\n",
      "EPOCH: 26554 LOSS: 40.97305077312721\n",
      "EPOCH: 26555 LOSS: 40.97304953358148\n",
      "EPOCH: 26556 LOSS: 40.97304829410787\n",
      "EPOCH: 26557 LOSS: 40.9730470547064\n",
      "EPOCH: 26558 LOSS: 40.973045815377056\n",
      "EPOCH: 26559 LOSS: 40.97304457611981\n",
      "EPOCH: 26560 LOSS: 40.973043336934666\n",
      "EPOCH: 26561 LOSS: 40.973042097821605\n",
      "EPOCH: 26562 LOSS: 40.97304085878066\n",
      "EPOCH: 26563 LOSS: 40.973039619811786\n",
      "EPOCH: 26564 LOSS: 40.97303838091497\n",
      "EPOCH: 26565 LOSS: 40.97303714209023\n",
      "EPOCH: 26566 LOSS: 40.97303590333755\n",
      "EPOCH: 26567 LOSS: 40.97303466465691\n",
      "EPOCH: 26568 LOSS: 40.97303342604832\n",
      "EPOCH: 26569 LOSS: 40.97303218751175\n",
      "EPOCH: 26570 LOSS: 40.9730309490472\n",
      "EPOCH: 26571 LOSS: 40.973029710654686\n",
      "EPOCH: 26572 LOSS: 40.97302847233417\n",
      "EPOCH: 26573 LOSS: 40.973027234085656\n",
      "EPOCH: 26574 LOSS: 40.97302599590911\n",
      "EPOCH: 26575 LOSS: 40.97302475780458\n",
      "EPOCH: 26576 LOSS: 40.97302351977201\n",
      "EPOCH: 26577 LOSS: 40.97302228181141\n",
      "EPOCH: 26578 LOSS: 40.973021043922785\n",
      "EPOCH: 26579 LOSS: 40.97301980610609\n",
      "EPOCH: 26580 LOSS: 40.97301856836136\n",
      "EPOCH: 26581 LOSS: 40.97301733068855\n",
      "EPOCH: 26582 LOSS: 40.97301609308769\n",
      "EPOCH: 26583 LOSS: 40.97301485555873\n",
      "EPOCH: 26584 LOSS: 40.973013618101696\n",
      "EPOCH: 26585 LOSS: 40.97301238071656\n",
      "EPOCH: 26586 LOSS: 40.97301114340331\n",
      "EPOCH: 26587 LOSS: 40.97300990616196\n",
      "EPOCH: 26588 LOSS: 40.97300866899249\n",
      "EPOCH: 26589 LOSS: 40.97300743189491\n",
      "EPOCH: 26590 LOSS: 40.97300619486917\n",
      "EPOCH: 26591 LOSS: 40.9730049579153\n",
      "EPOCH: 26592 LOSS: 40.973003721033294\n",
      "EPOCH: 26593 LOSS: 40.9730024842231\n",
      "EPOCH: 26594 LOSS: 40.97300124748475\n",
      "EPOCH: 26595 LOSS: 40.97300001081824\n",
      "EPOCH: 26596 LOSS: 40.97299877422354\n",
      "EPOCH: 26597 LOSS: 40.97299753770065\n",
      "EPOCH: 26598 LOSS: 40.97299630124955\n",
      "EPOCH: 26599 LOSS: 40.972995064870254\n",
      "EPOCH: 26600 LOSS: 40.97299382856275\n",
      "EPOCH: 26601 LOSS: 40.97299259232702\n",
      "EPOCH: 26602 LOSS: 40.97299135616305\n",
      "EPOCH: 26603 LOSS: 40.97299012007085\n",
      "EPOCH: 26604 LOSS: 40.97298888405041\n",
      "EPOCH: 26605 LOSS: 40.9729876481017\n",
      "EPOCH: 26606 LOSS: 40.97298641222474\n",
      "EPOCH: 26607 LOSS: 40.97298517641951\n",
      "EPOCH: 26608 LOSS: 40.97298394068599\n",
      "EPOCH: 26609 LOSS: 40.97298270502421\n",
      "EPOCH: 26610 LOSS: 40.972981469434124\n",
      "EPOCH: 26611 LOSS: 40.972980233915735\n",
      "EPOCH: 26612 LOSS: 40.972978998469046\n",
      "EPOCH: 26613 LOSS: 40.97297776309403\n",
      "EPOCH: 26614 LOSS: 40.97297652779069\n",
      "EPOCH: 26615 LOSS: 40.97297529255903\n",
      "EPOCH: 26616 LOSS: 40.97297405739903\n",
      "EPOCH: 26617 LOSS: 40.97297282231066\n",
      "EPOCH: 26618 LOSS: 40.97297158729395\n",
      "EPOCH: 26619 LOSS: 40.972970352348874\n",
      "EPOCH: 26620 LOSS: 40.972969117475415\n",
      "EPOCH: 26621 LOSS: 40.972967882673586\n",
      "EPOCH: 26622 LOSS: 40.97296664794338\n",
      "EPOCH: 26623 LOSS: 40.97296541328476\n",
      "EPOCH: 26624 LOSS: 40.97296417869775\n",
      "EPOCH: 26625 LOSS: 40.97296294418231\n",
      "EPOCH: 26626 LOSS: 40.97296170973847\n",
      "EPOCH: 26627 LOSS: 40.9729604753662\n",
      "EPOCH: 26628 LOSS: 40.9729592410655\n",
      "EPOCH: 26629 LOSS: 40.972958006836336\n",
      "EPOCH: 26630 LOSS: 40.972956772678735\n",
      "EPOCH: 26631 LOSS: 40.97295553859268\n",
      "EPOCH: 26632 LOSS: 40.97295430457815\n",
      "EPOCH: 26633 LOSS: 40.97295307063514\n",
      "EPOCH: 26634 LOSS: 40.97295183676367\n",
      "EPOCH: 26635 LOSS: 40.97295060296369\n",
      "EPOCH: 26636 LOSS: 40.97294936923522\n",
      "EPOCH: 26637 LOSS: 40.97294813557825\n",
      "EPOCH: 26638 LOSS: 40.97294690199274\n",
      "EPOCH: 26639 LOSS: 40.97294566847874\n",
      "EPOCH: 26640 LOSS: 40.9729444350362\n",
      "EPOCH: 26641 LOSS: 40.97294320166512\n",
      "EPOCH: 26642 LOSS: 40.97294196836549\n",
      "EPOCH: 26643 LOSS: 40.9729407351373\n",
      "EPOCH: 26644 LOSS: 40.97293950198057\n",
      "EPOCH: 26645 LOSS: 40.97293826889526\n",
      "EPOCH: 26646 LOSS: 40.97293703588139\n",
      "EPOCH: 26647 LOSS: 40.972935802938906\n",
      "EPOCH: 26648 LOSS: 40.97293457006785\n",
      "EPOCH: 26649 LOSS: 40.9729333372682\n",
      "EPOCH: 26650 LOSS: 40.97293210453992\n",
      "EPOCH: 26651 LOSS: 40.97293087188305\n",
      "EPOCH: 26652 LOSS: 40.97292963929754\n",
      "EPOCH: 26653 LOSS: 40.97292840678339\n",
      "EPOCH: 26654 LOSS: 40.97292717434061\n",
      "EPOCH: 26655 LOSS: 40.972925941969194\n",
      "EPOCH: 26656 LOSS: 40.97292470966911\n",
      "EPOCH: 26657 LOSS: 40.972923477440354\n",
      "EPOCH: 26658 LOSS: 40.972922245282945\n",
      "EPOCH: 26659 LOSS: 40.972921013196846\n",
      "EPOCH: 26660 LOSS: 40.97291978118208\n",
      "EPOCH: 26661 LOSS: 40.9729185492386\n",
      "EPOCH: 26662 LOSS: 40.972917317366424\n",
      "EPOCH: 26663 LOSS: 40.972916085565544\n",
      "EPOCH: 26664 LOSS: 40.97291485383593\n",
      "EPOCH: 26665 LOSS: 40.9729136221776\n",
      "EPOCH: 26666 LOSS: 40.97291239059054\n",
      "EPOCH: 26667 LOSS: 40.97291115907474\n",
      "EPOCH: 26668 LOSS: 40.97290992763018\n",
      "EPOCH: 26669 LOSS: 40.972908696256866\n",
      "EPOCH: 26670 LOSS: 40.9729074649548\n",
      "EPOCH: 26671 LOSS: 40.97290623372395\n",
      "EPOCH: 26672 LOSS: 40.97290500256432\n",
      "EPOCH: 26673 LOSS: 40.9729037714759\n",
      "EPOCH: 26674 LOSS: 40.97290254045869\n",
      "EPOCH: 26675 LOSS: 40.972901309512665\n",
      "EPOCH: 26676 LOSS: 40.972900078637856\n",
      "EPOCH: 26677 LOSS: 40.97289884783421\n",
      "EPOCH: 26678 LOSS: 40.97289761710173\n",
      "EPOCH: 26679 LOSS: 40.972896386440425\n",
      "EPOCH: 26680 LOSS: 40.97289515585026\n",
      "EPOCH: 26681 LOSS: 40.97289392533126\n",
      "EPOCH: 26682 LOSS: 40.9728926948834\n",
      "EPOCH: 26683 LOSS: 40.972891464506674\n",
      "EPOCH: 26684 LOSS: 40.972890234201074\n",
      "EPOCH: 26685 LOSS: 40.97288900396657\n",
      "EPOCH: 26686 LOSS: 40.97288777380321\n",
      "EPOCH: 26687 LOSS: 40.97288654371094\n",
      "EPOCH: 26688 LOSS: 40.972885313689744\n",
      "EPOCH: 26689 LOSS: 40.97288408373967\n",
      "EPOCH: 26690 LOSS: 40.97288285386065\n",
      "EPOCH: 26691 LOSS: 40.97288162405272\n",
      "EPOCH: 26692 LOSS: 40.97288039431584\n",
      "EPOCH: 26693 LOSS: 40.97287916465001\n",
      "EPOCH: 26694 LOSS: 40.97287793505524\n",
      "EPOCH: 26695 LOSS: 40.972876705531505\n",
      "EPOCH: 26696 LOSS: 40.972875476078805\n",
      "EPOCH: 26697 LOSS: 40.97287424669712\n",
      "EPOCH: 26698 LOSS: 40.972873017386455\n",
      "EPOCH: 26699 LOSS: 40.97287178814682\n",
      "EPOCH: 26700 LOSS: 40.972870558978165\n",
      "EPOCH: 26701 LOSS: 40.9728693298805\n",
      "EPOCH: 26702 LOSS: 40.97286810085383\n",
      "EPOCH: 26703 LOSS: 40.972866871898134\n",
      "EPOCH: 26704 LOSS: 40.97286564301341\n",
      "EPOCH: 26705 LOSS: 40.97286441419966\n",
      "EPOCH: 26706 LOSS: 40.97286318545683\n",
      "EPOCH: 26707 LOSS: 40.97286195678497\n",
      "EPOCH: 26708 LOSS: 40.97286072818405\n",
      "EPOCH: 26709 LOSS: 40.97285949965405\n",
      "EPOCH: 26710 LOSS: 40.97285827119499\n",
      "EPOCH: 26711 LOSS: 40.97285704280683\n",
      "EPOCH: 26712 LOSS: 40.97285581448959\n",
      "EPOCH: 26713 LOSS: 40.97285458624324\n",
      "EPOCH: 26714 LOSS: 40.9728533580678\n",
      "EPOCH: 26715 LOSS: 40.97285212996322\n",
      "EPOCH: 26716 LOSS: 40.97285090192953\n",
      "EPOCH: 26717 LOSS: 40.972849673966714\n",
      "EPOCH: 26718 LOSS: 40.97284844607475\n",
      "EPOCH: 26719 LOSS: 40.97284721825365\n",
      "EPOCH: 26720 LOSS: 40.97284599050336\n",
      "EPOCH: 26721 LOSS: 40.97284476282394\n",
      "EPOCH: 26722 LOSS: 40.97284353521535\n",
      "EPOCH: 26723 LOSS: 40.97284230767757\n",
      "EPOCH: 26724 LOSS: 40.972841080210614\n",
      "EPOCH: 26725 LOSS: 40.972839852814445\n",
      "EPOCH: 26726 LOSS: 40.9728386254891\n",
      "EPOCH: 26727 LOSS: 40.97283739823453\n",
      "EPOCH: 26728 LOSS: 40.972836171050766\n",
      "EPOCH: 26729 LOSS: 40.97283494393777\n",
      "EPOCH: 26730 LOSS: 40.972833716895515\n",
      "EPOCH: 26731 LOSS: 40.972832489924045\n",
      "EPOCH: 26732 LOSS: 40.97283126302332\n",
      "EPOCH: 26733 LOSS: 40.97283003619334\n",
      "EPOCH: 26734 LOSS: 40.9728288094341\n",
      "EPOCH: 26735 LOSS: 40.972827582745595\n",
      "EPOCH: 26736 LOSS: 40.9728263561278\n",
      "EPOCH: 26737 LOSS: 40.97282512958072\n",
      "EPOCH: 26738 LOSS: 40.972823903104356\n",
      "EPOCH: 26739 LOSS: 40.97282267669868\n",
      "EPOCH: 26740 LOSS: 40.97282145036369\n",
      "EPOCH: 26741 LOSS: 40.9728202240994\n",
      "EPOCH: 26742 LOSS: 40.972818997905776\n",
      "EPOCH: 26743 LOSS: 40.97281777178281\n",
      "EPOCH: 26744 LOSS: 40.97281654573051\n",
      "EPOCH: 26745 LOSS: 40.972815319748854\n",
      "EPOCH: 26746 LOSS: 40.972814093837854\n",
      "EPOCH: 26747 LOSS: 40.97281286799749\n",
      "EPOCH: 26748 LOSS: 40.97281164222775\n",
      "EPOCH: 26749 LOSS: 40.97281041652864\n",
      "EPOCH: 26750 LOSS: 40.97280919090013\n",
      "EPOCH: 26751 LOSS: 40.97280796534223\n",
      "EPOCH: 26752 LOSS: 40.97280673985494\n",
      "EPOCH: 26753 LOSS: 40.97280551443822\n",
      "EPOCH: 26754 LOSS: 40.972804289092096\n",
      "EPOCH: 26755 LOSS: 40.97280306381654\n",
      "EPOCH: 26756 LOSS: 40.972801838611545\n",
      "EPOCH: 26757 LOSS: 40.972800613477126\n",
      "EPOCH: 26758 LOSS: 40.97279938841324\n",
      "EPOCH: 26759 LOSS: 40.97279816341992\n",
      "EPOCH: 26760 LOSS: 40.97279693849711\n",
      "EPOCH: 26761 LOSS: 40.97279571364484\n",
      "EPOCH: 26762 LOSS: 40.97279448886309\n",
      "EPOCH: 26763 LOSS: 40.97279326415186\n",
      "EPOCH: 26764 LOSS: 40.97279203951112\n",
      "EPOCH: 26765 LOSS: 40.97279081494089\n",
      "EPOCH: 26766 LOSS: 40.97278959044114\n",
      "EPOCH: 26767 LOSS: 40.97278836601189\n",
      "EPOCH: 26768 LOSS: 40.9727871416531\n",
      "EPOCH: 26769 LOSS: 40.972785917364774\n",
      "EPOCH: 26770 LOSS: 40.97278469314691\n",
      "EPOCH: 26771 LOSS: 40.9727834689995\n",
      "EPOCH: 26772 LOSS: 40.972782244922534\n",
      "EPOCH: 26773 LOSS: 40.97278102091599\n",
      "EPOCH: 26774 LOSS: 40.9727797969799\n",
      "EPOCH: 26775 LOSS: 40.97277857311421\n",
      "EPOCH: 26776 LOSS: 40.97277734931893\n",
      "EPOCH: 26777 LOSS: 40.97277612559408\n",
      "EPOCH: 26778 LOSS: 40.972774901939616\n",
      "EPOCH: 26779 LOSS: 40.97277367835552\n",
      "EPOCH: 26780 LOSS: 40.97277245484183\n",
      "EPOCH: 26781 LOSS: 40.972771231398504\n",
      "EPOCH: 26782 LOSS: 40.97277000802555\n",
      "EPOCH: 26783 LOSS: 40.972768784722945\n",
      "EPOCH: 26784 LOSS: 40.972767561490684\n",
      "EPOCH: 26785 LOSS: 40.97276633832879\n",
      "EPOCH: 26786 LOSS: 40.97276511523722\n",
      "EPOCH: 26787 LOSS: 40.972763892215994\n",
      "EPOCH: 26788 LOSS: 40.97276266926506\n",
      "EPOCH: 26789 LOSS: 40.97276144638447\n",
      "EPOCH: 26790 LOSS: 40.972760223574156\n",
      "EPOCH: 26791 LOSS: 40.97275900083416\n",
      "EPOCH: 26792 LOSS: 40.97275777816444\n",
      "EPOCH: 26793 LOSS: 40.972756555565\n",
      "EPOCH: 26794 LOSS: 40.97275533303585\n",
      "EPOCH: 26795 LOSS: 40.97275411057695\n",
      "EPOCH: 26796 LOSS: 40.972752888188325\n",
      "EPOCH: 26797 LOSS: 40.972751665869936\n",
      "EPOCH: 26798 LOSS: 40.972750443621806\n",
      "EPOCH: 26799 LOSS: 40.97274922144389\n",
      "EPOCH: 26800 LOSS: 40.972747999336214\n",
      "EPOCH: 26801 LOSS: 40.972746777298774\n",
      "EPOCH: 26802 LOSS: 40.97274555533153\n",
      "EPOCH: 26803 LOSS: 40.97274433343446\n",
      "EPOCH: 26804 LOSS: 40.97274311160764\n",
      "EPOCH: 26805 LOSS: 40.972741889851\n",
      "EPOCH: 26806 LOSS: 40.97274066816455\n",
      "EPOCH: 26807 LOSS: 40.972739446548246\n",
      "EPOCH: 26808 LOSS: 40.97273822500212\n",
      "EPOCH: 26809 LOSS: 40.97273700352614\n",
      "EPOCH: 26810 LOSS: 40.97273578212034\n",
      "EPOCH: 26811 LOSS: 40.972734560784666\n",
      "EPOCH: 26812 LOSS: 40.97273333951914\n",
      "EPOCH: 26813 LOSS: 40.972732118323734\n",
      "EPOCH: 26814 LOSS: 40.97273089719846\n",
      "EPOCH: 26815 LOSS: 40.97272967614328\n",
      "EPOCH: 26816 LOSS: 40.972728455158226\n",
      "EPOCH: 26817 LOSS: 40.97272723424325\n",
      "EPOCH: 26818 LOSS: 40.97272601339837\n",
      "EPOCH: 26819 LOSS: 40.972724792623595\n",
      "EPOCH: 26820 LOSS: 40.97272357191886\n",
      "EPOCH: 26821 LOSS: 40.97272235128422\n",
      "EPOCH: 26822 LOSS: 40.97272113071962\n",
      "EPOCH: 26823 LOSS: 40.972719910225095\n",
      "EPOCH: 26824 LOSS: 40.9727186898006\n",
      "EPOCH: 26825 LOSS: 40.97271746944614\n",
      "EPOCH: 26826 LOSS: 40.97271624916171\n",
      "EPOCH: 26827 LOSS: 40.972715028947306\n",
      "EPOCH: 26828 LOSS: 40.972713808802915\n",
      "EPOCH: 26829 LOSS: 40.972712588728534\n",
      "EPOCH: 26830 LOSS: 40.97271136872415\n",
      "EPOCH: 26831 LOSS: 40.97271014878974\n",
      "EPOCH: 26832 LOSS: 40.972708928925336\n",
      "EPOCH: 26833 LOSS: 40.972707709130894\n",
      "EPOCH: 26834 LOSS: 40.97270648940643\n",
      "EPOCH: 26835 LOSS: 40.97270526975193\n",
      "EPOCH: 26836 LOSS: 40.97270405016738\n",
      "EPOCH: 26837 LOSS: 40.97270283065276\n",
      "EPOCH: 26838 LOSS: 40.972701611208095\n",
      "EPOCH: 26839 LOSS: 40.97270039183336\n",
      "EPOCH: 26840 LOSS: 40.972699172528536\n",
      "EPOCH: 26841 LOSS: 40.97269795329362\n",
      "EPOCH: 26842 LOSS: 40.97269673412865\n",
      "EPOCH: 26843 LOSS: 40.97269551503354\n",
      "EPOCH: 26844 LOSS: 40.97269429600834\n",
      "EPOCH: 26845 LOSS: 40.97269307705302\n",
      "EPOCH: 26846 LOSS: 40.97269185816758\n",
      "EPOCH: 26847 LOSS: 40.972690639351995\n",
      "EPOCH: 26848 LOSS: 40.9726894206063\n",
      "EPOCH: 26849 LOSS: 40.97268820193044\n",
      "EPOCH: 26850 LOSS: 40.97268698332444\n",
      "EPOCH: 26851 LOSS: 40.97268576478827\n",
      "EPOCH: 26852 LOSS: 40.972684546321915\n",
      "EPOCH: 26853 LOSS: 40.972683327925395\n",
      "EPOCH: 26854 LOSS: 40.9726821095987\n",
      "EPOCH: 26855 LOSS: 40.97268089134181\n",
      "EPOCH: 26856 LOSS: 40.972679673154715\n",
      "EPOCH: 26857 LOSS: 40.97267845503742\n",
      "EPOCH: 26858 LOSS: 40.972677236989895\n",
      "EPOCH: 26859 LOSS: 40.972676019012184\n",
      "EPOCH: 26860 LOSS: 40.972674801104205\n",
      "EPOCH: 26861 LOSS: 40.972673583266\n",
      "EPOCH: 26862 LOSS: 40.972672365497566\n",
      "EPOCH: 26863 LOSS: 40.97267114779886\n",
      "EPOCH: 26864 LOSS: 40.9726699301699\n",
      "EPOCH: 26865 LOSS: 40.97266871261068\n",
      "EPOCH: 26866 LOSS: 40.972667495121165\n",
      "EPOCH: 26867 LOSS: 40.97266627770138\n",
      "EPOCH: 26868 LOSS: 40.97266506035132\n",
      "EPOCH: 26869 LOSS: 40.97266384307093\n",
      "EPOCH: 26870 LOSS: 40.972662625860245\n",
      "EPOCH: 26871 LOSS: 40.972661408719276\n",
      "EPOCH: 26872 LOSS: 40.97266019164796\n",
      "EPOCH: 26873 LOSS: 40.97265897464632\n",
      "EPOCH: 26874 LOSS: 40.972657757714344\n",
      "EPOCH: 26875 LOSS: 40.97265654085203\n",
      "EPOCH: 26876 LOSS: 40.97265532405935\n",
      "EPOCH: 26877 LOSS: 40.972654107336325\n",
      "EPOCH: 26878 LOSS: 40.97265289068292\n",
      "EPOCH: 26879 LOSS: 40.97265167409917\n",
      "EPOCH: 26880 LOSS: 40.97265045758501\n",
      "EPOCH: 26881 LOSS: 40.97264924114048\n",
      "EPOCH: 26882 LOSS: 40.972648024765554\n",
      "EPOCH: 26883 LOSS: 40.9726468084602\n",
      "EPOCH: 26884 LOSS: 40.97264559222446\n",
      "EPOCH: 26885 LOSS: 40.972644376058284\n",
      "EPOCH: 26886 LOSS: 40.972643159961684\n",
      "EPOCH: 26887 LOSS: 40.97264194393466\n",
      "EPOCH: 26888 LOSS: 40.97264072797721\n",
      "EPOCH: 26889 LOSS: 40.97263951208928\n",
      "EPOCH: 26890 LOSS: 40.97263829627089\n",
      "EPOCH: 26891 LOSS: 40.97263708052205\n",
      "EPOCH: 26892 LOSS: 40.97263586484273\n",
      "EPOCH: 26893 LOSS: 40.97263464923295\n",
      "EPOCH: 26894 LOSS: 40.972633433692664\n",
      "EPOCH: 26895 LOSS: 40.9726322182219\n",
      "EPOCH: 26896 LOSS: 40.97263100282061\n",
      "EPOCH: 26897 LOSS: 40.97262978748883\n",
      "EPOCH: 26898 LOSS: 40.97262857222653\n",
      "EPOCH: 26899 LOSS: 40.972627357033694\n",
      "EPOCH: 26900 LOSS: 40.972626141910325\n",
      "EPOCH: 26901 LOSS: 40.972624926856426\n",
      "EPOCH: 26902 LOSS: 40.972623711871975\n",
      "EPOCH: 26903 LOSS: 40.97262249695697\n",
      "EPOCH: 26904 LOSS: 40.97262128211142\n",
      "EPOCH: 26905 LOSS: 40.972620067335264\n",
      "EPOCH: 26906 LOSS: 40.97261885262856\n",
      "EPOCH: 26907 LOSS: 40.97261763799126\n",
      "EPOCH: 26908 LOSS: 40.972616423423375\n",
      "EPOCH: 26909 LOSS: 40.97261520892487\n",
      "EPOCH: 26910 LOSS: 40.972613994495774\n",
      "EPOCH: 26911 LOSS: 40.972612780136046\n",
      "EPOCH: 26912 LOSS: 40.97261156584572\n",
      "EPOCH: 26913 LOSS: 40.97261035162475\n",
      "EPOCH: 26914 LOSS: 40.97260913747314\n",
      "EPOCH: 26915 LOSS: 40.97260792339088\n",
      "EPOCH: 26916 LOSS: 40.972606709378\n",
      "EPOCH: 26917 LOSS: 40.97260549543441\n",
      "EPOCH: 26918 LOSS: 40.97260428156018\n",
      "EPOCH: 26919 LOSS: 40.97260306775527\n",
      "EPOCH: 26920 LOSS: 40.97260185401968\n",
      "EPOCH: 26921 LOSS: 40.97260064035339\n",
      "EPOCH: 26922 LOSS: 40.97259942675642\n",
      "EPOCH: 26923 LOSS: 40.97259821322872\n",
      "EPOCH: 26924 LOSS: 40.972596999770325\n",
      "EPOCH: 26925 LOSS: 40.9725957863812\n",
      "EPOCH: 26926 LOSS: 40.97259457306136\n",
      "EPOCH: 26927 LOSS: 40.972593359810766\n",
      "EPOCH: 26928 LOSS: 40.97259214662945\n",
      "EPOCH: 26929 LOSS: 40.97259093351736\n",
      "EPOCH: 26930 LOSS: 40.97258972047454\n",
      "EPOCH: 26931 LOSS: 40.97258850750092\n",
      "EPOCH: 26932 LOSS: 40.972587294596536\n",
      "EPOCH: 26933 LOSS: 40.97258608176139\n",
      "EPOCH: 26934 LOSS: 40.97258486899543\n",
      "EPOCH: 26935 LOSS: 40.972583656298696\n",
      "EPOCH: 26936 LOSS: 40.97258244367116\n",
      "EPOCH: 26937 LOSS: 40.97258123111279\n",
      "EPOCH: 26938 LOSS: 40.97258001862362\n",
      "EPOCH: 26939 LOSS: 40.97257880620363\n",
      "EPOCH: 26940 LOSS: 40.97257759385279\n",
      "EPOCH: 26941 LOSS: 40.972576381571116\n",
      "EPOCH: 26942 LOSS: 40.97257516935859\n",
      "EPOCH: 26943 LOSS: 40.97257395721521\n",
      "EPOCH: 26944 LOSS: 40.972572745140965\n",
      "EPOCH: 26945 LOSS: 40.97257153313585\n",
      "EPOCH: 26946 LOSS: 40.97257032119987\n",
      "EPOCH: 26947 LOSS: 40.97256910933299\n",
      "EPOCH: 26948 LOSS: 40.97256789753523\n",
      "EPOCH: 26949 LOSS: 40.97256668580655\n",
      "EPOCH: 26950 LOSS: 40.972565474146975\n",
      "EPOCH: 26951 LOSS: 40.972564262556475\n",
      "EPOCH: 26952 LOSS: 40.97256305103507\n",
      "EPOCH: 26953 LOSS: 40.97256183958271\n",
      "EPOCH: 26954 LOSS: 40.97256062819942\n",
      "EPOCH: 26955 LOSS: 40.9725594168852\n",
      "EPOCH: 26956 LOSS: 40.972558205640006\n",
      "EPOCH: 26957 LOSS: 40.972556994463865\n",
      "EPOCH: 26958 LOSS: 40.972555783356746\n",
      "EPOCH: 26959 LOSS: 40.97255457231867\n",
      "EPOCH: 26960 LOSS: 40.97255336134959\n",
      "EPOCH: 26961 LOSS: 40.972552150449516\n",
      "EPOCH: 26962 LOSS: 40.97255093961846\n",
      "EPOCH: 26963 LOSS: 40.97254972885639\n",
      "EPOCH: 26964 LOSS: 40.972548518163315\n",
      "EPOCH: 26965 LOSS: 40.972547307539216\n",
      "EPOCH: 26966 LOSS: 40.972546096984075\n",
      "EPOCH: 26967 LOSS: 40.97254488649793\n",
      "EPOCH: 26968 LOSS: 40.97254367608073\n",
      "EPOCH: 26969 LOSS: 40.97254246573247\n",
      "EPOCH: 26970 LOSS: 40.97254125545314\n",
      "EPOCH: 26971 LOSS: 40.972540045242766\n",
      "EPOCH: 26972 LOSS: 40.97253883510131\n",
      "EPOCH: 26973 LOSS: 40.97253762502878\n",
      "EPOCH: 26974 LOSS: 40.97253641502516\n",
      "EPOCH: 26975 LOSS: 40.97253520509044\n",
      "EPOCH: 26976 LOSS: 40.97253399522462\n",
      "EPOCH: 26977 LOSS: 40.97253278542769\n",
      "EPOCH: 26978 LOSS: 40.97253157569965\n",
      "EPOCH: 26979 LOSS: 40.97253036604047\n",
      "EPOCH: 26980 LOSS: 40.97252915645018\n",
      "EPOCH: 26981 LOSS: 40.972527946928736\n",
      "EPOCH: 26982 LOSS: 40.97252673747613\n",
      "EPOCH: 26983 LOSS: 40.972525528092405\n",
      "EPOCH: 26984 LOSS: 40.97252431877749\n",
      "EPOCH: 26985 LOSS: 40.97252310953141\n",
      "EPOCH: 26986 LOSS: 40.97252190035415\n",
      "EPOCH: 26987 LOSS: 40.97252069124572\n",
      "EPOCH: 26988 LOSS: 40.97251948220608\n",
      "EPOCH: 26989 LOSS: 40.97251827323525\n",
      "EPOCH: 26990 LOSS: 40.97251706433322\n",
      "EPOCH: 26991 LOSS: 40.97251585549997\n",
      "EPOCH: 26992 LOSS: 40.9725146467355\n",
      "EPOCH: 26993 LOSS: 40.9725134380398\n",
      "EPOCH: 26994 LOSS: 40.972512229412864\n",
      "EPOCH: 26995 LOSS: 40.972511020854675\n",
      "EPOCH: 26996 LOSS: 40.972509812365246\n",
      "EPOCH: 26997 LOSS: 40.97250860394454\n",
      "EPOCH: 26998 LOSS: 40.972507395592594\n",
      "EPOCH: 26999 LOSS: 40.97250618730935\n",
      "EPOCH: 27000 LOSS: 40.97250497909483\n",
      "EPOCH: 27001 LOSS: 40.97250377094904\n",
      "EPOCH: 27002 LOSS: 40.97250256287194\n",
      "EPOCH: 27003 LOSS: 40.972501354863546\n",
      "EPOCH: 27004 LOSS: 40.97250014692382\n",
      "EPOCH: 27005 LOSS: 40.9724989390528\n",
      "EPOCH: 27006 LOSS: 40.97249773125043\n",
      "EPOCH: 27007 LOSS: 40.972496523516746\n",
      "EPOCH: 27008 LOSS: 40.9724953158517\n",
      "EPOCH: 27009 LOSS: 40.97249410825535\n",
      "EPOCH: 27010 LOSS: 40.97249290072761\n",
      "EPOCH: 27011 LOSS: 40.9724916932685\n",
      "EPOCH: 27012 LOSS: 40.97249048587804\n",
      "EPOCH: 27013 LOSS: 40.972489278556196\n",
      "EPOCH: 27014 LOSS: 40.972488071302955\n",
      "EPOCH: 27015 LOSS: 40.97248686411834\n",
      "EPOCH: 27016 LOSS: 40.97248565700232\n",
      "EPOCH: 27017 LOSS: 40.97248444995488\n",
      "EPOCH: 27018 LOSS: 40.97248324297604\n",
      "EPOCH: 27019 LOSS: 40.97248203606577\n",
      "EPOCH: 27020 LOSS: 40.972480829224075\n",
      "EPOCH: 27021 LOSS: 40.97247962245094\n",
      "EPOCH: 27022 LOSS: 40.972478415746366\n",
      "EPOCH: 27023 LOSS: 40.97247720911033\n",
      "EPOCH: 27024 LOSS: 40.972476002542855\n",
      "EPOCH: 27025 LOSS: 40.97247479604389\n",
      "EPOCH: 27026 LOSS: 40.97247358961346\n",
      "EPOCH: 27027 LOSS: 40.97247238325156\n",
      "EPOCH: 27028 LOSS: 40.97247117695816\n",
      "EPOCH: 27029 LOSS: 40.97246997073327\n",
      "EPOCH: 27030 LOSS: 40.97246876457685\n",
      "EPOCH: 27031 LOSS: 40.97246755848895\n",
      "EPOCH: 27032 LOSS: 40.972466352469525\n",
      "EPOCH: 27033 LOSS: 40.97246514651857\n",
      "EPOCH: 27034 LOSS: 40.97246394063609\n",
      "EPOCH: 27035 LOSS: 40.97246273482205\n",
      "EPOCH: 27036 LOSS: 40.97246152907648\n",
      "EPOCH: 27037 LOSS: 40.972460323399346\n",
      "EPOCH: 27038 LOSS: 40.97245911779066\n",
      "EPOCH: 27039 LOSS: 40.9724579122504\n",
      "EPOCH: 27040 LOSS: 40.97245670677855\n",
      "EPOCH: 27041 LOSS: 40.97245550137512\n",
      "EPOCH: 27042 LOSS: 40.97245429604011\n",
      "EPOCH: 27043 LOSS: 40.9724530907735\n",
      "EPOCH: 27044 LOSS: 40.97245188557526\n",
      "EPOCH: 27045 LOSS: 40.972450680445434\n",
      "EPOCH: 27046 LOSS: 40.972449475383975\n",
      "EPOCH: 27047 LOSS: 40.97244827039087\n",
      "EPOCH: 27048 LOSS: 40.972447065466156\n",
      "EPOCH: 27049 LOSS: 40.97244586060978\n",
      "EPOCH: 27050 LOSS: 40.97244465582176\n",
      "EPOCH: 27051 LOSS: 40.972443451102066\n",
      "EPOCH: 27052 LOSS: 40.972442246450726\n",
      "EPOCH: 27053 LOSS: 40.97244104186771\n",
      "EPOCH: 27054 LOSS: 40.97243983735301\n",
      "EPOCH: 27055 LOSS: 40.97243863290663\n",
      "EPOCH: 27056 LOSS: 40.97243742852855\n",
      "EPOCH: 27057 LOSS: 40.972436224218754\n",
      "EPOCH: 27058 LOSS: 40.97243501997726\n",
      "EPOCH: 27059 LOSS: 40.97243381580405\n",
      "EPOCH: 27060 LOSS: 40.972432611699105\n",
      "EPOCH: 27061 LOSS: 40.97243140766245\n",
      "EPOCH: 27062 LOSS: 40.97243020369403\n",
      "EPOCH: 27063 LOSS: 40.97242899979386\n",
      "EPOCH: 27064 LOSS: 40.97242779596196\n",
      "EPOCH: 27065 LOSS: 40.972426592198275\n",
      "EPOCH: 27066 LOSS: 40.972425388502856\n",
      "EPOCH: 27067 LOSS: 40.97242418487562\n",
      "EPOCH: 27068 LOSS: 40.97242298131663\n",
      "EPOCH: 27069 LOSS: 40.97242177782584\n",
      "EPOCH: 27070 LOSS: 40.972420574403245\n",
      "EPOCH: 27071 LOSS: 40.97241937104885\n",
      "EPOCH: 27072 LOSS: 40.97241816776263\n",
      "EPOCH: 27073 LOSS: 40.972416964544614\n",
      "EPOCH: 27074 LOSS: 40.97241576139474\n",
      "EPOCH: 27075 LOSS: 40.972414558313055\n",
      "EPOCH: 27076 LOSS: 40.97241335529951\n",
      "EPOCH: 27077 LOSS: 40.97241215235414\n",
      "EPOCH: 27078 LOSS: 40.9724109494769\n",
      "EPOCH: 27079 LOSS: 40.97240974666778\n",
      "EPOCH: 27080 LOSS: 40.972408543926804\n",
      "EPOCH: 27081 LOSS: 40.97240734125393\n",
      "EPOCH: 27082 LOSS: 40.972406138649205\n",
      "EPOCH: 27083 LOSS: 40.97240493611256\n",
      "EPOCH: 27084 LOSS: 40.97240373364403\n",
      "EPOCH: 27085 LOSS: 40.972402531243574\n",
      "EPOCH: 27086 LOSS: 40.972401328911204\n",
      "EPOCH: 27087 LOSS: 40.97240012664692\n",
      "EPOCH: 27088 LOSS: 40.972398924450694\n",
      "EPOCH: 27089 LOSS: 40.97239772232255\n",
      "EPOCH: 27090 LOSS: 40.97239652026245\n",
      "EPOCH: 27091 LOSS: 40.9723953182704\n",
      "EPOCH: 27092 LOSS: 40.97239411634639\n",
      "EPOCH: 27093 LOSS: 40.9723929144904\n",
      "EPOCH: 27094 LOSS: 40.972391712702446\n",
      "EPOCH: 27095 LOSS: 40.97239051098251\n",
      "EPOCH: 27096 LOSS: 40.97238930933058\n",
      "EPOCH: 27097 LOSS: 40.972388107746674\n",
      "EPOCH: 27098 LOSS: 40.97238690623073\n",
      "EPOCH: 27099 LOSS: 40.97238570478281\n",
      "EPOCH: 27100 LOSS: 40.972384503402836\n",
      "EPOCH: 27101 LOSS: 40.97238330209086\n",
      "EPOCH: 27102 LOSS: 40.97238210084686\n",
      "EPOCH: 27103 LOSS: 40.97238089967079\n",
      "EPOCH: 27104 LOSS: 40.9723796985627\n",
      "EPOCH: 27105 LOSS: 40.97237849752255\n",
      "EPOCH: 27106 LOSS: 40.97237729655032\n",
      "EPOCH: 27107 LOSS: 40.97237609564603\n",
      "EPOCH: 27108 LOSS: 40.97237489480966\n",
      "EPOCH: 27109 LOSS: 40.97237369404122\n",
      "EPOCH: 27110 LOSS: 40.97237249334068\n",
      "EPOCH: 27111 LOSS: 40.97237129270803\n",
      "EPOCH: 27112 LOSS: 40.97237009214329\n",
      "EPOCH: 27113 LOSS: 40.97236889164644\n",
      "EPOCH: 27114 LOSS: 40.97236769121746\n",
      "EPOCH: 27115 LOSS: 40.97236649085635\n",
      "EPOCH: 27116 LOSS: 40.97236529056312\n",
      "EPOCH: 27117 LOSS: 40.972364090337734\n",
      "EPOCH: 27118 LOSS: 40.97236289018019\n",
      "EPOCH: 27119 LOSS: 40.972361690090494\n",
      "EPOCH: 27120 LOSS: 40.97236049006866\n",
      "EPOCH: 27121 LOSS: 40.97235929011461\n",
      "EPOCH: 27122 LOSS: 40.972358090228425\n",
      "EPOCH: 27123 LOSS: 40.97235689041002\n",
      "EPOCH: 27124 LOSS: 40.97235569065943\n",
      "EPOCH: 27125 LOSS: 40.97235449097664\n",
      "EPOCH: 27126 LOSS: 40.97235329136166\n",
      "EPOCH: 27127 LOSS: 40.97235209181445\n",
      "EPOCH: 27128 LOSS: 40.972350892335015\n",
      "EPOCH: 27129 LOSS: 40.972349692923345\n",
      "EPOCH: 27130 LOSS: 40.97234849357946\n",
      "EPOCH: 27131 LOSS: 40.972347294303304\n",
      "EPOCH: 27132 LOSS: 40.972346095094906\n",
      "EPOCH: 27133 LOSS: 40.97234489595425\n",
      "EPOCH: 27134 LOSS: 40.97234369688133\n",
      "EPOCH: 27135 LOSS: 40.97234249787614\n",
      "EPOCH: 27136 LOSS: 40.97234129893866\n",
      "EPOCH: 27137 LOSS: 40.9723401000689\n",
      "EPOCH: 27138 LOSS: 40.97233890126684\n",
      "EPOCH: 27139 LOSS: 40.972337702532485\n",
      "EPOCH: 27140 LOSS: 40.97233650386579\n",
      "EPOCH: 27141 LOSS: 40.97233530526682\n",
      "EPOCH: 27142 LOSS: 40.9723341067355\n",
      "EPOCH: 27143 LOSS: 40.97233290827185\n",
      "EPOCH: 27144 LOSS: 40.97233170987587\n",
      "EPOCH: 27145 LOSS: 40.97233051154753\n",
      "EPOCH: 27146 LOSS: 40.97232931328685\n",
      "EPOCH: 27147 LOSS: 40.9723281150938\n",
      "EPOCH: 27148 LOSS: 40.9723269169684\n",
      "EPOCH: 27149 LOSS: 40.97232571891061\n",
      "EPOCH: 27150 LOSS: 40.97232452092044\n",
      "EPOCH: 27151 LOSS: 40.97232332299788\n",
      "EPOCH: 27152 LOSS: 40.97232212514292\n",
      "EPOCH: 27153 LOSS: 40.972320927355554\n",
      "EPOCH: 27154 LOSS: 40.97231972963578\n",
      "EPOCH: 27155 LOSS: 40.97231853198359\n",
      "EPOCH: 27156 LOSS: 40.972317334398966\n",
      "EPOCH: 27157 LOSS: 40.972316136881915\n",
      "EPOCH: 27158 LOSS: 40.97231493943242\n",
      "EPOCH: 27159 LOSS: 40.972313742050474\n",
      "EPOCH: 27160 LOSS: 40.972312544736084\n",
      "EPOCH: 27161 LOSS: 40.972311347489224\n",
      "EPOCH: 27162 LOSS: 40.972310150309895\n",
      "EPOCH: 27163 LOSS: 40.9723089531981\n",
      "EPOCH: 27164 LOSS: 40.97230775615381\n",
      "EPOCH: 27165 LOSS: 40.97230655917702\n",
      "EPOCH: 27166 LOSS: 40.97230536226775\n",
      "EPOCH: 27167 LOSS: 40.97230416542596\n",
      "EPOCH: 27168 LOSS: 40.97230296865166\n",
      "EPOCH: 27169 LOSS: 40.972301771944856\n",
      "EPOCH: 27170 LOSS: 40.9723005753055\n",
      "EPOCH: 27171 LOSS: 40.972299378733624\n",
      "EPOCH: 27172 LOSS: 40.97229818222919\n",
      "EPOCH: 27173 LOSS: 40.97229698579223\n",
      "EPOCH: 27174 LOSS: 40.972295789422695\n",
      "EPOCH: 27175 LOSS: 40.97229459312062\n",
      "EPOCH: 27176 LOSS: 40.972293396885945\n",
      "EPOCH: 27177 LOSS: 40.972292200718705\n",
      "EPOCH: 27178 LOSS: 40.97229100461888\n",
      "EPOCH: 27179 LOSS: 40.97228980858646\n",
      "EPOCH: 27180 LOSS: 40.97228861262145\n",
      "EPOCH: 27181 LOSS: 40.972287416723816\n",
      "EPOCH: 27182 LOSS: 40.97228622089358\n",
      "EPOCH: 27183 LOSS: 40.972285025130724\n",
      "EPOCH: 27184 LOSS: 40.97228382943524\n",
      "EPOCH: 27185 LOSS: 40.97228263380711\n",
      "EPOCH: 27186 LOSS: 40.972281438246334\n",
      "EPOCH: 27187 LOSS: 40.97228024275292\n",
      "EPOCH: 27188 LOSS: 40.97227904732684\n",
      "EPOCH: 27189 LOSS: 40.972277851968116\n",
      "EPOCH: 27190 LOSS: 40.9722766566767\n",
      "EPOCH: 27191 LOSS: 40.972275461452604\n",
      "EPOCH: 27192 LOSS: 40.97227426629583\n",
      "EPOCH: 27193 LOSS: 40.972273071206345\n",
      "EPOCH: 27194 LOSS: 40.97227187618418\n",
      "EPOCH: 27195 LOSS: 40.972270681229304\n",
      "EPOCH: 27196 LOSS: 40.9722694863417\n",
      "EPOCH: 27197 LOSS: 40.97226829152138\n",
      "EPOCH: 27198 LOSS: 40.972267096768334\n",
      "EPOCH: 27199 LOSS: 40.972265902082555\n",
      "EPOCH: 27200 LOSS: 40.97226470746403\n",
      "EPOCH: 27201 LOSS: 40.972263512912754\n",
      "EPOCH: 27202 LOSS: 40.972262318428704\n",
      "EPOCH: 27203 LOSS: 40.97226112401192\n",
      "EPOCH: 27204 LOSS: 40.97225992966232\n",
      "EPOCH: 27205 LOSS: 40.97225873537998\n",
      "EPOCH: 27206 LOSS: 40.97225754116482\n",
      "EPOCH: 27207 LOSS: 40.972256347016895\n",
      "EPOCH: 27208 LOSS: 40.97225515293616\n",
      "EPOCH: 27209 LOSS: 40.9722539589226\n",
      "EPOCH: 27210 LOSS: 40.97225276497623\n",
      "EPOCH: 27211 LOSS: 40.972251571097054\n",
      "EPOCH: 27212 LOSS: 40.97225037728503\n",
      "EPOCH: 27213 LOSS: 40.97224918354018\n",
      "EPOCH: 27214 LOSS: 40.97224798986249\n",
      "EPOCH: 27215 LOSS: 40.97224679625192\n",
      "EPOCH: 27216 LOSS: 40.97224560270852\n",
      "EPOCH: 27217 LOSS: 40.972244409232246\n",
      "EPOCH: 27218 LOSS: 40.9722432158231\n",
      "EPOCH: 27219 LOSS: 40.972242022481076\n",
      "EPOCH: 27220 LOSS: 40.97224082920614\n",
      "EPOCH: 27221 LOSS: 40.972239635998335\n",
      "EPOCH: 27222 LOSS: 40.97223844285761\n",
      "EPOCH: 27223 LOSS: 40.972237249783994\n",
      "EPOCH: 27224 LOSS: 40.97223605677745\n",
      "EPOCH: 27225 LOSS: 40.97223486383798\n",
      "EPOCH: 27226 LOSS: 40.97223367096558\n",
      "EPOCH: 27227 LOSS: 40.97223247816026\n",
      "EPOCH: 27228 LOSS: 40.97223128542198\n",
      "EPOCH: 27229 LOSS: 40.972230092750735\n",
      "EPOCH: 27230 LOSS: 40.97222890014655\n",
      "EPOCH: 27231 LOSS: 40.9722277076094\n",
      "EPOCH: 27232 LOSS: 40.972226515139255\n",
      "EPOCH: 27233 LOSS: 40.972225322736165\n",
      "EPOCH: 27234 LOSS: 40.97222413040005\n",
      "EPOCH: 27235 LOSS: 40.97222293813095\n",
      "EPOCH: 27236 LOSS: 40.97222174592885\n",
      "EPOCH: 27237 LOSS: 40.97222055379373\n",
      "EPOCH: 27238 LOSS: 40.97221936172562\n",
      "EPOCH: 27239 LOSS: 40.972218169724464\n",
      "EPOCH: 27240 LOSS: 40.972216977790296\n",
      "EPOCH: 27241 LOSS: 40.972215785923055\n",
      "EPOCH: 27242 LOSS: 40.9722145941228\n",
      "EPOCH: 27243 LOSS: 40.9722134023895\n",
      "EPOCH: 27244 LOSS: 40.972212210723114\n",
      "EPOCH: 27245 LOSS: 40.97221101912368\n",
      "EPOCH: 27246 LOSS: 40.97220982759116\n",
      "EPOCH: 27247 LOSS: 40.97220863612554\n",
      "EPOCH: 27248 LOSS: 40.97220744472688\n",
      "EPOCH: 27249 LOSS: 40.97220625339509\n",
      "EPOCH: 27250 LOSS: 40.97220506213021\n",
      "EPOCH: 27251 LOSS: 40.9722038709322\n",
      "EPOCH: 27252 LOSS: 40.97220267980109\n",
      "EPOCH: 27253 LOSS: 40.972201488736864\n",
      "EPOCH: 27254 LOSS: 40.97220029773949\n",
      "EPOCH: 27255 LOSS: 40.97219910680899\n",
      "EPOCH: 27256 LOSS: 40.97219791594536\n",
      "EPOCH: 27257 LOSS: 40.97219672514854\n",
      "EPOCH: 27258 LOSS: 40.972195534418574\n",
      "EPOCH: 27259 LOSS: 40.97219434375546\n",
      "EPOCH: 27260 LOSS: 40.97219315315913\n",
      "EPOCH: 27261 LOSS: 40.97219196262966\n",
      "EPOCH: 27262 LOSS: 40.97219077216699\n",
      "EPOCH: 27263 LOSS: 40.972189581771104\n",
      "EPOCH: 27264 LOSS: 40.97218839144206\n",
      "EPOCH: 27265 LOSS: 40.97218720117977\n",
      "EPOCH: 27266 LOSS: 40.972186010984274\n",
      "EPOCH: 27267 LOSS: 40.972184820855546\n",
      "EPOCH: 27268 LOSS: 40.972183630793594\n",
      "EPOCH: 27269 LOSS: 40.97218244079842\n",
      "EPOCH: 27270 LOSS: 40.97218125086997\n",
      "EPOCH: 27271 LOSS: 40.97218006100829\n",
      "EPOCH: 27272 LOSS: 40.97217887121334\n",
      "EPOCH: 27273 LOSS: 40.97217768148512\n",
      "EPOCH: 27274 LOSS: 40.97217649182363\n",
      "EPOCH: 27275 LOSS: 40.97217530222887\n",
      "EPOCH: 27276 LOSS: 40.97217411270081\n",
      "EPOCH: 27277 LOSS: 40.97217292323946\n",
      "EPOCH: 27278 LOSS: 40.97217173384481\n",
      "EPOCH: 27279 LOSS: 40.972170544516835\n",
      "EPOCH: 27280 LOSS: 40.97216935525556\n",
      "EPOCH: 27281 LOSS: 40.97216816606097\n",
      "EPOCH: 27282 LOSS: 40.972166976933025\n",
      "EPOCH: 27283 LOSS: 40.97216578787176\n",
      "EPOCH: 27284 LOSS: 40.972164598877136\n",
      "EPOCH: 27285 LOSS: 40.972163409949175\n",
      "EPOCH: 27286 LOSS: 40.97216222108784\n",
      "EPOCH: 27287 LOSS: 40.97216103229315\n",
      "EPOCH: 27288 LOSS: 40.97215984356508\n",
      "EPOCH: 27289 LOSS: 40.972158654903645\n",
      "EPOCH: 27290 LOSS: 40.97215746630881\n",
      "EPOCH: 27291 LOSS: 40.972156277780584\n",
      "EPOCH: 27292 LOSS: 40.97215508931894\n",
      "EPOCH: 27293 LOSS: 40.9721539009239\n",
      "EPOCH: 27294 LOSS: 40.972152712595445\n",
      "EPOCH: 27295 LOSS: 40.97215152433357\n",
      "EPOCH: 27296 LOSS: 40.97215033613824\n",
      "EPOCH: 27297 LOSS: 40.97214914800951\n",
      "EPOCH: 27298 LOSS: 40.97214795994732\n",
      "EPOCH: 27299 LOSS: 40.97214677195168\n",
      "EPOCH: 27300 LOSS: 40.97214558402259\n",
      "EPOCH: 27301 LOSS: 40.97214439616002\n",
      "EPOCH: 27302 LOSS: 40.97214320836398\n",
      "EPOCH: 27303 LOSS: 40.97214202063446\n",
      "EPOCH: 27304 LOSS: 40.972140832971455\n",
      "EPOCH: 27305 LOSS: 40.972139645374966\n",
      "EPOCH: 27306 LOSS: 40.97213845784496\n",
      "EPOCH: 27307 LOSS: 40.972137270381445\n",
      "EPOCH: 27308 LOSS: 40.972136082984434\n",
      "EPOCH: 27309 LOSS: 40.972134895653895\n",
      "EPOCH: 27310 LOSS: 40.972133708389805\n",
      "EPOCH: 27311 LOSS: 40.9721325211922\n",
      "EPOCH: 27312 LOSS: 40.97213133406105\n",
      "EPOCH: 27313 LOSS: 40.972130146996335\n",
      "EPOCH: 27314 LOSS: 40.97212895999809\n",
      "EPOCH: 27315 LOSS: 40.97212777306624\n",
      "EPOCH: 27316 LOSS: 40.97212658620086\n",
      "EPOCH: 27317 LOSS: 40.97212539940186\n",
      "EPOCH: 27318 LOSS: 40.972124212669314\n",
      "EPOCH: 27319 LOSS: 40.97212302600315\n",
      "EPOCH: 27320 LOSS: 40.97212183940341\n",
      "EPOCH: 27321 LOSS: 40.972120652870046\n",
      "EPOCH: 27322 LOSS: 40.97211946640306\n",
      "EPOCH: 27323 LOSS: 40.97211828000247\n",
      "EPOCH: 27324 LOSS: 40.97211709366824\n",
      "EPOCH: 27325 LOSS: 40.972115907400394\n",
      "EPOCH: 27326 LOSS: 40.97211472119887\n",
      "EPOCH: 27327 LOSS: 40.97211353506372\n",
      "EPOCH: 27328 LOSS: 40.972112348994905\n",
      "EPOCH: 27329 LOSS: 40.972111162992434\n",
      "EPOCH: 27330 LOSS: 40.97210997705629\n",
      "EPOCH: 27331 LOSS: 40.97210879118647\n",
      "EPOCH: 27332 LOSS: 40.97210760538297\n",
      "EPOCH: 27333 LOSS: 40.97210641964577\n",
      "EPOCH: 27334 LOSS: 40.97210523397487\n",
      "EPOCH: 27335 LOSS: 40.97210404837026\n",
      "EPOCH: 27336 LOSS: 40.97210286283196\n",
      "EPOCH: 27337 LOSS: 40.972101677359916\n",
      "EPOCH: 27338 LOSS: 40.97210049195415\n",
      "EPOCH: 27339 LOSS: 40.97209930661466\n",
      "EPOCH: 27340 LOSS: 40.97209812134142\n",
      "EPOCH: 27341 LOSS: 40.972096936134434\n",
      "EPOCH: 27342 LOSS: 40.97209575099369\n",
      "EPOCH: 27343 LOSS: 40.97209456591919\n",
      "EPOCH: 27344 LOSS: 40.97209338091091\n",
      "EPOCH: 27345 LOSS: 40.97209219596888\n",
      "EPOCH: 27346 LOSS: 40.97209101109305\n",
      "EPOCH: 27347 LOSS: 40.97208982628341\n",
      "EPOCH: 27348 LOSS: 40.97208864153998\n",
      "EPOCH: 27349 LOSS: 40.972087456862766\n",
      "EPOCH: 27350 LOSS: 40.97208627225174\n",
      "EPOCH: 27351 LOSS: 40.97208508770687\n",
      "EPOCH: 27352 LOSS: 40.9720839032282\n",
      "EPOCH: 27353 LOSS: 40.972082718815685\n",
      "EPOCH: 27354 LOSS: 40.972081534469325\n",
      "EPOCH: 27355 LOSS: 40.97208035018913\n",
      "EPOCH: 27356 LOSS: 40.972079165975074\n",
      "EPOCH: 27357 LOSS: 40.97207798182716\n",
      "EPOCH: 27358 LOSS: 40.97207679774538\n",
      "EPOCH: 27359 LOSS: 40.97207561372973\n",
      "EPOCH: 27360 LOSS: 40.9720744297802\n",
      "EPOCH: 27361 LOSS: 40.97207324589678\n",
      "EPOCH: 27362 LOSS: 40.97207206207945\n",
      "EPOCH: 27363 LOSS: 40.97207087832822\n",
      "EPOCH: 27364 LOSS: 40.97206969464308\n",
      "EPOCH: 27365 LOSS: 40.97206851102403\n",
      "EPOCH: 27366 LOSS: 40.97206732747105\n",
      "EPOCH: 27367 LOSS: 40.97206614398416\n",
      "EPOCH: 27368 LOSS: 40.97206496056331\n",
      "EPOCH: 27369 LOSS: 40.97206377720852\n",
      "EPOCH: 27370 LOSS: 40.97206259391977\n",
      "EPOCH: 27371 LOSS: 40.97206141069708\n",
      "EPOCH: 27372 LOSS: 40.97206022754041\n",
      "EPOCH: 27373 LOSS: 40.972059044449765\n",
      "EPOCH: 27374 LOSS: 40.97205786142515\n",
      "EPOCH: 27375 LOSS: 40.972056678466544\n",
      "EPOCH: 27376 LOSS: 40.97205549557394\n",
      "EPOCH: 27377 LOSS: 40.97205431274733\n",
      "EPOCH: 27378 LOSS: 40.972053129986726\n",
      "EPOCH: 27379 LOSS: 40.9720519472921\n",
      "EPOCH: 27380 LOSS: 40.972050764663464\n",
      "EPOCH: 27381 LOSS: 40.97204958210078\n",
      "EPOCH: 27382 LOSS: 40.97204839960408\n",
      "EPOCH: 27383 LOSS: 40.97204721717331\n",
      "EPOCH: 27384 LOSS: 40.972046034808514\n",
      "EPOCH: 27385 LOSS: 40.972044852509654\n",
      "EPOCH: 27386 LOSS: 40.972043670276726\n",
      "EPOCH: 27387 LOSS: 40.972042488109736\n",
      "EPOCH: 27388 LOSS: 40.972041306008656\n",
      "EPOCH: 27389 LOSS: 40.972040123973485\n",
      "EPOCH: 27390 LOSS: 40.97203894200425\n",
      "EPOCH: 27391 LOSS: 40.972037760100896\n",
      "EPOCH: 27392 LOSS: 40.97203657826344\n",
      "EPOCH: 27393 LOSS: 40.97203539649186\n",
      "EPOCH: 27394 LOSS: 40.97203421478618\n",
      "EPOCH: 27395 LOSS: 40.972033033146374\n",
      "EPOCH: 27396 LOSS: 40.97203185157241\n",
      "EPOCH: 27397 LOSS: 40.97203067006432\n",
      "EPOCH: 27398 LOSS: 40.972029488622084\n",
      "EPOCH: 27399 LOSS: 40.972028307245694\n",
      "EPOCH: 27400 LOSS: 40.97202712593514\n",
      "EPOCH: 27401 LOSS: 40.972025944690415\n",
      "EPOCH: 27402 LOSS: 40.97202476351151\n",
      "EPOCH: 27403 LOSS: 40.97202358239842\n",
      "EPOCH: 27404 LOSS: 40.97202240135116\n",
      "EPOCH: 27405 LOSS: 40.9720212203697\n",
      "EPOCH: 27406 LOSS: 40.97202003945401\n",
      "EPOCH: 27407 LOSS: 40.97201885860413\n",
      "EPOCH: 27408 LOSS: 40.97201767782003\n",
      "EPOCH: 27409 LOSS: 40.97201649710169\n",
      "EPOCH: 27410 LOSS: 40.97201531644914\n",
      "EPOCH: 27411 LOSS: 40.97201413586234\n",
      "EPOCH: 27412 LOSS: 40.97201295534131\n",
      "EPOCH: 27413 LOSS: 40.97201177488601\n",
      "EPOCH: 27414 LOSS: 40.97201059449647\n",
      "EPOCH: 27415 LOSS: 40.97200941417264\n",
      "EPOCH: 27416 LOSS: 40.97200823391455\n",
      "EPOCH: 27417 LOSS: 40.972007053722166\n",
      "EPOCH: 27418 LOSS: 40.972005873595506\n",
      "EPOCH: 27419 LOSS: 40.972004693534565\n",
      "EPOCH: 27420 LOSS: 40.972003513539306\n",
      "EPOCH: 27421 LOSS: 40.97200233360974\n",
      "EPOCH: 27422 LOSS: 40.972001153745865\n",
      "EPOCH: 27423 LOSS: 40.97199997394765\n",
      "EPOCH: 27424 LOSS: 40.971998794215125\n",
      "EPOCH: 27425 LOSS: 40.97199761454826\n",
      "EPOCH: 27426 LOSS: 40.971996434947044\n",
      "EPOCH: 27427 LOSS: 40.97199525541149\n",
      "EPOCH: 27428 LOSS: 40.97199407594158\n",
      "EPOCH: 27429 LOSS: 40.9719928965373\n",
      "EPOCH: 27430 LOSS: 40.97199171719865\n",
      "EPOCH: 27431 LOSS: 40.97199053792561\n",
      "EPOCH: 27432 LOSS: 40.97198935871822\n",
      "EPOCH: 27433 LOSS: 40.97198817957639\n",
      "EPOCH: 27434 LOSS: 40.9719870005002\n",
      "EPOCH: 27435 LOSS: 40.97198582148959\n",
      "EPOCH: 27436 LOSS: 40.971984642544584\n",
      "EPOCH: 27437 LOSS: 40.97198346366514\n",
      "EPOCH: 27438 LOSS: 40.97198228485127\n",
      "EPOCH: 27439 LOSS: 40.971981106102966\n",
      "EPOCH: 27440 LOSS: 40.97197992742022\n",
      "EPOCH: 27441 LOSS: 40.97197874880305\n",
      "EPOCH: 27442 LOSS: 40.9719775702514\n",
      "EPOCH: 27443 LOSS: 40.97197639176529\n",
      "EPOCH: 27444 LOSS: 40.97197521334473\n",
      "EPOCH: 27445 LOSS: 40.971974034989685\n",
      "EPOCH: 27446 LOSS: 40.97197285670017\n",
      "EPOCH: 27447 LOSS: 40.97197167847615\n",
      "EPOCH: 27448 LOSS: 40.97197050031764\n",
      "EPOCH: 27449 LOSS: 40.97196932222462\n",
      "EPOCH: 27450 LOSS: 40.97196814419709\n",
      "EPOCH: 27451 LOSS: 40.97196696623507\n",
      "EPOCH: 27452 LOSS: 40.97196578833851\n",
      "EPOCH: 27453 LOSS: 40.97196461050741\n",
      "EPOCH: 27454 LOSS: 40.97196343274179\n",
      "EPOCH: 27455 LOSS: 40.9719622550416\n",
      "EPOCH: 27456 LOSS: 40.971961077406895\n",
      "EPOCH: 27457 LOSS: 40.9719598998376\n",
      "EPOCH: 27458 LOSS: 40.97195872233375\n",
      "EPOCH: 27459 LOSS: 40.97195754489534\n",
      "EPOCH: 27460 LOSS: 40.971956367522345\n",
      "EPOCH: 27461 LOSS: 40.971955190214764\n",
      "EPOCH: 27462 LOSS: 40.97195401297259\n",
      "EPOCH: 27463 LOSS: 40.971952835795804\n",
      "EPOCH: 27464 LOSS: 40.97195165868443\n",
      "EPOCH: 27465 LOSS: 40.97195048163843\n",
      "EPOCH: 27466 LOSS: 40.97194930465781\n",
      "EPOCH: 27467 LOSS: 40.97194812774259\n",
      "EPOCH: 27468 LOSS: 40.9719469508927\n",
      "EPOCH: 27469 LOSS: 40.97194577410819\n",
      "EPOCH: 27470 LOSS: 40.971944597389026\n",
      "EPOCH: 27471 LOSS: 40.97194342073522\n",
      "EPOCH: 27472 LOSS: 40.97194224414673\n",
      "EPOCH: 27473 LOSS: 40.97194106762359\n",
      "EPOCH: 27474 LOSS: 40.97193989116575\n",
      "EPOCH: 27475 LOSS: 40.97193871477326\n",
      "EPOCH: 27476 LOSS: 40.971937538446056\n",
      "EPOCH: 27477 LOSS: 40.97193636218416\n",
      "EPOCH: 27478 LOSS: 40.97193518598757\n",
      "EPOCH: 27479 LOSS: 40.97193400985627\n",
      "EPOCH: 27480 LOSS: 40.97193283379026\n",
      "EPOCH: 27481 LOSS: 40.97193165778951\n",
      "EPOCH: 27482 LOSS: 40.97193048185403\n",
      "EPOCH: 27483 LOSS: 40.97192930598382\n",
      "EPOCH: 27484 LOSS: 40.97192813017886\n",
      "EPOCH: 27485 LOSS: 40.97192695443916\n",
      "EPOCH: 27486 LOSS: 40.9719257787647\n",
      "EPOCH: 27487 LOSS: 40.97192460315546\n",
      "EPOCH: 27488 LOSS: 40.97192342761146\n",
      "EPOCH: 27489 LOSS: 40.97192225213267\n",
      "EPOCH: 27490 LOSS: 40.97192107671911\n",
      "EPOCH: 27491 LOSS: 40.971919901370754\n",
      "EPOCH: 27492 LOSS: 40.9719187260876\n",
      "EPOCH: 27493 LOSS: 40.971917550869634\n",
      "EPOCH: 27494 LOSS: 40.97191637571686\n",
      "EPOCH: 27495 LOSS: 40.97191520062926\n",
      "EPOCH: 27496 LOSS: 40.971914025606836\n",
      "EPOCH: 27497 LOSS: 40.971912850649574\n",
      "EPOCH: 27498 LOSS: 40.971911675757475\n",
      "EPOCH: 27499 LOSS: 40.971910500930534\n",
      "EPOCH: 27500 LOSS: 40.97190932616873\n",
      "EPOCH: 27501 LOSS: 40.97190815147207\n",
      "EPOCH: 27502 LOSS: 40.97190697684053\n",
      "EPOCH: 27503 LOSS: 40.97190580227414\n",
      "EPOCH: 27504 LOSS: 40.971904627772865\n",
      "EPOCH: 27505 LOSS: 40.97190345333667\n",
      "EPOCH: 27506 LOSS: 40.9719022789656\n",
      "EPOCH: 27507 LOSS: 40.97190110465962\n",
      "EPOCH: 27508 LOSS: 40.97189993041874\n",
      "EPOCH: 27509 LOSS: 40.97189875624294\n",
      "EPOCH: 27510 LOSS: 40.971897582132215\n",
      "EPOCH: 27511 LOSS: 40.97189640808658\n",
      "EPOCH: 27512 LOSS: 40.971895234105986\n",
      "EPOCH: 27513 LOSS: 40.971894060190465\n",
      "EPOCH: 27514 LOSS: 40.97189288633997\n",
      "EPOCH: 27515 LOSS: 40.971891712554516\n",
      "EPOCH: 27516 LOSS: 40.971890538834145\n",
      "EPOCH: 27517 LOSS: 40.971889365178754\n",
      "EPOCH: 27518 LOSS: 40.971888191588405\n",
      "EPOCH: 27519 LOSS: 40.971887018063065\n",
      "EPOCH: 27520 LOSS: 40.971885844602724\n",
      "EPOCH: 27521 LOSS: 40.97188467120739\n",
      "EPOCH: 27522 LOSS: 40.97188349787707\n",
      "EPOCH: 27523 LOSS: 40.97188232461173\n",
      "EPOCH: 27524 LOSS: 40.97188115141137\n",
      "EPOCH: 27525 LOSS: 40.97187997827598\n",
      "EPOCH: 27526 LOSS: 40.971878805205556\n",
      "EPOCH: 27527 LOSS: 40.971877632200076\n",
      "EPOCH: 27528 LOSS: 40.97187645925958\n",
      "EPOCH: 27529 LOSS: 40.971875286384005\n",
      "EPOCH: 27530 LOSS: 40.97187411357339\n",
      "EPOCH: 27531 LOSS: 40.971872940827694\n",
      "EPOCH: 27532 LOSS: 40.97187176814695\n",
      "EPOCH: 27533 LOSS: 40.9718705955311\n",
      "EPOCH: 27534 LOSS: 40.97186942298018\n",
      "EPOCH: 27535 LOSS: 40.971868250494154\n",
      "EPOCH: 27536 LOSS: 40.97186707807301\n",
      "EPOCH: 27537 LOSS: 40.97186590571678\n",
      "EPOCH: 27538 LOSS: 40.971864733425434\n",
      "EPOCH: 27539 LOSS: 40.97186356119897\n",
      "EPOCH: 27540 LOSS: 40.971862389037376\n",
      "EPOCH: 27541 LOSS: 40.97186121694064\n",
      "EPOCH: 27542 LOSS: 40.971860044908766\n",
      "EPOCH: 27543 LOSS: 40.97185887294174\n",
      "EPOCH: 27544 LOSS: 40.971857701039575\n",
      "EPOCH: 27545 LOSS: 40.97185652920221\n",
      "EPOCH: 27546 LOSS: 40.97185535742971\n",
      "EPOCH: 27547 LOSS: 40.97185418572201\n",
      "EPOCH: 27548 LOSS: 40.97185301407913\n",
      "EPOCH: 27549 LOSS: 40.97185184250109\n",
      "EPOCH: 27550 LOSS: 40.97185067098782\n",
      "EPOCH: 27551 LOSS: 40.971849499539374\n",
      "EPOCH: 27552 LOSS: 40.971848328155694\n",
      "EPOCH: 27553 LOSS: 40.971847156836816\n",
      "EPOCH: 27554 LOSS: 40.97184598558269\n",
      "EPOCH: 27555 LOSS: 40.97184481439336\n",
      "EPOCH: 27556 LOSS: 40.97184364326877\n",
      "EPOCH: 27557 LOSS: 40.97184247220895\n",
      "EPOCH: 27558 LOSS: 40.971841301213864\n",
      "EPOCH: 27559 LOSS: 40.97184013028354\n",
      "EPOCH: 27560 LOSS: 40.971838959417944\n",
      "EPOCH: 27561 LOSS: 40.97183778861707\n",
      "EPOCH: 27562 LOSS: 40.97183661788091\n",
      "EPOCH: 27563 LOSS: 40.971835447209486\n",
      "EPOCH: 27564 LOSS: 40.97183427660276\n",
      "EPOCH: 27565 LOSS: 40.97183310606074\n",
      "EPOCH: 27566 LOSS: 40.971831935583396\n",
      "EPOCH: 27567 LOSS: 40.97183076517078\n",
      "EPOCH: 27568 LOSS: 40.9718295948228\n",
      "EPOCH: 27569 LOSS: 40.97182842453952\n",
      "EPOCH: 27570 LOSS: 40.9718272543209\n",
      "EPOCH: 27571 LOSS: 40.971826084166935\n",
      "EPOCH: 27572 LOSS: 40.97182491407763\n",
      "EPOCH: 27573 LOSS: 40.97182374405297\n",
      "EPOCH: 27574 LOSS: 40.97182257409295\n",
      "EPOCH: 27575 LOSS: 40.971821404197556\n",
      "EPOCH: 27576 LOSS: 40.971820234366795\n",
      "EPOCH: 27577 LOSS: 40.97181906460065\n",
      "EPOCH: 27578 LOSS: 40.97181789489913\n",
      "EPOCH: 27579 LOSS: 40.97181672526221\n",
      "EPOCH: 27580 LOSS: 40.9718155556899\n",
      "EPOCH: 27581 LOSS: 40.97181438618216\n",
      "EPOCH: 27582 LOSS: 40.97181321673902\n",
      "EPOCH: 27583 LOSS: 40.97181204736046\n",
      "EPOCH: 27584 LOSS: 40.971810878046455\n",
      "EPOCH: 27585 LOSS: 40.97180970879703\n",
      "EPOCH: 27586 LOSS: 40.97180853961216\n",
      "EPOCH: 27587 LOSS: 40.971807370491845\n",
      "EPOCH: 27588 LOSS: 40.97180620143607\n",
      "EPOCH: 27589 LOSS: 40.971805032444834\n",
      "EPOCH: 27590 LOSS: 40.97180386351813\n",
      "EPOCH: 27591 LOSS: 40.971802694655956\n",
      "EPOCH: 27592 LOSS: 40.97180152585829\n",
      "EPOCH: 27593 LOSS: 40.97180035712515\n",
      "EPOCH: 27594 LOSS: 40.97179918845651\n",
      "EPOCH: 27595 LOSS: 40.97179801985236\n",
      "EPOCH: 27596 LOSS: 40.97179685131269\n",
      "EPOCH: 27597 LOSS: 40.971795682837524\n",
      "EPOCH: 27598 LOSS: 40.97179451442683\n",
      "EPOCH: 27599 LOSS: 40.97179334608062\n",
      "EPOCH: 27600 LOSS: 40.97179217779884\n",
      "EPOCH: 27601 LOSS: 40.971791009581544\n",
      "EPOCH: 27602 LOSS: 40.97178984142869\n",
      "EPOCH: 27603 LOSS: 40.97178867334028\n",
      "EPOCH: 27604 LOSS: 40.971787505316314\n",
      "EPOCH: 27605 LOSS: 40.97178633735677\n",
      "EPOCH: 27606 LOSS: 40.971785169461654\n",
      "EPOCH: 27607 LOSS: 40.97178400163094\n",
      "EPOCH: 27608 LOSS: 40.971782833864644\n",
      "EPOCH: 27609 LOSS: 40.971781666162755\n",
      "EPOCH: 27610 LOSS: 40.97178049852526\n",
      "EPOCH: 27611 LOSS: 40.97177933095216\n",
      "EPOCH: 27612 LOSS: 40.97177816344343\n",
      "EPOCH: 27613 LOSS: 40.97177699599909\n",
      "EPOCH: 27614 LOSS: 40.97177582861911\n",
      "EPOCH: 27615 LOSS: 40.971774661303485\n",
      "EPOCH: 27616 LOSS: 40.97177349405224\n",
      "EPOCH: 27617 LOSS: 40.97177232686533\n",
      "EPOCH: 27618 LOSS: 40.97177115974276\n",
      "EPOCH: 27619 LOSS: 40.97176999268453\n",
      "EPOCH: 27620 LOSS: 40.971768825690624\n",
      "EPOCH: 27621 LOSS: 40.97176765876103\n",
      "EPOCH: 27622 LOSS: 40.97176649189577\n",
      "EPOCH: 27623 LOSS: 40.97176532509481\n",
      "EPOCH: 27624 LOSS: 40.971764158358155\n",
      "EPOCH: 27625 LOSS: 40.97176299168579\n",
      "EPOCH: 27626 LOSS: 40.97176182507771\n",
      "EPOCH: 27627 LOSS: 40.97176065853391\n",
      "EPOCH: 27628 LOSS: 40.9717594920544\n",
      "EPOCH: 27629 LOSS: 40.97175832563914\n",
      "EPOCH: 27630 LOSS: 40.97175715928816\n",
      "EPOCH: 27631 LOSS: 40.971755993001416\n",
      "EPOCH: 27632 LOSS: 40.971754826778934\n",
      "EPOCH: 27633 LOSS: 40.97175366062069\n",
      "EPOCH: 27634 LOSS: 40.97175249452668\n",
      "EPOCH: 27635 LOSS: 40.97175132849688\n",
      "EPOCH: 27636 LOSS: 40.97175016253133\n",
      "EPOCH: 27637 LOSS: 40.971748996629984\n",
      "EPOCH: 27638 LOSS: 40.971747830792836\n",
      "EPOCH: 27639 LOSS: 40.97174666501989\n",
      "EPOCH: 27640 LOSS: 40.97174549931115\n",
      "EPOCH: 27641 LOSS: 40.97174433366658\n",
      "EPOCH: 27642 LOSS: 40.9717431680862\n",
      "EPOCH: 27643 LOSS: 40.97174200256999\n",
      "EPOCH: 27644 LOSS: 40.97174083711796\n",
      "EPOCH: 27645 LOSS: 40.97173967173008\n",
      "EPOCH: 27646 LOSS: 40.97173850640635\n",
      "EPOCH: 27647 LOSS: 40.97173734114678\n",
      "EPOCH: 27648 LOSS: 40.97173617595135\n",
      "EPOCH: 27649 LOSS: 40.97173501082004\n",
      "EPOCH: 27650 LOSS: 40.971733845752865\n",
      "EPOCH: 27651 LOSS: 40.97173268074981\n",
      "EPOCH: 27652 LOSS: 40.97173151581085\n",
      "EPOCH: 27653 LOSS: 40.97173035093603\n",
      "EPOCH: 27654 LOSS: 40.97172918612529\n",
      "EPOCH: 27655 LOSS: 40.97172802137863\n",
      "EPOCH: 27656 LOSS: 40.97172685669607\n",
      "EPOCH: 27657 LOSS: 40.9717256920776\n",
      "EPOCH: 27658 LOSS: 40.971724527523186\n",
      "EPOCH: 27659 LOSS: 40.97172336303285\n",
      "EPOCH: 27660 LOSS: 40.97172219860657\n",
      "EPOCH: 27661 LOSS: 40.97172103424435\n",
      "EPOCH: 27662 LOSS: 40.971719869946156\n",
      "EPOCH: 27663 LOSS: 40.97171870571203\n",
      "EPOCH: 27664 LOSS: 40.97171754154192\n",
      "EPOCH: 27665 LOSS: 40.97171637743583\n",
      "EPOCH: 27666 LOSS: 40.97171521339377\n",
      "EPOCH: 27667 LOSS: 40.97171404941572\n",
      "EPOCH: 27668 LOSS: 40.97171288550169\n",
      "EPOCH: 27669 LOSS: 40.971711721651616\n",
      "EPOCH: 27670 LOSS: 40.97171055786557\n",
      "EPOCH: 27671 LOSS: 40.97170939414351\n",
      "EPOCH: 27672 LOSS: 40.97170823048542\n",
      "EPOCH: 27673 LOSS: 40.9717070668913\n",
      "EPOCH: 27674 LOSS: 40.97170590336117\n",
      "EPOCH: 27675 LOSS: 40.97170473989497\n",
      "EPOCH: 27676 LOSS: 40.97170357649274\n",
      "EPOCH: 27677 LOSS: 40.97170241315444\n",
      "EPOCH: 27678 LOSS: 40.97170124988009\n",
      "EPOCH: 27679 LOSS: 40.97170008666968\n",
      "EPOCH: 27680 LOSS: 40.97169892352318\n",
      "EPOCH: 27681 LOSS: 40.971697760440605\n",
      "EPOCH: 27682 LOSS: 40.97169659742195\n",
      "EPOCH: 27683 LOSS: 40.9716954344672\n",
      "EPOCH: 27684 LOSS: 40.971694271576325\n",
      "EPOCH: 27685 LOSS: 40.97169310874936\n",
      "EPOCH: 27686 LOSS: 40.971691945986294\n",
      "EPOCH: 27687 LOSS: 40.97169078328709\n",
      "EPOCH: 27688 LOSS: 40.97168962065176\n",
      "EPOCH: 27689 LOSS: 40.97168845808031\n",
      "EPOCH: 27690 LOSS: 40.97168729557269\n",
      "EPOCH: 27691 LOSS: 40.97168613312895\n",
      "EPOCH: 27692 LOSS: 40.971684970749045\n",
      "EPOCH: 27693 LOSS: 40.97168380843298\n",
      "EPOCH: 27694 LOSS: 40.971682646180746\n",
      "EPOCH: 27695 LOSS: 40.97168148399234\n",
      "EPOCH: 27696 LOSS: 40.971680321867744\n",
      "EPOCH: 27697 LOSS: 40.97167915980697\n",
      "EPOCH: 27698 LOSS: 40.971677997810005\n",
      "EPOCH: 27699 LOSS: 40.97167683587682\n",
      "EPOCH: 27700 LOSS: 40.97167567400744\n",
      "EPOCH: 27701 LOSS: 40.971674512201844\n",
      "EPOCH: 27702 LOSS: 40.97167335046004\n",
      "EPOCH: 27703 LOSS: 40.97167218878199\n",
      "EPOCH: 27704 LOSS: 40.97167102716772\n",
      "EPOCH: 27705 LOSS: 40.97166986561719\n",
      "EPOCH: 27706 LOSS: 40.971668704130444\n",
      "EPOCH: 27707 LOSS: 40.971667542707394\n",
      "EPOCH: 27708 LOSS: 40.97166638134812\n",
      "EPOCH: 27709 LOSS: 40.97166522005257\n",
      "EPOCH: 27710 LOSS: 40.97166405882075\n",
      "EPOCH: 27711 LOSS: 40.97166289765265\n",
      "EPOCH: 27712 LOSS: 40.97166173654827\n",
      "EPOCH: 27713 LOSS: 40.97166057550757\n",
      "EPOCH: 27714 LOSS: 40.971659414530585\n",
      "EPOCH: 27715 LOSS: 40.97165825361729\n",
      "EPOCH: 27716 LOSS: 40.971657092767686\n",
      "EPOCH: 27717 LOSS: 40.97165593198175\n",
      "EPOCH: 27718 LOSS: 40.971654771259495\n",
      "EPOCH: 27719 LOSS: 40.9716536106009\n",
      "EPOCH: 27720 LOSS: 40.971652450005976\n",
      "EPOCH: 27721 LOSS: 40.97165128947468\n",
      "EPOCH: 27722 LOSS: 40.97165012900707\n",
      "EPOCH: 27723 LOSS: 40.97164896860307\n",
      "EPOCH: 27724 LOSS: 40.9716478082627\n",
      "EPOCH: 27725 LOSS: 40.97164664798597\n",
      "EPOCH: 27726 LOSS: 40.97164548777285\n",
      "EPOCH: 27727 LOSS: 40.97164432762335\n",
      "EPOCH: 27728 LOSS: 40.971643167537465\n",
      "EPOCH: 27729 LOSS: 40.97164200751515\n",
      "EPOCH: 27730 LOSS: 40.97164084755645\n",
      "EPOCH: 27731 LOSS: 40.97163968766134\n",
      "EPOCH: 27732 LOSS: 40.9716385278298\n",
      "EPOCH: 27733 LOSS: 40.971637368061835\n",
      "EPOCH: 27734 LOSS: 40.97163620835744\n",
      "EPOCH: 27735 LOSS: 40.97163504871659\n",
      "EPOCH: 27736 LOSS: 40.9716338891393\n",
      "EPOCH: 27737 LOSS: 40.97163272962556\n",
      "EPOCH: 27738 LOSS: 40.971631570175376\n",
      "EPOCH: 27739 LOSS: 40.971630410788705\n",
      "EPOCH: 27740 LOSS: 40.97162925146558\n",
      "EPOCH: 27741 LOSS: 40.97162809220595\n",
      "EPOCH: 27742 LOSS: 40.971626933009844\n",
      "EPOCH: 27743 LOSS: 40.971625773877236\n",
      "EPOCH: 27744 LOSS: 40.97162461480814\n",
      "EPOCH: 27745 LOSS: 40.97162345580253\n",
      "EPOCH: 27746 LOSS: 40.97162229686042\n",
      "EPOCH: 27747 LOSS: 40.97162113798177\n",
      "EPOCH: 27748 LOSS: 40.97161997916662\n",
      "EPOCH: 27749 LOSS: 40.97161882041492\n",
      "EPOCH: 27750 LOSS: 40.97161766172668\n",
      "EPOCH: 27751 LOSS: 40.97161650310189\n",
      "EPOCH: 27752 LOSS: 40.97161534454054\n",
      "EPOCH: 27753 LOSS: 40.97161418604266\n",
      "EPOCH: 27754 LOSS: 40.9716130276082\n",
      "EPOCH: 27755 LOSS: 40.97161186923716\n",
      "EPOCH: 27756 LOSS: 40.97161071092955\n",
      "EPOCH: 27757 LOSS: 40.97160955268536\n",
      "EPOCH: 27758 LOSS: 40.97160839450454\n",
      "EPOCH: 27759 LOSS: 40.97160723638717\n",
      "EPOCH: 27760 LOSS: 40.97160607833316\n",
      "EPOCH: 27761 LOSS: 40.97160492034256\n",
      "EPOCH: 27762 LOSS: 40.97160376241533\n",
      "EPOCH: 27763 LOSS: 40.971602604551485\n",
      "EPOCH: 27764 LOSS: 40.971601446750995\n",
      "EPOCH: 27765 LOSS: 40.97160028901387\n",
      "EPOCH: 27766 LOSS: 40.9715991313401\n",
      "EPOCH: 27767 LOSS: 40.97159797372968\n",
      "EPOCH: 27768 LOSS: 40.971596816182604\n",
      "EPOCH: 27769 LOSS: 40.97159565869886\n",
      "EPOCH: 27770 LOSS: 40.97159450127843\n",
      "EPOCH: 27771 LOSS: 40.97159334392136\n",
      "EPOCH: 27772 LOSS: 40.971592186627575\n",
      "EPOCH: 27773 LOSS: 40.9715910293971\n",
      "EPOCH: 27774 LOSS: 40.97158987222994\n",
      "EPOCH: 27775 LOSS: 40.97158871512606\n",
      "EPOCH: 27776 LOSS: 40.971587558085474\n",
      "EPOCH: 27777 LOSS: 40.97158640110817\n",
      "EPOCH: 27778 LOSS: 40.971585244194145\n",
      "EPOCH: 27779 LOSS: 40.97158408734338\n",
      "EPOCH: 27780 LOSS: 40.97158293055591\n",
      "EPOCH: 27781 LOSS: 40.971581773831666\n",
      "EPOCH: 27782 LOSS: 40.97158061717068\n",
      "EPOCH: 27783 LOSS: 40.97157946057293\n",
      "EPOCH: 27784 LOSS: 40.97157830403843\n",
      "EPOCH: 27785 LOSS: 40.97157714756714\n",
      "EPOCH: 27786 LOSS: 40.971575991159085\n",
      "EPOCH: 27787 LOSS: 40.97157483481425\n",
      "EPOCH: 27788 LOSS: 40.971573678532614\n",
      "EPOCH: 27789 LOSS: 40.97157252231418\n",
      "EPOCH: 27790 LOSS: 40.97157136615897\n",
      "EPOCH: 27791 LOSS: 40.97157021006693\n",
      "EPOCH: 27792 LOSS: 40.971569054038056\n",
      "EPOCH: 27793 LOSS: 40.971567898072394\n",
      "EPOCH: 27794 LOSS: 40.97156674216987\n",
      "EPOCH: 27795 LOSS: 40.971565586330534\n",
      "EPOCH: 27796 LOSS: 40.97156443055434\n",
      "EPOCH: 27797 LOSS: 40.971563274841316\n",
      "EPOCH: 27798 LOSS: 40.97156211919142\n",
      "EPOCH: 27799 LOSS: 40.97156096360466\n",
      "EPOCH: 27800 LOSS: 40.97155980808104\n",
      "EPOCH: 27801 LOSS: 40.97155865262053\n",
      "EPOCH: 27802 LOSS: 40.97155749722316\n",
      "EPOCH: 27803 LOSS: 40.971556341888885\n",
      "EPOCH: 27804 LOSS: 40.971555186617714\n",
      "EPOCH: 27805 LOSS: 40.97155403140965\n",
      "EPOCH: 27806 LOSS: 40.97155287626469\n",
      "EPOCH: 27807 LOSS: 40.9715517211828\n",
      "EPOCH: 27808 LOSS: 40.971550566164005\n",
      "EPOCH: 27809 LOSS: 40.97154941120826\n",
      "EPOCH: 27810 LOSS: 40.97154825631558\n",
      "EPOCH: 27811 LOSS: 40.97154710148597\n",
      "EPOCH: 27812 LOSS: 40.9715459467194\n",
      "EPOCH: 27813 LOSS: 40.97154479201589\n",
      "EPOCH: 27814 LOSS: 40.971543637375405\n",
      "EPOCH: 27815 LOSS: 40.97154248279797\n",
      "EPOCH: 27816 LOSS: 40.97154132828356\n",
      "EPOCH: 27817 LOSS: 40.971540173832146\n",
      "EPOCH: 27818 LOSS: 40.97153901944377\n",
      "EPOCH: 27819 LOSS: 40.97153786511841\n",
      "EPOCH: 27820 LOSS: 40.97153671085602\n",
      "EPOCH: 27821 LOSS: 40.97153555665664\n",
      "EPOCH: 27822 LOSS: 40.97153440252025\n",
      "EPOCH: 27823 LOSS: 40.97153324844683\n",
      "EPOCH: 27824 LOSS: 40.9715320944364\n",
      "EPOCH: 27825 LOSS: 40.97153094048892\n",
      "EPOCH: 27826 LOSS: 40.9715297866044\n",
      "EPOCH: 27827 LOSS: 40.97152863278285\n",
      "EPOCH: 27828 LOSS: 40.971527479024225\n",
      "EPOCH: 27829 LOSS: 40.97152632532857\n",
      "EPOCH: 27830 LOSS: 40.97152517169583\n",
      "EPOCH: 27831 LOSS: 40.97152401812602\n",
      "EPOCH: 27832 LOSS: 40.97152286461913\n",
      "EPOCH: 27833 LOSS: 40.97152171117516\n",
      "EPOCH: 27834 LOSS: 40.9715205577941\n",
      "EPOCH: 27835 LOSS: 40.97151940447596\n",
      "EPOCH: 27836 LOSS: 40.97151825122069\n",
      "EPOCH: 27837 LOSS: 40.971517098028315\n",
      "EPOCH: 27838 LOSS: 40.97151594489882\n",
      "EPOCH: 27839 LOSS: 40.97151479183219\n",
      "EPOCH: 27840 LOSS: 40.971513638828455\n",
      "EPOCH: 27841 LOSS: 40.97151248588757\n",
      "EPOCH: 27842 LOSS: 40.97151133300953\n",
      "EPOCH: 27843 LOSS: 40.97151018019437\n",
      "EPOCH: 27844 LOSS: 40.97150902744204\n",
      "EPOCH: 27845 LOSS: 40.971507874752525\n",
      "EPOCH: 27846 LOSS: 40.971506722125866\n",
      "EPOCH: 27847 LOSS: 40.97150556956203\n",
      "EPOCH: 27848 LOSS: 40.971504417061006\n",
      "EPOCH: 27849 LOSS: 40.97150326462281\n",
      "EPOCH: 27850 LOSS: 40.97150211224739\n",
      "EPOCH: 27851 LOSS: 40.97150095993477\n",
      "EPOCH: 27852 LOSS: 40.97149980768495\n",
      "EPOCH: 27853 LOSS: 40.97149865549791\n",
      "EPOCH: 27854 LOSS: 40.97149750337366\n",
      "EPOCH: 27855 LOSS: 40.97149635131218\n",
      "EPOCH: 27856 LOSS: 40.97149519931345\n",
      "EPOCH: 27857 LOSS: 40.97149404737748\n",
      "EPOCH: 27858 LOSS: 40.971492895504284\n",
      "EPOCH: 27859 LOSS: 40.971491743693825\n",
      "EPOCH: 27860 LOSS: 40.97149059194609\n",
      "EPOCH: 27861 LOSS: 40.97148944026111\n",
      "EPOCH: 27862 LOSS: 40.97148828863884\n",
      "EPOCH: 27863 LOSS: 40.97148713707929\n",
      "EPOCH: 27864 LOSS: 40.97148598558245\n",
      "EPOCH: 27865 LOSS: 40.97148483414833\n",
      "EPOCH: 27866 LOSS: 40.97148368277692\n",
      "EPOCH: 27867 LOSS: 40.971482531468205\n",
      "EPOCH: 27868 LOSS: 40.97148138022214\n",
      "EPOCH: 27869 LOSS: 40.971480229038775\n",
      "EPOCH: 27870 LOSS: 40.97147907791809\n",
      "EPOCH: 27871 LOSS: 40.971477926860075\n",
      "EPOCH: 27872 LOSS: 40.9714767758647\n",
      "EPOCH: 27873 LOSS: 40.971475624932005\n",
      "EPOCH: 27874 LOSS: 40.971474474061964\n",
      "EPOCH: 27875 LOSS: 40.97147332325453\n",
      "EPOCH: 27876 LOSS: 40.971472172509756\n",
      "EPOCH: 27877 LOSS: 40.97147102182761\n",
      "EPOCH: 27878 LOSS: 40.971469871208086\n",
      "EPOCH: 27879 LOSS: 40.97146872065117\n",
      "EPOCH: 27880 LOSS: 40.971467570156875\n",
      "EPOCH: 27881 LOSS: 40.97146641972517\n",
      "EPOCH: 27882 LOSS: 40.971465269356074\n",
      "EPOCH: 27883 LOSS: 40.971464119049564\n",
      "EPOCH: 27884 LOSS: 40.97146296880563\n",
      "EPOCH: 27885 LOSS: 40.97146181862428\n",
      "EPOCH: 27886 LOSS: 40.9714606685055\n",
      "EPOCH: 27887 LOSS: 40.97145951844929\n",
      "EPOCH: 27888 LOSS: 40.97145836845563\n",
      "EPOCH: 27889 LOSS: 40.97145721852452\n",
      "EPOCH: 27890 LOSS: 40.97145606865596\n",
      "EPOCH: 27891 LOSS: 40.97145491884992\n",
      "EPOCH: 27892 LOSS: 40.971453769106446\n",
      "EPOCH: 27893 LOSS: 40.97145261942548\n",
      "EPOCH: 27894 LOSS: 40.971451469807015\n",
      "EPOCH: 27895 LOSS: 40.97145032025108\n",
      "EPOCH: 27896 LOSS: 40.97144917075765\n",
      "EPOCH: 27897 LOSS: 40.971448021326715\n",
      "EPOCH: 27898 LOSS: 40.97144687195828\n",
      "EPOCH: 27899 LOSS: 40.97144572265232\n",
      "EPOCH: 27900 LOSS: 40.97144457340886\n",
      "EPOCH: 27901 LOSS: 40.97144342422787\n",
      "EPOCH: 27902 LOSS: 40.971442275109325\n",
      "EPOCH: 27903 LOSS: 40.97144112605326\n",
      "EPOCH: 27904 LOSS: 40.971439977059646\n",
      "EPOCH: 27905 LOSS: 40.971438828128484\n",
      "EPOCH: 27906 LOSS: 40.97143767925975\n",
      "EPOCH: 27907 LOSS: 40.97143653045346\n",
      "EPOCH: 27908 LOSS: 40.97143538170959\n",
      "EPOCH: 27909 LOSS: 40.97143423302815\n",
      "EPOCH: 27910 LOSS: 40.971433084409135\n",
      "EPOCH: 27911 LOSS: 40.97143193585251\n",
      "EPOCH: 27912 LOSS: 40.9714307873583\n",
      "EPOCH: 27913 LOSS: 40.97142963892648\n",
      "EPOCH: 27914 LOSS: 40.97142849055705\n",
      "EPOCH: 27915 LOSS: 40.971427342249996\n",
      "EPOCH: 27916 LOSS: 40.97142619400533\n",
      "EPOCH: 27917 LOSS: 40.97142504582303\n",
      "EPOCH: 27918 LOSS: 40.9714238977031\n",
      "EPOCH: 27919 LOSS: 40.97142274964553\n",
      "EPOCH: 27920 LOSS: 40.9714216016503\n",
      "EPOCH: 27921 LOSS: 40.97142045371743\n",
      "EPOCH: 27922 LOSS: 40.971419305846865\n",
      "EPOCH: 27923 LOSS: 40.97141815803866\n",
      "EPOCH: 27924 LOSS: 40.97141701029278\n",
      "EPOCH: 27925 LOSS: 40.971415862609206\n",
      "EPOCH: 27926 LOSS: 40.97141471498796\n",
      "EPOCH: 27927 LOSS: 40.97141356742901\n",
      "EPOCH: 27928 LOSS: 40.97141241993236\n",
      "EPOCH: 27929 LOSS: 40.97141127249801\n",
      "EPOCH: 27930 LOSS: 40.97141012512593\n",
      "EPOCH: 27931 LOSS: 40.971408977816154\n",
      "EPOCH: 27932 LOSS: 40.97140783056863\n",
      "EPOCH: 27933 LOSS: 40.97140668338339\n",
      "EPOCH: 27934 LOSS: 40.9714055362604\n",
      "EPOCH: 27935 LOSS: 40.97140438919967\n",
      "EPOCH: 27936 LOSS: 40.97140324220119\n",
      "EPOCH: 27937 LOSS: 40.971402095264935\n",
      "EPOCH: 27938 LOSS: 40.97140094839094\n",
      "EPOCH: 27939 LOSS: 40.97139980157916\n",
      "EPOCH: 27940 LOSS: 40.971398654829606\n",
      "EPOCH: 27941 LOSS: 40.97139750814226\n",
      "EPOCH: 27942 LOSS: 40.97139636151713\n",
      "EPOCH: 27943 LOSS: 40.97139521495421\n",
      "EPOCH: 27944 LOSS: 40.97139406845348\n",
      "EPOCH: 27945 LOSS: 40.971392922014935\n",
      "EPOCH: 27946 LOSS: 40.97139177563857\n",
      "EPOCH: 27947 LOSS: 40.9713906293244\n",
      "EPOCH: 27948 LOSS: 40.97138948307239\n",
      "EPOCH: 27949 LOSS: 40.97138833688254\n",
      "EPOCH: 27950 LOSS: 40.971387190754854\n",
      "EPOCH: 27951 LOSS: 40.971386044689325\n",
      "EPOCH: 27952 LOSS: 40.97138489868594\n",
      "EPOCH: 27953 LOSS: 40.97138375274469\n",
      "EPOCH: 27954 LOSS: 40.971382606865575\n",
      "EPOCH: 27955 LOSS: 40.971381461048594\n",
      "EPOCH: 27956 LOSS: 40.97138031529372\n",
      "EPOCH: 27957 LOSS: 40.97137916960096\n",
      "EPOCH: 27958 LOSS: 40.97137802397031\n",
      "EPOCH: 27959 LOSS: 40.97137687840177\n",
      "EPOCH: 27960 LOSS: 40.97137573289531\n",
      "EPOCH: 27961 LOSS: 40.97137458745095\n",
      "EPOCH: 27962 LOSS: 40.97137344206865\n",
      "EPOCH: 27963 LOSS: 40.97137229674844\n",
      "EPOCH: 27964 LOSS: 40.9713711514903\n",
      "EPOCH: 27965 LOSS: 40.97137000629422\n",
      "EPOCH: 27966 LOSS: 40.9713688611602\n",
      "EPOCH: 27967 LOSS: 40.97136771608823\n",
      "EPOCH: 27968 LOSS: 40.971366571078306\n",
      "EPOCH: 27969 LOSS: 40.97136542613039\n",
      "EPOCH: 27970 LOSS: 40.97136428124454\n",
      "EPOCH: 27971 LOSS: 40.971363136420685\n",
      "EPOCH: 27972 LOSS: 40.971361991658874\n",
      "EPOCH: 27973 LOSS: 40.971360846959044\n",
      "EPOCH: 27974 LOSS: 40.971359702321244\n",
      "EPOCH: 27975 LOSS: 40.97135855774545\n",
      "EPOCH: 27976 LOSS: 40.97135741323164\n",
      "EPOCH: 27977 LOSS: 40.971356268779786\n",
      "EPOCH: 27978 LOSS: 40.971355124389945\n",
      "EPOCH: 27979 LOSS: 40.971353980062055\n",
      "EPOCH: 27980 LOSS: 40.971352835796154\n",
      "EPOCH: 27981 LOSS: 40.97135169159219\n",
      "EPOCH: 27982 LOSS: 40.9713505474502\n",
      "EPOCH: 27983 LOSS: 40.971349403370134\n",
      "EPOCH: 27984 LOSS: 40.97134825935202\n",
      "EPOCH: 27985 LOSS: 40.971347115395865\n",
      "EPOCH: 27986 LOSS: 40.97134597150159\n",
      "EPOCH: 27987 LOSS: 40.97134482766927\n",
      "EPOCH: 27988 LOSS: 40.97134368389885\n",
      "EPOCH: 27989 LOSS: 40.97134254019035\n",
      "EPOCH: 27990 LOSS: 40.97134139654375\n",
      "EPOCH: 27991 LOSS: 40.971340252959045\n",
      "EPOCH: 27992 LOSS: 40.97133910943623\n",
      "EPOCH: 27993 LOSS: 40.9713379659753\n",
      "EPOCH: 27994 LOSS: 40.97133682257624\n",
      "EPOCH: 27995 LOSS: 40.97133567923906\n",
      "EPOCH: 27996 LOSS: 40.97133453596374\n",
      "EPOCH: 27997 LOSS: 40.97133339275028\n",
      "EPOCH: 27998 LOSS: 40.97133224959867\n",
      "EPOCH: 27999 LOSS: 40.971331106508906\n",
      "EPOCH: 28000 LOSS: 40.97132996348098\n",
      "EPOCH: 28001 LOSS: 40.97132882051489\n",
      "EPOCH: 28002 LOSS: 40.97132767761061\n",
      "EPOCH: 28003 LOSS: 40.971326534768174\n",
      "EPOCH: 28004 LOSS: 40.971325391987534\n",
      "EPOCH: 28005 LOSS: 40.97132424926871\n",
      "EPOCH: 28006 LOSS: 40.971323106611685\n",
      "EPOCH: 28007 LOSS: 40.97132196401645\n",
      "EPOCH: 28008 LOSS: 40.971320821483005\n",
      "EPOCH: 28009 LOSS: 40.97131967901135\n",
      "EPOCH: 28010 LOSS: 40.97131853660146\n",
      "EPOCH: 28011 LOSS: 40.97131739425336\n",
      "EPOCH: 28012 LOSS: 40.971316251966996\n",
      "EPOCH: 28013 LOSS: 40.9713151097424\n",
      "EPOCH: 28014 LOSS: 40.97131396757955\n",
      "EPOCH: 28015 LOSS: 40.97131282547843\n",
      "EPOCH: 28016 LOSS: 40.97131168343907\n",
      "EPOCH: 28017 LOSS: 40.971310541461435\n",
      "EPOCH: 28018 LOSS: 40.97130939954552\n",
      "EPOCH: 28019 LOSS: 40.97130825769133\n",
      "EPOCH: 28020 LOSS: 40.971307115898824\n",
      "EPOCH: 28021 LOSS: 40.97130597416807\n",
      "EPOCH: 28022 LOSS: 40.97130483249899\n",
      "EPOCH: 28023 LOSS: 40.971303690891595\n",
      "EPOCH: 28024 LOSS: 40.97130254934591\n",
      "EPOCH: 28025 LOSS: 40.97130140786188\n",
      "EPOCH: 28026 LOSS: 40.97130026643953\n",
      "EPOCH: 28027 LOSS: 40.97129912507886\n",
      "EPOCH: 28028 LOSS: 40.971297983779834\n",
      "EPOCH: 28029 LOSS: 40.971296842542486\n",
      "EPOCH: 28030 LOSS: 40.97129570136676\n",
      "EPOCH: 28031 LOSS: 40.97129456025269\n",
      "EPOCH: 28032 LOSS: 40.97129341920026\n",
      "EPOCH: 28033 LOSS: 40.97129227820945\n",
      "EPOCH: 28034 LOSS: 40.971291137280275\n",
      "EPOCH: 28035 LOSS: 40.97128999641271\n",
      "EPOCH: 28036 LOSS: 40.97128885560676\n",
      "EPOCH: 28037 LOSS: 40.9712877148624\n",
      "EPOCH: 28038 LOSS: 40.97128657417964\n",
      "EPOCH: 28039 LOSS: 40.97128543355848\n",
      "EPOCH: 28040 LOSS: 40.971284292998895\n",
      "EPOCH: 28041 LOSS: 40.9712831525009\n",
      "EPOCH: 28042 LOSS: 40.97128201206448\n",
      "EPOCH: 28043 LOSS: 40.971280871689615\n",
      "EPOCH: 28044 LOSS: 40.97127973137631\n",
      "EPOCH: 28045 LOSS: 40.97127859112458\n",
      "EPOCH: 28046 LOSS: 40.971277450934366\n",
      "EPOCH: 28047 LOSS: 40.971276310805735\n",
      "EPOCH: 28048 LOSS: 40.97127517073861\n",
      "EPOCH: 28049 LOSS: 40.97127403073301\n",
      "EPOCH: 28050 LOSS: 40.971272890788924\n",
      "EPOCH: 28051 LOSS: 40.971271750906375\n",
      "EPOCH: 28052 LOSS: 40.97127061108533\n",
      "EPOCH: 28053 LOSS: 40.971269471325776\n",
      "EPOCH: 28054 LOSS: 40.97126833162774\n",
      "EPOCH: 28055 LOSS: 40.971267191991174\n",
      "EPOCH: 28056 LOSS: 40.9712660524161\n",
      "EPOCH: 28057 LOSS: 40.97126491290253\n",
      "EPOCH: 28058 LOSS: 40.97126377345038\n",
      "EPOCH: 28059 LOSS: 40.97126263405973\n",
      "EPOCH: 28060 LOSS: 40.97126149473053\n",
      "EPOCH: 28061 LOSS: 40.971260355462775\n",
      "EPOCH: 28062 LOSS: 40.97125921625647\n",
      "EPOCH: 28063 LOSS: 40.9712580771116\n",
      "EPOCH: 28064 LOSS: 40.971256938028176\n",
      "EPOCH: 28065 LOSS: 40.97125579900619\n",
      "EPOCH: 28066 LOSS: 40.971254660045616\n",
      "EPOCH: 28067 LOSS: 40.97125352114644\n",
      "EPOCH: 28068 LOSS: 40.97125238230869\n",
      "EPOCH: 28069 LOSS: 40.97125124353233\n",
      "EPOCH: 28070 LOSS: 40.97125010481738\n",
      "EPOCH: 28071 LOSS: 40.97124896616379\n",
      "EPOCH: 28072 LOSS: 40.971247827571624\n",
      "EPOCH: 28073 LOSS: 40.97124668904081\n",
      "EPOCH: 28074 LOSS: 40.97124555057138\n",
      "EPOCH: 28075 LOSS: 40.9712444121633\n",
      "EPOCH: 28076 LOSS: 40.97124327381658\n",
      "EPOCH: 28077 LOSS: 40.97124213553122\n",
      "EPOCH: 28078 LOSS: 40.97124099730721\n",
      "EPOCH: 28079 LOSS: 40.97123985914453\n",
      "EPOCH: 28080 LOSS: 40.97123872104318\n",
      "EPOCH: 28081 LOSS: 40.97123758300316\n",
      "EPOCH: 28082 LOSS: 40.971236445024466\n",
      "EPOCH: 28083 LOSS: 40.971235307107094\n",
      "EPOCH: 28084 LOSS: 40.971234169251005\n",
      "EPOCH: 28085 LOSS: 40.97123303145624\n",
      "EPOCH: 28086 LOSS: 40.971231893722745\n",
      "EPOCH: 28087 LOSS: 40.97123075605056\n",
      "EPOCH: 28088 LOSS: 40.971229618439644\n",
      "EPOCH: 28089 LOSS: 40.97122848089003\n",
      "EPOCH: 28090 LOSS: 40.97122734340165\n",
      "EPOCH: 28091 LOSS: 40.97122620597456\n",
      "EPOCH: 28092 LOSS: 40.97122506860873\n",
      "EPOCH: 28093 LOSS: 40.971223931304124\n",
      "EPOCH: 28094 LOSS: 40.9712227940608\n",
      "EPOCH: 28095 LOSS: 40.9712216568787\n",
      "EPOCH: 28096 LOSS: 40.971220519757814\n",
      "EPOCH: 28097 LOSS: 40.97121938269815\n",
      "EPOCH: 28098 LOSS: 40.971218245699745\n",
      "EPOCH: 28099 LOSS: 40.97121710876252\n",
      "EPOCH: 28100 LOSS: 40.97121597188653\n",
      "EPOCH: 28101 LOSS: 40.97121483507172\n",
      "EPOCH: 28102 LOSS: 40.97121369831811\n",
      "EPOCH: 28103 LOSS: 40.9712125616257\n",
      "EPOCH: 28104 LOSS: 40.971211424994465\n",
      "EPOCH: 28105 LOSS: 40.9712102884244\n",
      "EPOCH: 28106 LOSS: 40.971209151915495\n",
      "EPOCH: 28107 LOSS: 40.97120801546779\n",
      "EPOCH: 28108 LOSS: 40.971206879081194\n",
      "EPOCH: 28109 LOSS: 40.97120574275579\n",
      "EPOCH: 28110 LOSS: 40.97120460649152\n",
      "EPOCH: 28111 LOSS: 40.97120347028837\n",
      "EPOCH: 28112 LOSS: 40.97120233414637\n",
      "EPOCH: 28113 LOSS: 40.9712011980655\n",
      "EPOCH: 28114 LOSS: 40.97120006204574\n",
      "EPOCH: 28115 LOSS: 40.9711989260871\n",
      "EPOCH: 28116 LOSS: 40.97119779018955\n",
      "EPOCH: 28117 LOSS: 40.971196654353115\n",
      "EPOCH: 28118 LOSS: 40.97119551857779\n",
      "EPOCH: 28119 LOSS: 40.97119438286353\n",
      "EPOCH: 28120 LOSS: 40.97119324721036\n",
      "EPOCH: 28121 LOSS: 40.97119211161826\n",
      "EPOCH: 28122 LOSS: 40.97119097608724\n",
      "EPOCH: 28123 LOSS: 40.97118984061727\n",
      "EPOCH: 28124 LOSS: 40.97118870520838\n",
      "EPOCH: 28125 LOSS: 40.97118756986053\n",
      "EPOCH: 28126 LOSS: 40.97118643457372\n",
      "EPOCH: 28127 LOSS: 40.971185299347944\n",
      "EPOCH: 28128 LOSS: 40.971184164183214\n",
      "EPOCH: 28129 LOSS: 40.9711830290795\n",
      "EPOCH: 28130 LOSS: 40.97118189403682\n",
      "EPOCH: 28131 LOSS: 40.97118075905512\n",
      "EPOCH: 28132 LOSS: 40.97117962413446\n",
      "EPOCH: 28133 LOSS: 40.97117848927479\n",
      "EPOCH: 28134 LOSS: 40.971177354476126\n",
      "EPOCH: 28135 LOSS: 40.97117621973843\n",
      "EPOCH: 28136 LOSS: 40.97117508506174\n",
      "EPOCH: 28137 LOSS: 40.971173950446016\n",
      "EPOCH: 28138 LOSS: 40.971172815891265\n",
      "EPOCH: 28139 LOSS: 40.971171681397465\n",
      "EPOCH: 28140 LOSS: 40.97117054696463\n",
      "EPOCH: 28141 LOSS: 40.97116941259273\n",
      "EPOCH: 28142 LOSS: 40.97116827828182\n",
      "EPOCH: 28143 LOSS: 40.97116714403181\n",
      "EPOCH: 28144 LOSS: 40.97116600984274\n",
      "EPOCH: 28145 LOSS: 40.97116487571461\n",
      "EPOCH: 28146 LOSS: 40.971163741647395\n",
      "EPOCH: 28147 LOSS: 40.971162607641084\n",
      "EPOCH: 28148 LOSS: 40.97116147369567\n",
      "EPOCH: 28149 LOSS: 40.97116033981118\n",
      "EPOCH: 28150 LOSS: 40.97115920598757\n",
      "EPOCH: 28151 LOSS: 40.97115807222488\n",
      "EPOCH: 28152 LOSS: 40.97115693852305\n",
      "EPOCH: 28153 LOSS: 40.97115580488209\n",
      "EPOCH: 28154 LOSS: 40.97115467130201\n",
      "EPOCH: 28155 LOSS: 40.97115353778278\n",
      "EPOCH: 28156 LOSS: 40.971152404324435\n",
      "EPOCH: 28157 LOSS: 40.971151270926924\n",
      "EPOCH: 28158 LOSS: 40.97115013759026\n",
      "EPOCH: 28159 LOSS: 40.97114900431444\n",
      "EPOCH: 28160 LOSS: 40.97114787109945\n",
      "EPOCH: 28161 LOSS: 40.971146737945304\n",
      "EPOCH: 28162 LOSS: 40.97114560485194\n",
      "EPOCH: 28163 LOSS: 40.97114447181941\n",
      "EPOCH: 28164 LOSS: 40.971143338847696\n",
      "EPOCH: 28165 LOSS: 40.971142205936786\n",
      "EPOCH: 28166 LOSS: 40.97114107308665\n",
      "EPOCH: 28167 LOSS: 40.971139940297334\n",
      "EPOCH: 28168 LOSS: 40.971138807568785\n",
      "EPOCH: 28169 LOSS: 40.97113767490101\n",
      "EPOCH: 28170 LOSS: 40.971136542294005\n",
      "EPOCH: 28171 LOSS: 40.97113540974778\n",
      "EPOCH: 28172 LOSS: 40.971134277262294\n",
      "EPOCH: 28173 LOSS: 40.971133144837566\n",
      "EPOCH: 28174 LOSS: 40.9711320124736\n",
      "EPOCH: 28175 LOSS: 40.971130880170364\n",
      "EPOCH: 28176 LOSS: 40.97112974792786\n",
      "EPOCH: 28177 LOSS: 40.97112861574609\n",
      "EPOCH: 28178 LOSS: 40.97112748362504\n",
      "EPOCH: 28179 LOSS: 40.9711263515647\n",
      "EPOCH: 28180 LOSS: 40.97112521956507\n",
      "EPOCH: 28181 LOSS: 40.97112408762614\n",
      "EPOCH: 28182 LOSS: 40.971122955747916\n",
      "EPOCH: 28183 LOSS: 40.971121823930375\n",
      "EPOCH: 28184 LOSS: 40.971120692173535\n",
      "EPOCH: 28185 LOSS: 40.971119560477334\n",
      "EPOCH: 28186 LOSS: 40.97111842884184\n",
      "EPOCH: 28187 LOSS: 40.97111729726701\n",
      "EPOCH: 28188 LOSS: 40.97111616575282\n",
      "EPOCH: 28189 LOSS: 40.971115034299295\n",
      "EPOCH: 28190 LOSS: 40.97111390290643\n",
      "EPOCH: 28191 LOSS: 40.9711127715742\n",
      "EPOCH: 28192 LOSS: 40.97111164030259\n",
      "EPOCH: 28193 LOSS: 40.971110509091616\n",
      "EPOCH: 28194 LOSS: 40.97110937794126\n",
      "EPOCH: 28195 LOSS: 40.97110824685153\n",
      "EPOCH: 28196 LOSS: 40.97110711582241\n",
      "EPOCH: 28197 LOSS: 40.971105984853885\n",
      "EPOCH: 28198 LOSS: 40.97110485394597\n",
      "EPOCH: 28199 LOSS: 40.97110372309865\n",
      "EPOCH: 28200 LOSS: 40.971102592311894\n",
      "EPOCH: 28201 LOSS: 40.97110146158574\n",
      "EPOCH: 28202 LOSS: 40.97110033092014\n",
      "EPOCH: 28203 LOSS: 40.971099200315116\n",
      "EPOCH: 28204 LOSS: 40.971098069770655\n",
      "EPOCH: 28205 LOSS: 40.97109693928675\n",
      "EPOCH: 28206 LOSS: 40.971095808863396\n",
      "EPOCH: 28207 LOSS: 40.97109467850058\n",
      "EPOCH: 28208 LOSS: 40.97109354819828\n",
      "EPOCH: 28209 LOSS: 40.971092417956534\n",
      "EPOCH: 28210 LOSS: 40.97109128777531\n",
      "EPOCH: 28211 LOSS: 40.97109015765461\n",
      "EPOCH: 28212 LOSS: 40.97108902759441\n",
      "EPOCH: 28213 LOSS: 40.971087897594714\n",
      "EPOCH: 28214 LOSS: 40.97108676765552\n",
      "EPOCH: 28215 LOSS: 40.97108563777681\n",
      "EPOCH: 28216 LOSS: 40.97108450795861\n",
      "EPOCH: 28217 LOSS: 40.97108337820088\n",
      "EPOCH: 28218 LOSS: 40.97108224850362\n",
      "EPOCH: 28219 LOSS: 40.97108111886682\n",
      "EPOCH: 28220 LOSS: 40.9710799892905\n",
      "EPOCH: 28221 LOSS: 40.97107885977463\n",
      "EPOCH: 28222 LOSS: 40.97107773031921\n",
      "EPOCH: 28223 LOSS: 40.971076600924235\n",
      "EPOCH: 28224 LOSS: 40.9710754715897\n",
      "EPOCH: 28225 LOSS: 40.97107434231558\n",
      "EPOCH: 28226 LOSS: 40.97107321310192\n",
      "EPOCH: 28227 LOSS: 40.97107208394864\n",
      "EPOCH: 28228 LOSS: 40.97107095485579\n",
      "EPOCH: 28229 LOSS: 40.97106982582335\n",
      "EPOCH: 28230 LOSS: 40.97106869685131\n",
      "EPOCH: 28231 LOSS: 40.97106756793967\n",
      "EPOCH: 28232 LOSS: 40.971066439088396\n",
      "EPOCH: 28233 LOSS: 40.97106531029752\n",
      "EPOCH: 28234 LOSS: 40.971064181567016\n",
      "EPOCH: 28235 LOSS: 40.9710630528969\n",
      "EPOCH: 28236 LOSS: 40.97106192428713\n",
      "EPOCH: 28237 LOSS: 40.97106079573773\n",
      "EPOCH: 28238 LOSS: 40.97105966724868\n",
      "EPOCH: 28239 LOSS: 40.97105853881995\n",
      "EPOCH: 28240 LOSS: 40.97105741045158\n",
      "EPOCH: 28241 LOSS: 40.97105628214355\n",
      "EPOCH: 28242 LOSS: 40.97105515389583\n",
      "EPOCH: 28243 LOSS: 40.971054025708455\n",
      "EPOCH: 28244 LOSS: 40.97105289758137\n",
      "EPOCH: 28245 LOSS: 40.9710517695146\n",
      "EPOCH: 28246 LOSS: 40.97105064150814\n",
      "EPOCH: 28247 LOSS: 40.97104951356198\n",
      "EPOCH: 28248 LOSS: 40.971048385676085\n",
      "EPOCH: 28249 LOSS: 40.9710472578505\n",
      "EPOCH: 28250 LOSS: 40.971046130085185\n",
      "EPOCH: 28251 LOSS: 40.97104500238016\n",
      "EPOCH: 28252 LOSS: 40.971043874735365\n",
      "EPOCH: 28253 LOSS: 40.97104274715086\n",
      "EPOCH: 28254 LOSS: 40.971041619626604\n",
      "EPOCH: 28255 LOSS: 40.97104049216258\n",
      "EPOCH: 28256 LOSS: 40.971039364758795\n",
      "EPOCH: 28257 LOSS: 40.971038237415264\n",
      "EPOCH: 28258 LOSS: 40.97103711013196\n",
      "EPOCH: 28259 LOSS: 40.97103598290889\n",
      "EPOCH: 28260 LOSS: 40.971034855746\n",
      "EPOCH: 28261 LOSS: 40.97103372864335\n",
      "EPOCH: 28262 LOSS: 40.971032601600896\n",
      "EPOCH: 28263 LOSS: 40.971031474618634\n",
      "EPOCH: 28264 LOSS: 40.97103034769656\n",
      "EPOCH: 28265 LOSS: 40.9710292208347\n",
      "EPOCH: 28266 LOSS: 40.971028094033\n",
      "EPOCH: 28267 LOSS: 40.97102696729148\n",
      "EPOCH: 28268 LOSS: 40.97102584061014\n",
      "EPOCH: 28269 LOSS: 40.971024713988925\n",
      "EPOCH: 28270 LOSS: 40.97102358742791\n",
      "EPOCH: 28271 LOSS: 40.97102246092702\n",
      "EPOCH: 28272 LOSS: 40.97102133448627\n",
      "EPOCH: 28273 LOSS: 40.971020208105664\n",
      "EPOCH: 28274 LOSS: 40.971019081785194\n",
      "EPOCH: 28275 LOSS: 40.97101795552484\n",
      "EPOCH: 28276 LOSS: 40.971016829324626\n",
      "EPOCH: 28277 LOSS: 40.971015703184506\n",
      "EPOCH: 28278 LOSS: 40.971014577104484\n",
      "EPOCH: 28279 LOSS: 40.971013451084595\n",
      "EPOCH: 28280 LOSS: 40.971012325124775\n",
      "EPOCH: 28281 LOSS: 40.97101119922505\n",
      "EPOCH: 28282 LOSS: 40.9710100733854\n",
      "EPOCH: 28283 LOSS: 40.97100894760584\n",
      "EPOCH: 28284 LOSS: 40.971007821886346\n",
      "EPOCH: 28285 LOSS: 40.97100669622691\n",
      "EPOCH: 28286 LOSS: 40.97100557062753\n",
      "EPOCH: 28287 LOSS: 40.97100444508822\n",
      "EPOCH: 28288 LOSS: 40.971003319608954\n",
      "EPOCH: 28289 LOSS: 40.971002194189715\n",
      "EPOCH: 28290 LOSS: 40.97100106883052\n",
      "EPOCH: 28291 LOSS: 40.97099994353134\n",
      "EPOCH: 28292 LOSS: 40.97099881829219\n",
      "EPOCH: 28293 LOSS: 40.97099769311305\n",
      "EPOCH: 28294 LOSS: 40.970996567993936\n",
      "EPOCH: 28295 LOSS: 40.97099544293482\n",
      "EPOCH: 28296 LOSS: 40.9709943179357\n",
      "EPOCH: 28297 LOSS: 40.970993192996545\n",
      "EPOCH: 28298 LOSS: 40.97099206811742\n",
      "EPOCH: 28299 LOSS: 40.97099094329823\n",
      "EPOCH: 28300 LOSS: 40.97098981853905\n",
      "EPOCH: 28301 LOSS: 40.9709886938398\n",
      "EPOCH: 28302 LOSS: 40.970987569200545\n",
      "EPOCH: 28303 LOSS: 40.970986444621225\n",
      "EPOCH: 28304 LOSS: 40.97098532010187\n",
      "EPOCH: 28305 LOSS: 40.97098419564244\n",
      "EPOCH: 28306 LOSS: 40.970983071242955\n",
      "EPOCH: 28307 LOSS: 40.9709819469034\n",
      "EPOCH: 28308 LOSS: 40.97098082262377\n",
      "EPOCH: 28309 LOSS: 40.97097969840406\n",
      "EPOCH: 28310 LOSS: 40.97097857424428\n",
      "EPOCH: 28311 LOSS: 40.97097745014436\n",
      "EPOCH: 28312 LOSS: 40.97097632610437\n",
      "EPOCH: 28313 LOSS: 40.97097520212427\n",
      "EPOCH: 28314 LOSS: 40.97097407820406\n",
      "EPOCH: 28315 LOSS: 40.97097295434375\n",
      "EPOCH: 28316 LOSS: 40.970971830543284\n",
      "EPOCH: 28317 LOSS: 40.9709707068027\n",
      "EPOCH: 28318 LOSS: 40.970969583121985\n",
      "EPOCH: 28319 LOSS: 40.97096845950112\n",
      "EPOCH: 28320 LOSS: 40.9709673359401\n",
      "EPOCH: 28321 LOSS: 40.97096621243895\n",
      "EPOCH: 28322 LOSS: 40.970965088997616\n",
      "EPOCH: 28323 LOSS: 40.97096396561613\n",
      "EPOCH: 28324 LOSS: 40.97096284229447\n",
      "EPOCH: 28325 LOSS: 40.97096171903263\n",
      "EPOCH: 28326 LOSS: 40.97096059583061\n",
      "EPOCH: 28327 LOSS: 40.97095947268838\n",
      "EPOCH: 28328 LOSS: 40.97095834960597\n",
      "EPOCH: 28329 LOSS: 40.97095722658336\n",
      "EPOCH: 28330 LOSS: 40.97095610362052\n",
      "EPOCH: 28331 LOSS: 40.970954980717494\n",
      "EPOCH: 28332 LOSS: 40.97095385787422\n",
      "EPOCH: 28333 LOSS: 40.97095273509074\n",
      "EPOCH: 28334 LOSS: 40.97095161236702\n",
      "EPOCH: 28335 LOSS: 40.97095048970305\n",
      "EPOCH: 28336 LOSS: 40.97094936709885\n",
      "EPOCH: 28337 LOSS: 40.97094824455439\n",
      "EPOCH: 28338 LOSS: 40.97094712206967\n",
      "EPOCH: 28339 LOSS: 40.970945999644705\n",
      "EPOCH: 28340 LOSS: 40.970944877279436\n",
      "EPOCH: 28341 LOSS: 40.97094375497393\n",
      "EPOCH: 28342 LOSS: 40.970942632728125\n",
      "EPOCH: 28343 LOSS: 40.97094151054203\n",
      "EPOCH: 28344 LOSS: 40.97094038841564\n",
      "EPOCH: 28345 LOSS: 40.97093926634895\n",
      "EPOCH: 28346 LOSS: 40.97093814434197\n",
      "EPOCH: 28347 LOSS: 40.970937022394665\n",
      "EPOCH: 28348 LOSS: 40.970935900507044\n",
      "EPOCH: 28349 LOSS: 40.97093477867909\n",
      "EPOCH: 28350 LOSS: 40.97093365691082\n",
      "EPOCH: 28351 LOSS: 40.97093253520221\n",
      "EPOCH: 28352 LOSS: 40.97093141355326\n",
      "EPOCH: 28353 LOSS: 40.97093029196396\n",
      "EPOCH: 28354 LOSS: 40.97092917043431\n",
      "EPOCH: 28355 LOSS: 40.970928048964296\n",
      "EPOCH: 28356 LOSS: 40.97092692755393\n",
      "EPOCH: 28357 LOSS: 40.97092580620317\n",
      "EPOCH: 28358 LOSS: 40.97092468491205\n",
      "EPOCH: 28359 LOSS: 40.97092356368054\n",
      "EPOCH: 28360 LOSS: 40.97092244250864\n",
      "EPOCH: 28361 LOSS: 40.97092132139633\n",
      "EPOCH: 28362 LOSS: 40.970920200343635\n",
      "EPOCH: 28363 LOSS: 40.97091907935052\n",
      "EPOCH: 28364 LOSS: 40.970917958417004\n",
      "EPOCH: 28365 LOSS: 40.97091683754306\n",
      "EPOCH: 28366 LOSS: 40.9709157167287\n",
      "EPOCH: 28367 LOSS: 40.970914595973895\n",
      "EPOCH: 28368 LOSS: 40.97091347527866\n",
      "EPOCH: 28369 LOSS: 40.970912354642984\n",
      "EPOCH: 28370 LOSS: 40.97091123406685\n",
      "EPOCH: 28371 LOSS: 40.97091011355026\n",
      "EPOCH: 28372 LOSS: 40.970908993093204\n",
      "EPOCH: 28373 LOSS: 40.97090787269569\n",
      "EPOCH: 28374 LOSS: 40.97090675235768\n",
      "EPOCH: 28375 LOSS: 40.97090563207921\n",
      "EPOCH: 28376 LOSS: 40.97090451186026\n",
      "EPOCH: 28377 LOSS: 40.9709033917008\n",
      "EPOCH: 28378 LOSS: 40.97090227160085\n",
      "EPOCH: 28379 LOSS: 40.9709011515604\n",
      "EPOCH: 28380 LOSS: 40.970900031579426\n",
      "EPOCH: 28381 LOSS: 40.97089891165797\n",
      "EPOCH: 28382 LOSS: 40.97089779179595\n",
      "EPOCH: 28383 LOSS: 40.97089667199341\n",
      "EPOCH: 28384 LOSS: 40.97089555225035\n",
      "EPOCH: 28385 LOSS: 40.97089443256674\n",
      "EPOCH: 28386 LOSS: 40.97089331294258\n",
      "EPOCH: 28387 LOSS: 40.97089219337788\n",
      "EPOCH: 28388 LOSS: 40.97089107387261\n",
      "EPOCH: 28389 LOSS: 40.97088995442678\n",
      "EPOCH: 28390 LOSS: 40.9708888350404\n",
      "EPOCH: 28391 LOSS: 40.9708877157134\n",
      "EPOCH: 28392 LOSS: 40.97088659644586\n",
      "EPOCH: 28393 LOSS: 40.970885477237715\n",
      "EPOCH: 28394 LOSS: 40.970884358088966\n",
      "EPOCH: 28395 LOSS: 40.970883238999626\n",
      "EPOCH: 28396 LOSS: 40.97088211996969\n",
      "EPOCH: 28397 LOSS: 40.97088100099913\n",
      "EPOCH: 28398 LOSS: 40.97087988208795\n",
      "EPOCH: 28399 LOSS: 40.97087876323614\n",
      "EPOCH: 28400 LOSS: 40.97087764444371\n",
      "EPOCH: 28401 LOSS: 40.97087652571065\n",
      "EPOCH: 28402 LOSS: 40.970875407036935\n",
      "EPOCH: 28403 LOSS: 40.970874288422564\n",
      "EPOCH: 28404 LOSS: 40.97087316986756\n",
      "EPOCH: 28405 LOSS: 40.9708720513719\n",
      "EPOCH: 28406 LOSS: 40.97087093293555\n",
      "EPOCH: 28407 LOSS: 40.97086981455855\n",
      "EPOCH: 28408 LOSS: 40.970868696240856\n",
      "EPOCH: 28409 LOSS: 40.970867577982474\n",
      "EPOCH: 28410 LOSS: 40.970866459783416\n",
      "EPOCH: 28411 LOSS: 40.97086534164366\n",
      "EPOCH: 28412 LOSS: 40.970864223563204\n",
      "EPOCH: 28413 LOSS: 40.97086310554202\n",
      "EPOCH: 28414 LOSS: 40.97086198758015\n",
      "EPOCH: 28415 LOSS: 40.97086086967754\n",
      "EPOCH: 28416 LOSS: 40.97085975183422\n",
      "EPOCH: 28417 LOSS: 40.970858634050145\n",
      "EPOCH: 28418 LOSS: 40.97085751632536\n",
      "EPOCH: 28419 LOSS: 40.97085639865982\n",
      "EPOCH: 28420 LOSS: 40.97085528105353\n",
      "EPOCH: 28421 LOSS: 40.97085416350648\n",
      "EPOCH: 28422 LOSS: 40.97085304601866\n",
      "EPOCH: 28423 LOSS: 40.970851928590086\n",
      "EPOCH: 28424 LOSS: 40.97085081122074\n",
      "EPOCH: 28425 LOSS: 40.97084969391062\n",
      "EPOCH: 28426 LOSS: 40.9708485766597\n",
      "EPOCH: 28427 LOSS: 40.97084745946799\n",
      "EPOCH: 28428 LOSS: 40.97084634233548\n",
      "EPOCH: 28429 LOSS: 40.970845225262174\n",
      "EPOCH: 28430 LOSS: 40.970844108248045\n",
      "EPOCH: 28431 LOSS: 40.97084299129313\n",
      "EPOCH: 28432 LOSS: 40.97084187439737\n",
      "EPOCH: 28433 LOSS: 40.97084075756079\n",
      "EPOCH: 28434 LOSS: 40.97083964078338\n",
      "EPOCH: 28435 LOSS: 40.9708385240651\n",
      "EPOCH: 28436 LOSS: 40.970837407406016\n",
      "EPOCH: 28437 LOSS: 40.970836290806076\n",
      "EPOCH: 28438 LOSS: 40.97083517426526\n",
      "EPOCH: 28439 LOSS: 40.97083405778359\n",
      "EPOCH: 28440 LOSS: 40.97083294136105\n",
      "EPOCH: 28441 LOSS: 40.97083182499764\n",
      "EPOCH: 28442 LOSS: 40.97083070869334\n",
      "EPOCH: 28443 LOSS: 40.970829592448155\n",
      "EPOCH: 28444 LOSS: 40.970828476262085\n",
      "EPOCH: 28445 LOSS: 40.97082736013511\n",
      "EPOCH: 28446 LOSS: 40.97082624406723\n",
      "EPOCH: 28447 LOSS: 40.97082512805843\n",
      "EPOCH: 28448 LOSS: 40.97082401210873\n",
      "EPOCH: 28449 LOSS: 40.97082289621811\n",
      "EPOCH: 28450 LOSS: 40.97082178038656\n",
      "EPOCH: 28451 LOSS: 40.97082066461405\n",
      "EPOCH: 28452 LOSS: 40.970819548900636\n",
      "EPOCH: 28453 LOSS: 40.970818433246265\n",
      "EPOCH: 28454 LOSS: 40.97081731765092\n",
      "EPOCH: 28455 LOSS: 40.97081620211463\n",
      "EPOCH: 28456 LOSS: 40.97081508663737\n",
      "EPOCH: 28457 LOSS: 40.97081397121916\n",
      "EPOCH: 28458 LOSS: 40.97081285585996\n",
      "EPOCH: 28459 LOSS: 40.970811740559775\n",
      "EPOCH: 28460 LOSS: 40.970810625318606\n",
      "EPOCH: 28461 LOSS: 40.97080951013645\n",
      "EPOCH: 28462 LOSS: 40.97080839501328\n",
      "EPOCH: 28463 LOSS: 40.97080727994912\n",
      "EPOCH: 28464 LOSS: 40.97080616494394\n",
      "EPOCH: 28465 LOSS: 40.970805049997736\n",
      "EPOCH: 28466 LOSS: 40.970803935110524\n",
      "EPOCH: 28467 LOSS: 40.97080282028229\n",
      "EPOCH: 28468 LOSS: 40.970801705513\n",
      "EPOCH: 28469 LOSS: 40.97080059080267\n",
      "EPOCH: 28470 LOSS: 40.970799476151285\n",
      "EPOCH: 28471 LOSS: 40.97079836155886\n",
      "EPOCH: 28472 LOSS: 40.970797247025374\n",
      "EPOCH: 28473 LOSS: 40.97079613255083\n",
      "EPOCH: 28474 LOSS: 40.97079501813522\n",
      "EPOCH: 28475 LOSS: 40.970793903778514\n",
      "EPOCH: 28476 LOSS: 40.97079278948072\n",
      "EPOCH: 28477 LOSS: 40.97079167524187\n",
      "EPOCH: 28478 LOSS: 40.970790561061904\n",
      "EPOCH: 28479 LOSS: 40.97078944694084\n",
      "EPOCH: 28480 LOSS: 40.97078833287867\n",
      "EPOCH: 28481 LOSS: 40.9707872188754\n",
      "EPOCH: 28482 LOSS: 40.97078610493098\n",
      "EPOCH: 28483 LOSS: 40.97078499104546\n",
      "EPOCH: 28484 LOSS: 40.97078387721881\n",
      "EPOCH: 28485 LOSS: 40.97078276345103\n",
      "EPOCH: 28486 LOSS: 40.97078164974208\n",
      "EPOCH: 28487 LOSS: 40.970780536092015\n",
      "EPOCH: 28488 LOSS: 40.97077942250078\n",
      "EPOCH: 28489 LOSS: 40.97077830896839\n",
      "EPOCH: 28490 LOSS: 40.97077719549483\n",
      "EPOCH: 28491 LOSS: 40.970776082080114\n",
      "EPOCH: 28492 LOSS: 40.970774968724186\n",
      "EPOCH: 28493 LOSS: 40.9707738554271\n",
      "EPOCH: 28494 LOSS: 40.97077274218883\n",
      "EPOCH: 28495 LOSS: 40.970771629009356\n",
      "EPOCH: 28496 LOSS: 40.970770515888674\n",
      "EPOCH: 28497 LOSS: 40.97076940282679\n",
      "EPOCH: 28498 LOSS: 40.97076828982371\n",
      "EPOCH: 28499 LOSS: 40.97076717687937\n",
      "EPOCH: 28500 LOSS: 40.97076606399386\n",
      "EPOCH: 28501 LOSS: 40.9707649511671\n",
      "EPOCH: 28502 LOSS: 40.97076383839907\n",
      "EPOCH: 28503 LOSS: 40.97076272568984\n",
      "EPOCH: 28504 LOSS: 40.97076161303934\n",
      "EPOCH: 28505 LOSS: 40.9707605004476\n",
      "EPOCH: 28506 LOSS: 40.97075938791458\n",
      "EPOCH: 28507 LOSS: 40.97075827544032\n",
      "EPOCH: 28508 LOSS: 40.97075716302478\n",
      "EPOCH: 28509 LOSS: 40.97075605066795\n",
      "EPOCH: 28510 LOSS: 40.97075493836984\n",
      "EPOCH: 28511 LOSS: 40.97075382613045\n",
      "EPOCH: 28512 LOSS: 40.97075271394976\n",
      "EPOCH: 28513 LOSS: 40.97075160182777\n",
      "EPOCH: 28514 LOSS: 40.970750489764455\n",
      "EPOCH: 28515 LOSS: 40.970749377759844\n",
      "EPOCH: 28516 LOSS: 40.97074826581392\n",
      "EPOCH: 28517 LOSS: 40.97074715392668\n",
      "EPOCH: 28518 LOSS: 40.970746042098085\n",
      "EPOCH: 28519 LOSS: 40.970744930328166\n",
      "EPOCH: 28520 LOSS: 40.970743818616896\n",
      "EPOCH: 28521 LOSS: 40.970742706964295\n",
      "EPOCH: 28522 LOSS: 40.97074159537032\n",
      "EPOCH: 28523 LOSS: 40.970740483835\n",
      "EPOCH: 28524 LOSS: 40.97073937235832\n",
      "EPOCH: 28525 LOSS: 40.97073826094025\n",
      "EPOCH: 28526 LOSS: 40.97073714958081\n",
      "EPOCH: 28527 LOSS: 40.970736038279995\n",
      "EPOCH: 28528 LOSS: 40.97073492703777\n",
      "EPOCH: 28529 LOSS: 40.97073381585416\n",
      "EPOCH: 28530 LOSS: 40.97073270472916\n",
      "EPOCH: 28531 LOSS: 40.97073159366275\n",
      "EPOCH: 28532 LOSS: 40.97073048265491\n",
      "EPOCH: 28533 LOSS: 40.97072937170566\n",
      "EPOCH: 28534 LOSS: 40.970728260814994\n",
      "EPOCH: 28535 LOSS: 40.970727149982906\n",
      "EPOCH: 28536 LOSS: 40.97072603920935\n",
      "EPOCH: 28537 LOSS: 40.97072492849437\n",
      "EPOCH: 28538 LOSS: 40.97072381783795\n",
      "EPOCH: 28539 LOSS: 40.97072270724006\n",
      "EPOCH: 28540 LOSS: 40.970721596700734\n",
      "EPOCH: 28541 LOSS: 40.97072048621992\n",
      "EPOCH: 28542 LOSS: 40.970719375797636\n",
      "EPOCH: 28543 LOSS: 40.97071826543389\n",
      "EPOCH: 28544 LOSS: 40.97071715512864\n",
      "EPOCH: 28545 LOSS: 40.97071604488192\n",
      "EPOCH: 28546 LOSS: 40.9707149346937\n",
      "EPOCH: 28547 LOSS: 40.970713824563965\n",
      "EPOCH: 28548 LOSS: 40.97071271449274\n",
      "EPOCH: 28549 LOSS: 40.97071160448\n",
      "EPOCH: 28550 LOSS: 40.97071049452573\n",
      "EPOCH: 28551 LOSS: 40.970709384629956\n",
      "EPOCH: 28552 LOSS: 40.97070827479265\n",
      "EPOCH: 28553 LOSS: 40.97070716501379\n",
      "EPOCH: 28554 LOSS: 40.97070605529342\n",
      "EPOCH: 28555 LOSS: 40.97070494563147\n",
      "EPOCH: 28556 LOSS: 40.970703836027965\n",
      "EPOCH: 28557 LOSS: 40.97070272648292\n",
      "EPOCH: 28558 LOSS: 40.9707016169963\n",
      "EPOCH: 28559 LOSS: 40.9707005075681\n",
      "EPOCH: 28560 LOSS: 40.97069939819836\n",
      "EPOCH: 28561 LOSS: 40.97069828888699\n",
      "EPOCH: 28562 LOSS: 40.97069717963407\n",
      "EPOCH: 28563 LOSS: 40.97069607043953\n",
      "EPOCH: 28564 LOSS: 40.97069496130342\n",
      "EPOCH: 28565 LOSS: 40.97069385222567\n",
      "EPOCH: 28566 LOSS: 40.97069274320633\n",
      "EPOCH: 28567 LOSS: 40.97069163424538\n",
      "EPOCH: 28568 LOSS: 40.970690525342775\n",
      "EPOCH: 28569 LOSS: 40.97068941649856\n",
      "EPOCH: 28570 LOSS: 40.970688307712706\n",
      "EPOCH: 28571 LOSS: 40.9706871989852\n",
      "EPOCH: 28572 LOSS: 40.97068609031608\n",
      "EPOCH: 28573 LOSS: 40.97068498170529\n",
      "EPOCH: 28574 LOSS: 40.97068387315283\n",
      "EPOCH: 28575 LOSS: 40.97068276465872\n",
      "EPOCH: 28576 LOSS: 40.97068165622294\n",
      "EPOCH: 28577 LOSS: 40.970680547845475\n",
      "EPOCH: 28578 LOSS: 40.97067943952632\n",
      "EPOCH: 28579 LOSS: 40.97067833126549\n",
      "EPOCH: 28580 LOSS: 40.970677223062964\n",
      "EPOCH: 28581 LOSS: 40.97067611491876\n",
      "EPOCH: 28582 LOSS: 40.97067500683282\n",
      "EPOCH: 28583 LOSS: 40.970673898805174\n",
      "EPOCH: 28584 LOSS: 40.97067279083582\n",
      "EPOCH: 28585 LOSS: 40.970671682924745\n",
      "EPOCH: 28586 LOSS: 40.970670575071935\n",
      "EPOCH: 28587 LOSS: 40.97066946727739\n",
      "EPOCH: 28588 LOSS: 40.97066835954111\n",
      "EPOCH: 28589 LOSS: 40.97066725186309\n",
      "EPOCH: 28590 LOSS: 40.97066614424331\n",
      "EPOCH: 28591 LOSS: 40.97066503668178\n",
      "EPOCH: 28592 LOSS: 40.970663929178485\n",
      "EPOCH: 28593 LOSS: 40.97066282173341\n",
      "EPOCH: 28594 LOSS: 40.97066171434656\n",
      "EPOCH: 28595 LOSS: 40.97066060701793\n",
      "EPOCH: 28596 LOSS: 40.97065949974751\n",
      "EPOCH: 28597 LOSS: 40.97065839253533\n",
      "EPOCH: 28598 LOSS: 40.97065728538132\n",
      "EPOCH: 28599 LOSS: 40.97065617828551\n",
      "EPOCH: 28600 LOSS: 40.970655071247904\n",
      "EPOCH: 28601 LOSS: 40.970653964268465\n",
      "EPOCH: 28602 LOSS: 40.97065285734722\n",
      "EPOCH: 28603 LOSS: 40.97065175048414\n",
      "EPOCH: 28604 LOSS: 40.97065064367922\n",
      "EPOCH: 28605 LOSS: 40.97064953693247\n",
      "EPOCH: 28606 LOSS: 40.97064843024388\n",
      "EPOCH: 28607 LOSS: 40.97064732361343\n",
      "EPOCH: 28608 LOSS: 40.970646217041136\n",
      "EPOCH: 28609 LOSS: 40.97064511052695\n",
      "EPOCH: 28610 LOSS: 40.970644004070934\n",
      "EPOCH: 28611 LOSS: 40.97064289767303\n",
      "EPOCH: 28612 LOSS: 40.97064179133324\n",
      "EPOCH: 28613 LOSS: 40.970640685051556\n",
      "EPOCH: 28614 LOSS: 40.970639578828006\n",
      "EPOCH: 28615 LOSS: 40.970638472662536\n",
      "EPOCH: 28616 LOSS: 40.97063736655519\n",
      "EPOCH: 28617 LOSS: 40.97063626050591\n",
      "EPOCH: 28618 LOSS: 40.97063515451474\n",
      "EPOCH: 28619 LOSS: 40.97063404858163\n",
      "EPOCH: 28620 LOSS: 40.9706329427066\n",
      "EPOCH: 28621 LOSS: 40.97063183688962\n",
      "EPOCH: 28622 LOSS: 40.97063073113074\n",
      "EPOCH: 28623 LOSS: 40.97062962542989\n",
      "EPOCH: 28624 LOSS: 40.9706285197871\n",
      "EPOCH: 28625 LOSS: 40.970627414202355\n",
      "EPOCH: 28626 LOSS: 40.97062630867564\n",
      "EPOCH: 28627 LOSS: 40.970625203206964\n",
      "EPOCH: 28628 LOSS: 40.970624097796325\n",
      "EPOCH: 28629 LOSS: 40.97062299244371\n",
      "EPOCH: 28630 LOSS: 40.97062188714909\n",
      "EPOCH: 28631 LOSS: 40.970620781912515\n",
      "EPOCH: 28632 LOSS: 40.97061967673392\n",
      "EPOCH: 28633 LOSS: 40.97061857161333\n",
      "EPOCH: 28634 LOSS: 40.97061746655073\n",
      "EPOCH: 28635 LOSS: 40.97061636154611\n",
      "EPOCH: 28636 LOSS: 40.97061525659948\n",
      "EPOCH: 28637 LOSS: 40.97061415171085\n",
      "EPOCH: 28638 LOSS: 40.97061304688014\n",
      "EPOCH: 28639 LOSS: 40.97061194210743\n",
      "EPOCH: 28640 LOSS: 40.97061083739266\n",
      "EPOCH: 28641 LOSS: 40.97060973273586\n",
      "EPOCH: 28642 LOSS: 40.970608628136986\n",
      "EPOCH: 28643 LOSS: 40.97060752359609\n",
      "EPOCH: 28644 LOSS: 40.97060641911308\n",
      "EPOCH: 28645 LOSS: 40.97060531468803\n",
      "EPOCH: 28646 LOSS: 40.970604210320914\n",
      "EPOCH: 28647 LOSS: 40.97060310601169\n",
      "EPOCH: 28648 LOSS: 40.97060200176038\n",
      "EPOCH: 28649 LOSS: 40.970600897566996\n",
      "EPOCH: 28650 LOSS: 40.9705997934315\n",
      "EPOCH: 28651 LOSS: 40.97059868935389\n",
      "EPOCH: 28652 LOSS: 40.97059758533419\n",
      "EPOCH: 28653 LOSS: 40.97059648137236\n",
      "EPOCH: 28654 LOSS: 40.97059537746843\n",
      "EPOCH: 28655 LOSS: 40.97059427362235\n",
      "EPOCH: 28656 LOSS: 40.97059316983414\n",
      "EPOCH: 28657 LOSS: 40.97059206610379\n",
      "EPOCH: 28658 LOSS: 40.97059096243128\n",
      "EPOCH: 28659 LOSS: 40.970589858816645\n",
      "EPOCH: 28660 LOSS: 40.970588755259854\n",
      "EPOCH: 28661 LOSS: 40.97058765176088\n",
      "EPOCH: 28662 LOSS: 40.970586548319744\n",
      "EPOCH: 28663 LOSS: 40.97058544493644\n",
      "EPOCH: 28664 LOSS: 40.97058434161095\n",
      "EPOCH: 28665 LOSS: 40.97058323834327\n",
      "EPOCH: 28666 LOSS: 40.97058213513342\n",
      "EPOCH: 28667 LOSS: 40.97058103198135\n",
      "EPOCH: 28668 LOSS: 40.97057992888709\n",
      "EPOCH: 28669 LOSS: 40.97057882585062\n",
      "EPOCH: 28670 LOSS: 40.97057772287194\n",
      "EPOCH: 28671 LOSS: 40.97057661995103\n",
      "EPOCH: 28672 LOSS: 40.97057551708788\n",
      "EPOCH: 28673 LOSS: 40.970574414282524\n",
      "EPOCH: 28674 LOSS: 40.97057331153493\n",
      "EPOCH: 28675 LOSS: 40.97057220884507\n",
      "EPOCH: 28676 LOSS: 40.97057110621299\n",
      "EPOCH: 28677 LOSS: 40.970570003638656\n",
      "EPOCH: 28678 LOSS: 40.970568901122036\n",
      "EPOCH: 28679 LOSS: 40.97056779866316\n",
      "EPOCH: 28680 LOSS: 40.97056669626202\n",
      "EPOCH: 28681 LOSS: 40.97056559391859\n",
      "EPOCH: 28682 LOSS: 40.970564491632885\n",
      "EPOCH: 28683 LOSS: 40.9705633894049\n",
      "EPOCH: 28684 LOSS: 40.97056228723459\n",
      "EPOCH: 28685 LOSS: 40.97056118512201\n",
      "EPOCH: 28686 LOSS: 40.9705600830671\n",
      "EPOCH: 28687 LOSS: 40.9705589810699\n",
      "EPOCH: 28688 LOSS: 40.97055787913037\n",
      "EPOCH: 28689 LOSS: 40.97055677724852\n",
      "EPOCH: 28690 LOSS: 40.97055567542433\n",
      "EPOCH: 28691 LOSS: 40.97055457365783\n",
      "EPOCH: 28692 LOSS: 40.97055347194898\n",
      "EPOCH: 28693 LOSS: 40.97055237029777\n",
      "EPOCH: 28694 LOSS: 40.97055126870423\n",
      "EPOCH: 28695 LOSS: 40.97055016716831\n",
      "EPOCH: 28696 LOSS: 40.970549065690044\n",
      "EPOCH: 28697 LOSS: 40.97054796426939\n",
      "EPOCH: 28698 LOSS: 40.970546862906374\n",
      "EPOCH: 28699 LOSS: 40.970545761600974\n",
      "EPOCH: 28700 LOSS: 40.97054466035319\n",
      "EPOCH: 28701 LOSS: 40.97054355916302\n",
      "EPOCH: 28702 LOSS: 40.97054245803043\n",
      "EPOCH: 28703 LOSS: 40.97054135695546\n",
      "EPOCH: 28704 LOSS: 40.97054025593806\n",
      "EPOCH: 28705 LOSS: 40.97053915497827\n",
      "EPOCH: 28706 LOSS: 40.97053805407605\n",
      "EPOCH: 28707 LOSS: 40.9705369532314\n",
      "EPOCH: 28708 LOSS: 40.970535852444314\n",
      "EPOCH: 28709 LOSS: 40.970534751714794\n",
      "EPOCH: 28710 LOSS: 40.97053365104282\n",
      "EPOCH: 28711 LOSS: 40.970532550428416\n",
      "EPOCH: 28712 LOSS: 40.970531449871544\n",
      "EPOCH: 28713 LOSS: 40.970530349372204\n",
      "EPOCH: 28714 LOSS: 40.97052924893043\n",
      "EPOCH: 28715 LOSS: 40.97052814854615\n",
      "EPOCH: 28716 LOSS: 40.97052704821942\n",
      "EPOCH: 28717 LOSS: 40.97052594795018\n",
      "EPOCH: 28718 LOSS: 40.97052484773847\n",
      "EPOCH: 28719 LOSS: 40.97052374758426\n",
      "EPOCH: 28720 LOSS: 40.97052264748753\n",
      "EPOCH: 28721 LOSS: 40.97052154744833\n",
      "EPOCH: 28722 LOSS: 40.97052044746658\n",
      "EPOCH: 28723 LOSS: 40.970519347542336\n",
      "EPOCH: 28724 LOSS: 40.97051824767556\n",
      "EPOCH: 28725 LOSS: 40.970517147866246\n",
      "EPOCH: 28726 LOSS: 40.97051604811441\n",
      "EPOCH: 28727 LOSS: 40.97051494842003\n",
      "EPOCH: 28728 LOSS: 40.97051384878311\n",
      "EPOCH: 28729 LOSS: 40.970512749203635\n",
      "EPOCH: 28730 LOSS: 40.970511649681605\n",
      "EPOCH: 28731 LOSS: 40.970510550217014\n",
      "EPOCH: 28732 LOSS: 40.97050945080984\n",
      "EPOCH: 28733 LOSS: 40.9705083514601\n",
      "EPOCH: 28734 LOSS: 40.970507252167764\n",
      "EPOCH: 28735 LOSS: 40.97050615293287\n",
      "EPOCH: 28736 LOSS: 40.97050505375537\n",
      "EPOCH: 28737 LOSS: 40.97050395463526\n",
      "EPOCH: 28738 LOSS: 40.97050285557255\n",
      "EPOCH: 28739 LOSS: 40.970501756567266\n",
      "EPOCH: 28740 LOSS: 40.97050065761934\n",
      "EPOCH: 28741 LOSS: 40.97049955872878\n",
      "EPOCH: 28742 LOSS: 40.970498459895616\n",
      "EPOCH: 28743 LOSS: 40.97049736111981\n",
      "EPOCH: 28744 LOSS: 40.97049626240137\n",
      "EPOCH: 28745 LOSS: 40.970495163740296\n",
      "EPOCH: 28746 LOSS: 40.97049406513656\n",
      "EPOCH: 28747 LOSS: 40.97049296659017\n",
      "EPOCH: 28748 LOSS: 40.970491868101135\n",
      "EPOCH: 28749 LOSS: 40.9704907696694\n",
      "EPOCH: 28750 LOSS: 40.970489671295034\n",
      "EPOCH: 28751 LOSS: 40.970488572977956\n",
      "EPOCH: 28752 LOSS: 40.97048747471822\n",
      "EPOCH: 28753 LOSS: 40.970486376515794\n",
      "EPOCH: 28754 LOSS: 40.97048527837066\n",
      "EPOCH: 28755 LOSS: 40.97048418028284\n",
      "EPOCH: 28756 LOSS: 40.9704830822523\n",
      "EPOCH: 28757 LOSS: 40.97048198427906\n",
      "EPOCH: 28758 LOSS: 40.97048088636309\n",
      "EPOCH: 28759 LOSS: 40.97047978850441\n",
      "EPOCH: 28760 LOSS: 40.970478690703\n",
      "EPOCH: 28761 LOSS: 40.97047759295886\n",
      "EPOCH: 28762 LOSS: 40.97047649527199\n",
      "EPOCH: 28763 LOSS: 40.970475397642346\n",
      "EPOCH: 28764 LOSS: 40.97047430006998\n",
      "EPOCH: 28765 LOSS: 40.97047320255484\n",
      "EPOCH: 28766 LOSS: 40.97047210509693\n",
      "EPOCH: 28767 LOSS: 40.97047100769626\n",
      "EPOCH: 28768 LOSS: 40.97046991035282\n",
      "EPOCH: 28769 LOSS: 40.9704688130666\n",
      "EPOCH: 28770 LOSS: 40.97046771583759\n",
      "EPOCH: 28771 LOSS: 40.970466618665796\n",
      "EPOCH: 28772 LOSS: 40.97046552155121\n",
      "EPOCH: 28773 LOSS: 40.97046442449382\n",
      "EPOCH: 28774 LOSS: 40.97046332749362\n",
      "EPOCH: 28775 LOSS: 40.970462230550595\n",
      "EPOCH: 28776 LOSS: 40.97046113366477\n",
      "EPOCH: 28777 LOSS: 40.970460036836116\n",
      "EPOCH: 28778 LOSS: 40.97045894006462\n",
      "EPOCH: 28779 LOSS: 40.97045784335029\n",
      "EPOCH: 28780 LOSS: 40.970456746693145\n",
      "EPOCH: 28781 LOSS: 40.970455650093115\n",
      "EPOCH: 28782 LOSS: 40.970454553550255\n",
      "EPOCH: 28783 LOSS: 40.97045345706454\n",
      "EPOCH: 28784 LOSS: 40.970452360635946\n",
      "EPOCH: 28785 LOSS: 40.9704512642645\n",
      "EPOCH: 28786 LOSS: 40.97045016795015\n",
      "EPOCH: 28787 LOSS: 40.97044907169295\n",
      "EPOCH: 28788 LOSS: 40.97044797549284\n",
      "EPOCH: 28789 LOSS: 40.97044687934983\n",
      "EPOCH: 28790 LOSS: 40.97044578326395\n",
      "EPOCH: 28791 LOSS: 40.97044468723515\n",
      "EPOCH: 28792 LOSS: 40.97044359126346\n",
      "EPOCH: 28793 LOSS: 40.97044249534883\n",
      "EPOCH: 28794 LOSS: 40.97044139949129\n",
      "EPOCH: 28795 LOSS: 40.97044030369083\n",
      "EPOCH: 28796 LOSS: 40.970439207947436\n",
      "EPOCH: 28797 LOSS: 40.97043811226109\n",
      "EPOCH: 28798 LOSS: 40.97043701663181\n",
      "EPOCH: 28799 LOSS: 40.970435921059575\n",
      "EPOCH: 28800 LOSS: 40.97043482554441\n",
      "EPOCH: 28801 LOSS: 40.97043373008627\n",
      "EPOCH: 28802 LOSS: 40.97043263468516\n",
      "EPOCH: 28803 LOSS: 40.97043153934108\n",
      "EPOCH: 28804 LOSS: 40.97043044405403\n",
      "EPOCH: 28805 LOSS: 40.970429348823984\n",
      "EPOCH: 28806 LOSS: 40.97042825365095\n",
      "EPOCH: 28807 LOSS: 40.970427158534925\n",
      "EPOCH: 28808 LOSS: 40.97042606347592\n",
      "EPOCH: 28809 LOSS: 40.97042496847391\n",
      "EPOCH: 28810 LOSS: 40.97042387352886\n",
      "EPOCH: 28811 LOSS: 40.970422778640796\n",
      "EPOCH: 28812 LOSS: 40.97042168380972\n",
      "EPOCH: 28813 LOSS: 40.970420589035626\n",
      "EPOCH: 28814 LOSS: 40.970419494318506\n",
      "EPOCH: 28815 LOSS: 40.970418399658314\n",
      "EPOCH: 28816 LOSS: 40.97041730505509\n",
      "EPOCH: 28817 LOSS: 40.97041621050883\n",
      "EPOCH: 28818 LOSS: 40.97041511601951\n",
      "EPOCH: 28819 LOSS: 40.97041402158712\n",
      "EPOCH: 28820 LOSS: 40.97041292721166\n",
      "EPOCH: 28821 LOSS: 40.970411832893134\n",
      "EPOCH: 28822 LOSS: 40.97041073863154\n",
      "EPOCH: 28823 LOSS: 40.97040964442685\n",
      "EPOCH: 28824 LOSS: 40.97040855027906\n",
      "EPOCH: 28825 LOSS: 40.970407456188205\n",
      "EPOCH: 28826 LOSS: 40.97040636215422\n",
      "EPOCH: 28827 LOSS: 40.970405268177146\n",
      "EPOCH: 28828 LOSS: 40.97040417425696\n",
      "EPOCH: 28829 LOSS: 40.970403080393645\n",
      "EPOCH: 28830 LOSS: 40.97040198658722\n",
      "EPOCH: 28831 LOSS: 40.970400892837674\n",
      "EPOCH: 28832 LOSS: 40.97039979914496\n",
      "EPOCH: 28833 LOSS: 40.97039870550911\n",
      "EPOCH: 28834 LOSS: 40.97039761193014\n",
      "EPOCH: 28835 LOSS: 40.970396518408\n",
      "EPOCH: 28836 LOSS: 40.97039542494272\n",
      "EPOCH: 28837 LOSS: 40.970394331534266\n",
      "EPOCH: 28838 LOSS: 40.97039323818264\n",
      "EPOCH: 28839 LOSS: 40.97039214488785\n",
      "EPOCH: 28840 LOSS: 40.970391051649884\n",
      "EPOCH: 28841 LOSS: 40.970389958468715\n",
      "EPOCH: 28842 LOSS: 40.970388865344376\n",
      "EPOCH: 28843 LOSS: 40.97038777227684\n",
      "EPOCH: 28844 LOSS: 40.970386679266085\n",
      "EPOCH: 28845 LOSS: 40.97038558631212\n",
      "EPOCH: 28846 LOSS: 40.97038449341497\n",
      "EPOCH: 28847 LOSS: 40.970383400574576\n",
      "EPOCH: 28848 LOSS: 40.97038230779097\n",
      "EPOCH: 28849 LOSS: 40.97038121506413\n",
      "EPOCH: 28850 LOSS: 40.970380122394054\n",
      "EPOCH: 28851 LOSS: 40.97037902978075\n",
      "EPOCH: 28852 LOSS: 40.97037793722419\n",
      "EPOCH: 28853 LOSS: 40.97037684472437\n",
      "EPOCH: 28854 LOSS: 40.9703757522813\n",
      "EPOCH: 28855 LOSS: 40.97037465989497\n",
      "EPOCH: 28856 LOSS: 40.97037356756537\n",
      "EPOCH: 28857 LOSS: 40.9703724752925\n",
      "EPOCH: 28858 LOSS: 40.97037138307633\n",
      "EPOCH: 28859 LOSS: 40.97037029091689\n",
      "EPOCH: 28860 LOSS: 40.970369198814154\n",
      "EPOCH: 28861 LOSS: 40.97036810676812\n",
      "EPOCH: 28862 LOSS: 40.97036701477879\n",
      "EPOCH: 28863 LOSS: 40.97036592284614\n",
      "EPOCH: 28864 LOSS: 40.9703648309702\n",
      "EPOCH: 28865 LOSS: 40.97036373915092\n",
      "EPOCH: 28866 LOSS: 40.97036264738832\n",
      "EPOCH: 28867 LOSS: 40.970361555682395\n",
      "EPOCH: 28868 LOSS: 40.97036046403312\n",
      "EPOCH: 28869 LOSS: 40.97035937244053\n",
      "EPOCH: 28870 LOSS: 40.97035828090456\n",
      "EPOCH: 28871 LOSS: 40.97035718942527\n",
      "EPOCH: 28872 LOSS: 40.9703560980026\n",
      "EPOCH: 28873 LOSS: 40.970355006636574\n",
      "EPOCH: 28874 LOSS: 40.970353915327166\n",
      "EPOCH: 28875 LOSS: 40.9703528240744\n",
      "EPOCH: 28876 LOSS: 40.97035173287825\n",
      "EPOCH: 28877 LOSS: 40.97035064173872\n",
      "EPOCH: 28878 LOSS: 40.97034955065578\n",
      "EPOCH: 28879 LOSS: 40.97034845962945\n",
      "EPOCH: 28880 LOSS: 40.970347368659716\n",
      "EPOCH: 28881 LOSS: 40.970346277746586\n",
      "EPOCH: 28882 LOSS: 40.97034518689003\n",
      "EPOCH: 28883 LOSS: 40.97034409609007\n",
      "EPOCH: 28884 LOSS: 40.97034300534666\n",
      "EPOCH: 28885 LOSS: 40.97034191465984\n",
      "EPOCH: 28886 LOSS: 40.97034082402959\n",
      "EPOCH: 28887 LOSS: 40.97033973345587\n",
      "EPOCH: 28888 LOSS: 40.970338642938714\n",
      "EPOCH: 28889 LOSS: 40.970337552478114\n",
      "EPOCH: 28890 LOSS: 40.970336462074044\n",
      "EPOCH: 28891 LOSS: 40.97033537172652\n",
      "EPOCH: 28892 LOSS: 40.97033428143553\n",
      "EPOCH: 28893 LOSS: 40.97033319120105\n",
      "EPOCH: 28894 LOSS: 40.970332101023104\n",
      "EPOCH: 28895 LOSS: 40.97033101090166\n",
      "EPOCH: 28896 LOSS: 40.97032992083672\n",
      "EPOCH: 28897 LOSS: 40.9703288308283\n",
      "EPOCH: 28898 LOSS: 40.97032774087637\n",
      "EPOCH: 28899 LOSS: 40.97032665098093\n",
      "EPOCH: 28900 LOSS: 40.97032556114197\n",
      "EPOCH: 28901 LOSS: 40.97032447135949\n",
      "EPOCH: 28902 LOSS: 40.97032338163349\n",
      "EPOCH: 28903 LOSS: 40.97032229196397\n",
      "EPOCH: 28904 LOSS: 40.97032120235089\n",
      "EPOCH: 28905 LOSS: 40.97032011279429\n",
      "EPOCH: 28906 LOSS: 40.97031902329413\n",
      "EPOCH: 28907 LOSS: 40.97031793385044\n",
      "EPOCH: 28908 LOSS: 40.97031684446317\n",
      "EPOCH: 28909 LOSS: 40.97031575513233\n",
      "EPOCH: 28910 LOSS: 40.970314665857934\n",
      "EPOCH: 28911 LOSS: 40.97031357663995\n",
      "EPOCH: 28912 LOSS: 40.970312487478395\n",
      "EPOCH: 28913 LOSS: 40.97031139837327\n",
      "EPOCH: 28914 LOSS: 40.97031030932454\n",
      "EPOCH: 28915 LOSS: 40.97030922033219\n",
      "EPOCH: 28916 LOSS: 40.970308131396266\n",
      "EPOCH: 28917 LOSS: 40.970307042516716\n",
      "EPOCH: 28918 LOSS: 40.970305953693554\n",
      "EPOCH: 28919 LOSS: 40.97030486492679\n",
      "EPOCH: 28920 LOSS: 40.9703037762164\n",
      "EPOCH: 28921 LOSS: 40.97030268756235\n",
      "EPOCH: 28922 LOSS: 40.9703015989647\n",
      "EPOCH: 28923 LOSS: 40.9703005104234\n",
      "EPOCH: 28924 LOSS: 40.97029942193843\n",
      "EPOCH: 28925 LOSS: 40.97029833350982\n",
      "EPOCH: 28926 LOSS: 40.97029724513757\n",
      "EPOCH: 28927 LOSS: 40.97029615682163\n",
      "EPOCH: 28928 LOSS: 40.97029506856204\n",
      "EPOCH: 28929 LOSS: 40.97029398035876\n",
      "EPOCH: 28930 LOSS: 40.9702928922118\n",
      "EPOCH: 28931 LOSS: 40.97029180412116\n",
      "EPOCH: 28932 LOSS: 40.970290716086836\n",
      "EPOCH: 28933 LOSS: 40.970289628108794\n",
      "EPOCH: 28934 LOSS: 40.97028854018708\n",
      "EPOCH: 28935 LOSS: 40.97028745232163\n",
      "EPOCH: 28936 LOSS: 40.97028636451249\n",
      "EPOCH: 28937 LOSS: 40.97028527675961\n",
      "EPOCH: 28938 LOSS: 40.97028418906302\n",
      "EPOCH: 28939 LOSS: 40.970283101422694\n",
      "EPOCH: 28940 LOSS: 40.970282013838634\n",
      "EPOCH: 28941 LOSS: 40.970280926310835\n",
      "EPOCH: 28942 LOSS: 40.970279838839275\n",
      "EPOCH: 28943 LOSS: 40.97027875142397\n",
      "EPOCH: 28944 LOSS: 40.97027766406491\n",
      "EPOCH: 28945 LOSS: 40.9702765767621\n",
      "EPOCH: 28946 LOSS: 40.97027548951549\n",
      "EPOCH: 28947 LOSS: 40.970274402325146\n",
      "EPOCH: 28948 LOSS: 40.970273315191\n",
      "EPOCH: 28949 LOSS: 40.97027222811306\n",
      "EPOCH: 28950 LOSS: 40.97027114109136\n",
      "EPOCH: 28951 LOSS: 40.970270054125834\n",
      "EPOCH: 28952 LOSS: 40.97026896721651\n",
      "EPOCH: 28953 LOSS: 40.970267880363394\n",
      "EPOCH: 28954 LOSS: 40.970266793566445\n",
      "EPOCH: 28955 LOSS: 40.97026570682569\n",
      "EPOCH: 28956 LOSS: 40.97026462014112\n",
      "EPOCH: 28957 LOSS: 40.97026353351271\n",
      "EPOCH: 28958 LOSS: 40.97026244694047\n",
      "EPOCH: 28959 LOSS: 40.97026136042438\n",
      "EPOCH: 28960 LOSS: 40.970260273964435\n",
      "EPOCH: 28961 LOSS: 40.97025918756067\n",
      "EPOCH: 28962 LOSS: 40.97025810121303\n",
      "EPOCH: 28963 LOSS: 40.970257014921536\n",
      "EPOCH: 28964 LOSS: 40.97025592868616\n",
      "EPOCH: 28965 LOSS: 40.970254842506904\n",
      "EPOCH: 28966 LOSS: 40.9702537563838\n",
      "EPOCH: 28967 LOSS: 40.970252670316796\n",
      "EPOCH: 28968 LOSS: 40.97025158430589\n",
      "EPOCH: 28969 LOSS: 40.970250498351106\n",
      "EPOCH: 28970 LOSS: 40.970249412452404\n",
      "EPOCH: 28971 LOSS: 40.97024832660982\n",
      "EPOCH: 28972 LOSS: 40.97024724082331\n",
      "EPOCH: 28973 LOSS: 40.97024615509289\n",
      "EPOCH: 28974 LOSS: 40.97024506941853\n",
      "EPOCH: 28975 LOSS: 40.970243983800245\n",
      "EPOCH: 28976 LOSS: 40.97024289823804\n",
      "EPOCH: 28977 LOSS: 40.970241812731885\n",
      "EPOCH: 28978 LOSS: 40.97024072728179\n",
      "EPOCH: 28979 LOSS: 40.970239641887744\n",
      "EPOCH: 28980 LOSS: 40.97023855654976\n",
      "EPOCH: 28981 LOSS: 40.970237471267794\n",
      "EPOCH: 28982 LOSS: 40.970236386041854\n",
      "EPOCH: 28983 LOSS: 40.97023530087195\n",
      "EPOCH: 28984 LOSS: 40.97023421575807\n",
      "EPOCH: 28985 LOSS: 40.97023313070021\n",
      "EPOCH: 28986 LOSS: 40.97023204569836\n",
      "EPOCH: 28987 LOSS: 40.97023096075252\n",
      "EPOCH: 28988 LOSS: 40.97022987586268\n",
      "EPOCH: 28989 LOSS: 40.970228791028816\n",
      "EPOCH: 28990 LOSS: 40.97022770625097\n",
      "EPOCH: 28991 LOSS: 40.97022662152909\n",
      "EPOCH: 28992 LOSS: 40.97022553686319\n",
      "EPOCH: 28993 LOSS: 40.97022445225326\n",
      "EPOCH: 28994 LOSS: 40.970223367699305\n",
      "EPOCH: 28995 LOSS: 40.97022228320131\n",
      "EPOCH: 28996 LOSS: 40.97022119875926\n",
      "EPOCH: 28997 LOSS: 40.970220114373184\n",
      "EPOCH: 28998 LOSS: 40.97021903004304\n",
      "EPOCH: 28999 LOSS: 40.970217945768844\n",
      "EPOCH: 29000 LOSS: 40.97021686155057\n",
      "EPOCH: 29001 LOSS: 40.970215777388226\n",
      "EPOCH: 29002 LOSS: 40.970214693281825\n",
      "EPOCH: 29003 LOSS: 40.97021360923132\n",
      "EPOCH: 29004 LOSS: 40.97021252523673\n",
      "EPOCH: 29005 LOSS: 40.97021144129806\n",
      "EPOCH: 29006 LOSS: 40.97021035741528\n",
      "EPOCH: 29007 LOSS: 40.970209273588395\n",
      "EPOCH: 29008 LOSS: 40.970208189817406\n",
      "EPOCH: 29009 LOSS: 40.970207106102315\n",
      "EPOCH: 29010 LOSS: 40.9702060224431\n",
      "EPOCH: 29011 LOSS: 40.97020493883975\n",
      "EPOCH: 29012 LOSS: 40.97020385529226\n",
      "EPOCH: 29013 LOSS: 40.970202771800636\n",
      "EPOCH: 29014 LOSS: 40.970201688364895\n",
      "EPOCH: 29015 LOSS: 40.970200604984996\n",
      "EPOCH: 29016 LOSS: 40.970199521660916\n",
      "EPOCH: 29017 LOSS: 40.970198438392714\n",
      "EPOCH: 29018 LOSS: 40.97019735518033\n",
      "EPOCH: 29019 LOSS: 40.9701962720238\n",
      "EPOCH: 29020 LOSS: 40.97019518892306\n",
      "EPOCH: 29021 LOSS: 40.97019410587815\n",
      "EPOCH: 29022 LOSS: 40.97019302288908\n",
      "EPOCH: 29023 LOSS: 40.97019193995579\n",
      "EPOCH: 29024 LOSS: 40.97019085707832\n",
      "EPOCH: 29025 LOSS: 40.97018977425664\n",
      "EPOCH: 29026 LOSS: 40.97018869149075\n",
      "EPOCH: 29027 LOSS: 40.970187608780655\n",
      "EPOCH: 29028 LOSS: 40.97018652612634\n",
      "EPOCH: 29029 LOSS: 40.9701854435278\n",
      "EPOCH: 29030 LOSS: 40.970184360985016\n",
      "EPOCH: 29031 LOSS: 40.97018327849803\n",
      "EPOCH: 29032 LOSS: 40.97018219606679\n",
      "EPOCH: 29033 LOSS: 40.97018111369129\n",
      "EPOCH: 29034 LOSS: 40.970180031371555\n",
      "EPOCH: 29035 LOSS: 40.97017894910756\n",
      "EPOCH: 29036 LOSS: 40.9701778668993\n",
      "EPOCH: 29037 LOSS: 40.97017678474678\n",
      "EPOCH: 29038 LOSS: 40.97017570264996\n",
      "EPOCH: 29039 LOSS: 40.970174620608894\n",
      "EPOCH: 29040 LOSS: 40.97017353862353\n",
      "EPOCH: 29041 LOSS: 40.97017245669389\n",
      "EPOCH: 29042 LOSS: 40.970171374819934\n",
      "EPOCH: 29043 LOSS: 40.9701702930017\n",
      "EPOCH: 29044 LOSS: 40.97016921123915\n",
      "EPOCH: 29045 LOSS: 40.9701681295323\n",
      "EPOCH: 29046 LOSS: 40.970167047881105\n",
      "EPOCH: 29047 LOSS: 40.970165966285606\n",
      "EPOCH: 29048 LOSS: 40.97016488474579\n",
      "EPOCH: 29049 LOSS: 40.97016380326163\n",
      "EPOCH: 29050 LOSS: 40.970162721833134\n",
      "EPOCH: 29051 LOSS: 40.97016164046029\n",
      "EPOCH: 29052 LOSS: 40.97016055914311\n",
      "EPOCH: 29053 LOSS: 40.970159477881566\n",
      "EPOCH: 29054 LOSS: 40.97015839667567\n",
      "EPOCH: 29055 LOSS: 40.9701573155254\n",
      "EPOCH: 29056 LOSS: 40.97015623443077\n",
      "EPOCH: 29057 LOSS: 40.970155153391744\n",
      "EPOCH: 29058 LOSS: 40.97015407240834\n",
      "EPOCH: 29059 LOSS: 40.97015299148056\n",
      "EPOCH: 29060 LOSS: 40.970151910608394\n",
      "EPOCH: 29061 LOSS: 40.97015082979182\n",
      "EPOCH: 29062 LOSS: 40.97014974903084\n",
      "EPOCH: 29063 LOSS: 40.970148668325464\n",
      "EPOCH: 29064 LOSS: 40.97014758767566\n",
      "EPOCH: 29065 LOSS: 40.97014650708145\n",
      "EPOCH: 29066 LOSS: 40.9701454265428\n",
      "EPOCH: 29067 LOSS: 40.97014434605975\n",
      "EPOCH: 29068 LOSS: 40.97014326563222\n",
      "EPOCH: 29069 LOSS: 40.97014218526029\n",
      "EPOCH: 29070 LOSS: 40.97014110494388\n",
      "EPOCH: 29071 LOSS: 40.97014002468303\n",
      "EPOCH: 29072 LOSS: 40.97013894447774\n",
      "EPOCH: 29073 LOSS: 40.97013786432796\n",
      "EPOCH: 29074 LOSS: 40.970136784233745\n",
      "EPOCH: 29075 LOSS: 40.97013570419503\n",
      "EPOCH: 29076 LOSS: 40.97013462421184\n",
      "EPOCH: 29077 LOSS: 40.97013354428417\n",
      "EPOCH: 29078 LOSS: 40.97013246441202\n",
      "EPOCH: 29079 LOSS: 40.97013138459534\n",
      "EPOCH: 29080 LOSS: 40.970130304834186\n",
      "EPOCH: 29081 LOSS: 40.97012922512853\n",
      "EPOCH: 29082 LOSS: 40.970128145478355\n",
      "EPOCH: 29083 LOSS: 40.970127065883666\n",
      "EPOCH: 29084 LOSS: 40.970125986344456\n",
      "EPOCH: 29085 LOSS: 40.97012490686073\n",
      "EPOCH: 29086 LOSS: 40.97012382743243\n",
      "EPOCH: 29087 LOSS: 40.97012274805962\n",
      "EPOCH: 29088 LOSS: 40.97012166874228\n",
      "EPOCH: 29089 LOSS: 40.97012058948037\n",
      "EPOCH: 29090 LOSS: 40.97011951027392\n",
      "EPOCH: 29091 LOSS: 40.97011843112287\n",
      "EPOCH: 29092 LOSS: 40.9701173520273\n",
      "EPOCH: 29093 LOSS: 40.970116272987156\n",
      "EPOCH: 29094 LOSS: 40.97011519400242\n",
      "EPOCH: 29095 LOSS: 40.9701141150731\n",
      "EPOCH: 29096 LOSS: 40.97011303619921\n",
      "EPOCH: 29097 LOSS: 40.97011195738071\n",
      "EPOCH: 29098 LOSS: 40.97011087861762\n",
      "EPOCH: 29099 LOSS: 40.97010979990993\n",
      "EPOCH: 29100 LOSS: 40.970108721257624\n",
      "EPOCH: 29101 LOSS: 40.970107642660714\n",
      "EPOCH: 29102 LOSS: 40.97010656411917\n",
      "EPOCH: 29103 LOSS: 40.97010548563301\n",
      "EPOCH: 29104 LOSS: 40.970104407202214\n",
      "EPOCH: 29105 LOSS: 40.97010332882681\n",
      "EPOCH: 29106 LOSS: 40.97010225050673\n",
      "EPOCH: 29107 LOSS: 40.97010117224201\n",
      "EPOCH: 29108 LOSS: 40.970100094032645\n",
      "EPOCH: 29109 LOSS: 40.970099015878624\n",
      "EPOCH: 29110 LOSS: 40.97009793777994\n",
      "EPOCH: 29111 LOSS: 40.970096859736586\n",
      "EPOCH: 29112 LOSS: 40.97009578174857\n",
      "EPOCH: 29113 LOSS: 40.970094703815874\n",
      "EPOCH: 29114 LOSS: 40.97009362593847\n",
      "EPOCH: 29115 LOSS: 40.9700925481164\n",
      "EPOCH: 29116 LOSS: 40.97009147034964\n",
      "EPOCH: 29117 LOSS: 40.970090392638156\n",
      "EPOCH: 29118 LOSS: 40.970089314981976\n",
      "EPOCH: 29119 LOSS: 40.97008823738109\n",
      "EPOCH: 29120 LOSS: 40.97008715983548\n",
      "EPOCH: 29121 LOSS: 40.97008608234515\n",
      "EPOCH: 29122 LOSS: 40.9700850049101\n",
      "EPOCH: 29123 LOSS: 40.970083927530325\n",
      "EPOCH: 29124 LOSS: 40.9700828502058\n",
      "EPOCH: 29125 LOSS: 40.97008177293653\n",
      "EPOCH: 29126 LOSS: 40.970080695722515\n",
      "EPOCH: 29127 LOSS: 40.97007961856374\n",
      "EPOCH: 29128 LOSS: 40.97007854146021\n",
      "EPOCH: 29129 LOSS: 40.970077464411915\n",
      "EPOCH: 29130 LOSS: 40.970076387418864\n",
      "EPOCH: 29131 LOSS: 40.97007531048102\n",
      "EPOCH: 29132 LOSS: 40.970074233598396\n",
      "EPOCH: 29133 LOSS: 40.970073156770994\n",
      "EPOCH: 29134 LOSS: 40.9700720799988\n",
      "EPOCH: 29135 LOSS: 40.97007100328182\n",
      "EPOCH: 29136 LOSS: 40.97006992662002\n",
      "EPOCH: 29137 LOSS: 40.97006885001341\n",
      "EPOCH: 29138 LOSS: 40.970067773462006\n",
      "EPOCH: 29139 LOSS: 40.970066696965766\n",
      "EPOCH: 29140 LOSS: 40.97006562052469\n",
      "EPOCH: 29141 LOSS: 40.97006454413882\n",
      "EPOCH: 29142 LOSS: 40.9700634678081\n",
      "EPOCH: 29143 LOSS: 40.97006239153254\n",
      "EPOCH: 29144 LOSS: 40.97006131531213\n",
      "EPOCH: 29145 LOSS: 40.97006023914689\n",
      "EPOCH: 29146 LOSS: 40.970059163036765\n",
      "EPOCH: 29147 LOSS: 40.970058086981794\n",
      "EPOCH: 29148 LOSS: 40.970057010981954\n",
      "EPOCH: 29149 LOSS: 40.97005593503725\n",
      "EPOCH: 29150 LOSS: 40.97005485914765\n",
      "EPOCH: 29151 LOSS: 40.97005378331319\n",
      "EPOCH: 29152 LOSS: 40.97005270753384\n",
      "EPOCH: 29153 LOSS: 40.97005163180958\n",
      "EPOCH: 29154 LOSS: 40.970050556140436\n",
      "EPOCH: 29155 LOSS: 40.97004948052638\n",
      "EPOCH: 29156 LOSS: 40.97004840496741\n",
      "EPOCH: 29157 LOSS: 40.97004732946354\n",
      "EPOCH: 29158 LOSS: 40.97004625401475\n",
      "EPOCH: 29159 LOSS: 40.970045178621014\n",
      "EPOCH: 29160 LOSS: 40.97004410328237\n",
      "EPOCH: 29161 LOSS: 40.970043027998784\n",
      "EPOCH: 29162 LOSS: 40.97004195277023\n",
      "EPOCH: 29163 LOSS: 40.97004087759676\n",
      "EPOCH: 29164 LOSS: 40.97003980247834\n",
      "EPOCH: 29165 LOSS: 40.970038727414966\n",
      "EPOCH: 29166 LOSS: 40.9700376524066\n",
      "EPOCH: 29167 LOSS: 40.970036577453286\n",
      "EPOCH: 29168 LOSS: 40.97003550255499\n",
      "EPOCH: 29169 LOSS: 40.970034427711724\n",
      "EPOCH: 29170 LOSS: 40.97003335292348\n",
      "EPOCH: 29171 LOSS: 40.97003227819023\n",
      "EPOCH: 29172 LOSS: 40.97003120351199\n",
      "EPOCH: 29173 LOSS: 40.970030128888745\n",
      "EPOCH: 29174 LOSS: 40.970029054320506\n",
      "EPOCH: 29175 LOSS: 40.970027979807256\n",
      "EPOCH: 29176 LOSS: 40.97002690534898\n",
      "EPOCH: 29177 LOSS: 40.9700258309457\n",
      "EPOCH: 29178 LOSS: 40.9700247565974\n",
      "EPOCH: 29179 LOSS: 40.970023682304024\n",
      "EPOCH: 29180 LOSS: 40.97002260806565\n",
      "EPOCH: 29181 LOSS: 40.97002153388222\n",
      "EPOCH: 29182 LOSS: 40.97002045975373\n",
      "EPOCH: 29183 LOSS: 40.9700193856802\n",
      "EPOCH: 29184 LOSS: 40.970018311661605\n",
      "EPOCH: 29185 LOSS: 40.97001723769798\n",
      "EPOCH: 29186 LOSS: 40.97001616378924\n",
      "EPOCH: 29187 LOSS: 40.97001508993544\n",
      "EPOCH: 29188 LOSS: 40.97001401613656\n",
      "EPOCH: 29189 LOSS: 40.97001294239259\n",
      "EPOCH: 29190 LOSS: 40.97001186870355\n",
      "EPOCH: 29191 LOSS: 40.970010795069385\n",
      "EPOCH: 29192 LOSS: 40.97000972149015\n",
      "EPOCH: 29193 LOSS: 40.970008647965784\n",
      "EPOCH: 29194 LOSS: 40.97000757449631\n",
      "EPOCH: 29195 LOSS: 40.970006501081734\n",
      "EPOCH: 29196 LOSS: 40.970005427722015\n",
      "EPOCH: 29197 LOSS: 40.970004354417185\n",
      "EPOCH: 29198 LOSS: 40.97000328116721\n",
      "EPOCH: 29199 LOSS: 40.97000220797211\n",
      "EPOCH: 29200 LOSS: 40.970001134831854\n",
      "EPOCH: 29201 LOSS: 40.97000006174646\n",
      "EPOCH: 29202 LOSS: 40.9699989887159\n",
      "EPOCH: 29203 LOSS: 40.96999791574019\n",
      "EPOCH: 29204 LOSS: 40.9699968428193\n",
      "EPOCH: 29205 LOSS: 40.96999576995326\n",
      "EPOCH: 29206 LOSS: 40.96999469714203\n",
      "EPOCH: 29207 LOSS: 40.96999362438562\n",
      "EPOCH: 29208 LOSS: 40.96999255168402\n",
      "EPOCH: 29209 LOSS: 40.96999147903723\n",
      "EPOCH: 29210 LOSS: 40.96999040644525\n",
      "EPOCH: 29211 LOSS: 40.969989333908075\n",
      "EPOCH: 29212 LOSS: 40.9699882614257\n",
      "EPOCH: 29213 LOSS: 40.969987188998076\n",
      "EPOCH: 29214 LOSS: 40.96998611662526\n",
      "EPOCH: 29215 LOSS: 40.96998504430721\n",
      "EPOCH: 29216 LOSS: 40.969983972043934\n",
      "EPOCH: 29217 LOSS: 40.96998289983543\n",
      "EPOCH: 29218 LOSS: 40.96998182768168\n",
      "EPOCH: 29219 LOSS: 40.9699807555827\n",
      "EPOCH: 29220 LOSS: 40.96997968353845\n",
      "EPOCH: 29221 LOSS: 40.96997861154895\n",
      "EPOCH: 29222 LOSS: 40.96997753961419\n",
      "EPOCH: 29223 LOSS: 40.96997646773417\n",
      "EPOCH: 29224 LOSS: 40.96997539590887\n",
      "EPOCH: 29225 LOSS: 40.969974324138306\n",
      "EPOCH: 29226 LOSS: 40.96997325242244\n",
      "EPOCH: 29227 LOSS: 40.96997218076132\n",
      "EPOCH: 29228 LOSS: 40.969971109154876\n",
      "EPOCH: 29229 LOSS: 40.969970037603154\n",
      "EPOCH: 29230 LOSS: 40.96996896610612\n",
      "EPOCH: 29231 LOSS: 40.96996789466378\n",
      "EPOCH: 29232 LOSS: 40.969966823276124\n",
      "EPOCH: 29233 LOSS: 40.969965751943164\n",
      "EPOCH: 29234 LOSS: 40.96996468066485\n",
      "EPOCH: 29235 LOSS: 40.96996360944123\n",
      "EPOCH: 29236 LOSS: 40.96996253827228\n",
      "EPOCH: 29237 LOSS: 40.96996146715797\n",
      "EPOCH: 29238 LOSS: 40.96996039609833\n",
      "EPOCH: 29239 LOSS: 40.96995932509334\n",
      "EPOCH: 29240 LOSS: 40.96995825414299\n",
      "EPOCH: 29241 LOSS: 40.969957183247274\n",
      "EPOCH: 29242 LOSS: 40.969956112406194\n",
      "EPOCH: 29243 LOSS: 40.96995504161975\n",
      "EPOCH: 29244 LOSS: 40.969953970887914\n",
      "EPOCH: 29245 LOSS: 40.969952900210714\n",
      "EPOCH: 29246 LOSS: 40.96995182958812\n",
      "EPOCH: 29247 LOSS: 40.969950759020136\n",
      "EPOCH: 29248 LOSS: 40.96994968850675\n",
      "EPOCH: 29249 LOSS: 40.96994861804796\n",
      "EPOCH: 29250 LOSS: 40.969947547643756\n",
      "EPOCH: 29251 LOSS: 40.969946477294144\n",
      "EPOCH: 29252 LOSS: 40.969945406999116\n",
      "EPOCH: 29253 LOSS: 40.969944336758665\n",
      "EPOCH: 29254 LOSS: 40.969943266572784\n",
      "EPOCH: 29255 LOSS: 40.96994219644145\n",
      "EPOCH: 29256 LOSS: 40.9699411263647\n",
      "EPOCH: 29257 LOSS: 40.9699400563425\n",
      "EPOCH: 29258 LOSS: 40.96993898637484\n",
      "EPOCH: 29259 LOSS: 40.96993791646173\n",
      "EPOCH: 29260 LOSS: 40.96993684660316\n",
      "EPOCH: 29261 LOSS: 40.96993577679912\n",
      "EPOCH: 29262 LOSS: 40.96993470704961\n",
      "EPOCH: 29263 LOSS: 40.96993363735463\n",
      "EPOCH: 29264 LOSS: 40.96993256771416\n",
      "EPOCH: 29265 LOSS: 40.969931498128204\n",
      "EPOCH: 29266 LOSS: 40.969930428596754\n",
      "EPOCH: 29267 LOSS: 40.9699293591198\n",
      "EPOCH: 29268 LOSS: 40.96992828969736\n",
      "EPOCH: 29269 LOSS: 40.96992722032941\n",
      "EPOCH: 29270 LOSS: 40.96992615101591\n",
      "EPOCH: 29271 LOSS: 40.969925081756934\n",
      "EPOCH: 29272 LOSS: 40.96992401255241\n",
      "EPOCH: 29273 LOSS: 40.96992294340238\n",
      "EPOCH: 29274 LOSS: 40.96992187430679\n",
      "EPOCH: 29275 LOSS: 40.96992080526567\n",
      "EPOCH: 29276 LOSS: 40.96991973627901\n",
      "EPOCH: 29277 LOSS: 40.969918667346796\n",
      "EPOCH: 29278 LOSS: 40.969917598469024\n",
      "EPOCH: 29279 LOSS: 40.969916529645694\n",
      "EPOCH: 29280 LOSS: 40.96991546087679\n",
      "EPOCH: 29281 LOSS: 40.96991439216233\n",
      "EPOCH: 29282 LOSS: 40.96991332350227\n",
      "EPOCH: 29283 LOSS: 40.969912254896656\n",
      "EPOCH: 29284 LOSS: 40.96991118634544\n",
      "EPOCH: 29285 LOSS: 40.969910117848634\n",
      "EPOCH: 29286 LOSS: 40.969909049406205\n",
      "EPOCH: 29287 LOSS: 40.96990798101821\n",
      "EPOCH: 29288 LOSS: 40.96990691268458\n",
      "EPOCH: 29289 LOSS: 40.969905844405346\n",
      "EPOCH: 29290 LOSS: 40.96990477618051\n",
      "EPOCH: 29291 LOSS: 40.96990370801004\n",
      "EPOCH: 29292 LOSS: 40.96990263989394\n",
      "EPOCH: 29293 LOSS: 40.96990157183219\n",
      "EPOCH: 29294 LOSS: 40.96990050382482\n",
      "EPOCH: 29295 LOSS: 40.969899435871795\n",
      "EPOCH: 29296 LOSS: 40.96989836797312\n",
      "EPOCH: 29297 LOSS: 40.96989730012879\n",
      "EPOCH: 29298 LOSS: 40.96989623233881\n",
      "EPOCH: 29299 LOSS: 40.969895164603145\n",
      "EPOCH: 29300 LOSS: 40.96989409692183\n",
      "EPOCH: 29301 LOSS: 40.96989302929482\n",
      "EPOCH: 29302 LOSS: 40.96989196172214\n",
      "EPOCH: 29303 LOSS: 40.969890894203765\n",
      "EPOCH: 29304 LOSS: 40.9698898267397\n",
      "EPOCH: 29305 LOSS: 40.969888759329955\n",
      "EPOCH: 29306 LOSS: 40.969887691974485\n",
      "EPOCH: 29307 LOSS: 40.96988662467331\n",
      "EPOCH: 29308 LOSS: 40.96988555742644\n",
      "EPOCH: 29309 LOSS: 40.96988449023383\n",
      "EPOCH: 29310 LOSS: 40.969883423095496\n",
      "EPOCH: 29311 LOSS: 40.96988235601145\n",
      "EPOCH: 29312 LOSS: 40.969881288981654\n",
      "EPOCH: 29313 LOSS: 40.96988022200612\n",
      "EPOCH: 29314 LOSS: 40.96987915508487\n",
      "EPOCH: 29315 LOSS: 40.96987808821784\n",
      "EPOCH: 29316 LOSS: 40.969877021405075\n",
      "EPOCH: 29317 LOSS: 40.96987595464654\n",
      "EPOCH: 29318 LOSS: 40.96987488794225\n",
      "EPOCH: 29319 LOSS: 40.96987382129217\n",
      "EPOCH: 29320 LOSS: 40.96987275469632\n",
      "EPOCH: 29321 LOSS: 40.96987168815468\n",
      "EPOCH: 29322 LOSS: 40.969870621667276\n",
      "EPOCH: 29323 LOSS: 40.96986955523407\n",
      "EPOCH: 29324 LOSS: 40.969868488855056\n",
      "EPOCH: 29325 LOSS: 40.96986742253026\n",
      "EPOCH: 29326 LOSS: 40.96986635625965\n",
      "EPOCH: 29327 LOSS: 40.96986529004323\n",
      "EPOCH: 29328 LOSS: 40.969864223881\n",
      "EPOCH: 29329 LOSS: 40.969863157772934\n",
      "EPOCH: 29330 LOSS: 40.96986209171904\n",
      "EPOCH: 29331 LOSS: 40.9698610257193\n",
      "EPOCH: 29332 LOSS: 40.96985995977376\n",
      "EPOCH: 29333 LOSS: 40.96985889388235\n",
      "EPOCH: 29334 LOSS: 40.96985782804509\n",
      "EPOCH: 29335 LOSS: 40.96985676226198\n",
      "EPOCH: 29336 LOSS: 40.969855696533024\n",
      "EPOCH: 29337 LOSS: 40.96985463085819\n",
      "EPOCH: 29338 LOSS: 40.96985356523749\n",
      "EPOCH: 29339 LOSS: 40.969852499670914\n",
      "EPOCH: 29340 LOSS: 40.969851434158464\n",
      "EPOCH: 29341 LOSS: 40.96985036870012\n",
      "EPOCH: 29342 LOSS: 40.96984930329589\n",
      "EPOCH: 29343 LOSS: 40.96984823794577\n",
      "EPOCH: 29344 LOSS: 40.96984717264974\n",
      "EPOCH: 29345 LOSS: 40.96984610740779\n",
      "EPOCH: 29346 LOSS: 40.96984504221997\n",
      "EPOCH: 29347 LOSS: 40.96984397708621\n",
      "EPOCH: 29348 LOSS: 40.96984291200653\n",
      "EPOCH: 29349 LOSS: 40.969841846980906\n",
      "EPOCH: 29350 LOSS: 40.96984078200937\n",
      "EPOCH: 29351 LOSS: 40.96983971709188\n",
      "EPOCH: 29352 LOSS: 40.96983865222846\n",
      "EPOCH: 29353 LOSS: 40.969837587419114\n",
      "EPOCH: 29354 LOSS: 40.969836522663776\n",
      "EPOCH: 29355 LOSS: 40.96983545796251\n",
      "EPOCH: 29356 LOSS: 40.96983439331527\n",
      "EPOCH: 29357 LOSS: 40.96983332872205\n",
      "EPOCH: 29358 LOSS: 40.96983226418287\n",
      "EPOCH: 29359 LOSS: 40.969831199697715\n",
      "EPOCH: 29360 LOSS: 40.96983013526656\n",
      "EPOCH: 29361 LOSS: 40.96982907088943\n",
      "EPOCH: 29362 LOSS: 40.969828006566296\n",
      "EPOCH: 29363 LOSS: 40.969826942297175\n",
      "EPOCH: 29364 LOSS: 40.96982587808204\n",
      "EPOCH: 29365 LOSS: 40.96982481392091\n",
      "EPOCH: 29366 LOSS: 40.969823749813756\n",
      "EPOCH: 29367 LOSS: 40.96982268576056\n",
      "EPOCH: 29368 LOSS: 40.96982162176136\n",
      "EPOCH: 29369 LOSS: 40.96982055781613\n",
      "EPOCH: 29370 LOSS: 40.96981949392485\n",
      "EPOCH: 29371 LOSS: 40.96981843008757\n",
      "EPOCH: 29372 LOSS: 40.9698173663042\n",
      "EPOCH: 29373 LOSS: 40.969816302574785\n",
      "EPOCH: 29374 LOSS: 40.969815238899315\n",
      "EPOCH: 29375 LOSS: 40.9698141752778\n",
      "EPOCH: 29376 LOSS: 40.96981311171021\n",
      "EPOCH: 29377 LOSS: 40.969812048196545\n",
      "EPOCH: 29378 LOSS: 40.969810984736796\n",
      "EPOCH: 29379 LOSS: 40.96980992133099\n",
      "EPOCH: 29380 LOSS: 40.96980885797906\n",
      "EPOCH: 29381 LOSS: 40.96980779468107\n",
      "EPOCH: 29382 LOSS: 40.96980673143698\n",
      "EPOCH: 29383 LOSS: 40.969805668246764\n",
      "EPOCH: 29384 LOSS: 40.96980460511044\n",
      "EPOCH: 29385 LOSS: 40.969803542028025\n",
      "EPOCH: 29386 LOSS: 40.96980247899947\n",
      "EPOCH: 29387 LOSS: 40.96980141602481\n",
      "EPOCH: 29388 LOSS: 40.96980035310402\n",
      "EPOCH: 29389 LOSS: 40.96979929023708\n",
      "EPOCH: 29390 LOSS: 40.969798227424\n",
      "EPOCH: 29391 LOSS: 40.9697971646648\n",
      "EPOCH: 29392 LOSS: 40.96979610195944\n",
      "EPOCH: 29393 LOSS: 40.96979503930791\n",
      "EPOCH: 29394 LOSS: 40.969793976710235\n",
      "EPOCH: 29395 LOSS: 40.96979291416639\n",
      "EPOCH: 29396 LOSS: 40.96979185167639\n",
      "EPOCH: 29397 LOSS: 40.96979078924019\n",
      "EPOCH: 29398 LOSS: 40.969789726857826\n",
      "EPOCH: 29399 LOSS: 40.96978866452927\n",
      "EPOCH: 29400 LOSS: 40.969787602254506\n",
      "EPOCH: 29401 LOSS: 40.969786540033596\n",
      "EPOCH: 29402 LOSS: 40.96978547786644\n",
      "EPOCH: 29403 LOSS: 40.96978441575309\n",
      "EPOCH: 29404 LOSS: 40.969783353693536\n",
      "EPOCH: 29405 LOSS: 40.96978229168775\n",
      "EPOCH: 29406 LOSS: 40.969781229735744\n",
      "EPOCH: 29407 LOSS: 40.96978016783753\n",
      "EPOCH: 29408 LOSS: 40.969779105993055\n",
      "EPOCH: 29409 LOSS: 40.96977804420237\n",
      "EPOCH: 29410 LOSS: 40.96977698246545\n",
      "EPOCH: 29411 LOSS: 40.969775920782254\n",
      "EPOCH: 29412 LOSS: 40.969774859152814\n",
      "EPOCH: 29413 LOSS: 40.96977379757712\n",
      "EPOCH: 29414 LOSS: 40.96977273605518\n",
      "EPOCH: 29415 LOSS: 40.969771674586944\n",
      "EPOCH: 29416 LOSS: 40.969770613172436\n",
      "EPOCH: 29417 LOSS: 40.969769551811666\n",
      "EPOCH: 29418 LOSS: 40.96976849050459\n",
      "EPOCH: 29419 LOSS: 40.96976742925124\n",
      "EPOCH: 29420 LOSS: 40.9697663680516\n",
      "EPOCH: 29421 LOSS: 40.96976530690567\n",
      "EPOCH: 29422 LOSS: 40.96976424581341\n",
      "EPOCH: 29423 LOSS: 40.96976318477486\n",
      "EPOCH: 29424 LOSS: 40.96976212378999\n",
      "EPOCH: 29425 LOSS: 40.96976106285881\n",
      "EPOCH: 29426 LOSS: 40.969760001981285\n",
      "EPOCH: 29427 LOSS: 40.96975894115744\n",
      "EPOCH: 29428 LOSS: 40.96975788038726\n",
      "EPOCH: 29429 LOSS: 40.96975681967075\n",
      "EPOCH: 29430 LOSS: 40.96975575900788\n",
      "EPOCH: 29431 LOSS: 40.96975469839867\n",
      "EPOCH: 29432 LOSS: 40.969753637843084\n",
      "EPOCH: 29433 LOSS: 40.96975257734117\n",
      "EPOCH: 29434 LOSS: 40.96975151689286\n",
      "EPOCH: 29435 LOSS: 40.9697504564982\n",
      "EPOCH: 29436 LOSS: 40.96974939615716\n",
      "EPOCH: 29437 LOSS: 40.969748335869724\n",
      "EPOCH: 29438 LOSS: 40.96974727563591\n",
      "EPOCH: 29439 LOSS: 40.969746215455714\n",
      "EPOCH: 29440 LOSS: 40.96974515532911\n",
      "EPOCH: 29441 LOSS: 40.96974409525612\n",
      "EPOCH: 29442 LOSS: 40.969743035236704\n",
      "EPOCH: 29443 LOSS: 40.96974197527088\n",
      "EPOCH: 29444 LOSS: 40.969740915358656\n",
      "EPOCH: 29445 LOSS: 40.9697398555\n",
      "EPOCH: 29446 LOSS: 40.9697387956949\n",
      "EPOCH: 29447 LOSS: 40.96973773594338\n",
      "EPOCH: 29448 LOSS: 40.96973667624543\n",
      "EPOCH: 29449 LOSS: 40.96973561660103\n",
      "EPOCH: 29450 LOSS: 40.969734557010185\n",
      "EPOCH: 29451 LOSS: 40.96973349747289\n",
      "EPOCH: 29452 LOSS: 40.96973243798914\n",
      "EPOCH: 29453 LOSS: 40.96973137855891\n",
      "EPOCH: 29454 LOSS: 40.969730319182226\n",
      "EPOCH: 29455 LOSS: 40.96972925985905\n",
      "EPOCH: 29456 LOSS: 40.969728200589415\n",
      "EPOCH: 29457 LOSS: 40.96972714137328\n",
      "EPOCH: 29458 LOSS: 40.969726082210684\n",
      "EPOCH: 29459 LOSS: 40.96972502310158\n",
      "EPOCH: 29460 LOSS: 40.96972396404597\n",
      "EPOCH: 29461 LOSS: 40.96972290504387\n",
      "EPOCH: 29462 LOSS: 40.969721846095254\n",
      "EPOCH: 29463 LOSS: 40.9697207872001\n",
      "EPOCH: 29464 LOSS: 40.96971972835845\n",
      "EPOCH: 29465 LOSS: 40.969718669570284\n",
      "EPOCH: 29466 LOSS: 40.96971761083557\n",
      "EPOCH: 29467 LOSS: 40.969716552154324\n",
      "EPOCH: 29468 LOSS: 40.96971549352654\n",
      "EPOCH: 29469 LOSS: 40.96971443495221\n",
      "EPOCH: 29470 LOSS: 40.96971337643134\n",
      "EPOCH: 29471 LOSS: 40.96971231796392\n",
      "EPOCH: 29472 LOSS: 40.969711259549925\n",
      "EPOCH: 29473 LOSS: 40.96971020118937\n",
      "EPOCH: 29474 LOSS: 40.96970914288224\n",
      "EPOCH: 29475 LOSS: 40.969708084628536\n",
      "EPOCH: 29476 LOSS: 40.96970702642825\n",
      "EPOCH: 29477 LOSS: 40.969705968281374\n",
      "EPOCH: 29478 LOSS: 40.96970491018792\n",
      "EPOCH: 29479 LOSS: 40.96970385214787\n",
      "EPOCH: 29480 LOSS: 40.9697027941612\n",
      "EPOCH: 29481 LOSS: 40.96970173622795\n",
      "EPOCH: 29482 LOSS: 40.96970067834808\n",
      "EPOCH: 29483 LOSS: 40.96969962052158\n",
      "EPOCH: 29484 LOSS: 40.969698562748476\n",
      "EPOCH: 29485 LOSS: 40.96969750502874\n",
      "EPOCH: 29486 LOSS: 40.96969644736235\n",
      "EPOCH: 29487 LOSS: 40.96969538974935\n",
      "EPOCH: 29488 LOSS: 40.96969433218969\n",
      "EPOCH: 29489 LOSS: 40.96969327468341\n",
      "EPOCH: 29490 LOSS: 40.96969221723047\n",
      "EPOCH: 29491 LOSS: 40.969691159830845\n",
      "EPOCH: 29492 LOSS: 40.96969010248458\n",
      "EPOCH: 29493 LOSS: 40.96968904519163\n",
      "EPOCH: 29494 LOSS: 40.96968798795205\n",
      "EPOCH: 29495 LOSS: 40.969686930765754\n",
      "EPOCH: 29496 LOSS: 40.969685873632784\n",
      "EPOCH: 29497 LOSS: 40.969684816553126\n",
      "EPOCH: 29498 LOSS: 40.96968375952679\n",
      "EPOCH: 29499 LOSS: 40.96968270255374\n",
      "EPOCH: 29500 LOSS: 40.969681645634004\n",
      "EPOCH: 29501 LOSS: 40.96968058876754\n",
      "EPOCH: 29502 LOSS: 40.96967953195437\n",
      "EPOCH: 29503 LOSS: 40.969678475194485\n",
      "EPOCH: 29504 LOSS: 40.96967741848787\n",
      "EPOCH: 29505 LOSS: 40.96967636183453\n",
      "EPOCH: 29506 LOSS: 40.96967530523446\n",
      "EPOCH: 29507 LOSS: 40.96967424868765\n",
      "EPOCH: 29508 LOSS: 40.969673192194094\n",
      "EPOCH: 29509 LOSS: 40.96967213575378\n",
      "EPOCH: 29510 LOSS: 40.96967107936674\n",
      "EPOCH: 29511 LOSS: 40.96967002303292\n",
      "EPOCH: 29512 LOSS: 40.969668966752344\n",
      "EPOCH: 29513 LOSS: 40.969667910525004\n",
      "EPOCH: 29514 LOSS: 40.96966685435086\n",
      "EPOCH: 29515 LOSS: 40.96966579822997\n",
      "EPOCH: 29516 LOSS: 40.96966474216228\n",
      "EPOCH: 29517 LOSS: 40.96966368614781\n",
      "EPOCH: 29518 LOSS: 40.969662630186534\n",
      "EPOCH: 29519 LOSS: 40.96966157427847\n",
      "EPOCH: 29520 LOSS: 40.969660518423595\n",
      "EPOCH: 29521 LOSS: 40.96965946262192\n",
      "EPOCH: 29522 LOSS: 40.969658406873414\n",
      "EPOCH: 29523 LOSS: 40.9696573511781\n",
      "EPOCH: 29524 LOSS: 40.96965629553595\n",
      "EPOCH: 29525 LOSS: 40.969655239947\n",
      "EPOCH: 29526 LOSS: 40.96965418441118\n",
      "EPOCH: 29527 LOSS: 40.96965312892853\n",
      "EPOCH: 29528 LOSS: 40.96965207349905\n",
      "EPOCH: 29529 LOSS: 40.96965101812272\n",
      "EPOCH: 29530 LOSS: 40.969649962799515\n",
      "EPOCH: 29531 LOSS: 40.96964890752946\n",
      "EPOCH: 29532 LOSS: 40.96964785231255\n",
      "EPOCH: 29533 LOSS: 40.96964679714876\n",
      "EPOCH: 29534 LOSS: 40.969645742038075\n",
      "EPOCH: 29535 LOSS: 40.969644686980544\n",
      "EPOCH: 29536 LOSS: 40.9696436319761\n",
      "EPOCH: 29537 LOSS: 40.969642577024786\n",
      "EPOCH: 29538 LOSS: 40.969641522126565\n",
      "EPOCH: 29539 LOSS: 40.96964046728145\n",
      "EPOCH: 29540 LOSS: 40.96963941248943\n",
      "EPOCH: 29541 LOSS: 40.96963835775048\n",
      "EPOCH: 29542 LOSS: 40.96963730306464\n",
      "EPOCH: 29543 LOSS: 40.96963624843187\n",
      "EPOCH: 29544 LOSS: 40.96963519385217\n",
      "EPOCH: 29545 LOSS: 40.969634139325535\n",
      "EPOCH: 29546 LOSS: 40.969633084851985\n",
      "EPOCH: 29547 LOSS: 40.96963203043148\n",
      "EPOCH: 29548 LOSS: 40.96963097606402\n",
      "EPOCH: 29549 LOSS: 40.96962992174963\n",
      "EPOCH: 29550 LOSS: 40.96962886748827\n",
      "EPOCH: 29551 LOSS: 40.96962781327994\n",
      "EPOCH: 29552 LOSS: 40.96962675912465\n",
      "EPOCH: 29553 LOSS: 40.969625705022395\n",
      "EPOCH: 29554 LOSS: 40.96962465097317\n",
      "EPOCH: 29555 LOSS: 40.96962359697696\n",
      "EPOCH: 29556 LOSS: 40.96962254303376\n",
      "EPOCH: 29557 LOSS: 40.969621489143556\n",
      "EPOCH: 29558 LOSS: 40.96962043530637\n",
      "EPOCH: 29559 LOSS: 40.969619381522186\n",
      "EPOCH: 29560 LOSS: 40.96961832779099\n",
      "EPOCH: 29561 LOSS: 40.96961727411278\n",
      "EPOCH: 29562 LOSS: 40.96961622048755\n",
      "EPOCH: 29563 LOSS: 40.969615166915304\n",
      "EPOCH: 29564 LOSS: 40.96961411339604\n",
      "EPOCH: 29565 LOSS: 40.96961305992973\n",
      "EPOCH: 29566 LOSS: 40.969612006516385\n",
      "EPOCH: 29567 LOSS: 40.96961095315599\n",
      "EPOCH: 29568 LOSS: 40.969609899848564\n",
      "EPOCH: 29569 LOSS: 40.969608846594085\n",
      "EPOCH: 29570 LOSS: 40.96960779339254\n",
      "EPOCH: 29571 LOSS: 40.96960674024394\n",
      "EPOCH: 29572 LOSS: 40.969605687148274\n",
      "EPOCH: 29573 LOSS: 40.969604634105536\n",
      "EPOCH: 29574 LOSS: 40.96960358111572\n",
      "EPOCH: 29575 LOSS: 40.96960252817882\n",
      "EPOCH: 29576 LOSS: 40.96960147529483\n",
      "EPOCH: 29577 LOSS: 40.969600422463756\n",
      "EPOCH: 29578 LOSS: 40.96959936968558\n",
      "EPOCH: 29579 LOSS: 40.96959831696029\n",
      "EPOCH: 29580 LOSS: 40.96959726428791\n",
      "EPOCH: 29581 LOSS: 40.96959621166843\n",
      "EPOCH: 29582 LOSS: 40.96959515910179\n",
      "EPOCH: 29583 LOSS: 40.96959410658806\n",
      "EPOCH: 29584 LOSS: 40.9695930541272\n",
      "EPOCH: 29585 LOSS: 40.96959200171921\n",
      "EPOCH: 29586 LOSS: 40.96959094936406\n",
      "EPOCH: 29587 LOSS: 40.96958989706179\n",
      "EPOCH: 29588 LOSS: 40.96958884481235\n",
      "EPOCH: 29589 LOSS: 40.96958779261578\n",
      "EPOCH: 29590 LOSS: 40.96958674047206\n",
      "EPOCH: 29591 LOSS: 40.96958568838115\n",
      "EPOCH: 29592 LOSS: 40.9695846363431\n",
      "EPOCH: 29593 LOSS: 40.96958358435786\n",
      "EPOCH: 29594 LOSS: 40.96958253242545\n",
      "EPOCH: 29595 LOSS: 40.96958148054584\n",
      "EPOCH: 29596 LOSS: 40.96958042871907\n",
      "EPOCH: 29597 LOSS: 40.969579376945084\n",
      "EPOCH: 29598 LOSS: 40.96957832522393\n",
      "EPOCH: 29599 LOSS: 40.969577273555544\n",
      "EPOCH: 29600 LOSS: 40.96957622193996\n",
      "EPOCH: 29601 LOSS: 40.96957517037717\n",
      "EPOCH: 29602 LOSS: 40.96957411886714\n",
      "EPOCH: 29603 LOSS: 40.969573067409925\n",
      "EPOCH: 29604 LOSS: 40.96957201600545\n",
      "EPOCH: 29605 LOSS: 40.969570964653755\n",
      "EPOCH: 29606 LOSS: 40.96956991335482\n",
      "EPOCH: 29607 LOSS: 40.969568862108645\n",
      "EPOCH: 29608 LOSS: 40.96956781091522\n",
      "EPOCH: 29609 LOSS: 40.96956675977454\n",
      "EPOCH: 29610 LOSS: 40.969565708686616\n",
      "EPOCH: 29611 LOSS: 40.96956465765141\n",
      "EPOCH: 29612 LOSS: 40.96956360666894\n",
      "EPOCH: 29613 LOSS: 40.96956255573921\n",
      "EPOCH: 29614 LOSS: 40.9695615048622\n",
      "EPOCH: 29615 LOSS: 40.969560454037904\n",
      "EPOCH: 29616 LOSS: 40.96955940326632\n",
      "EPOCH: 29617 LOSS: 40.96955835254745\n",
      "EPOCH: 29618 LOSS: 40.96955730188125\n",
      "EPOCH: 29619 LOSS: 40.969556251267775\n",
      "EPOCH: 29620 LOSS: 40.969555200707006\n",
      "EPOCH: 29621 LOSS: 40.9695541501989\n",
      "EPOCH: 29622 LOSS: 40.96955309974349\n",
      "EPOCH: 29623 LOSS: 40.96955204934075\n",
      "EPOCH: 29624 LOSS: 40.96955099899069\n",
      "EPOCH: 29625 LOSS: 40.96954994869328\n",
      "EPOCH: 29626 LOSS: 40.969548898448544\n",
      "EPOCH: 29627 LOSS: 40.96954784825646\n",
      "EPOCH: 29628 LOSS: 40.96954679811705\n",
      "EPOCH: 29629 LOSS: 40.96954574803027\n",
      "EPOCH: 29630 LOSS: 40.969544697996135\n",
      "EPOCH: 29631 LOSS: 40.969543648014636\n",
      "EPOCH: 29632 LOSS: 40.96954259808577\n",
      "EPOCH: 29633 LOSS: 40.969541548209534\n",
      "EPOCH: 29634 LOSS: 40.96954049838591\n",
      "EPOCH: 29635 LOSS: 40.969539448614924\n",
      "EPOCH: 29636 LOSS: 40.969538398896546\n",
      "EPOCH: 29637 LOSS: 40.96953734923074\n",
      "EPOCH: 29638 LOSS: 40.96953629961757\n",
      "EPOCH: 29639 LOSS: 40.969535250057\n",
      "EPOCH: 29640 LOSS: 40.96953420054902\n",
      "EPOCH: 29641 LOSS: 40.969533151093614\n",
      "EPOCH: 29642 LOSS: 40.96953210169081\n",
      "EPOCH: 29643 LOSS: 40.96953105234057\n",
      "EPOCH: 29644 LOSS: 40.96953000304289\n",
      "EPOCH: 29645 LOSS: 40.969528953797806\n",
      "EPOCH: 29646 LOSS: 40.96952790460527\n",
      "EPOCH: 29647 LOSS: 40.969526855465304\n",
      "EPOCH: 29648 LOSS: 40.969525806377874\n",
      "EPOCH: 29649 LOSS: 40.96952475734301\n",
      "EPOCH: 29650 LOSS: 40.969523708360654\n",
      "EPOCH: 29651 LOSS: 40.96952265943087\n",
      "EPOCH: 29652 LOSS: 40.96952161055362\n",
      "EPOCH: 29653 LOSS: 40.96952056172888\n",
      "EPOCH: 29654 LOSS: 40.96951951295665\n",
      "EPOCH: 29655 LOSS: 40.96951846423697\n",
      "EPOCH: 29656 LOSS: 40.969517415569804\n",
      "EPOCH: 29657 LOSS: 40.96951636695512\n",
      "EPOCH: 29658 LOSS: 40.969515318392936\n",
      "EPOCH: 29659 LOSS: 40.96951426988329\n",
      "EPOCH: 29660 LOSS: 40.9695132214261\n",
      "EPOCH: 29661 LOSS: 40.969512173021414\n",
      "EPOCH: 29662 LOSS: 40.96951112466921\n",
      "EPOCH: 29663 LOSS: 40.96951007636948\n",
      "EPOCH: 29664 LOSS: 40.96950902812223\n",
      "EPOCH: 29665 LOSS: 40.96950797992744\n",
      "EPOCH: 29666 LOSS: 40.96950693178511\n",
      "EPOCH: 29667 LOSS: 40.969505883695255\n",
      "EPOCH: 29668 LOSS: 40.96950483565784\n",
      "EPOCH: 29669 LOSS: 40.96950378767289\n",
      "EPOCH: 29670 LOSS: 40.96950273974036\n",
      "EPOCH: 29671 LOSS: 40.96950169186029\n",
      "EPOCH: 29672 LOSS: 40.96950064403265\n",
      "EPOCH: 29673 LOSS: 40.96949959625742\n",
      "EPOCH: 29674 LOSS: 40.96949854853463\n",
      "EPOCH: 29675 LOSS: 40.96949750086425\n",
      "EPOCH: 29676 LOSS: 40.969496453246286\n",
      "EPOCH: 29677 LOSS: 40.969495405680746\n",
      "EPOCH: 29678 LOSS: 40.969494358167594\n",
      "EPOCH: 29679 LOSS: 40.969493310706845\n",
      "EPOCH: 29680 LOSS: 40.96949226329849\n",
      "EPOCH: 29681 LOSS: 40.969491215942526\n",
      "EPOCH: 29682 LOSS: 40.96949016863894\n",
      "EPOCH: 29683 LOSS: 40.96948912138775\n",
      "EPOCH: 29684 LOSS: 40.96948807418891\n",
      "EPOCH: 29685 LOSS: 40.969487027042454\n",
      "EPOCH: 29686 LOSS: 40.969485979948345\n",
      "EPOCH: 29687 LOSS: 40.969484932906624\n",
      "EPOCH: 29688 LOSS: 40.96948388591724\n",
      "EPOCH: 29689 LOSS: 40.96948283898021\n",
      "EPOCH: 29690 LOSS: 40.969481792095515\n",
      "EPOCH: 29691 LOSS: 40.969480745263176\n",
      "EPOCH: 29692 LOSS: 40.96947969848317\n",
      "EPOCH: 29693 LOSS: 40.96947865175548\n",
      "EPOCH: 29694 LOSS: 40.96947760508013\n",
      "EPOCH: 29695 LOSS: 40.96947655845708\n",
      "EPOCH: 29696 LOSS: 40.96947551188635\n",
      "EPOCH: 29697 LOSS: 40.96947446536794\n",
      "EPOCH: 29698 LOSS: 40.96947341890184\n",
      "EPOCH: 29699 LOSS: 40.96947237248802\n",
      "EPOCH: 29700 LOSS: 40.969471326126495\n",
      "EPOCH: 29701 LOSS: 40.969470279817294\n",
      "EPOCH: 29702 LOSS: 40.96946923356034\n",
      "EPOCH: 29703 LOSS: 40.96946818735568\n",
      "EPOCH: 29704 LOSS: 40.969467141203324\n",
      "EPOCH: 29705 LOSS: 40.96946609510319\n",
      "EPOCH: 29706 LOSS: 40.96946504905535\n",
      "EPOCH: 29707 LOSS: 40.969464003059755\n",
      "EPOCH: 29708 LOSS: 40.96946295711643\n",
      "EPOCH: 29709 LOSS: 40.96946191122535\n",
      "EPOCH: 29710 LOSS: 40.969460865386516\n",
      "EPOCH: 29711 LOSS: 40.96945981959992\n",
      "EPOCH: 29712 LOSS: 40.96945877386557\n",
      "EPOCH: 29713 LOSS: 40.969457728183436\n",
      "EPOCH: 29714 LOSS: 40.96945668255354\n",
      "EPOCH: 29715 LOSS: 40.969455636975866\n",
      "EPOCH: 29716 LOSS: 40.969454591450386\n",
      "EPOCH: 29717 LOSS: 40.96945354597713\n",
      "EPOCH: 29718 LOSS: 40.96945250055609\n",
      "EPOCH: 29719 LOSS: 40.969451455187254\n",
      "EPOCH: 29720 LOSS: 40.96945040987061\n",
      "EPOCH: 29721 LOSS: 40.96944936460614\n",
      "EPOCH: 29722 LOSS: 40.969448319393884\n",
      "EPOCH: 29723 LOSS: 40.9694472742338\n",
      "EPOCH: 29724 LOSS: 40.96944622912588\n",
      "EPOCH: 29725 LOSS: 40.969445184070125\n",
      "EPOCH: 29726 LOSS: 40.96944413906657\n",
      "EPOCH: 29727 LOSS: 40.969443094115164\n",
      "EPOCH: 29728 LOSS: 40.969442049215914\n",
      "EPOCH: 29729 LOSS: 40.96944100436882\n",
      "EPOCH: 29730 LOSS: 40.96943995957387\n",
      "EPOCH: 29731 LOSS: 40.969438914831045\n",
      "EPOCH: 29732 LOSS: 40.96943787014037\n",
      "EPOCH: 29733 LOSS: 40.969436825501816\n",
      "EPOCH: 29734 LOSS: 40.96943578091542\n",
      "EPOCH: 29735 LOSS: 40.96943473638112\n",
      "EPOCH: 29736 LOSS: 40.96943369189895\n",
      "EPOCH: 29737 LOSS: 40.9694326474689\n",
      "EPOCH: 29738 LOSS: 40.96943160309094\n",
      "EPOCH: 29739 LOSS: 40.9694305587651\n",
      "EPOCH: 29740 LOSS: 40.96942951449134\n",
      "EPOCH: 29741 LOSS: 40.96942847026968\n",
      "EPOCH: 29742 LOSS: 40.96942742610012\n",
      "EPOCH: 29743 LOSS: 40.969426381982636\n",
      "EPOCH: 29744 LOSS: 40.96942533791722\n",
      "EPOCH: 29745 LOSS: 40.969424293903884\n",
      "EPOCH: 29746 LOSS: 40.969423249942636\n",
      "EPOCH: 29747 LOSS: 40.96942220603343\n",
      "EPOCH: 29748 LOSS: 40.96942116217629\n",
      "EPOCH: 29749 LOSS: 40.969420118371204\n",
      "EPOCH: 29750 LOSS: 40.96941907461817\n",
      "EPOCH: 29751 LOSS: 40.96941803091717\n",
      "EPOCH: 29752 LOSS: 40.96941698726822\n",
      "EPOCH: 29753 LOSS: 40.9694159436713\n",
      "EPOCH: 29754 LOSS: 40.969414900126395\n",
      "EPOCH: 29755 LOSS: 40.969413856633544\n",
      "EPOCH: 29756 LOSS: 40.96941281319269\n",
      "EPOCH: 29757 LOSS: 40.969411769803855\n",
      "EPOCH: 29758 LOSS: 40.96941072646704\n",
      "EPOCH: 29759 LOSS: 40.96940968318222\n",
      "EPOCH: 29760 LOSS: 40.969408639949414\n",
      "EPOCH: 29761 LOSS: 40.96940759676858\n",
      "EPOCH: 29762 LOSS: 40.96940655363976\n",
      "EPOCH: 29763 LOSS: 40.96940551056291\n",
      "EPOCH: 29764 LOSS: 40.96940446753805\n",
      "EPOCH: 29765 LOSS: 40.96940342456515\n",
      "EPOCH: 29766 LOSS: 40.96940238164424\n",
      "EPOCH: 29767 LOSS: 40.969401338775285\n",
      "EPOCH: 29768 LOSS: 40.96940029595828\n",
      "EPOCH: 29769 LOSS: 40.969399253193245\n",
      "EPOCH: 29770 LOSS: 40.969398210480165\n",
      "EPOCH: 29771 LOSS: 40.96939716781904\n",
      "EPOCH: 29772 LOSS: 40.96939612520984\n",
      "EPOCH: 29773 LOSS: 40.969395082652575\n",
      "EPOCH: 29774 LOSS: 40.96939404014725\n",
      "EPOCH: 29775 LOSS: 40.96939299769385\n",
      "EPOCH: 29776 LOSS: 40.96939195529238\n",
      "EPOCH: 29777 LOSS: 40.96939091294281\n",
      "EPOCH: 29778 LOSS: 40.969389870645145\n",
      "EPOCH: 29779 LOSS: 40.96938882839942\n",
      "EPOCH: 29780 LOSS: 40.96938778620558\n",
      "EPOCH: 29781 LOSS: 40.96938674406363\n",
      "EPOCH: 29782 LOSS: 40.969385701973586\n",
      "EPOCH: 29783 LOSS: 40.96938465993542\n",
      "EPOCH: 29784 LOSS: 40.969383617949134\n",
      "EPOCH: 29785 LOSS: 40.969382576014745\n",
      "EPOCH: 29786 LOSS: 40.96938153413221\n",
      "EPOCH: 29787 LOSS: 40.96938049230155\n",
      "EPOCH: 29788 LOSS: 40.969379450522744\n",
      "EPOCH: 29789 LOSS: 40.96937840879582\n",
      "EPOCH: 29790 LOSS: 40.96937736712074\n",
      "EPOCH: 29791 LOSS: 40.96937632549749\n",
      "EPOCH: 29792 LOSS: 40.9693752839261\n",
      "EPOCH: 29793 LOSS: 40.96937424240655\n",
      "EPOCH: 29794 LOSS: 40.96937320093883\n",
      "EPOCH: 29795 LOSS: 40.96937215952295\n",
      "EPOCH: 29796 LOSS: 40.96937111815889\n",
      "EPOCH: 29797 LOSS: 40.96937007684662\n",
      "EPOCH: 29798 LOSS: 40.9693690355862\n",
      "EPOCH: 29799 LOSS: 40.969367994377585\n",
      "EPOCH: 29800 LOSS: 40.96936695322077\n",
      "EPOCH: 29801 LOSS: 40.96936591211575\n",
      "EPOCH: 29802 LOSS: 40.969364871062524\n",
      "EPOCH: 29803 LOSS: 40.96936383006109\n",
      "EPOCH: 29804 LOSS: 40.969362789111464\n",
      "EPOCH: 29805 LOSS: 40.9693617482136\n",
      "EPOCH: 29806 LOSS: 40.9693607073675\n",
      "EPOCH: 29807 LOSS: 40.96935966657319\n",
      "EPOCH: 29808 LOSS: 40.96935862583063\n",
      "EPOCH: 29809 LOSS: 40.96935758513983\n",
      "EPOCH: 29810 LOSS: 40.96935654450081\n",
      "EPOCH: 29811 LOSS: 40.969355503913526\n",
      "EPOCH: 29812 LOSS: 40.96935446337798\n",
      "EPOCH: 29813 LOSS: 40.96935342289419\n",
      "EPOCH: 29814 LOSS: 40.96935238246213\n",
      "EPOCH: 29815 LOSS: 40.96935134208181\n",
      "EPOCH: 29816 LOSS: 40.969350301753224\n",
      "EPOCH: 29817 LOSS: 40.96934926147635\n",
      "EPOCH: 29818 LOSS: 40.96934822125118\n",
      "EPOCH: 29819 LOSS: 40.96934718107774\n",
      "EPOCH: 29820 LOSS: 40.969346140956\n",
      "EPOCH: 29821 LOSS: 40.96934510088596\n",
      "EPOCH: 29822 LOSS: 40.96934406086763\n",
      "EPOCH: 29823 LOSS: 40.96934302090098\n",
      "EPOCH: 29824 LOSS: 40.969341980986016\n",
      "EPOCH: 29825 LOSS: 40.96934094112275\n",
      "EPOCH: 29826 LOSS: 40.96933990131116\n",
      "EPOCH: 29827 LOSS: 40.969338861551236\n",
      "EPOCH: 29828 LOSS: 40.969337821843\n",
      "EPOCH: 29829 LOSS: 40.9693367821864\n",
      "EPOCH: 29830 LOSS: 40.96933574258148\n",
      "EPOCH: 29831 LOSS: 40.96933470302819\n",
      "EPOCH: 29832 LOSS: 40.969333663526584\n",
      "EPOCH: 29833 LOSS: 40.9693326240766\n",
      "EPOCH: 29834 LOSS: 40.969331584678265\n",
      "EPOCH: 29835 LOSS: 40.96933054533156\n",
      "EPOCH: 29836 LOSS: 40.96932950603649\n",
      "EPOCH: 29837 LOSS: 40.969328466793044\n",
      "EPOCH: 29838 LOSS: 40.96932742760122\n",
      "EPOCH: 29839 LOSS: 40.96932638846099\n",
      "EPOCH: 29840 LOSS: 40.96932534937239\n",
      "EPOCH: 29841 LOSS: 40.969324310335395\n",
      "EPOCH: 29842 LOSS: 40.96932327135002\n",
      "EPOCH: 29843 LOSS: 40.969322232416204\n",
      "EPOCH: 29844 LOSS: 40.96932119353399\n",
      "EPOCH: 29845 LOSS: 40.96932015470338\n",
      "EPOCH: 29846 LOSS: 40.96931911592436\n",
      "EPOCH: 29847 LOSS: 40.96931807719689\n",
      "EPOCH: 29848 LOSS: 40.969317038520984\n",
      "EPOCH: 29849 LOSS: 40.96931599989668\n",
      "EPOCH: 29850 LOSS: 40.96931496132392\n",
      "EPOCH: 29851 LOSS: 40.96931392280271\n",
      "EPOCH: 29852 LOSS: 40.96931288433308\n",
      "EPOCH: 29853 LOSS: 40.96931184591496\n",
      "EPOCH: 29854 LOSS: 40.96931080754841\n",
      "EPOCH: 29855 LOSS: 40.969309769233384\n",
      "EPOCH: 29856 LOSS: 40.9693087309699\n",
      "EPOCH: 29857 LOSS: 40.96930769275794\n",
      "EPOCH: 29858 LOSS: 40.969306654597524\n",
      "EPOCH: 29859 LOSS: 40.9693056164886\n",
      "EPOCH: 29860 LOSS: 40.969304578431206\n",
      "EPOCH: 29861 LOSS: 40.969303540425315\n",
      "EPOCH: 29862 LOSS: 40.96930250247093\n",
      "EPOCH: 29863 LOSS: 40.96930146456805\n",
      "EPOCH: 29864 LOSS: 40.96930042671667\n",
      "EPOCH: 29865 LOSS: 40.96929938891675\n",
      "EPOCH: 29866 LOSS: 40.969298351168334\n",
      "EPOCH: 29867 LOSS: 40.96929731347141\n",
      "EPOCH: 29868 LOSS: 40.96929627582594\n",
      "EPOCH: 29869 LOSS: 40.96929523823196\n",
      "EPOCH: 29870 LOSS: 40.96929420068945\n",
      "EPOCH: 29871 LOSS: 40.969293163198365\n",
      "EPOCH: 29872 LOSS: 40.96929212575877\n",
      "EPOCH: 29873 LOSS: 40.96929108837061\n",
      "EPOCH: 29874 LOSS: 40.969290051033916\n",
      "EPOCH: 29875 LOSS: 40.96928901374866\n",
      "EPOCH: 29876 LOSS: 40.96928797651483\n",
      "EPOCH: 29877 LOSS: 40.96928693933243\n",
      "EPOCH: 29878 LOSS: 40.969285902201456\n",
      "EPOCH: 29879 LOSS: 40.96928486512192\n",
      "EPOCH: 29880 LOSS: 40.969283828093786\n",
      "EPOCH: 29881 LOSS: 40.96928279111707\n",
      "EPOCH: 29882 LOSS: 40.96928175419177\n",
      "EPOCH: 29883 LOSS: 40.96928071731787\n",
      "EPOCH: 29884 LOSS: 40.96927968049536\n",
      "EPOCH: 29885 LOSS: 40.969278643724266\n",
      "EPOCH: 29886 LOSS: 40.96927760700454\n",
      "EPOCH: 29887 LOSS: 40.969276570336206\n",
      "EPOCH: 29888 LOSS: 40.96927553371925\n",
      "EPOCH: 29889 LOSS: 40.96927449715368\n",
      "EPOCH: 29890 LOSS: 40.96927346063945\n",
      "EPOCH: 29891 LOSS: 40.9692724241766\n",
      "EPOCH: 29892 LOSS: 40.96927138776512\n",
      "EPOCH: 29893 LOSS: 40.96927035140498\n",
      "EPOCH: 29894 LOSS: 40.9692693150962\n",
      "EPOCH: 29895 LOSS: 40.96926827883877\n",
      "EPOCH: 29896 LOSS: 40.96926724263267\n",
      "EPOCH: 29897 LOSS: 40.969266206477926\n",
      "EPOCH: 29898 LOSS: 40.9692651703745\n",
      "EPOCH: 29899 LOSS: 40.96926413432239\n",
      "EPOCH: 29900 LOSS: 40.96926309832162\n",
      "EPOCH: 29901 LOSS: 40.96926206237215\n",
      "EPOCH: 29902 LOSS: 40.969261026474\n",
      "EPOCH: 29903 LOSS: 40.96925999062716\n",
      "EPOCH: 29904 LOSS: 40.969258954831616\n",
      "EPOCH: 29905 LOSS: 40.96925791908738\n",
      "EPOCH: 29906 LOSS: 40.96925688339442\n",
      "EPOCH: 29907 LOSS: 40.96925584775278\n",
      "EPOCH: 29908 LOSS: 40.9692548121624\n",
      "EPOCH: 29909 LOSS: 40.9692537766233\n",
      "EPOCH: 29910 LOSS: 40.969252741135485\n",
      "EPOCH: 29911 LOSS: 40.969251705698916\n",
      "EPOCH: 29912 LOSS: 40.96925067031363\n",
      "EPOCH: 29913 LOSS: 40.969249634979604\n",
      "EPOCH: 29914 LOSS: 40.96924859969682\n",
      "EPOCH: 29915 LOSS: 40.96924756446529\n",
      "EPOCH: 29916 LOSS: 40.96924652928501\n",
      "EPOCH: 29917 LOSS: 40.969245494155984\n",
      "EPOCH: 29918 LOSS: 40.96924445907817\n",
      "EPOCH: 29919 LOSS: 40.969243424051605\n",
      "EPOCH: 29920 LOSS: 40.96924238907626\n",
      "EPOCH: 29921 LOSS: 40.96924135415213\n",
      "EPOCH: 29922 LOSS: 40.969240319279216\n",
      "EPOCH: 29923 LOSS: 40.96923928445751\n",
      "EPOCH: 29924 LOSS: 40.969238249687024\n",
      "EPOCH: 29925 LOSS: 40.969237214967734\n",
      "EPOCH: 29926 LOSS: 40.96923618029964\n",
      "EPOCH: 29927 LOSS: 40.969235145682745\n",
      "EPOCH: 29928 LOSS: 40.96923411111702\n",
      "EPOCH: 29929 LOSS: 40.96923307660251\n",
      "EPOCH: 29930 LOSS: 40.96923204213914\n",
      "EPOCH: 29931 LOSS: 40.969231007726975\n",
      "EPOCH: 29932 LOSS: 40.96922997336598\n",
      "EPOCH: 29933 LOSS: 40.96922893905612\n",
      "EPOCH: 29934 LOSS: 40.969227904797435\n",
      "EPOCH: 29935 LOSS: 40.9692268705899\n",
      "EPOCH: 29936 LOSS: 40.96922583643352\n",
      "EPOCH: 29937 LOSS: 40.96922480232828\n",
      "EPOCH: 29938 LOSS: 40.969223768274176\n",
      "EPOCH: 29939 LOSS: 40.96922273427123\n",
      "EPOCH: 29940 LOSS: 40.96922170031939\n",
      "EPOCH: 29941 LOSS: 40.96922066641869\n",
      "EPOCH: 29942 LOSS: 40.96921963256909\n",
      "EPOCH: 29943 LOSS: 40.96921859877064\n",
      "EPOCH: 29944 LOSS: 40.969217565023285\n",
      "EPOCH: 29945 LOSS: 40.96921653132702\n",
      "EPOCH: 29946 LOSS: 40.96921549768188\n",
      "EPOCH: 29947 LOSS: 40.96921446408784\n",
      "EPOCH: 29948 LOSS: 40.96921343054488\n",
      "EPOCH: 29949 LOSS: 40.969212397053006\n",
      "EPOCH: 29950 LOSS: 40.96921136361223\n",
      "EPOCH: 29951 LOSS: 40.9692103302225\n",
      "EPOCH: 29952 LOSS: 40.96920929688387\n",
      "EPOCH: 29953 LOSS: 40.969208263596315\n",
      "EPOCH: 29954 LOSS: 40.9692072303598\n",
      "EPOCH: 29955 LOSS: 40.969206197174344\n",
      "EPOCH: 29956 LOSS: 40.96920516403997\n",
      "EPOCH: 29957 LOSS: 40.969204130956626\n",
      "EPOCH: 29958 LOSS: 40.96920309792434\n",
      "EPOCH: 29959 LOSS: 40.969202064943076\n",
      "EPOCH: 29960 LOSS: 40.969201032012855\n",
      "EPOCH: 29961 LOSS: 40.969199999133664\n",
      "EPOCH: 29962 LOSS: 40.9691989663055\n",
      "EPOCH: 29963 LOSS: 40.969197933528356\n",
      "EPOCH: 29964 LOSS: 40.96919690080222\n",
      "EPOCH: 29965 LOSS: 40.96919586812711\n",
      "EPOCH: 29966 LOSS: 40.969194835503004\n",
      "EPOCH: 29967 LOSS: 40.969193802929894\n",
      "EPOCH: 29968 LOSS: 40.96919277040779\n",
      "EPOCH: 29969 LOSS: 40.96919173793667\n",
      "EPOCH: 29970 LOSS: 40.96919070551654\n",
      "EPOCH: 29971 LOSS: 40.96918967314739\n",
      "EPOCH: 29972 LOSS: 40.96918864082923\n",
      "EPOCH: 29973 LOSS: 40.969187608562024\n",
      "EPOCH: 29974 LOSS: 40.969186576345805\n",
      "EPOCH: 29975 LOSS: 40.96918554418053\n",
      "EPOCH: 29976 LOSS: 40.96918451206623\n",
      "EPOCH: 29977 LOSS: 40.96918348000288\n",
      "EPOCH: 29978 LOSS: 40.96918244799049\n",
      "EPOCH: 29979 LOSS: 40.96918141602904\n",
      "EPOCH: 29980 LOSS: 40.96918038411852\n",
      "EPOCH: 29981 LOSS: 40.969179352258955\n",
      "EPOCH: 29982 LOSS: 40.9691783204503\n",
      "EPOCH: 29983 LOSS: 40.96917728869258\n",
      "EPOCH: 29984 LOSS: 40.96917625698578\n",
      "EPOCH: 29985 LOSS: 40.969175225329906\n",
      "EPOCH: 29986 LOSS: 40.96917419372493\n",
      "EPOCH: 29987 LOSS: 40.96917316217086\n",
      "EPOCH: 29988 LOSS: 40.9691721306677\n",
      "EPOCH: 29989 LOSS: 40.96917109921543\n",
      "EPOCH: 29990 LOSS: 40.96917006781407\n",
      "EPOCH: 29991 LOSS: 40.96916903646358\n",
      "EPOCH: 29992 LOSS: 40.96916800516398\n",
      "EPOCH: 29993 LOSS: 40.96916697391526\n",
      "EPOCH: 29994 LOSS: 40.96916594271742\n",
      "EPOCH: 29995 LOSS: 40.96916491157044\n",
      "EPOCH: 29996 LOSS: 40.969163880474326\n",
      "EPOCH: 29997 LOSS: 40.96916284942907\n",
      "EPOCH: 29998 LOSS: 40.969161818434685\n",
      "EPOCH: 29999 LOSS: 40.96916078749113\n"
     ]
    }
   ],
   "source": [
    "\n",
    "settings = {}\n",
    "settings['n'] = 5                   # dimension of word embeddings\n",
    "settings['window_size'] = 2         # context window +/- center word\n",
    "settings['min_count'] = 0           # minimum word count\n",
    "settings['epochs'] = 30000           # number of training epochs\n",
    "settings['neg_samp'] = 10           # number of negative words to use during training\n",
    "settings['learning_rate'] = 0.01    # learning rate\n",
    "np.random.seed(0)                   # set the seed for reproducibility\n",
    "\n",
    "corpus = [['the','quick','brown','fox','jumped','over','the','lazy','dog']]\n",
    "\n",
    "# INITIALIZE W2V MODEL\n",
    "w2v = word2vec()\n",
    "\n",
    "# generate training data\n",
    "training_data = w2v.generate_training_data(settings, corpus)\n",
    "\n",
    "# train word2vec model\n",
    "w2v.train(training_data)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "WORD EMBEDDINGS: [[-2.23674708  1.03244829  0.82157013 -0.64676677 -2.22089404]\n",
      " [ 1.56739884  1.02944415 -0.20785105  3.55926319 -0.97603172]\n",
      " [ 0.0606542  -0.40922824  1.26143234 -3.78443936  0.58368752]\n",
      " [-0.34960732 -3.00731856  1.11198674  0.42891148  0.69661937]\n",
      " [ 0.8663663  -2.10375673 -2.65276693  0.95982568 -1.21829331]\n",
      " [ 0.07597795  0.90009406  2.74946442  2.05932677 -1.01954995]\n",
      " [-2.66610952 -1.54780811  0.29743046  0.43074061  2.38359804]\n",
      " [ 1.0461709   0.47387405 -0.1179152  -0.62239887  0.44490241]]\n"
     ]
    }
   ],
   "source": [
    "\n",
    "print('WORD EMBEDDINGS:', w2v.w1)"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": ".venv",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.2"
  },
  "orig_nbformat": 4
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
